@@ -24,8 +24,8 @@
  *
  */
 
-#ifndef _ARCHDEP_H
-#define _ARCHDEP_H
+#ifndef VICE_ARCHDEP_H
+#define VICE_ARCHDEP_H
 
 #include "archapi.h"
 
@@ -103,8 +103,10 @@
 /* Ethernet default device */
 #define ARCHDEP_ETHERNET_DEFAULT_DEVICE "eth0"
 
+/* Default sound fragment size */
+#define ARCHDEP_SOUND_FRAGMENT_SIZE 1
+
 /* No key symcode.  */
 #define ARCHDEP_KEYBOARD_SYM_NONE -1
 
 #endif
-
