@@ -24,15 +24,13 @@
  *
  */
 
-#ifndef _JOY_H
-#define _JOY_H
+#ifndef VICE_JOY_H
+#define VICE_JOY_H
 
-#define JOYDEV_NONE     0
-#define JOYDEV_NUMPAD   1
-#define JOYDEV_KEYSET1  2
-#define JOYDEV_KEYSET2  3
-
-extern int joystick_port_map[2];
+#define JOYDEV_NONE    0
+#define JOYDEV_NUMPAD  1
+#define JOYDEV_KEYSET1 2
+#define JOYDEV_KEYSET2 3
 
 extern int joy_arch_init(void);
 extern int joystick_arch_init_resources(void);
