@@ -24,17 +24,15 @@
  *
  */
 
-#ifndef _JOYLL_H
-#define _JOYLL_H
+#ifndef VICE_JOYLL_H
+#define VICE_JOYLL_H
 
-#define JOYDEV_NONE     0
-#define JOYDEV_NUMPAD   1
-#define JOYDEV_JOY0     2
-#define JOYDEV_JOY1     3
-#define JOYDEV_JOY2     4
-#define JOYDEV_JOY3     5
-
-extern int joystick_port_map[2];
+#define JOYDEV_NONE   0
+#define JOYDEV_NUMPAD 1
+#define JOYDEV_JOY0   2
+#define JOYDEV_JOY1   3
+#define JOYDEV_JOY2   4
+#define JOYDEV_JOY3   5
 
 extern int joy_arch_init(void);
 extern int joystick_arch_init_resources(void);
