@@ -24,8 +24,8 @@
  *
  */
 
-#ifndef _UIACIA_H
-#define _UIACIA_H
+#ifndef VICE_UIACIA_H
+#define VICE_UIACIA_H
 
 extern void ui_acia_settings_dialog(void);
 extern void ui_acia64128_settings_dialog(void);
