@@ -24,8 +24,8 @@
  *
  */
 
-#ifndef _UI_DRIVEC64VIC20_H
-#define _UI_DRIVEC64VIC20_H
+#ifndef VICE_UI_DRIVEC64VIC20_H
+#define VICE_UI_DRIVEC64VIC20_H
 
 extern void uidrivec64vic20_settings_dialog(void);
 
