@@ -24,8 +24,8 @@
  *
  */
 
-#ifndef _UIPETSETTINGS_H
-#define _UIPETSETTINGS_H
+#ifndef VICE_UIPETSETTINGS_H
+#define VICE_UIPETSETTINGS_H
 
 extern void ui_pet_settings_dialog(void);
 extern void ui_pet_model_dialog(void);
