@@ -47,6 +47,8 @@
 extern "C" {
 #include "archdep.h"
 #include "constants.h"
+#include "easyflash.h"
+#include "mouse.h"
 #include "resources.h"
 #include "statusbar.h"
 #include "types.h"
@@ -60,7 +62,7 @@ extern "C" {
 
 extern ViceWindow *windowlist[];
 
-ui_menu_toggle  c128_ui_menu_toggles[]={
+ui_menu_toggle  c128_ui_menu_toggles[] = {
     { "VICIIDoubleSize", MENU_TOGGLE_DOUBLESIZE },
     { "VICIIDoubleScan", MENU_TOGGLE_DOUBLESCAN },
     { "VICIIVideoCache", MENU_TOGGLE_VIDEOCACHE },
@@ -75,88 +77,109 @@ ui_menu_toggle  c128_ui_menu_toggles[]={
     { "VDC64KB", MENU_TOGGLE_VDC64KB },
     { "PALEmulation", MENU_TOGGLE_FASTPAL },
     { "VICIIScale2x", MENU_TOGGLE_SCALE2X },
+    { "C128FullBanks", MENU_TOGGLE_C128FULLBANKS },
+    { "SFXSoundExpander", MENU_TOGGLE_SFX_SE },
+    { "SFXSoundSampler", MENU_TOGGLE_SFX_SS },
+    { "EasyFlashJumper", MENU_TOGGLE_EASYFLASH_JUMPER },
+    { "EasyFlashWriteCRT", MENU_TOGGLE_EASYFLASH_AUTOSAVE },
     { NULL, 0 }
 };
 
 ui_res_possible_values c128ReuSize[] = {
-        {128, MENU_REU_SIZE_128},
-        {256, MENU_REU_SIZE_256},
-        {512, MENU_REU_SIZE_512},
-        {1024, MENU_REU_SIZE_1024},
-        {2048, MENU_REU_SIZE_2048},
-        {4096, MENU_REU_SIZE_4096},
-        {8192, MENU_REU_SIZE_8192},
-        {16384, MENU_REU_SIZE_16384},
-        {-1, 0}
+    { 128, MENU_REU_SIZE_128 },
+    { 256, MENU_REU_SIZE_256 },
+    { 512, MENU_REU_SIZE_512 },
+    { 1024, MENU_REU_SIZE_1024 },
+    { 2048, MENU_REU_SIZE_2048 },
+    { 4096, MENU_REU_SIZE_4096 },
+    { 8192, MENU_REU_SIZE_8192 },
+    { 16384, MENU_REU_SIZE_16384 },
+    { -1, 0 }
 };
 
 ui_res_possible_values c128GeoRAMSize[] = {
-        {64, MENU_GEORAM_SIZE_64},
-        {128, MENU_GEORAM_SIZE_128},
-        {256, MENU_GEORAM_SIZE_256},
-        {512, MENU_GEORAM_SIZE_512},
-        {1024, MENU_GEORAM_SIZE_1024},
-        {2048, MENU_GEORAM_SIZE_2048},
-        {4096, MENU_GEORAM_SIZE_4096},
-        {-1, 0}
+    { 64, MENU_GEORAM_SIZE_64 },
+    { 128, MENU_GEORAM_SIZE_128 },
+    { 256, MENU_GEORAM_SIZE_256 },
+    { 512, MENU_GEORAM_SIZE_512 },
+    { 1024, MENU_GEORAM_SIZE_1024 },
+    { 2048, MENU_GEORAM_SIZE_2048 },
+    { 4096, MENU_GEORAM_SIZE_4096 },
+    { -1, 0 }
 };
 
 ui_res_possible_values c128RamCartSize[] = {
-        {64, MENU_RAMCART_SIZE_64},
-        {128, MENU_RAMCART_SIZE_128},
-        {-1, 0}
+    { 64, MENU_RAMCART_SIZE_64 },
+    { 128, MENU_RAMCART_SIZE_128 },
+    { -1, 0 }
 };
 
 ui_res_possible_values c128DigimaxBase[] = {
-        {0xdd00, MENU_DIGIMAX_BASE_DD00},
-        {0xde00, MENU_DIGIMAX_BASE_DE00},
-        {0xde20, MENU_DIGIMAX_BASE_DE20},
-        {0xde40, MENU_DIGIMAX_BASE_DE40},
-        {0xde60, MENU_DIGIMAX_BASE_DE60},
-        {0xde80, MENU_DIGIMAX_BASE_DE80},
-        {0xdea0, MENU_DIGIMAX_BASE_DEA0},
-        {0xdec0, MENU_DIGIMAX_BASE_DEC0},
-        {0xdee0, MENU_DIGIMAX_BASE_DEE0},
-        {0xdf00, MENU_DIGIMAX_BASE_DF00},
-        {0xdf20, MENU_DIGIMAX_BASE_DF20},
-        {0xdf40, MENU_DIGIMAX_BASE_DF40},
-        {0xdf60, MENU_DIGIMAX_BASE_DF60},
-        {0xdf80, MENU_DIGIMAX_BASE_DF80},
-        {0xdfa0, MENU_DIGIMAX_BASE_DFA0},
-        {0xdfc0, MENU_DIGIMAX_BASE_DFC0},
-        {0xdfe0, MENU_DIGIMAX_BASE_DFE0},
-        {-1, 0}
+    { 0xdd00, MENU_DIGIMAX_BASE_DD00 },
+    { 0xde00, MENU_DIGIMAX_BASE_DE00 },
+    { 0xde20, MENU_DIGIMAX_BASE_DE20 },
+    { 0xde40, MENU_DIGIMAX_BASE_DE40 },
+    { 0xde60, MENU_DIGIMAX_BASE_DE60 },
+    { 0xde80, MENU_DIGIMAX_BASE_DE80 },
+    { 0xdea0, MENU_DIGIMAX_BASE_DEA0 },
+    { 0xdec0, MENU_DIGIMAX_BASE_DEC0 },
+    { 0xdee0, MENU_DIGIMAX_BASE_DEE0 },
+    { 0xdf00, MENU_DIGIMAX_BASE_DF00 },
+    { 0xdf20, MENU_DIGIMAX_BASE_DF20 },
+    { 0xdf40, MENU_DIGIMAX_BASE_DF40 },
+    { 0xdf60, MENU_DIGIMAX_BASE_DF60 },
+    { 0xdf80, MENU_DIGIMAX_BASE_DF80 },
+    { 0xdfa0, MENU_DIGIMAX_BASE_DFA0 },
+    { 0xdfc0, MENU_DIGIMAX_BASE_DFC0 },
+    { 0xdfe0, MENU_DIGIMAX_BASE_DFE0 },
+    { -1, 0 }
+};
+
+ui_res_possible_values c128SFXSoundExpanderChip[] = {
+    { 3526, MENU_SFX_SE_3526 },
+    { 3812, MENU_SFX_SE_3812 },
+    { -1, 0 }
 };
 
 ui_res_possible_values c128viciiBorders[] = {
-        {0, MENU_VICII_BORDERS_NORMAL},
-        {1, MENU_VICII_BORDERS_FULL},
-        {2, MENU_VICII_BORDERS_DEBUG},
-        {-1, 0}
+    { 0, MENU_VICII_BORDERS_NORMAL },
+    { 1, MENU_VICII_BORDERS_FULL} ,
+    { 2, MENU_VICII_BORDERS_DEBUG },
+    { -1, 0 }
+};
+
+ui_res_possible_values c128VDCrev[] = {
+    { 0, MENU_VDC_REV_0 },
+    { 1, MENU_VDC_REV_1 },
+    { 2, MENU_VDC_REV_2 },
+    { -1, 0 }
 };
 
 ui_res_possible_values c128mousetypes[] = {
-        {0, MENU_MOUSE_TYPE_1351},
-        {1, MENU_MOUSE_TYPE_NEOS},
-        {2, MENU_MOUSE_TYPE_AMIGA},
-        {-1, 0}
+    { MOUSE_TYPE_1351, MENU_MOUSE_TYPE_1351 },
+    { MOUSE_TYPE_NEOS, MENU_MOUSE_TYPE_NEOS },
+    { MOUSE_TYPE_AMIGA, MENU_MOUSE_TYPE_AMIGA },
+    { MOUSE_TYPE_PADDLE, MENU_MOUSE_TYPE_PADDLE },
+    { -1, 0 }
 };
 
 ui_res_possible_values c128mouseports[] = {
-        {1, MENU_MOUSE_PORT_JOY1},
-        {2, MENU_MOUSE_PORT_JOY2},
-        {-1, 0}
+    { 1, MENU_MOUSE_PORT_JOY1 },
+    { 2, MENU_MOUSE_PORT_JOY2 },
+    { -1, 0 }
 };
 
 ui_res_value_list c128_ui_res_values[] = {
-    {"REUsize", c128ReuSize},
-    {"GeoRAMsize", c128GeoRAMSize},
-    {"RAMCARTsize", c128RamCartSize},
-    {"DIGIMAXbase", c128DigimaxBase},
-    {"VICIIBorderMode", c128viciiBorders},
-    {"Mousetype", c128mousetypes},
-    {"Mouseport", c128mouseports},
-    {NULL,NULL}
+    { "REUsize", c128ReuSize },
+    { "GeoRAMsize", c128GeoRAMSize },
+    { "RAMCARTsize", c128RamCartSize },
+    { "DIGIMAXbase", c128DigimaxBase },
+    { "SFXSoundExpanderChip", c128SFXSoundExpanderChip },
+    { "VICIIBorderMode", c128viciiBorders },
+    { "VDCRevision", c128VDCrev },
+    { "Mousetype", c128mousetypes },
+    { "Mouseport", c128mouseports },
+    { NULL, NULL }
 };
 
 
@@ -175,8 +198,13 @@ void c128_ui_specific(void *msg, void *window)
         case MENU_RAMCART_FILE:
             ui_select_file(windowlist[0]->savepanel,RAMCART_FILE,(void*)0);
             break;
-
-    	default: ;
+        case MENU_EASYFLASH_SAVE_NOW:
+            if (easyflash_save_crt() < 0) {
+                ui_error("Error saving EasyFlash .crt file");
+            }
+            break;
+        default:
+            break;
     }
 }
 
