@@ -24,8 +24,8 @@
  *
  */
 
-#ifndef _VIDEOARCH_H
-#define _VIDEOARCH_H
+#ifndef VICE_VIDEOARCH_H
+#define VICE_VIDEOARCH_H
 
 #ifdef EXACT_TYPE_NEEDED
 #include "vicewindow.h"
@@ -72,4 +72,3 @@ typedef struct _color_def color_def_t;
 /* ------------------------------------------------------------------------- */
 
 #endif
-
