@@ -35,6 +35,7 @@
 #include "lib.h"
 #include "machine.h"
 #include "menudefs.h"
+#include "mouse.h"
 #include "resources.h"
 #include "tui.h"
 #include "tuifs.h"
@@ -45,19 +46,21 @@
 #include "uic64cart.h"
 #include "uidigimax.h"
 #include "uidqbb.h"
+#include "uieasyflash.h"
 #include "uigeoram.h"
 #include "uiisepic.h"
+#include "uilightpen.h"
 #include "uimmc64.h"
 #include "uiplus256k.h"
 #include "uiplus60k.h"
 #include "uiramcart.h"
 #include "uireu.h"
 #include "uisid.h"
+#include "uisoundexpander.h"
 #ifdef HAVE_TFE
 #include "uitfe.h"
 #endif
 
-
 TUI_MENU_DEFINE_TOGGLE(VICIIVideoCache)
 TUI_MENU_DEFINE_TOGGLE(VICIICheckSsColl)
 TUI_MENU_DEFINE_TOGGLE(VICIICheckSbColl)
@@ -70,25 +73,26 @@ static TUI_MENU_CALLBACK(toggle_MachineVideoStandard_callback)
     resources_get_int("MachineVideoStandard", &value);
 
     if (been_activated) {
-            if (value == MACHINE_SYNC_PAL)
-                value = MACHINE_SYNC_NTSC;
-            else if (value == MACHINE_SYNC_NTSC)
-                value = MACHINE_SYNC_NTSCOLD;
-        else
-                value = MACHINE_SYNC_PAL;
+        if (value == MACHINE_SYNC_PAL) {
+            value = MACHINE_SYNC_NTSC;
+        } else if (value == MACHINE_SYNC_NTSC) {
+            value = MACHINE_SYNC_NTSCOLD;
+        } else {
+            value = MACHINE_SYNC_PAL;
+        }
 
         resources_set_int("MachineVideoStandard", value);
     }
 
     switch (value) {
-      case MACHINE_SYNC_PAL:
-        return "PAL-G";
-      case MACHINE_SYNC_NTSC:
-        return "NTSC-M";
-      case MACHINE_SYNC_NTSCOLD:
-        return "old NTSC-M";
-      default:
-        return "(Custom)";
+        case MACHINE_SYNC_PAL:
+            return "PAL-G";
+        case MACHINE_SYNC_NTSC:
+            return "NTSC-M";
+        case MACHINE_SYNC_NTSCOLD:
+            return "old NTSC-M";
+        default:
+            return "(Custom)";
     }
 }
 
@@ -134,14 +138,16 @@ static TUI_MENU_CALLBACK(toggle_MouseType_callback)
     }
 
     switch (value) {
-      case 0:
-        return "1351";
-      case 1:
-        return "NEOS";
-      case 2:
-        return "AMIGA";
-      default:
-        return "unknown";
+        case MOUSE_TYPE_1351:
+            return "1351";
+        case MOUSE_TYPE_NEOS:
+            return "NEOS";
+        case MOUSE_TYPE_AMIGA:
+            return "AMIGA";
+        case MOUSE_TYPE_PADDLE:
+            return "PADDLE";
+        default:
+            return "unknown";
     }
 }
 
@@ -154,16 +160,16 @@ static TUI_MENU_CALLBACK(toggle_MousePort_callback)
 
     if (been_activated) {
         value = (value + 1) % 2;
-        resources_set_int("Mouseport", value+1);
+        resources_set_int("Mouseport", value + 1);
     }
 
     switch (value) {
-      case 0:
-        return "Joy1";
-      case 1:
-        return "Joy2";
-      default:
-        return "unknown";
+        case 0:
+            return "Joy1";
+        case 1:
+            return "Joy2";
+        default:
+            return "unknown";
     }
 }
 
@@ -204,7 +210,8 @@ static struct {
     { "frodo", "Frodo", "_Frodo",
       "Palette from the Frodo emulator by Christian Bauer" },
     { "godot", "GoDot", "_GoDot",
-      "Palette as suggested by the authors of the GoDot C64 graphics package" },    { "pc64", "PC64", "_PC64",
+      "Palette as suggested by the authors of the GoDot C64 graphics package"},
+    { "pc64", "PC64", "_PC64",
       "Palette from the PC64 emulator by Wolfgang Lorenz" },
     { NULL }
 };
@@ -212,8 +219,9 @@ static struct {
 static TUI_MENU_CALLBACK(palette_callback)
 {
     if (been_activated) {
-        if (resources_set_string("VICIIPaletteFile", (const char *)param) < 0)
+        if (resources_set_string("VICIIPaletteFile", (const char *)param) < 0) {
            tui_error("Invalid palette file");
+        }
         ui_update_menus();
     }
     return NULL;
@@ -224,12 +232,12 @@ static TUI_MENU_CALLBACK(custom_palette_callback)
     if (been_activated) {
         char *name;
 
-        name = tui_file_selector("Load custom palette",
-                                 NULL, "*.vpl", NULL, 0, NULL, 0, NULL, NULL);
+        name = tui_file_selector("Load custom palette", NULL, "*.vpl", NULL, NULL, NULL, NULL);
 
         if (name != NULL) {
-            if (resources_set_string("VICIIPaletteFile", name) < 0)
+            if (resources_set_string("VICIIPaletteFile", name) < 0) {
                 tui_error("Invalid palette file");
+            }
             ui_update_menus();
             lib_free(name);
         }
@@ -244,8 +252,9 @@ static TUI_MENU_CALLBACK(palette_menu_callback)
 
     resources_get_string("VICIIPaletteFile", &s);
     for (i = 0; palette_items[i].name != NULL; i++) {
-        if (strcmp(s, palette_items[i].name) == 0)
+        if (strcmp(s, palette_items[i].name) == 0) {
            return palette_items[i].brief_description;
+        }
     }
     return "Custom";
 }
@@ -257,16 +266,15 @@ static void add_palette_submenu(tui_menu_t parent)
     int i;
     tui_menu_t palette_menu = tui_menu_create("Color Set", 1);
 
-    for (i = 0; palette_items[i].name != NULL; i++)
-        tui_menu_add_item(palette_menu,
-                          palette_items[i].menu_item,
+    for (i = 0; palette_items[i].name != NULL; i++) {
+        tui_menu_add_item(palette_menu, palette_items[i].menu_item,
                           palette_items[i].long_description,
                           palette_callback,
-                          (void *) palette_items[i].name, 0,
+                          (void *)palette_items[i].name, 0,
                           TUI_MENU_BEH_RESUME);
+    }
 
-    tui_menu_add_item(palette_menu,
-                      "C_ustom",
+    tui_menu_add_item(palette_menu, "C_ustom",
                       "Load a custom palette",
                       custom_palette_callback,
                       NULL, 0,
@@ -275,14 +283,14 @@ static void add_palette_submenu(tui_menu_t parent)
     tui_menu_add_item(parent, "Use external Palette",
                       "Use the palette file below",
                       toggle_VICIIExternalPalette_callback,
-                      NULL, 3, TUI_MENU_BEH_RESUME);
+                      NULL, 3,
+                      TUI_MENU_BEH_RESUME);
 
     tui_menu_add_submenu(parent, "Color _Palette:",
                          "Choose color palette",
                          palette_menu,
                          palette_menu_callback,
-                         NULL,
-                         10);
+                         NULL, 10);
 }
 
 /* ------------------------------------------------------------------------- */
@@ -292,12 +300,12 @@ static TUI_MENU_CALLBACK(load_rom_file_callback)
     if (been_activated) {
         char *name;
 
-        name = tui_file_selector("Load ROM file",
-                                 NULL, "*", NULL, 0, NULL, 0, NULL, NULL);
+        name = tui_file_selector("Load ROM file", NULL, "*", NULL, NULL, NULL, NULL);
 
         if (name != NULL) {
-            if (resources_set_string(param, name) < 0)
+            if (resources_set_string(param, name) < 0) {
                 ui_error("Could not load ROM file '%s'", name);
+            }
             lib_free(name);
         }
     }
@@ -347,6 +355,8 @@ static tui_menu_item_def_t rom_menu_items[] = {
 
 /* ------------------------------------------------------------------------- */
 
+TUI_MENU_DEFINE_TOGGLE(SFXSoundSampler)
+
 int c64ui_init(void)
 {
     tui_menu_t ui_ioextensions_submenu;
@@ -359,7 +369,8 @@ int c64ui_init(void)
     tui_menu_add(ui_ioextensions_submenu, ioextenstions_menu_items);
     tui_menu_add_submenu(ui_special_submenu, "_I/O extensions...",
                          "Configure I/O extensions",
-                         ui_ioextensions_submenu, NULL, 0,
+                         ui_ioextensions_submenu,
+                         NULL, 0,
                          TUI_MENU_BEH_CONTINUE);
 
     uic64cart_init(NULL);
@@ -371,6 +382,8 @@ int c64ui_init(void)
     tui_menu_add(ui_sound_submenu, sid_ui_menu_items);
     tui_menu_add(ui_rom_submenu, rom_menu_items);
 
+    uilightpen_init(ui_ioextensions_submenu);
+
     uireu_init(ui_ioextensions_submenu);
 
     uigeoram_init(ui_ioextensions_submenu);
@@ -395,6 +408,16 @@ int c64ui_init(void)
     uitfe_init(ui_ioextensions_submenu);
 #endif
 
+    uieasyflash_init(ui_ioextensions_submenu);
+
+    uisoundexpander_init(ui_ioextensions_submenu);
+
+    tui_menu_add_item(ui_ioextensions_submenu, "Enable SFX Sound Sampler",
+                      "Enable SFX Sound Sampler",
+                      toggle_SFXSoundSampler_callback,
+                      NULL, 3,
+                      TUI_MENU_BEH_CONTINUE);
+
     return 0;
 }
 
