@@ -40,7 +40,6 @@
 #include "video.h"
 #include "videoarch.h"
 
-
 static int old_input_mode, old_output_mode;
 static FILE *mon_output, *mon_input;
 
@@ -102,7 +101,7 @@ int console_out(console_t *log, const char *format, ...)
 
 char *console_in(console_t *log, const char *prompt)
 {
-    char *p = (char *)lib_malloc(1024);
+    char *p = lib_malloc(1024);
 
     console_out(log, "%s", prompt);
 
@@ -113,10 +112,9 @@ char *console_in(console_t *log, const char *prompt)
     {
         int len;
 
-        for (len = strlen(p);
-             len > 0 && (p[len - 1] == '\r' || p[len - 1] == '\n');
-             len--)
+        for (len = strlen(p); len > 0 && (p[len - 1] == '\r' || p[len - 1] == '\n'); len--) {
             p[len - 1] = '\0';
+        }
     }
 
     return p;
@@ -126,4 +124,3 @@ int console_close_all(void)
 {
     return 0;
 }
-
