@@ -25,8 +25,8 @@
  *
  */
 
-#ifndef _MENUDEFS_H
-#define _MENUDEFS_H
+#ifndef VICE_MENUDEFS_H
+#define VICE_MENUDEFS_H
 
 #include "tuimenu.h"
 
@@ -43,9 +43,6 @@ extern tui_menu_t ui_reset_submenu;
 extern tui_menu_t ui_quit_submenu;
 extern tui_menu_t ui_info_submenu;
 
-extern void ui_create_main_menu(int has_tape, int has_true1541,
-                                int has_serial_traps, int num_joysticks,
-                                int has_datasette);
+extern void ui_create_main_menu(int has_tape, int has_true1541, int has_serial_traps, int num_joysticks, int has_datasette);
 
 #endif /* _MENUDEFS_H */
-
