@@ -23,8 +23,8 @@
  *
  */
 
-#ifndef _MOUSEDRV_H
-#define _MOUSEDRV_H
+#ifndef VICE_MOUSEDRV_H
+#define VICE_MOUSEDRV_H
 
 #include "types.h"
 
@@ -42,4 +42,3 @@ extern int _mouse_x, _mouse_y;
 extern int _mouse_coords_dirty;
 
 #endif
-
