@@ -61,8 +61,9 @@ static struct {
 static TUI_MENU_CALLBACK(palette_callback)
 {
     if (been_activated) {
-        if (resources_set_string("CrtcPaletteFile", (const char *)param) < 0)
+        if (resources_set_string("CrtcPaletteFile", (const char *)param) < 0) {
             tui_error("Invalid palette file");
+        }
         ui_update_menus();
     }
 
@@ -74,12 +75,12 @@ static TUI_MENU_CALLBACK(custom_palette_callback)
     if (been_activated) {
         char *name;
 
-        name = tui_file_selector("Load custom palette",
-                                 NULL, "*.vpl", NULL, 0, NULL, 0, NULL, NULL);
+        name = tui_file_selector("Load custom palette", NULL, "*.vpl", NULL, NULL, NULL, NULL);
 
         if (name != NULL) {
-            if (resources_set_string("CrtcPaletteFile", name) < 0)
+            if (resources_set_string("CrtcPaletteFile", name) < 0) {
                 tui_error("Invalid palette file");
+            }
             ui_update_menus();
             lib_free(name);
         }
@@ -94,8 +95,9 @@ static TUI_MENU_CALLBACK(palette_menu_callback)
 
     resources_get_string("CrtcPaletteFile", &s);
     for (i = 0; palette_items[i].name != NULL; i++) {
-        if (strcmp(s, palette_items[i].name) == 0)
+        if (strcmp(s, palette_items[i].name) == 0) {
            return palette_items[i].brief_description;
+        }
     }
 
     return "Custom";
@@ -106,27 +108,25 @@ static void add_palette_submenu(tui_menu_t parent)
     int i;
     tui_menu_t palette_menu = tui_menu_create("Color Set", 1);
 
-    for (i = 0; palette_items[i].name != NULL; i++)
-        tui_menu_add_item(palette_menu,
-                          palette_items[i].menu_item,
+    for (i = 0; palette_items[i].name != NULL; i++) {
+        tui_menu_add_item(palette_menu, palette_items[i].menu_item,
                           palette_items[i].long_description,
                           palette_callback,
-                          (void *) palette_items[i].name, 0,
+                          (void *)palette_items[i].name, 0,
                           TUI_MENU_BEH_RESUME);
+    }
 
-    tui_menu_add_item(palette_menu,
-                      "C_ustom",
+    tui_menu_add_item(palette_menu, "C_ustom",
                       "Load a custom palette",
                       custom_palette_callback,
                       NULL, 0,
                       TUI_MENU_BEH_RESUME);
 
     tui_menu_add_submenu(parent, "Color _Palette:",
-			 "Choose color palette",
-			 palette_menu,
-			 palette_menu_callback,
-			 NULL,
-			 15);
+                         "Choose color palette",
+                         palette_menu,
+                         palette_menu_callback,
+                         NULL, 15);
 }
 
 /* ------------------------------------------------------------------------- */
@@ -224,14 +224,14 @@ static TUI_MENU_CALLBACK(video_size_callback)
     resources_get_int("VideoSize", &value);
 
     switch (value) {
-      case 0:
-        return "Autodetect";
-      case 40:
-        return "40 columns";
-      case 80:
-        return "80 columns";
-      default:
-        return "Unknown";
+        case 0:
+            return "Autodetect";
+        case 40:
+            return "40 columns";
+        case 80:
+            return "80 columns";
+        default:
+            return "Unknown";
     }
 }
 
@@ -300,12 +300,12 @@ static TUI_MENU_CALLBACK(iosize_callback)
     resources_get_int("IOSize", &value);
 
     switch (value) {
-      case 0x800:
-        return "2 KBytes";
-      case 0x100:
-        return "256 Bytes";
-      default:
-        return "Unknown";
+        case 0x800:
+            return "2 KBytes";
+        case 0x100:
+            return "256 Bytes";
+        default:
+            return "Unknown";
     }
 }
 
@@ -341,12 +341,12 @@ static TUI_MENU_CALLBACK(set_keyboard_callback)
     }
 
     switch (value) {
-      case 0:
-        return "Business (UK)";
-      case 2:
-        return "Graphics";
-      default:
-        return "Unknown";
+        case 0:
+            return "Business (UK)";
+        case 2:
+            return "Graphics";
+        default:
+            return "Unknown";
     }
 }
 
@@ -407,12 +407,12 @@ static TUI_MENU_CALLBACK(load_rom_file_callback)
     if (been_activated) {
         char *name;
 
-        name = tui_file_selector("Load ROM file",
-                                 NULL, "*", NULL, 0, NULL, 0, NULL, NULL);
+        name = tui_file_selector("Load ROM file", NULL, "*", NULL, NULL, NULL, NULL);
 
         if (name != NULL) {
-            if (resources_set_string(param, name) < 0)
+            if (resources_set_string(param, name) < 0) {
                 ui_error("Could not load ROM file '%s'", name);
+            }
             lib_free(name);
         }
     }
@@ -484,7 +484,8 @@ int petui_init(void)
     tui_menu_add(ui_ioextensions_submenu, ioextenstions_menu_items);
     tui_menu_add_submenu(ui_special_submenu, "_I/O extensions",
                          "Configure I/O extensions",
-                         ui_ioextensions_submenu, NULL, 0,
+                         ui_ioextensions_submenu,
+                         NULL, 0,
                          TUI_MENU_BEH_CONTINUE);
 
     tui_menu_add(ui_rom_submenu, rom_menu_items);
