@@ -54,8 +54,9 @@ static struct {
 static TUI_MENU_CALLBACK(palette_callback)
 {
     if (been_activated) {
-        if (resources_set_string("TEDPaletteFile", (const char *)param) < 0)
+        if (resources_set_string("TEDPaletteFile", (const char *)param) < 0) {
             tui_error("Invalid palette file");
+        }
         ui_update_menus();
     }
 
@@ -67,12 +68,12 @@ static TUI_MENU_CALLBACK(custom_palette_callback)
     if (been_activated) {
         char *name;
 
-        name = tui_file_selector("Load custom palette",
-                                 NULL, "*.vpl", NULL, 0, NULL, 0, NULL, NULL);
+        name = tui_file_selector("Load custom palette", NULL, "*.vpl", NULL, NULL, NULL, NULL);
 
         if (name != NULL) {
-            if (resources_set_string("TEDPaletteFile", name) < 0)
+            if (resources_set_string("TEDPaletteFile", name) < 0) {
                 tui_error("Invalid palette file");
+            }
             ui_update_menus();
             lib_free(name);
         }
@@ -87,8 +88,9 @@ static TUI_MENU_CALLBACK(palette_menu_callback)
 
     resources_get_string("TEDPaletteFile", &s);
     for (i = 0; palette_items[i].name != NULL; i++) {
-        if (strcmp(s, palette_items[i].name) == 0)
+        if (strcmp(s, palette_items[i].name) == 0) {
            return palette_items[i].brief_description;
+        }
     }
 
     return "Custom";
@@ -99,16 +101,15 @@ static void add_palette_submenu(tui_menu_t parent)
     int i;
     tui_menu_t palette_menu = tui_menu_create("Color Set", 1);
 
-    for (i = 0; palette_items[i].name != NULL; i++)
-        tui_menu_add_item(palette_menu,
-                          palette_items[i].menu_item,
+    for (i = 0; palette_items[i].name != NULL; i++) {
+        tui_menu_add_item(palette_menu, palette_items[i].menu_item,
                           palette_items[i].long_description,
                           palette_callback,
-                          (void *) palette_items[i].name, 0,
+                          (void *)palette_items[i].name, 0,
                           TUI_MENU_BEH_RESUME);
+    }
 
-    tui_menu_add_item(palette_menu,
-                      "C_ustom",
+    tui_menu_add_item(palette_menu, "C_ustom",
                       "Load a custom palette",
                       custom_palette_callback,
                       NULL, 0,
@@ -118,8 +119,7 @@ static void add_palette_submenu(tui_menu_t parent)
 			 "Choose color palette",
 			 palette_menu,
 			 palette_menu_callback,
-			 NULL,
-			 15);
+			 NULL, 15);
 }
 
 /* ------------------------------------------------------------------------- */
@@ -141,12 +141,12 @@ static TUI_MENU_CALLBACK(load_rom_file_callback)
     if (been_activated) {
         char *name;
 
-        name = tui_file_selector("Load ROM file",
-                                 NULL, "*", NULL, 0, NULL, 0, NULL, NULL);
+        name = tui_file_selector("Load ROM file", NULL, "*", NULL, NULL, NULL, NULL);
 
         if (name != NULL) {
-            if (resources_set_string(param, name) < 0)
+            if (resources_set_string(param, name) < 0) {
                 ui_error("Could not load ROM file '%s'", name);
+            }
             lib_free(name);
         }
     }
@@ -203,7 +203,7 @@ int plus4ui_init(void)
     tui_menu_add_separator(ui_video_submenu);
     tui_menu_add(ui_sound_submenu, sid_ui_menu_items);
 
-    uisidcart_init(ui_sound_submenu, "$FD40", "$FE80", "PLUS4");
+    uisidcart_plus4_init(ui_sound_submenu, "$FD40", "$FE80", "PLUS4");
 
     add_palette_submenu(ui_video_submenu);
 
@@ -216,4 +216,3 @@ int plus4ui_init(void)
 void plus4ui_shutdown(void)
 {
 }
-
