@@ -54,13 +54,10 @@ static TUI_MENU_CALLBACK(attach_cartridge_callback)
 
         filter = (type == CARTRIDGE_CRT) ? "*.crt" : "*";
 
-        name = tui_file_selector("Attach cartridge image",
-                                 directory, filter, default_item, 0, NULL, 0,
-                                 NULL, NULL);
-        if (name != NULL
-            && (s == NULL || strcasecmp(name, s) != 0)
-            && cartridge_attach_image(type, name) < 0)
+        name = tui_file_selector("Attach cartridge image", directory, filter, default_item, NULL, NULL, NULL);
+        if (name != NULL && (s == NULL || strcasecmp(name, s) != 0) && cartridge_attach_image(type, name) < 0) {
             tui_error("Invalid cartridge image.");
+        }
         ui_update_menus();
         lib_free(name);
     }
@@ -70,8 +67,9 @@ static TUI_MENU_CALLBACK(attach_cartridge_callback)
 
 static TUI_MENU_CALLBACK(cartridge_set_default_callback)
 {
-    if (been_activated)
+    if (been_activated) {
         cartridge_set_default();
+    }
 
     return NULL;
 }
@@ -81,10 +79,11 @@ static TUI_MENU_CALLBACK(cartridge_callback)
 {
     const char *s = cartridge_get_file_name((WORD)0);
 
-    if (s == NULL || *s == '\0')
+    if (s == NULL || *s == '\0') {
         return "(none)";
-    else
+    } else {
         return s;
+    }
 }
 
 static tui_menu_item_def_t attach_cartridge_submenu_items[] = {
@@ -166,15 +165,17 @@ static TUI_MENU_CALLBACK(detach_cartridge_callback)
 {
     const char *s;
 
-    if (been_activated)
+    if (been_activated) {
         cartridge_detach_image();
+    }
 
     s = cartridge_get_file_name((WORD)0);
 
-    if (s == NULL || *s == '\0')
+    if (s == NULL || *s == '\0') {
         return "(none)";
-    else
+    } else {
         return s;
+    }
 }
 
 static tui_menu_item_def_t detach_cartridge_menu_items[] = {
@@ -212,4 +213,3 @@ void uic64cart_init(struct tui_menu *parent_submenu)
     tui_menu_add(ui_detach_submenu, detach_cartridge_menu_items);
     tui_menu_add(ui_reset_submenu, freeze_cartridge_menu_items);
 }
-
