@@ -33,11 +33,11 @@
 #include "tuimenu.h"
 #include "uiprinter.h"
 
-
 static TUI_MENU_CALLBACK(form_feed_callback)
 {
-    if (been_activated)
+    if (been_activated) {
         printer_formfeed((unsigned int)param);
+    }
 
     *become_default = 0;
 
@@ -119,17 +119,12 @@ static TUI_MENU_CALLBACK(printer_device_submenu_callback)
     resources_get_int((char *)param, &value);
 
     switch (value) {
-      case PRINTER_DEVICE_NONE:
-        sprintf(s, "None");
-        break;
-      case PRINTER_DEVICE_FS:
-        sprintf(s, "File system access");
-        break;
-#if 0
-      case PRINTER_DEVICE_REAL:
-        sprintf(s, "Real device access");
-        break;
-#endif
+        case PRINTER_DEVICE_NONE:
+            sprintf(s, "None");
+            break;
+        case PRINTER_DEVICE_FS:
+            sprintf(s, "File system access");
+            break;
     }
 
     return s;
@@ -142,10 +137,6 @@ static tui_menu_item_def_t printer4dev_submenu[] = {
       (void *)PRINTER_DEVICE_NONE, 19, TUI_MENU_BEH_CLOSE, NULL, NULL },
     { "_File system access", NULL, radio_Printer4_callback,
       (void *)PRINTER_DEVICE_FS, 19, TUI_MENU_BEH_CLOSE, NULL, NULL },
-#if 0
-    { "Real device access", NULL, radio_Printer4_callback,
-      (void *)PRINTER_DEVICE_REAL, 19, TUI_MENU_BEH_CLOSE, NULL, NULL },
-#endif
     { NULL }
 };
 
@@ -206,10 +197,6 @@ static tui_menu_item_def_t printer5dev_submenu[] = {
       (void *)PRINTER_DEVICE_NONE, 19, TUI_MENU_BEH_CLOSE, NULL, NULL },
     { "_File system access", NULL, radio_Printer5_callback,
       (void *)PRINTER_DEVICE_FS, 19, TUI_MENU_BEH_CLOSE, NULL, NULL },
-#if 0
-    { "Real device access", NULL, radio_Printer5_callback,
-      (void *)PRINTER_DEVICE_REAL, 19, TUI_MENU_BEH_CLOSE, NULL, NULL },
-#endif
     { NULL }
 };
 
@@ -305,6 +292,4 @@ void uiprinter_init(struct tui_menu *parent_submenu)
                          "P_rinter settings...",
                          "Various printer settings",
                          tmp, NULL, NULL, 0);
-
 }
-
