@@ -33,7 +33,6 @@
 #include "tuimenu.h"
 #include "uiramcart.h"
 
-
 TUI_MENU_DEFINE_TOGGLE(RAMCART)
 TUI_MENU_DEFINE_RADIO(RAMCARTsize)
 TUI_MENU_DEFINE_TOGGLE(RAMCART_RO)
@@ -65,12 +64,13 @@ static TUI_MENU_CALLBACK(ramcart_image_file_callback)
 
         *s = '\0';
 
-        if (tui_input_string("Change RAMCART image name",
-                             "New image name:", s, 255) == -1)
+        if (tui_input_string("Change RAMCART image name", "New image name:", s, 255) == -1) {
             return NULL;
+        }
 
-        if (*s == '\0')
+        if (*s == '\0') {
             return NULL;
+        }
 
         resources_set_string("RAMCARTfilename", s);
     }
@@ -106,7 +106,7 @@ void uiramcart_init(struct tui_menu *parent_submenu)
 
     tui_menu_add_submenu(parent_submenu, "_RAMCART settings...",
                          "RAMCART settings",
-                         ui_ramcart_submenu, NULL, 0,
+                         ui_ramcart_submenu,
+                         NULL, 0,
                          TUI_MENU_BEH_CONTINUE);
 }
-
