@@ -33,22 +33,20 @@
 #include "tuimenu.h"
 #include "uireu.h"
 
-
 TUI_MENU_DEFINE_TOGGLE(REU)
 TUI_MENU_DEFINE_RADIO(REUsize)
 
-
 static TUI_MENU_CALLBACK(reu_size_submenu_callback)
 {
     int value;
     static char s[100];
 
     resources_get_int("REUsize", &value);
-    sprintf(s, "%dKB",value);
+    sprintf(s, "%dKB", value);
     return s;
 }
 
-static tui_menu_item_def_t reu_size_submenu[] = {
+ static tui_menu_item_def_t reu_size_submenu[] = {
     { "_128KB", NULL, radio_REUsize_callback,
       (void *)128, 7, TUI_MENU_BEH_CLOSE, NULL, NULL },
     { "_256KB", NULL, radio_REUsize_callback,
@@ -77,12 +75,13 @@ static TUI_MENU_CALLBACK(reu_image_file_callback)
 
         *s = '\0';
 
-        if (tui_input_string("Change REU image name",
-                             "New image name:", s, 255) == -1)
+        if (tui_input_string("Change REU image name", "New image name:", s, 255) == -1) {
             return NULL;
+        }
 
-        if (*s == '\0')
+        if (*s == '\0') {
             return NULL;
+        }
 
         resources_set_string("REUfilename", s);
     }
@@ -115,7 +114,7 @@ void uireu_init(struct tui_menu *parent_submenu)
 
     tui_menu_add_submenu(parent_submenu, "_REU settings...",
                          "REU settings",
-                         ui_reu_submenu, NULL, 0,
+                         ui_reu_submenu,
+                         NULL, 0,
                          TUI_MENU_BEH_CONTINUE);
 }
-
