@@ -35,18 +35,16 @@
 #include "tuimenu.h"
 #include "uitfe.h"
 
-
 TUI_MENU_DEFINE_TOGGLE(ETHERNET_ACTIVE)
 TUI_MENU_DEFINE_RADIO(ETHERNET_AS_RR)
 
-
 static TUI_MENU_CALLBACK(ethernet_as_rr_submenu_callback)
 {
     int value;
     static char s[100];
 
     resources_get_int("ETHERNET_AS_RR", &value);
-    sprintf(s, "%s",(value==0) ? "TFE" : "RRNET");
+    sprintf(s, "%s", (value==0) ? "TFE" : "RRNET");
     return s;
 }
 
@@ -79,7 +77,8 @@ void uitfe_init(struct tui_menu *parent_submenu)
 
     tui_menu_add_submenu(parent_submenu, "_TFE settings...",
                          "TFE settings",
-                         ui_tfe_submenu, NULL, 0,
+                         ui_tfe_submenu,
+                         NULL, 0,
                          TUI_MENU_BEH_CONTINUE);
 }
 
