@@ -46,6 +46,7 @@
 #include <string.h>
 #include <ctype.h>
 #include <process.h>
+
 #if defined(__IBMC__) || defined(WATCOM_COMPILE)
 #include <io.h>
 #include <fcntl.h>
@@ -78,7 +79,9 @@ static char argv0[CCHMAXPATH];
 
 static void restore_workdir(void)
 {
-    if (orig_workdir) chdir(orig_workdir);
+    if (orig_workdir) {
+        chdir(orig_workdir);
+    }
 }
 
 HAB habMain;
@@ -90,13 +93,15 @@ void PM_close(void)
 
     log_message(archlog, "Releasing PM.");
 
-    rc=WinDestroyMsgQueue(hmqMain);  // Destroy Msg Queue
-    if (!rc)
+    rc = WinDestroyMsgQueue(hmqMain);  // Destroy Msg Queue
+    if (!rc) {
         log_error(archlog, "WinDestroyMsgQueue.");
+    }
 
-    rc=WinTerminate(habMain);  // Release Anchor to PM
-    if (!rc)
+    rc = WinTerminate(habMain);  // Release Anchor to PM
+    if (!rc) {
         log_error(archlog, "WinTerminate.");
+    }
 
     log_message(archlog, "PM released.");
 }
@@ -110,28 +115,27 @@ void PM_open(void)
 
     // this should make sure, that the system doesn't hang because
     // vice uses 100% CPU time
-    if (rc=DosSetPriority(PRTYS_THREAD, PRTYC_REGULAR, -1, 0))
+    if (rc = DosSetPriority(PRTYS_THREAD, PRTYC_REGULAR, -1, 0)) {
         log_error(archlog, "DosSetPriority (rc=%li)", rc);
-
-//    atexit(PM_close);
+    }
 }
 
-#if !defined __X1541__ && !defined __PETCAT__
+#if !defined(__X1541__) && !defined(__PETCAT__)
 /* ------------------------------------------------------------------------ */
 void archdep_create_mutex_sem(HMTX *hmtx, const char *pszName, int fState)
 {
     APIRET rc;
 
-    char *sem = lib_malloc(13+strlen(pszName)+5+1);
+    char *sem = lib_malloc(13+strlen(pszName) + 5 + 1);
 
     sprintf(sem, "\\SEM32\\VICE2\\%s_%04x", pszName, vsyncarch_gettime()&0xffff);
 
-    if (rc=DosCreateMutexSem(sem, hmtx, 0, fState))
+    if (rc = DosCreateMutexSem(sem, hmtx, 0, fState)) {
         log_error(archlog, "DosCreateMutexSem '%s' (rc=%i)", pszName, rc);
+    }
 }
 
 HMTX hmtxSpawn;
-
 #endif
 
 int archdep_init(int *argc, char **argv)
@@ -147,22 +151,23 @@ int archdep_init(int *argc, char **argv)
     atexit(restore_workdir);
 
     PM_open();
+
 #if !defined __X1541__ && !defined __PETCAT__
     archdep_create_mutex_sem(&hmtxSpawn, "Spawn", FALSE);
 #endif
+
     return 0;
 }
 
 char *archdep_program_name(void)
 {
-    static char *name=NULL;
+    static char *name = NULL;
 
-    if (!name)
-    {
+    if (!name) {
         char drive[_MAX_DRIVE];
-        char dir  [_MAX_DIR];
+        char dir[_MAX_DIR];
         char fname[_MAX_FNAME+_MAX_EXT];
-        char ext  [_MAX_EXT];
+        char ext[_MAX_EXT];
         _splitpath(argv0, drive, dir, fname, ext);
         name = util_concat(fname, ext, NULL);
     }
@@ -171,17 +176,18 @@ char *archdep_program_name(void)
 
 const char *archdep_boot_path(void)
 {
-    static char *boot_path=NULL;
+    static char *boot_path = NULL;
 
-    if (!boot_path)
-    {
+    if (!boot_path) {
         char drive[_MAX_DRIVE+_MAX_DIR];
-        char dir  [_MAX_DIR];
+        char dir[_MAX_DIR];
         char fname[_MAX_FNAME+_MAX_EXT];
-        char ext  [_MAX_EXT];
+        char ext[_MAX_EXT];
+
         _splitpath(argv0, drive, dir, fname, ext);
-        if (strlen(dir))
-            *(dir+strlen(dir)-1) = '\0'; // cut last backslash
+        if (strlen(dir)) {
+            *(dir + strlen(dir) - 1) = '\0'; // cut last backslash
+        }
         boot_path = util_concat(drive, dir, NULL);
     }
     return boot_path;
@@ -189,14 +195,11 @@ const char *archdep_boot_path(void)
 
 char *archdep_default_sysfile_pathlist(const char *emu_id)
 {
-    static char *pathlist=NULL;
-
-    if (!pathlist)
-        pathlist = util_concat(emu_id,
-                               ARCHDEP_FINDPATH_SEPARATOR_STRING, "DRIVES",
-                               ARCHDEP_FINDPATH_SEPARATOR_STRING, "PRINTER",
-                               NULL);
+    static char *pathlist = NULL;
 
+    if (!pathlist) {
+        pathlist = util_concat(emu_id, ARCHDEP_FINDPATH_SEPARATOR_STRING, "DRIVES", ARCHDEP_FINDPATH_SEPARATOR_STRING, "PRINTER", NULL);
+    }
     return pathlist;
 }
 
@@ -215,6 +218,14 @@ char *archdep_default_fliplist_file_name(void)
     return util_concat(archdep_boot_path(), "\\vice2-", machine_name, ".vfl", NULL);
 }
 
+char *archdep_default_autostart_disk_image_file_name(void)
+{
+    const char *home;
+
+    home = archdep_boot_path();
+    return util_concat(home, "\\autostart-", machine_name, ".d64", NULL);
+}
+
 FILE *fLog=NULL;
 
 int archdep_default_logger(const char *lvl, const char *txt)
@@ -222,27 +233,35 @@ int archdep_default_logger(const char *lvl, const char *txt)
     //
     // This is used if archdep_open_default_log_file returns NULL
     //
+
 #ifndef __X1541__
     char *text = util_concat(lvl, txt, NULL);
+
     WinSendMsg(hwndLog, WM_INSERT, text, FALSE);
     lib_free(text);
 #endif
-    if (fLog)
+
+    if (fLog) {
         fprintf(fLog, "%s%s\n", lvl, txt);
+    }
     return 0;
 }
 
 FILE *archdep_open_default_log_file()
 {
+
 #ifndef __X1541__
     int val;
 #endif
 
     char *fname = util_concat(archdep_boot_path(), "\\vice2.log", NULL);
+
     fLog = fopen(fname, "w");
     lib_free(fname);
-    if (fLog)
+    if (fLog) {
         setbuf(fLog, NULL);
+    }
+
 #ifndef __X1541__
     resources_get_int("Logwin", &val);
     log_dialog(val);
@@ -276,9 +295,7 @@ int archdep_num_text_columns(void)
 
 int archdep_path_is_relative(const char *path)
 {
-    return !(isalpha(path[0]) && path[1] == ':' &&
-            (path[2] == '/' || path[2] == '\\') ||
-            (path[0] == '/' || path[0] == '\\'));
+    return !(isalpha(path[0]) && path[1] == ':' && (path[2] == '/' || path[2] == '\\') || (path[0] == '/' || path[0] == '\\'));
 }
 
 /* Return a malloc'ed backup file name for file `fname'.  */
@@ -290,13 +307,13 @@ char *archdep_make_backup_filename(const char *fname)
 /* return malloced version of full pathname of filename */
 int archdep_expand_path(char **return_path, const char *filename)
 {
-    if (filename[0] == '\\' || filename[1] == ':')
+    if (filename[0] == '\\' || filename[1] == ':') {
         *return_path = lib_stralloc(filename);
-    else
-    {
+    } else {
         char *p = (char *)malloc(512);
-        while (getcwd(p, 512) == NULL)
+        while (getcwd(p, 512) == NULL) {
             return 0;
+        }
 
         *return_path = util_concat(p, "\\", filename, NULL);
         lib_free(p);
@@ -307,15 +324,15 @@ int archdep_expand_path(char **return_path, const char *filename)
 int archdep_search_path(const char *name, char *pBuf, int lBuf)
 {
     const int flags = SEARCH_CUR_DIRECTORY|SEARCH_IGNORENETERRS;
-    char *path      = "";        /* PATH environment variable */
-    char *pgmName   = util_concat(name, ".exe", NULL);
+    char *path = "";        /* PATH environment variable */
+    char *pgmName = util_concat(name, ".exe", NULL);
 
     // Search the program in the path
-    if (DosScanEnv("PATH",&path))
+    if (DosScanEnv("PATH", &path)) {
         log_warning(archlog, "Environment variable PATH not found.");
+    }
 
-    if (DosSearchPath(flags, path, pgmName, pBuf, lBuf))
-    {
+    if (DosSearchPath(flags, path, pgmName, pBuf, lBuf)) {
         log_error(archlog, "File \"%s\" not found.", pgmName);
         return -1;
     }
@@ -328,28 +345,29 @@ char *archdep_cmdline(const char *name, char **argv, const char *sout, const cha
 {
     char *res;
     int length = 0;
-
     int i = 0;
-    while (argv[++i])
+
+    while (argv[++i]) {
         length += strlen(argv[i]);
+    }
 
-    length += i+1
-        +(name?strlen(name):0)+3
-        +(sout?strlen(sout):0)+5
-        +(serr?strlen(serr):0)+6; // need space for the spaces
-    res = lib_calloc(1,length);
+    length += i + 1 + (name ? strlen(name) : 0) + 3 + (sout ? strlen(sout) : 0) + 5 +(serr ? strlen(serr) : 0) + 6; // need space for the spaces
+    res = lib_calloc(1, length);
 
-    strcat(strcpy(res,"/c "),name);
+    strcat(strcpy(res,"/c "), name);
 
     i = 0;
-    while (argv[++i])
+    while (argv[++i]) {
         strcat(strcat(res," "), argv[i]);
+    }
 
-    if (sout)
+    if (sout) {
         strcat(strcat(strcat(res,  " > \""), sout), "\"");
+    }
 
-    if (serr)
+    if (serr) {
         strcat(strcat(strcat(res, " 2> \""), serr), "\"");
+    }
 
     return res;
 }
@@ -358,50 +376,53 @@ char *archdep_cmdline(const char *name, char **argv, const char *sout, const cha
    passing `argv' as the parameters, wait for it to exit and return its
    exit status. If `stdout_redir' or `stderr_redir' are != NULL,
    redirect stdout or stderr to the corresponding file.  */
-int archdep_spawn(const char *name, char **argv,
-                  char **pstdout_redir, const char *stderr_redir)
-{  // how to redirect stdout & stderr??
+int archdep_spawn(const char *name, char **argv, char **pstdout_redir, const char *stderr_redir)
+{
+    // how to redirect stdout & stderr??
     typedef struct _CHILDINFO {  /* Define a structure for the queue data */
         USHORT usSessionID;
         USHORT usReturn;
     } CHILDINFO;
 
-    UCHAR       fqName[256] = ""; /* Result of PATH search             */
-    HQUEUE      hqQueue;          /* Queue handle                      */
-    REQUESTDATA rdRequest;        /* Request data for the queue        */
-    ULONG       ulSzData;         /* Size of the queue data            */
-    BYTE        bPriority;        /* For the queue                     */
-    PVOID       pvData;           /* Pointer to the queue data         */
-    STARTDATA   sd;               /* Start Data for DosStartSession    */
-    PID         pid;              /* PID for the started child session */
-    ULONG       ulSession;        /* Session ID for the child session  */
-    APIRET      rc;               /* Return code from API's            */
-    char       *cmdline;
+    UCHAR fqName[256] = ""; /* Result of PATH search             */
+    HQUEUE hqQueue;         /* Queue handle                      */
+    REQUESTDATA rdRequest;  /* Request data for the queue        */
+    ULONG ulSzData;         /* Size of the queue data            */
+    BYTE bPriority;         /* For the queue                     */
+    PVOID pvData;           /* Pointer to the queue data         */
+    STARTDATA sd;           /* Start Data for DosStartSession    */
+    PID pid;                /* PID for the started child session */
+    ULONG ulSession;        /* Session ID for the child session  */
+    APIRET rc;              /* Return code from API's            */
+    char *cmdline;
     char *stdout_redir = NULL;
 
     if (pstdout_redir != NULL) {
-        if (*pstdout_redir == NULL)
+        if (*pstdout_redir == NULL) {
             *pstdout_redir = archdep_tmpnam();
+        }
         stdout_redir = *pstdout_redir;
     }
 
-    if (archdep_search_path(name, fqName, sizeof(fqName)))
+    if (archdep_search_path(name, fqName, sizeof(fqName))) {
         return -1;
+    }
 
     // Make the needed command string
     cmdline = archdep_cmdline(fqName, argv, stdout_redir, stderr_redir);
-#if !defined __X1541__ && !defined __PETCAT__
+
+#if !defined(__X1541__) && !defined(__PETCAT__)
     log_message(archlog, "Spawning \"cmd.exe %s\"", cmdline);
 #endif
 
     memset(&sd, 0, sizeof(STARTDATA));
-    sd.Length     = sizeof(STARTDATA);
-    sd.FgBg       = SSF_FGBG_BACK;      /* Start session in background */
-    sd.Related    = SSF_RELATED_CHILD;  /* Start a child session       */
-    sd.PgmName    = "cmd.exe";
-    sd.PgmInputs  = cmdline;
-    sd.PgmControl = SSF_CONTROL_INVISIBLE;  // | SSF_CONTROL_NOAUTOCLOSE;
-    sd.TermQ      = "\\QUEUES\\VICE2\\CHILD.QUE";
+    sd.Length = sizeof(STARTDATA);
+    sd.FgBg = SSF_FGBG_BACK;      /* Start session in background */
+    sd.Related = SSF_RELATED_CHILD;  /* Start a child session       */
+    sd.PgmName = "cmd.exe";
+    sd.PgmInputs = cmdline;
+    sd.PgmControl = SSF_CONTROL_INVISIBLE;
+    sd.TermQ = "\\QUEUES\\VICE2\\CHILD.QUE";
     sd.InheritOpt = SSF_INHERTOPT_SHELL;
 
     /* Start a child process and return it's session ID.
@@ -410,32 +431,35 @@ int archdep_spawn(const char *name, char **argv,
 
     // this prevents you from closing Vice while a child is running
 #if !defined __X1541__ && !defined __PETCAT__
-    if (DosRequestMutexSem(hmtxSpawn, SEM_INDEFINITE_WAIT))
+    if (DosRequestMutexSem(hmtxSpawn, SEM_INDEFINITE_WAIT)) {
         return 0;
+    }
 #endif
-    if(rc=DosCreateQueue(&hqQueue, QUE_FIFO|QUE_CONVERT_ADDRESS, sd.TermQ))
+
+    if (rc = DosCreateQueue(&hqQueue, QUE_FIFO|QUE_CONVERT_ADDRESS, sd.TermQ)) {
         log_error(archlog, "DosCreateQueue (rc=%li).",rc);
-    else
-    {
-        if(rc=DosStartSession(&sd, &ulSession, &pid))  /* Start the child session */
+    } else {
+        if (rc = DosStartSession(&sd, &ulSession, &pid))  {
+            /* Start the child session */
             log_error(archlog, "DosStartSession (rc=%li).",rc);
-        else
-        {
-            if(rc=DosReadQueue(hqQueue, &rdRequest, &ulSzData,        /* Wait for the child session to end (you'll have to end it */
-                               &pvData, 0, DCWW_WAIT, &bPriority, 0)) /* in some other way) */
+        } else {
+            if (rc = DosReadQueue(hqQueue, &rdRequest, &ulSzData, &pvData, 0, DCWW_WAIT, &bPriority, 0)) {
+                /* in some other way) */
                 log_error(archlog, "DosReadQueue (rc=%li).",rc);
-            else
-            {
-                if (rc = ((CHILDINFO*)pvData)->usReturn)
+            } else {
+                if (rc = ((CHILDINFO*)pvData)->usReturn) {
                     log_message(archlog, "'%s' returns rc = %li", cmdline, rc);
+                }
                 DosFreeMem(pvData); /* Free the memory of the queue data element read */
             }
         }
         DosCloseQueue(hqQueue);
     }
-#if !defined __X1541__ && !defined __PETCAT__
+
+#if !defined(__X1541__) && !defined(__PETCAT__)
     DosReleaseMutexSem(hmtxSpawn);
 #endif
+
     lib_free(cmdline);
     return rc;
 }
@@ -444,35 +468,35 @@ void archdep_startup_log_error(const char *format, ...)
 {
     char *txt;
     va_list ap;
+
     va_start(ap, format);
     txt = lib_mvsprintf(format, ap);
-#if !defined __X1541__ && !defined __PETCAT__
-    WinMessageBox(HWND_DESKTOP, HWND_DESKTOP,
-                  txt, "VICE/2 Startup Error", 0, MB_OK);
+
+#if !defined(__X1541__) && !defined(__PETCAT__)
+    WinMessageBox(HWND_DESKTOP, HWND_DESKTOP, txt, "VICE/2 Startup Error", 0, MB_OK);
 #else
     printf(txt);
 #endif
+
     lib_free(txt);
 }
 
-
 char *archdep_quote_parameter(const char *name)
 {
     return util_concat("\"", name, "\"", NULL);
 }
 
-
 char *archdep_filename_parameter(const char *name)
 {
     char *exp;
     char *a;
+
     archdep_expand_path(&exp, name);
     a = archdep_quote_parameter(exp);
     lib_free(exp);
     return a;
 }
 
-
 char *archdep_tmpnam(void)
 {
     return lib_stralloc(tmpnam(NULL));
@@ -487,8 +511,9 @@ FILE *archdep_mkstemp_fd(char **filename, const char *mode)
 
     fd = fopen(tmp, mode);
 
-    if (fd == NULL)
+    if (fd == NULL) {
         return NULL;
+    }
 
     *filename = tmp;
 
@@ -499,10 +524,9 @@ int archdep_file_is_gzip(const char *name)
 {
     size_t l = strlen(name);
 
-    if ((l < 4 || strcasecmp(name + l - 3, ".gz")) &&
-        (l < 3 || strcasecmp(name + l - 2, ".z"))  &&
-        (l < 4 || toupper(name[l - 1]) != 'Z' || name[l - 4] != '.'))
+    if ((l < 4 || strcasecmp(name + l - 3, ".gz")) && (l < 3 || strcasecmp(name + l - 2, ".z")) && (l < 4 || toupper(name[l - 1]) != 'Z' || name[l - 4] != '.')) {
         return 0;
+    }
     return 1;
 }
 
@@ -520,11 +544,12 @@ int archdep_stat(const char *file_name, unsigned int *len, unsigned int *isdir)
 {
     struct stat statbuf;
 
-    if (stat(file_name, &statbuf) < 0)
+    if (stat(file_name, &statbuf) < 0) {
         return -1;
+    }
 
     *len = statbuf.st_size;
-    *isdir = statbuf.st_mode&S_IFDIR;
+    *isdir = statbuf.st_mode & S_IFDIR;
 
     return 0;
 }
@@ -541,6 +566,4 @@ int archdep_file_is_chardev(const char *name)
 
 void archdep_shutdown(void)
 {
-
 }
-
