@@ -24,8 +24,8 @@
  *
  */
 
-#ifndef _ARCHDEP_H
-#define _ARCHDEP_H
+#ifndef VICE_ARCHDEP_H
+#define VICE_ARCHDEP_H
 
 #include "archapi.h"
 #include "posix.h"
@@ -34,15 +34,15 @@
 #define RESOURCE_FILE_NAME "VICERC"
 
 /* Filesystem dependant operators.  */
-#define FSDEVICE_DEFAULT_DIR   "@"
-#define FSDEV_DIR_SEP_STR      "."
-#define FSDEV_DIR_SEP_CHR      '.'
-#define FSDEV_EXT_SEP_STR      "/"
-#define FSDEV_EXT_SEP_CHR      '/'
+#define FSDEVICE_DEFAULT_DIR "@"
+#define FSDEV_DIR_SEP_STR    "."
+#define FSDEV_DIR_SEP_CHR    '.'
+#define FSDEV_EXT_SEP_STR    "/"
+#define FSDEV_EXT_SEP_CHR    '/'
 
 /* Path separator.  */
-#define ARCHDEP_FINDPATH_SEPARATOR_CHAR         ':'
-#define ARCHDEP_FINDPATH_SEPARATOR_STRING       ":"
+#define ARCHDEP_FINDPATH_SEPARATOR_CHAR   ':'
+#define ARCHDEP_FINDPATH_SEPARATOR_STRING ":"
 
 /* Modes for fopen().  */
 #define MODE_READ              "r"
@@ -103,6 +103,9 @@
 /* Ethernet default device */
 #define ARCHDEP_ETHERNET_DEFAULT_DEVICE ""
 
+/* Default sound fragment size */
+#define ARCHDEP_SOUND_FRAGMENT_SIZE 1
+
 /* No key symcode.  */
 #define ARCHDEP_KEYBOARD_SYM_NONE 0
 
