@@ -1,6 +1,5 @@
-#ifndef _VICE_CONFIG_H
-#define _VICE_CONFIG_H
-
+#ifndef VICE_CONFIG_H
+#define VICE_CONFIG_H
 
 /* Define as the return type of signal handlers (int or void).  */
 #define RETSIGTYPE void
