@@ -27,8 +27,8 @@
  *
  */
 
-#ifndef _TYPES_H
-#define _TYPES_H
+#ifndef VICE_TYPES_H
+#define VICE_TYPES_H
 
 #include "vice.h"
 
@@ -65,5 +65,9 @@ typedef DWORD CLOCK;
 #define PATH_MAX 256
 #endif
 
-#endif  /* _TYPES_H */
+#define vice_ptr_to_int(x) ((int)(long)(x))
+#define vice_ptr_to_uint(x) ((unsigned int)(unsigned long)(x))
+#define int_to_void_ptr(x) ((void *)(long)(x))
+#define uint_to_void_ptr(x) ((void *)(unsigned long)(x))
 
+#endif  /* _TYPES_H */
