@@ -24,20 +24,20 @@
  *
  */
 
-#ifndef _UIIMAGE_H
-#define _UIIMAGE_H
+#ifndef VICE_UIIMAGE_H
+#define VICE_UIIMAGE_H
 
-#define FileType_D64File	0x164
-#define FileType_Data		0xffd
-#define FileType_Directory	0x1000
+#define FileType_D64File   0x164
+#define FileType_Data      0xffd
+#define FileType_Directory 0x1000
 
-int  ui_image_contents_disk(const char *imagefile);
-int  ui_image_contents_tape(const char *imagefile);
-int  ui_image_contents_dir(const char *dirname);
-int  ui_image_contents_generic(const char *imagefile, int filetype);
-void ui_image_contents_close(void);
-void ui_image_contents_redraw(int *block);
-void ui_image_contents_click(int *block);
-void ui_image_contents_exit(void);
+extern int ui_image_contents_disk(const char *imagefile);
+extern int ui_image_contents_tape(const char *imagefile);
+extern int ui_image_contents_dir(const char *dirname);
+extern int ui_image_contents_generic(const char *imagefile, int filetype);
+extern void ui_image_contents_close(void);
+extern void ui_image_contents_redraw(int *block);
+extern void ui_image_contents_click(int *block);
+extern void ui_image_contents_exit(void);
 
 #endif
