@@ -36,6 +36,7 @@
 #include "machine.h"
 #include "machine-video.h"
 #include "resources.h"
+#include "uiapi.h"
 #include "uiattach.h"
 #include "uic64_256k.h"
 #include "uic64cart.h"
@@ -46,6 +47,7 @@
 #include "uidrive.h"
 #include "uidrivec64.h"
 #include "uidrivec64vic20.h"
+#include "uieasyflash.h"
 #include "uigeoram.h"
 #include "uiide64.h"
 #include "uiisepic.h"
@@ -55,6 +57,7 @@
 #include "uimidi.h"
 #include "uimmc64.h"
 #include "uimouse.h"
+#include "uilightpen.h"
 #include "uiperipheraliec.h"
 #include "uiplus256k.h"
 #include "uiplus60k.h"
@@ -66,11 +69,11 @@
 #include "uisettings.h"
 #include "uisid.h"
 #include "uisound.h"
+#include "uisoundexpander.h"
 #include "uitfe.h"
 #include "uivicii.h"
 #include "vsync.h"
 
-
 UI_MENU_DEFINE_RADIO(MachineVideoStandard)
 
 static ui_menu_entry_t set_video_standard_c64_submenu[] = {
@@ -225,8 +228,8 @@ UI_MENU_DEFINE_TOGGLE(SidStereo)
 UI_MENU_DEFINE_TOGGLE(SidFilters)
 
 ui_menu_entry_t sid_submenu[] = {
-    { N_("SID engine"),
-      NULL, NULL, sid_engine_submenu },
+    { N_("SID model"),
+      NULL, NULL, sid_model_submenu },
     { "--" },
     { N_("*Second SID"),
       (ui_callback_t)toggle_SidStereo, NULL, NULL },
@@ -235,8 +238,6 @@ ui_menu_entry_t sid_submenu[] = {
     { "--" },
     { N_("*Emulate filters"),
       (ui_callback_t)toggle_SidFilters, NULL, NULL },
-    { N_("Chip model"),
-      NULL, NULL, sid_model_submenu },
 #ifdef HAVE_RESID
     { "--" },
     { N_("reSID sampling method"),
@@ -250,8 +251,8 @@ ui_menu_entry_t sid_submenu[] = {
 UI_MENU_DEFINE_TOGGLE(Sound)
 
 static ui_menu_entry_t sid_options_submenu[] = {
-    { N_("SID engine"),
-      NULL, NULL, sid_engine_submenu },
+    { N_("SID model"),
+      NULL, NULL, sid_model_submenu },
     { N_("*Enable sound playback"),
       (ui_callback_t)toggle_Sound, NULL, NULL },
     { N_("*Second SID"),
@@ -260,14 +261,13 @@ static ui_menu_entry_t sid_options_submenu[] = {
       NULL, NULL, set_sid_stereo_address_submenu },
     { N_("*Emulate filters"),
       (ui_callback_t)toggle_SidFilters, NULL, NULL },
-    { N_("Chip model"),
-      NULL, NULL, sid_model_submenu },
     { NULL }
 };
 
 /* ------------------------------------------------------------------------- */
 
 UI_MENU_DEFINE_TOGGLE(EmuID)
+UI_MENU_DEFINE_TOGGLE(SFXSoundSampler)
 
 static ui_menu_entry_t io_extensions_submenu[] = {
     { N_("RAM Expansion Unit"),
@@ -280,6 +280,8 @@ static ui_menu_entry_t io_extensions_submenu[] = {
       NULL, NULL, dqbb_submenu },
     { N_("Isepic cartridge"),
       NULL, NULL, isepic_submenu },
+    { N_("EasyFlash cartridge"),
+      NULL, NULL, easyflash_submenu },
     { N_("PLUS60K RAM Expansion"),
       NULL, NULL, plus60k_submenu },
     { N_("PLUS256K RAM Expansion"),
@@ -301,11 +303,19 @@ static ui_menu_entry_t io_extensions_submenu[] = {
 #ifdef HAVE_MOUSE
     { N_("*Mouse Emulation"),
       NULL, NULL, mouse_submenu },
+#ifdef USE_GNOMEUI
+    { N_("*Lightpen Emulation"),
+      NULL, NULL, lightpen_submenu },
+#endif
 #endif
 #ifdef HAVE_MIDI
     { N_("MIDI Emulation"),
       NULL, NULL, midi_c64_submenu },
 #endif
+    { N_("*SFX Sound Expander emulation"),
+      NULL, NULL, soundexpander_submenu },
+    { N_("*SFX Sound Sampler emulation"),
+      (ui_callback_t)toggle_SFXSoundSampler, NULL, NULL },
     { NULL }
 };
 
@@ -350,15 +360,16 @@ static UI_CALLBACK(save_screenshot)
 {
     /* Where does the 1024 come from?  */
     char filename[1024];
-    unsigned int wid = (unsigned int)UI_MENU_CB_PARAM;
+    unsigned int wid = vice_ptr_to_uint(UI_MENU_CB_PARAM);
 
     vsync_suspend_speed_eval();
 
     /* The following code depends on a zeroed filename.  */
     memset(filename, 0, 1024);
 
-    if (ui_screenshot_dialog(filename, machine_video_canvas_get(wid)) < 0)
+    if (ui_screenshot_dialog(filename, machine_video_canvas_get(wid)) < 0) {
         return;
+    }
 }
 
 static ui_menu_entry_t ui_screenshot_commands_menu[] = {
@@ -425,7 +436,7 @@ static ui_menu_entry_t x64_right_menu[] = {
     { "",
       NULL, NULL, ui_peripheraliec_settings_menu },
     { "",
-      NULL, NULL, joystick_settings_menu },
+      NULL, NULL, joystick_settings_c64_menu },
     { "--",
       NULL, NULL, c64_menu },
     { "--",
@@ -493,7 +504,7 @@ static ui_menu_entry_t x64_settings_submenu[] = {
     { "",
       NULL, NULL, ui_peripheraliec_settings_menu },
     { "",
-      NULL, NULL, joystick_settings_menu },
+      NULL, NULL, joystick_settings_c64_menu },
     { "--",
       NULL, NULL, c64_menu },
     { "--",
@@ -547,9 +558,7 @@ static void c64ui_dynamic_menu_shutdown(void)
 
 int c64ui_init(void)
 {
-    memcpy(set_video_standard_submenu, 
-           set_video_standard_c64_submenu,
-           sizeof(set_video_standard_c64_submenu));
+    memcpy(set_video_standard_submenu, set_video_standard_c64_submenu, sizeof(set_video_standard_c64_submenu));
 
     ui_set_application_icon(c64_icon_data);
     c64ui_dynamic_menu_create();
