@@ -33,18 +33,22 @@
 #include "attach.h"
 #include "autostart.h"
 #include "imagecontents.h"
+#include "tapecontents.h"
+#include "diskcontents.h"
 #include "lib.h"
 #include "resources.h"
 #include "tape.h"
+#include "uiapi.h"
 #include "uiattach.h"
+#include "uiautostart.h"
 #include "uiedisk.h"
 #include "uifliplist.h"
+#include "uilib.h"
 #include "uimenu.h"
 #include "util.h"
 #include "vsync.h"
 #include "ioutil.h"
 
-
 static int selection_from_image = 0;
 
 void ui_set_selected_file(int num)
@@ -52,32 +56,27 @@ void ui_set_selected_file(int num)
     selection_from_image = num;
 }
 
-static char *read_disk_image_contents(const char *name, unsigned int unit)
-{
-#ifdef USE_GNOMEUI
-    return image_contents_read_string(IMAGE_CONTENTS_DISK, name, unit,
-                                      IMAGE_CONTENTS_STRING_PETSCII);
-#else
-    return image_contents_read_string(IMAGE_CONTENTS_DISK, name, unit,
-                                      IMAGE_CONTENTS_STRING_ASCII);
-#endif
-}
-
 static char *attach_disk_last_dir = NULL;
 
+static read_contents_func_type funcs[] = {
+    diskcontents_read_unit8,
+    diskcontents_read_unit9,
+    diskcontents_read_unit10,
+    diskcontents_read_unit11
+};
+
 UI_CALLBACK(attach_disk)
 {
-    int unit = (int)UI_MENU_CB_PARAM;
+    int unit = vice_ptr_to_int(UI_MENU_CB_PARAM);
     char *filename, *title;
     ui_button_t button;
     int attach_wp = 0;
+    uilib_file_filter_enum_t filter[] = { UILIB_FILTER_DISK, UILIB_FILTER_ALL };
 
     vsync_suspend_speed_eval();
     title = lib_msprintf(_("Attach Disk Image as unit #%d"), unit);
-    filename = ui_select_file(title, read_disk_image_contents, unit,
-                              unit == 8 ? 1 : 0, attach_disk_last_dir,
-                              "*.[gdxGDX]*", &button, 1, &attach_wp,
-			      UI_FC_LOAD);
+    filename = ui_select_file(title, funcs[unit - 8], unit == 8 ? 1 : 0, attach_disk_last_dir,
+                              filter, sizeof(filter) / sizeof(*filter), &button,  1, &attach_wp, UI_FC_LOAD);
 
     lib_free(title);
     if (attach_wp) {
@@ -86,28 +85,26 @@ UI_CALLBACK(attach_disk)
     }
 
     switch (button) {
-      case UI_BUTTON_OK:
-        if (file_system_attach_disk(unit, filename) < 0)
-            ui_error(_("Invalid Disk Image"));
-        if (attach_disk_last_dir)
+        case UI_BUTTON_OK:
+            if (file_system_attach_disk(unit, filename) < 0) {
+                ui_error(_("Invalid Disk Image"));
+            }
             lib_free(attach_disk_last_dir);
-        util_fname_split(filename, &attach_disk_last_dir, NULL);
-        break;
-      case UI_BUTTON_AUTOSTART:
-        if (autostart_disk(filename, NULL, selection_from_image,
-            AUTOSTART_MODE_RUN) < 0)
-            ui_error(_("Invalid Disk Image or Filename"));
-        if (attach_disk_last_dir)
+            util_fname_split(filename, &attach_disk_last_dir, NULL);
+            break;
+        case UI_BUTTON_AUTOSTART:
+            if (autostart_disk(filename, NULL, selection_from_image, AUTOSTART_MODE_RUN) < 0) {
+                ui_error(_("Invalid Disk Image or Filename"));
+            }
             lib_free(attach_disk_last_dir);
-        util_fname_split(filename, &attach_disk_last_dir, NULL);
-        break;
-      default:
-        /* Do nothing special.  */
-        break;
+            util_fname_split(filename, &attach_disk_last_dir, NULL);
+            break;
+        default:
+            /* Do nothing special.  */
+            break;
     }
 
-    if (filename != NULL)
-        lib_free(filename);
+    lib_free(filename);
 }
 
 static ui_menu_entry_t attach_disk_image_submenu[] = {
@@ -128,7 +125,8 @@ static ui_menu_entry_t attach_disk_image_submenu[] = {
 
 static UI_CALLBACK(attach_empty_disk)
 {
-    int unit = (int)UI_MENU_CB_PARAM;
+    int unit = vice_ptr_to_int(UI_MENU_CB_PARAM);
+
     /* Where does the 1024 come from?  */
     char filename[1024];
 
@@ -137,11 +135,13 @@ static UI_CALLBACK(attach_empty_disk)
     /* The following code depends on a zeroed filename.  */
     memset(filename, 0, 1024);
 
-    if (ui_empty_disk_dialog(filename) < 0)
+    if (ui_empty_disk_dialog(filename) < 0) {
         return;
+    }
 
-    if (file_system_attach_disk(unit, filename) < 0)
+    if (file_system_attach_disk(unit, filename) < 0) {
         ui_error(_("Invalid Disk Image"));
+    }
 }
 
 static ui_menu_entry_t attach_empty_disk_image_submenu[] = {
@@ -158,7 +158,7 @@ static ui_menu_entry_t attach_empty_disk_image_submenu[] = {
 
 UI_CALLBACK(detach_disk)
 {
-    int unit = (int)UI_MENU_CB_PARAM;
+    int unit = vice_ptr_to_int(UI_MENU_CB_PARAM);
 
     vsync_suspend_speed_eval();
     file_system_detach_disk(unit);
@@ -191,53 +191,38 @@ ui_menu_entry_t uiattach_disk_menu[] = {
     { NULL }
 };
 
-static char *read_tape_image_contents(const char *name, unsigned int unit)
-{
-#ifdef USE_GNOMEUI
-    return image_contents_read_string(IMAGE_CONTENTS_TAPE, name, unit,
-                                      IMAGE_CONTENTS_STRING_PETSCII);
-#else
-    return image_contents_read_string(IMAGE_CONTENTS_TAPE, name, unit,
-                                      IMAGE_CONTENTS_STRING_ASCII);
-#endif
-}
-
 static char *attach_tape_last_dir = NULL;
 
 static UI_CALLBACK(attach_tape)
 {
     char *filename;
     ui_button_t button;
+    uilib_file_filter_enum_t filter[] = { UILIB_FILTER_TAPE, UILIB_FILTER_ALL };
 
     vsync_suspend_speed_eval();
 
-    filename = ui_select_file(_("Attach a tape image"),
-                              read_tape_image_contents, 0,
-                              1, attach_tape_last_dir, "*.[tT]*",
-                              &button, 1, NULL, UI_FC_LOAD);
+    filename = ui_select_file(_("Attach a tape image"), tapecontents_read, 1, attach_tape_last_dir, filter, sizeof(filter) / sizeof(*filter), &button, 1, NULL, UI_FC_LOAD);
 
     switch (button) {
-      case UI_BUTTON_OK:
-        if (tape_image_attach(1, filename) < 0)
-            ui_error(_("Invalid Tape Image"));
-        if (attach_tape_last_dir)
+        case UI_BUTTON_OK:
+            if (tape_image_attach(1, filename) < 0) {
+                ui_error(_("Invalid Tape Image"));
+            }
             lib_free(attach_tape_last_dir);
-        util_fname_split(filename, &attach_tape_last_dir, NULL);
-        break;
-      case UI_BUTTON_AUTOSTART:
-        if (autostart_tape(filename, NULL, selection_from_image,
-            AUTOSTART_MODE_RUN) < 0)
-            ui_error(_("Invalid Tape Image"));
-        if (attach_tape_last_dir)
+            util_fname_split(filename, &attach_tape_last_dir, NULL);
+            break;
+        case UI_BUTTON_AUTOSTART:
+            if (autostart_tape(filename, NULL, selection_from_image, AUTOSTART_MODE_RUN) < 0) {
+                ui_error(_("Invalid Tape Image"));
+            }
             lib_free(attach_tape_last_dir);
-        util_fname_split(filename, &attach_tape_last_dir, NULL);
-        break;
-      default:
-        /* Do nothing special.  */
-        break;
+            util_fname_split(filename, &attach_tape_last_dir, NULL);
+            break;
+        default:
+            /* Do nothing special.  */
+            break;
     }
-    if (filename != NULL)
-        lib_free(filename);
+    lib_free(filename);
 }
 
 static UI_CALLBACK(detach_tape)
@@ -254,15 +239,15 @@ ui_menu_entry_t uiattach_tape_menu[] = {
     { NULL }
 };
 
-static char *read_disk_or_tape_image_contents(const char *fname,
-                                              unsigned int unit)
+static image_contents_t *read_disk_or_tape_image_contents(const char *fname)
 {
-    char *tmp;
+    image_contents_t *tmp;
 
-    tmp = read_disk_image_contents(fname, unit);
-    if (tmp)
+    tmp = diskcontents_filesystem_read(fname);
+    if (tmp) {
         return tmp;
-    return read_tape_image_contents(fname, unit);
+    }
+    return tapecontents_read(fname);
 }
 
 static char *smart_attach_last_dir = NULL;
@@ -273,55 +258,50 @@ static UI_CALLBACK(smart_attach)
     ui_button_t button;
     int do_free_dir;
     char *dir;
+    uilib_file_filter_enum_t filter[] = { UILIB_FILTER_TAPE, UILIB_FILTER_DISK, UILIB_FILTER_PRGP00, UILIB_FILTER_ALL };
 
     vsync_suspend_speed_eval();
 
     if (smart_attach_last_dir) {
         dir = smart_attach_last_dir;
         do_free_dir = 0;
-    }
-    else {
+    } else {
         dir = ioutil_current_dir();
         do_free_dir = 1;
     }
-    filename = ui_select_file(_("Smart-attach a file"),
-                              read_disk_or_tape_image_contents, 0,
-                              1, dir, NULL, &button, 1, NULL, UI_FC_LOAD);
-    if (do_free_dir)
+    filename = ui_select_file(_("Smart-attach a file"), read_disk_or_tape_image_contents, 1, dir, filter, sizeof(filter) / sizeof(*filter), &button, 1, NULL, UI_FC_LOAD);
+    if (do_free_dir) {
         lib_free(dir);
+    }
 
     switch (button) {
-      case UI_BUTTON_OK:
-        if (file_system_attach_disk(8, filename) < 0
-            && tape_image_attach(1, filename) < 0
-            && autostart_snapshot(filename, NULL) < 0
-            && autostart_prg(filename, AUTOSTART_MODE_LOAD) < 0) {
-            ui_error(_("Unknown image type"));
-        }
-        if (smart_attach_last_dir)
+        case UI_BUTTON_OK:
+            if (file_system_attach_disk(8, filename) < 0 && tape_image_attach(1, filename) < 0 && autostart_snapshot(filename, NULL) < 0 && autostart_prg(filename, AUTOSTART_MODE_LOAD) < 0) {
+                ui_error(_("Unknown image type"));
+            }
             lib_free(smart_attach_last_dir);
-        util_fname_split(filename, &smart_attach_last_dir, NULL);
-        break;
-      case UI_BUTTON_AUTOSTART:
-        if (autostart_autodetect(filename, NULL, selection_from_image,
-            AUTOSTART_MODE_RUN) < 0)
-            ui_error(_("Unknown image type"));
-        if (smart_attach_last_dir)
+            util_fname_split(filename, &smart_attach_last_dir, NULL);
+            break;
+        case UI_BUTTON_AUTOSTART:
+            if (autostart_autodetect(filename, NULL, selection_from_image, AUTOSTART_MODE_RUN) < 0) {
+                ui_error(_("Unknown image type"));
+            }
             lib_free(smart_attach_last_dir);
-        util_fname_split(filename, &smart_attach_last_dir, NULL);
-        break;
-      default:
-        /* Do nothing special.  */
-        break;
+            util_fname_split(filename, &smart_attach_last_dir, NULL);
+            break;
+        default:
+            /* Do nothing special.  */
+            break;
     }
-    if (filename != NULL)
-        lib_free(filename);
+    lib_free(filename);
 }
 
 ui_menu_entry_t uiattach_smart_attach_menu[] = {
     { N_("Smart-attach disk/tape..."),
       (ui_callback_t)smart_attach, NULL, NULL,
       KEYSYM_a, UI_HOTMOD_META },
+    { N_("Autostart settings"),
+      NULL, NULL, uiautostart_settings_submenu },
     { NULL }
 };
 
@@ -331,4 +311,3 @@ void uiattach_shutdown(void)
     lib_free(attach_tape_last_dir);
     lib_free(smart_attach_last_dir);
 }
-
