@@ -25,8 +25,8 @@
  *
  */
 
-#ifndef _UICRTC_H
-#define _UICRTC_H
+#ifndef VICE_UICRTC_H
+#define VICE_UICRTC_H
 
 #include "uimenu.h"
 
@@ -36,4 +36,3 @@ extern void uicrtc_menu_create(void);
 extern void uicrtc_menu_shutdown(void);
 
 #endif
-
