@@ -24,12 +24,11 @@
  *
  */
 
-#ifndef _UIKEYBOARD_H
-#define _UIKEYBOARD_H
+#ifndef VICE_UIKEYBOARD_H
+#define VICE_UIKEYBOARD_H
 
 #include "uimenu.h"
 
 extern struct ui_menu_entry_s uikeyboard_settings_menu[];
 
 #endif
-
