@@ -32,37 +32,36 @@
 #include "lib.h"
 #include "resources.h"
 #include "ui.h"
+#include "uiapi.h"
+#include "uilib.h"
 #include "uimenu.h"
 #include "util.h"
 #include "vsync.h"
 
-
 UI_CALLBACK(ui_load_palette)
 {
     char *filename, *title;
     ui_button_t button;
     static char *last_dir;
+    uilib_file_filter_enum_t filter[] = { UILIB_FILTER_PALETTE, UILIB_FILTER_ALL };
 
     vsync_suspend_speed_eval();
     title = lib_stralloc(_("Load custom palette"));
-    filename = ui_select_file(title, NULL, 0, 0, last_dir, "*.vpl",
-                              &button, 0, NULL, UI_FC_LOAD);
+    filename = ui_select_file(title, NULL, 0, last_dir, filter, sizeof(filter) / sizeof(*filter), &button, 0, NULL, UI_FC_LOAD);
 
     lib_free(title);
     switch (button) {
-      case UI_BUTTON_OK:
-        if (resources_set_string(UI_MENU_CB_PARAM, filename) < 0)
-            ui_error(_("Could not load palette file\n'%s'"), filename);
-        if (last_dir)
+        case UI_BUTTON_OK:
+            if (resources_set_string(UI_MENU_CB_PARAM, filename) < 0) {
+                ui_error(_("Could not load palette file\n'%s'"), filename);
+            }
             lib_free(last_dir);
-        util_fname_split(filename, &last_dir, NULL);
-        break;
-      default:
-        /* Do nothing special.  */
-        break;
+            util_fname_split(filename, &last_dir, NULL);
+            break;
+        default:
+            /* Do nothing special.  */
+            break;
     }
     ui_update_menus();
-    if (filename != NULL)
-        lib_free(filename);
+    lib_free(filename);
 }
-
