@@ -24,16 +24,16 @@
  *
  */
 
-#ifndef _UI_SID_H
-#define _UI_SID_H
+#ifndef VICE_UI_SID_H
+#define VICE_UI_SID_H
 
 #include "uimenu.h"
 
-extern struct ui_menu_entry_s sid_engine_submenu[];
 extern struct ui_menu_entry_s sid_model_submenu[];
+extern struct ui_menu_entry_s sid_dtv_model_submenu[];
+extern struct ui_menu_entry_s sid_model_noresid_submenu[];
 extern struct ui_menu_entry_s sid_resid_sampling_submenu[];
 
 extern UI_CALLBACK(set_sid_resid_passband);
 
 #endif
-
