@@ -35,19 +35,17 @@
 #include "uimenu.h"
 #include "uisound.h"
 
-
 UI_MENU_DEFINE_TOGGLE(Sound)
 UI_MENU_DEFINE_STRING_RADIO(SoundDeviceName)
 UI_MENU_DEFINE_RADIO(SoundSpeedAdjustment)
 UI_MENU_DEFINE_RADIO(SoundSampleRate)
 UI_MENU_DEFINE_RADIO(SoundBufferSize)
+UI_MENU_DEFINE_RADIO(SoundFragmentSize)
 UI_MENU_DEFINE_RADIO(SoundSuspendTime)
-UI_MENU_DEFINE_RADIO(SoundOversample)
 
 UI_CALLBACK(set_sound_device_arg)
 {
-    uilib_select_string((char *)UI_MENU_CB_PARAM, _("Sound driver argument"),
-                        _("Argument:"));
+    uilib_select_string((char *)UI_MENU_CB_PARAM, _("Sound driver argument"), _("Argument:"));
 }
 
 ui_menu_entry_t set_sound_sample_rate_submenu[] = {
@@ -65,24 +63,36 @@ ui_menu_entry_t set_sound_sample_rate_submenu[] = {
 };
 
 static ui_menu_entry_t set_sound_buffer_size_submenu[] = {
-    { N_("*1.00 sec"), (ui_callback_t)radio_SoundBufferSize,
-      (ui_callback_data_t)1000, NULL },
-    { N_("*0.75 sec"), (ui_callback_t)radio_SoundBufferSize,
-      (ui_callback_data_t)750, NULL },
-    { N_("*0.50 sec"), (ui_callback_t)radio_SoundBufferSize,
-      (ui_callback_data_t)500, NULL },
     { N_("*0.35 sec"), (ui_callback_t)radio_SoundBufferSize,
       (ui_callback_data_t)350, NULL },
     { N_("*0.30 sec"), (ui_callback_t)radio_SoundBufferSize,
-      (ui_callback_data_t)300, NULL },
-    { N_("*0.25 sec"), (ui_callback_t)radio_SoundBufferSize,
       (ui_callback_data_t)250, NULL },
     { N_("*0.20 sec"), (ui_callback_t)radio_SoundBufferSize,
-      (ui_callback_data_t)200, NULL },
-    { N_("*0.15 sec"), (ui_callback_t)radio_SoundBufferSize,
       (ui_callback_data_t)150, NULL },
     { N_("*0.10 sec"), (ui_callback_t)radio_SoundBufferSize,
       (ui_callback_data_t)100, NULL },
+    { N_("*0.075 sec"), (ui_callback_t)radio_SoundBufferSize,
+      (ui_callback_data_t)75, NULL },
+    { N_("*0.05 sec"), (ui_callback_t)radio_SoundBufferSize,
+      (ui_callback_data_t)50, NULL },
+    { N_("*0.04 sec"), (ui_callback_t)radio_SoundBufferSize,
+      (ui_callback_data_t)40, NULL },
+    { N_("*0.03 sec"), (ui_callback_t)radio_SoundBufferSize,
+      (ui_callback_data_t)30, NULL },
+    { N_("*0.025 sec"), (ui_callback_t)radio_SoundBufferSize,
+      (ui_callback_data_t)25, NULL },
+    { N_("*0.02 sec"), (ui_callback_t)radio_SoundBufferSize,
+      (ui_callback_data_t)20, NULL },
+    { NULL }
+};
+
+static ui_menu_entry_t set_sound_fragment_size_submenu[] = {
+    { N_("*Small"), (ui_callback_t)radio_SoundFragmentSize,
+      (ui_callback_data_t)SOUND_FRAGMENT_SMALL, NULL },
+    { N_("*Medium"), (ui_callback_t)radio_SoundFragmentSize,
+      (ui_callback_data_t)SOUND_FRAGMENT_MEDIUM, NULL },
+    { N_("*Large"), (ui_callback_t)radio_SoundFragmentSize,
+      (ui_callback_data_t)SOUND_FRAGMENT_LARGE, NULL },
     { NULL }
 };
 
@@ -100,18 +110,6 @@ static ui_menu_entry_t set_sound_suspend_time_submenu[] = {
     { NULL }
 };
 
-ui_menu_entry_t set_sound_oversample_submenu [] = {
-    { "*1x",
-      (ui_callback_t)radio_SoundOversample, (ui_callback_data_t)0, NULL },
-    { "*2x",
-      (ui_callback_t)radio_SoundOversample, (ui_callback_data_t)1, NULL },
-    { "*4x",
-      (ui_callback_t)radio_SoundOversample, (ui_callback_data_t)2, NULL },
-    { "*8x",
-      (ui_callback_t)radio_SoundOversample, (ui_callback_data_t)3, NULL },
-    { NULL }
-};
-
 static ui_menu_entry_t set_sound_adjustment_submenu [] = {
     { N_("*Flexible"),
       (ui_callback_t)radio_SoundSpeedAdjustment,
@@ -143,10 +141,10 @@ ui_menu_entry_t sound_settings_submenu[] = {
       NULL, NULL, set_sound_sample_rate_submenu },
     { N_("Buffer size"),
       NULL, NULL, set_sound_buffer_size_submenu },
+    { N_("Fragment size"),
+      NULL, NULL, set_sound_fragment_size_submenu },
     { N_("Suspend time"),
       NULL, NULL, set_sound_suspend_time_submenu },
-    { N_("Oversample"),
-      NULL, NULL, set_sound_oversample_submenu },
     { NULL },
 };
 
@@ -163,18 +161,16 @@ void uisound_menu_create(void)
 
     num = sound_device_num();
 
-    if (num == 0)
+    if (num == 0) {
         return;
+    }
 
-    devices_submenu = (ui_menu_entry_t *)lib_calloc((size_t)(num + 1),
-                      sizeof(ui_menu_entry_t));
+    devices_submenu = lib_calloc((size_t)(num + 1), sizeof(ui_menu_entry_t));
 
     for (i = 0; i < num ; i++) {
-        devices_submenu[i].string =
-            (ui_callback_data_t)lib_msprintf("*%s", sound_device_name(i));
+        devices_submenu[i].string = (ui_callback_data_t)lib_msprintf("*%s", sound_device_name(i));
         devices_submenu[i].callback = (ui_callback_t)radio_SoundDeviceName;
-        devices_submenu[i].callback_data
-            = (ui_callback_data_t)lib_stralloc(sound_device_name(i));
+        devices_submenu[i].callback_data = (ui_callback_data_t)lib_stralloc(sound_device_name(i));
     }
 
     sound_settings_submenu[2].sub_menu = devices_submenu;
@@ -187,8 +183,9 @@ void uisound_menu_shutdown(void)
 
     devices_submenu = sound_settings_submenu[2].sub_menu;
 
-    if (devices_submenu == NULL)
+    if (devices_submenu == NULL) {
         return;
+    }
 
     sound_settings_submenu[2].sub_menu = NULL;
 
@@ -202,4 +199,3 @@ void uisound_menu_shutdown(void)
 
     lib_free(devices_submenu);
 }
-
