@@ -38,6 +38,7 @@
 #include "lib.h"
 #include "machine-video.h"
 #include "resources.h"
+#include "uiapi.h"
 #include "uiattach.h"
 #include "uicommands.h"
 #include "uidatasette.h"
@@ -45,21 +46,23 @@
 #include "uidrivec64vic20.h"
 #include "uidrivevic20.h"
 #include "uikeyboard.h"
+#include "uilib.h"
 #include "uimenu.h"
 #include "uimidi.h"
+#include "uimouse.h"
+#include "uilightpen.h"
 #include "uiperipheraliec.h"
 #include "uiromset.h"
 #include "uirs232.h"
 #include "uirs232user.h"
 #include "uiscreenshot.h"
 #include "uisettings.h"
-#include "uisidcart.h"
+#include "uisid.h"
 #include "uisound.h"
 #include "uivic.h"
 #include "util.h"
 #include "vsync.h"
 
-
 enum {
     MEM_NONE,
     MEM_ALL,
@@ -81,29 +84,29 @@ static UI_CALLBACK(set_common_memory_configuration)
 {
     int blocks;
 
-    switch ((int) UI_MENU_CB_PARAM) {
-      case MEM_NONE:
-        blocks = 0;
-        break;
-      case MEM_ALL:
-        blocks = BLOCK_0 | BLOCK_1 | BLOCK_2 | BLOCK_3 | BLOCK_5;
-        break;
-      case MEM_3K:
-        blocks = BLOCK_0;
-        break;
-      case MEM_8K:
-        blocks = BLOCK_1;
-        break;
-      case MEM_16K:
-        blocks = BLOCK_1 | BLOCK_2;
-        break;
-      case MEM_24K:
-        blocks = BLOCK_1 | BLOCK_2 | BLOCK_3;
-        break;
-      default:
-        /* Shouldn't happen.  */
-        fprintf(stderr, _("What?!\n"));
-        blocks = 0;         /* Make compiler happy.  */
+    switch (vice_ptr_to_int(UI_MENU_CB_PARAM)) {
+        case MEM_NONE:
+            blocks = 0;
+            break;
+        case MEM_ALL:
+            blocks = BLOCK_0 | BLOCK_1 | BLOCK_2 | BLOCK_3 | BLOCK_5;
+            break;
+        case MEM_3K:
+            blocks = BLOCK_0;
+            break;
+        case MEM_8K:
+            blocks = BLOCK_1;
+            break;
+        case MEM_16K:
+            blocks = BLOCK_1 | BLOCK_2;
+            break;
+        case MEM_24K:
+            blocks = BLOCK_1 | BLOCK_2 | BLOCK_3;
+            break;
+        default:
+            /* Shouldn't happen.  */
+            fprintf(stderr, _("What?!\n"));
+            blocks = 0;         /* Make compiler happy.  */
     }
     resources_set_int("RamBlock0", blocks & BLOCK_0 ? 1 : 0);
     resources_set_int("RamBlock1", blocks & BLOCK_1 ? 1 : 0);
@@ -140,10 +143,8 @@ static ui_menu_entry_t sidcart_clock_submenu[] = {
 static ui_menu_entry_t sidcart_submenu[] = {
     { N_("*Enable SID cart"),
       (ui_callback_t)toggle_SidCart, NULL, NULL },
-    { N_("SID engine"),
-      NULL, NULL, sidcart_engine_submenu },
-    { N_("Chip model"),
-      NULL, NULL, sidcart_model_submenu },
+    { N_("SID model"),
+      NULL, NULL, sid_model_noresid_submenu },
     { N_("*Emulate filters"),
       (ui_callback_t)toggle_SidFilters, NULL, NULL },
     { N_("SID address"),
@@ -252,48 +253,35 @@ static ui_menu_entry_t memory_settings_menu[] = {
 
 static UI_CALLBACK(attach_cartridge)
 {
-    int type = (int)UI_MENU_CB_PARAM;
+    int type = vice_ptr_to_int(UI_MENU_CB_PARAM);
     char *filename;
     ui_button_t button;
     static char *last_dir;
+    uilib_file_filter_enum_t filter[] = { UILIB_FILTER_VIC20CART, UILIB_FILTER_ALL };
 
     vsync_suspend_speed_eval();
-    filename = ui_select_file(_("Attach cartridge image"),
-                              NULL, 0, 0, last_dir, "*.prg", &button,
-                              0, NULL, UI_FC_LOAD);
+    filename = ui_select_file(_("Attach cartridge image"), NULL, 0, last_dir, filter, sizeof(filter) / sizeof(*filter), &button, 0, NULL, UI_FC_LOAD);
     switch (button) {
-      case UI_BUTTON_OK:
-        if (cartridge_attach_image(type, filename) < 0)
-            ui_error(_("Invalid cartridge image"));
-        if (last_dir)
+        case UI_BUTTON_OK:
+            if (cartridge_attach_image(type, filename) < 0) {
+                ui_error(_("Invalid cartridge image"));
+            }
             lib_free(last_dir);
-        util_fname_split(filename, &last_dir, NULL);
-        ui_update_menus();
-        break;
-      default:
-        /* Do nothing special.  */
-        break;
+            util_fname_split(filename, &last_dir, NULL);
+            ui_update_menus();
+            break;
+        default:
+            /* Do nothing special.  */
+            break;
     }
-    if (filename != NULL)
-        lib_free(filename);
+    lib_free(filename);
 }
 
-static UI_CALLBACK(detach_cartridge)
-{
-    cartridge_detach_image();
-}
-
-static UI_CALLBACK(default_cartridge)
-{
-    cartridge_set_default();
-}
-
-static ui_menu_entry_t attach_cartridge_image_submenu[] = {
+static ui_menu_entry_t add_to_generic_cart_submenu[] = {
     { N_("Smart-attach cartridge image..."),
       (ui_callback_t)attach_cartridge,
       (ui_callback_data_t)CARTRIDGE_VIC20_DETECT, NULL,
       KEYSYM_c, UI_HOTMOD_META },
-    { "--" },
     { N_("Attach 4/8/16KB image at $2000..."),
       (ui_callback_t)attach_cartridge,
       (ui_callback_data_t)CARTRIDGE_VIC20_16KB_2000, NULL },
@@ -309,17 +297,67 @@ static ui_menu_entry_t attach_cartridge_image_submenu[] = {
     { N_("Attach 4KB image at $B000..."),
       (ui_callback_t)attach_cartridge,
       (ui_callback_data_t)CARTRIDGE_VIC20_4KB_B000, NULL },
+    { NULL }
+};
+
+static UI_CALLBACK(detach_cartridge)
+{
+    cartridge_detach_image();
+}
+
+static UI_CALLBACK(default_cartridge)
+{
+    cartridge_set_default();
+}
+
+static ui_menu_entry_t attach_cartridge_image_submenu[] = {
+    { N_("Attach generic image..."),
+      (ui_callback_t)attach_cartridge,
+      (ui_callback_data_t)CARTRIDGE_VIC20_GENERIC, NULL },
+    { N_("Attach Mega-Cart image..."),
+      (ui_callback_t)attach_cartridge,
+      (ui_callback_data_t)CARTRIDGE_VIC20_MEGACART, NULL },
+    { N_("Attach Final Expansion image..."),
+      (ui_callback_t)attach_cartridge,
+      (ui_callback_data_t)CARTRIDGE_VIC20_FINAL_EXPANSION, NULL },
+    { "--" },
+    { N_("Add to generic cartridge"),
+      NULL, NULL, add_to_generic_cart_submenu },
     { "--" },
     { N_("Set cartridge as default"),
       (ui_callback_t)default_cartridge, NULL, NULL },
     { NULL }
 };
 
+UI_MENU_DEFINE_TOGGLE(CartridgeReset)
+UI_MENU_DEFINE_TOGGLE(FinalExpansionWriteBack)
+UI_MENU_DEFINE_TOGGLE(MegaCartNvRAMWriteBack)
+
+UI_CALLBACK(set_mc_nvram_image_name)
+{
+    uilib_select_string((char *)UI_MENU_CB_PARAM, _("Mega-Cart NvRAM image name"), _("Name:"));
+}
+
+static ui_menu_entry_t cartridge_options_submenu[] = {
+    { N_("*Reset on cartridge change"),
+      (ui_callback_t)toggle_CartridgeReset, NULL, NULL },
+    { N_("*Final Expansion write back"),
+      (ui_callback_t)toggle_FinalExpansionWriteBack, NULL, NULL },
+    { N_("*Mega-Cart NvRAM write back"),
+      (ui_callback_t)toggle_MegaCartNvRAMWriteBack, NULL, NULL },
+    { N_("Mega-Cart NvRAM file..."),
+      (ui_callback_t)set_mc_nvram_image_name,
+      (ui_callback_data_t)"MegaCartNvRAMfilename", NULL },
+    { NULL }
+};
+
 static ui_menu_entry_t vic20_cartridge_commands_menu[] = {
     { N_("Attach a cartridge image"),
       NULL, NULL, attach_cartridge_image_submenu },
     { N_("Detach cartridge image(s)"),
       (ui_callback_t)detach_cartridge, NULL, NULL },
+    { N_("Cartridge options"),
+      NULL, NULL, cartridge_options_submenu },
     { NULL }
 };
 
@@ -330,13 +368,13 @@ static UI_CALLBACK(set_joystick_device)
 {
     vsync_suspend_speed_eval();
     if (!CHECK_MENUS) {
-        resources_set_int("JoyDevice1", (int)UI_MENU_CB_PARAM);
+        resources_set_int("JoyDevice1", vice_ptr_to_int(UI_MENU_CB_PARAM));
         ui_update_menus();
     } else {
         int tmp;
 
         resources_get_int("JoyDevice1", &tmp);
-        ui_menu_set_tick(w, tmp == (int)UI_MENU_CB_PARAM);
+        ui_menu_set_tick(w, tmp == vice_ptr_to_int(UI_MENU_CB_PARAM));
     }
 }
 
@@ -424,37 +462,20 @@ static ui_menu_entry_t rs232_settings_menu[] = {
 
 /*------------------------------------------------------------*/
 
-/*
-UI_MENU_DEFINE_TOGGLE(IEEE488)
-
-static ui_menu_entry_t vic20_io_submenu[] = {
-    { "*VIC-1112 IEEE 488 module",
-      (ui_callback_t)toggle_IEEE488, NULL, NULL },
-    { NULL }
-};
-
-static ui_menu_entry_t vic20_io_settings_menu[] = {
-    { "I/O settings",
-      NULL, NULL, vic20_io_submenu },
-    { NULL }
-};
-*/
-
-/*------------------------------------------------------------*/
-
 static UI_CALLBACK(save_screenshot)
 {
     /* Where does the 1024 come from?  */
     char filename[1024];
-    unsigned int wid = (unsigned int)UI_MENU_CB_PARAM;
+    unsigned int wid = vice_ptr_to_uint(UI_MENU_CB_PARAM);
 
     vsync_suspend_speed_eval();
 
     /* The following code depends on a zeroed filename.  */
     memset(filename, 0, 1024);
 
-    if (ui_screenshot_dialog(filename, machine_video_canvas_get(wid)) < 0)
+    if (ui_screenshot_dialog(filename, machine_video_canvas_get(wid)) < 0) {
         return;
+    }
 }
 
 static ui_menu_entry_t ui_screenshot_commands_menu[] = {
@@ -470,6 +491,12 @@ static ui_menu_entry_t vic20_menu[] = {
       NULL, NULL, memory_settings_submenu },
     { N_("SID cartridge settings"),
       NULL, NULL, sidcart_submenu },
+    { N_("Paddle emulation"),
+      NULL, NULL, mouse_vic20_submenu },
+#if defined(HAVE_MOUSE) && defined(USE_GNOMEUI)
+    { N_("*Lightpen Emulation"),
+      NULL, NULL, lightpen_submenu },
+#endif
 #ifdef HAVE_MIDI
     { N_("MIDI emulation"),
       NULL, NULL, midi_vic20_submenu },
@@ -518,9 +545,6 @@ static ui_menu_entry_t vic20_right_menu[] = {
       NULL, NULL, ui_drivevic20_settings_menu },
     { "",
       NULL, NULL, ui_peripheraliec_settings_menu },
-/*
-                                     vic20_io_settings_menu,
-*/
     { "",
       NULL, NULL, joystick_settings_menu },
     { "",
@@ -652,4 +676,3 @@ void vic20ui_shutdown(void)
 {
     vic20ui_dynamic_menu_shutdown();
 }
-
