@@ -24,13 +24,15 @@
  *
  */
 
-#import "vicemachinecontroller.h"
+#import "cbm2controller.h"
+#import "cbm2machinecontroller.h"
 #import "vicemachine.h"
 
 int cbm2ui_init(void)
 {
-    // TODO: use CBM2MachineController
-    [theVICEMachine setMachineController:[[VICEMachineController alloc] init]];
+    // ensure that the CBM2Controller gets compiled in
+    [CBM2Controller class];
+    [theVICEMachine setMachineController:[[CBM2MachineController alloc] init]];
     return 0;
 }
 
