@@ -25,11 +25,13 @@
  */
 
 #import <Cocoa/Cocoa.h>
+
 #import "drivesettingswindowcontroller.h"
 #import "iecdrivesettingswindowcontroller.h"
 #import "printersettingswindowcontroller.h"
 #import "keyboardsettingswindowcontroller.h"
 #import "joysticksettingswindowcontroller.h"
+#import "sidsettingswindowcontroller.h"
 #import "soundsettingswindowcontroller.h"
 #import "videosettingswindowcontroller.h"
 
@@ -39,6 +41,8 @@
 #import "recordmediawindowcontroller.h"
 #import "netplaycontrolwindowcontroller.h"
 
+#import "vicefilepanel.h"
+
 @interface VICEAppController : NSObject
 {
     // Dialog Controllers
@@ -47,6 +51,7 @@
     PrinterSettingsWindowController *printerSettingsController;
     KeyboardSettingsWindowController *keyboardSettingsController;
     JoystickSettingsWindowController *joystickSettingsController;
+    SIDSettingsWindowController *sidSettingsController;
     SoundSettingsWindowController *soundSettingsController;
     VideoSettingsWindowController *videoSettingsController;
 
@@ -56,6 +61,8 @@
     RecordMediaWindowController *recordMediaController;
     NetplayControlWindowController *netplayController;
     
+    VICEFilePanel *filePanel;
+    
     // Options Outlets
     IBOutlet NSMenu *refreshRateMenu;
     IBOutlet NSMenu *maximumSpeedMenu;
@@ -68,10 +75,28 @@
     IBOutlet NSMenuItem *virtualDevicesMenuItem;
     IBOutlet NSMenuItem *emuIDMenuItem;
     IBOutlet NSMenuItem *keySetEnableMenuItem;
+
+    IBOutlet NSMenuItem *mouseEmulationMenuItem;  // opt
+    IBOutlet NSMenuItem *lightPenEmulationMenuItem; // opt
     
     // Settings Outlets
     IBOutlet NSMenuItem *saveResourcesOnExitMenuItem;
     IBOutlet NSMenuItem *confirmOnExitMenuItem;
+
+    // Video 0
+    IBOutlet NSMenu     *video0Menu;
+    IBOutlet NSMenuItem *video0VideoCacheMenuItem;
+    IBOutlet NSMenuItem *video0DoubleSizeMenuItem;
+    IBOutlet NSMenuItem *video0DoubleScanMenuItem;
+    IBOutlet NSMenuItem *video0Scale2xMenuItem;
+    IBOutlet NSMenuItem *palEmulationMenuItem;
+
+    // Video 1
+    IBOutlet NSMenu     *video1Menu;
+    IBOutlet NSMenuItem *video1VideoCacheMenuItem;
+    IBOutlet NSMenuItem *video1DoubleSizeMenuItem;
+    IBOutlet NSMenuItem *video1DoubleScanMenuItem;
+    IBOutlet NSMenuItem *video1Scale2xMenuItem;
 }
 
 // File
@@ -124,6 +149,22 @@
 - (IBAction)toggleKeySetEnable:(id)sender;
 - (IBAction)toggleEmuID:(id)sender;
 
+- (IBAction)toggleMouseEmulation:(id)sender;
+- (IBAction)toggleLightPenEmulation:(id)sender;
+
+// Video
+- (IBAction)toggleVideo0VideoCache:(id)sender;
+- (IBAction)toggleVideo0DoubleSize:(id)sender;
+- (IBAction)toggleVideo0DoubleScan:(id)sender;
+- (IBAction)toggleVideo0Scale2x:(id)sender;
+
+- (IBAction)toggleVideo1VideoCache:(id)sender;
+- (IBAction)toggleVideo1DoubleSize:(id)sender;
+- (IBAction)toggleVideo1DoubleScan:(id)sender;
+- (IBAction)toggleVideo1Scale2x:(id)sender;
+
+- (IBAction)togglePALEmulation:(id)sender;
+
 // Settings
 - (IBAction)showDriveSettings:(id)sender;
 - (IBAction)showIECDriveSettings:(id)sender;
@@ -131,6 +172,7 @@
 - (IBAction)showKeyboardSettings:(id)sender;
 - (IBAction)showJoystickSettings:(id)sender;
 - (IBAction)showSoundSettings:(id)sender;
+- (IBAction)showSIDSettings:(id)sender;
 - (IBAction)showVideoSettings:(id)sender;
 
 // Resources
@@ -145,9 +187,7 @@
 - (IBAction)showInformation:(id)sender;
 
 // Tools
-- (NSString *)pickOpenFileWithTitle:(NSString *)title types:(NSArray *)types;
-- (NSString *)pickSaveFileWithTitle:(NSString *)title types:(NSArray *)types;
-- (NSString *)pickDirectoryWithTitle:(NSString *)title;
+- (VICEFilePanel *)getFilePanel;
 
 - (void)attachDiskImageForUnit:(int)unit;
 
@@ -155,6 +195,8 @@
 - (void)updateSettingsResources;
 - (void)updateOptionsResources;
 - (void)updateMachineResources;
+- (void)updateVideo0Resources;
+- (void)updateVideo1Resources;
 
 - (BOOL)updateSubMenuCheckState:(NSMenu *)menu withTag:(int)tagValue;
 
