@@ -44,15 +44,22 @@
 
 -(void)dealloc
 {
-    // release dialog controllers
     [driveSettingsController release];
     [iecDriveSettingsController release];
     [printerSettingsController release];
     [keyboardSettingsController release];
     [joystickSettingsController release];
+    [sidSettingsController release];
     [soundSettingsController release];
+    [videoSettingsController release];
+    
     [infoController release];
     [resourceEditorController release];
+    [recordHistoryController release];
+    [recordMediaController release];
+    [netplayController release];
+    
+    [filePanel release];
     
     [super dealloc];
 }
@@ -89,9 +96,14 @@
 
 - (IBAction)smartAttachImage:(id)sender
 {
-    NSString *path = [self pickOpenFileWithTitle:@"Smart Attach Image" types:nil];
-    if(path!=nil) {
-        if(![[VICEApplication theMachineController] smartAttachImage:path])
+    NSString *path = [[self getFilePanel] pickOpenFileWithPreviewAndType:@"CBMImage" allowRun:YES];
+    if (path!=nil) {
+        int progNum = [filePanel selectedProgNum];
+        BOOL doRun  = [filePanel selectedAutostart];
+        if (![[VICEApplication theMachineController] 
+                smartAttachImage:path 
+                     withProgNum:progNum
+                          andRun:doRun])
             [VICEApplication runErrorMessage:@"Error attaching image!"];
     }
 }
@@ -104,11 +116,9 @@
 
 - (void)attachDiskImageForUnit:(int)unit
 {    
-    NSArray *types = [NSArray arrayWithObjects:
-      @"d64", @"d67", @"d71", @"d80", @"d81", @"d82", @"g64", @"x64", nil];
-    NSString *path = [self pickOpenFileWithTitle:@"Attach Disk Image" types:types];
-    if(path!=nil) {
-        if(![[VICEApplication theMachineController] attachDiskImage:unit 
+    NSString *path = [[self getFilePanel] pickOpenFileWithPreviewAndType:@"DiskImage" allowRun:NO];
+    if (path!=nil) {
+        if (![[VICEApplication theMachineController] attachDiskImage:unit 
                                                                path:path]) {
             [VICEApplication runErrorMessage:@"Error attaching image!"];
         }
@@ -159,18 +169,18 @@
     [panel setTitle:@"Create Disk Image"];
     [panel setPrompt:@"Create"];
 
-    if ([panel runModalForDirectory:nil file:nil] == NSOKButton) {
+    if ([panel runModal] == NSFileHandlingPanelOKButton) {
         int type = [type_button indexOfSelectedItem];
         NSString * path = [[panel filename] stringByAppendingPathExtension:[extensions objectAtIndex:type]];
 
-        if(![[VICEApplication theMachineController] 
+        if (![[VICEApplication theMachineController] 
                     createDiskImage:type
                                path:path
                                name:[name_entry stringValue]]) {
             [VICEApplication runErrorMessage:@"Error creating image!"];
         } else {
             int unit = [sender tag];
-            if(![[VICEApplication theMachineController] attachDiskImage:unit 
+            if (![[VICEApplication theMachineController] attachDiskImage:unit 
                                                                    path:path]) {
                 [VICEApplication runErrorMessage:@"Error attaching image!"];
             }
@@ -214,10 +224,9 @@
 - (IBAction)fliplistLoad:(id)sender
 {
     int unit = [sender tag];
-    NSArray *types = [NSArray arrayWithObject:@"vfl"];
-    NSString *path = [self pickOpenFileWithTitle:@"Loading Fliplist" types:types];
-    if(path!=nil) {
-        if(![[VICEApplication theMachineController] loadFliplist:unit path:path autoAttach:TRUE])
+    NSString *path = [[self getFilePanel] pickOpenFileWithType:@"FlipList"];
+    if (path!=nil) {
+        if (![[VICEApplication theMachineController] loadFliplist:unit path:path autoAttach:TRUE])
             [VICEApplication runErrorMessage:@"Error loading fliplist!"];
     }
 }
@@ -225,10 +234,9 @@
 - (IBAction)fliplistSave:(id)sender
 {
     int unit = [sender tag];
-    NSArray *types = [NSArray arrayWithObject:@"vfl"];
-    NSString *path = [self pickSaveFileWithTitle:@"Saving Fliplist" types:types];
-    if(path!=nil) {
-        if(![[VICEApplication theMachineController] saveFliplist:unit path:path])
+    NSString *path = [[self getFilePanel] pickSaveFileWithType:@"FlipList"];
+    if (path!=nil) {
+        if (![[VICEApplication theMachineController] saveFliplist:unit path:path])
             [VICEApplication runErrorMessage:@"Error saving fliplist!"];
     }
 }
@@ -237,9 +245,8 @@
 
 - (IBAction)attachTapeImage:(id)sender
 {
-    NSArray *types = [NSArray arrayWithObjects:@"t64",@"tap",nil];
-    NSString *path = [self pickOpenFileWithTitle:@"Open Tape Image" types:types];
-    if(path!=nil) {
+    NSString *path = [[self getFilePanel] pickOpenFileWithPreviewAndType:@"TapeImage" allowRun:NO];
+    if (path!=nil) {
         [[VICEApplication theMachineController] attachTapeImage:path];
     }
 }
@@ -253,9 +260,8 @@
 
 - (IBAction)loadSnapshot:(id)sender
 {
-    NSArray *types = [NSArray arrayWithObject:@"vsf"];
-    NSString *path = [self pickOpenFileWithTitle:@"Load Snapshot" types:types];
-    if(path!=nil) {
+    NSString *path = [[self getFilePanel] pickOpenFileWithType:@"Snapshot"];
+    if (path!=nil) {
         [[VICEApplication theMachineController] loadSnapshot:path];
     }
 }
@@ -286,11 +292,11 @@
     [panel setTitle:@"Save Snapshot"];
     [panel setAllowedFileTypes:types];
 
-    if ([panel runModalForDirectory:nil file:nil] == NSOKButton) {
+    if ([panel runModal] == NSFileHandlingPanelOKButton) {
         BOOL saveRoms  = ([saveRomsCheck state] == NSOnState);
         BOOL saveDisks = ([saveDisksCheck state] == NSOnState);
         NSString * path = [panel filename];
-        if(path!=nil) {
+        if (path!=nil) {
             [[VICEApplication theMachineController] saveSnapshot:path withROMS:saveRoms andDisks:saveDisks];
         }
     }
@@ -309,7 +315,7 @@
 
 - (IBAction)showRecordHistory:(id)sender
 {
-    if(!recordHistoryController) {
+    if (!recordHistoryController) {
         recordHistoryController = [[RecordHistoryWindowController alloc] init];
     }
     [recordHistoryController showWindow:self];
@@ -317,7 +323,7 @@
 
 - (IBAction)showRecordMedia:(id)sender
 {
-    if(!recordMediaController) {
+    if (!recordMediaController) {
         recordMediaController = [[RecordMediaWindowController alloc] init];
     }
     [recordMediaController showWindow:self];
@@ -325,7 +331,7 @@
 
 - (IBAction)showNetplay:(id)sender
 {
-    if(!netplayController) {
+    if (!netplayController) {
         netplayController = [[NetplayControlWindowController alloc] init];
     }
     [netplayController showWindow:self];
@@ -406,11 +412,98 @@
     [self updateOptionsResources];
 }
 
+// Mouse
+
+- (IBAction)toggleMouseEmulation:(id)sender
+{
+    [self setIntResource:@"Mouse" toValue:![sender state]];
+    [self updateOptionsResources];
+}
+
+- (IBAction)toggleLightPenEmulation:(id)sender
+{
+    int state = ![sender state];
+    [self setIntResource:@"Lightpen" toValue:state];
+    [self updateOptionsResources];
+    
+    // directly post a notification here as lightpen driver has no callback
+    NSDictionary * dict =
+        [NSDictionary dictionaryWithObject:[NSNumber numberWithInt:state]
+                                    forKey: @"lightpen"];
+    [[NSNotificationCenter defaultCenter] postNotificationName:VICEToggleLightpenNotification
+                                                        object:self
+                                                      userInfo:dict];
+}
+
+// Video Rendering
+
+- (IBAction)toggleVideo0VideoCache:(id)sender
+{
+    NSString *res = [NSString stringWithFormat:@"%@VideoCache", [video0Menu title]];
+    [self setIntResource:res toValue:![sender state]];
+    [self updateVideo0Resources];
+}
+
+- (IBAction)toggleVideo0DoubleSize:(id)sender
+{
+    NSString *res = [NSString stringWithFormat:@"%@DoubleSize", [video0Menu title]];
+    [self setIntResource:res toValue:![sender state]];
+    [self updateVideo0Resources];
+}
+
+- (IBAction)toggleVideo0DoubleScan:(id)sender
+{
+    NSString *res = [NSString stringWithFormat:@"%@DoubleScan", [video0Menu title]];
+    [self setIntResource:res toValue:![sender state]];
+    [self updateVideo0Resources];
+}
+
+- (IBAction)toggleVideo0Scale2x:(id)sender
+{
+    NSString *res = [NSString stringWithFormat:@"%@Scale2x", [video0Menu title]];
+    [self setIntResource:res toValue:![sender state]];
+    [self updateVideo0Resources];
+}
+
+- (IBAction)toggleVideo1VideoCache:(id)sender
+{
+    NSString *res = [NSString stringWithFormat:@"%@VideoCache", [video1Menu title]];
+    [self setIntResource:res toValue:![sender state]];
+    [self updateVideo1Resources];
+}
+
+- (IBAction)toggleVideo1DoubleSize:(id)sender
+{
+    NSString *res = [NSString stringWithFormat:@"%@DoubleSize", [video1Menu title]];
+    [self setIntResource:res toValue:![sender state]];
+    [self updateVideo1Resources];
+}
+
+- (IBAction)toggleVideo1DoubleScan:(id)sender
+{
+    NSString *res = [NSString stringWithFormat:@"%@DoubleScan", [video1Menu title]];
+    [self setIntResource:res toValue:![sender state]];
+    [self updateVideo1Resources];
+}
+
+- (IBAction)toggleVideo1Scale2x:(id)sender
+{
+    NSString *res = [NSString stringWithFormat:@"%@Scale2x", [video1Menu title]];
+    [self setIntResource:res toValue:![sender state]];
+    [self updateVideo1Resources];
+}
+
+- (IBAction)togglePALEmulation:(id)sender
+{
+    [self setIntResource:@"PALEmulation" toValue:![sender state]];
+    [self updateVideo0Resources];
+}
+
 // ----- Settings -----
 
 - (IBAction)showDriveSettings:(id)sender
 {
-    if(!driveSettingsController) {
+    if (!driveSettingsController) {
         driveSettingsController = [[DriveSettingsWindowController alloc] init];
     }
     [driveSettingsController showWindow:self];
@@ -418,7 +511,7 @@
 
 - (IBAction)showIECDriveSettings:(id)sender
 {
-    if(!iecDriveSettingsController) {
+    if (!iecDriveSettingsController) {
         iecDriveSettingsController = [[IECDriveSettingsWindowController alloc] init];
     }
     [iecDriveSettingsController showWindow:self];
@@ -426,7 +519,7 @@
 
 - (IBAction)showPrinterSettings:(id)sender
 {
-    if(!printerSettingsController) {
+    if (!printerSettingsController) {
         printerSettingsController = [[PrinterSettingsWindowController alloc] init];
     }
     [printerSettingsController showWindow:self];
@@ -434,7 +527,7 @@
 
 - (IBAction)showKeyboardSettings:(id)sender
 {
-    if(!keyboardSettingsController) {
+    if (!keyboardSettingsController) {
         keyboardSettingsController = [[KeyboardSettingsWindowController alloc] init];
     }
     [keyboardSettingsController showWindow:self];
@@ -443,16 +536,24 @@
 - (IBAction)showJoystickSettings:(id)sender
 {
 #ifdef HAS_JOYSTICK
-    if(!joystickSettingsController) {
+    if (!joystickSettingsController) {
         joystickSettingsController = [[JoystickSettingsWindowController alloc] init];
     }
     [joystickSettingsController showWindow:self];
 #endif
 }
 
+- (IBAction)showSIDSettings:(id)sender
+{
+    if (!sidSettingsController) {
+        sidSettingsController = [[SIDSettingsWindowController alloc] init];
+    }
+    [sidSettingsController showWindow:self];
+}
+
 - (IBAction)showSoundSettings:(id)sender
 {
-    if(!soundSettingsController) {
+    if (!soundSettingsController) {
         soundSettingsController = [[SoundSettingsWindowController alloc] init];
     }
     [soundSettingsController showWindow:self];
@@ -460,7 +561,7 @@
 
 - (IBAction)showVideoSettings:(id)sender
 {
-    if(!videoSettingsController) {
+    if (!videoSettingsController) {
         videoSettingsController = [[VideoSettingsWindowController alloc] init];
     }
     [videoSettingsController showWindow:self];
@@ -470,7 +571,7 @@
 
 - (IBAction)showResourceEditor:(id)sender
 {
-    if(!resourceEditorController) {
+    if (!resourceEditorController) {
         resourceEditorController = [[ResourceEditorController alloc] init];
     }
     [resourceEditorController showWindow:self];
@@ -478,14 +579,14 @@
 
 - (IBAction)saveResources:(id)sender
 {
-    if(![[VICEApplication theMachineController] saveResources:nil]) {
+    if (![[VICEApplication theMachineController] saveResources:nil]) {
         [VICEApplication runErrorMessage:@"Error saving Resources!"];
     }
 }
 
 - (IBAction)loadResources:(id)sender
 {
-    if(![[VICEApplication theMachineController] loadResources:nil]) {
+    if (![[VICEApplication theMachineController] loadResources:nil]) {
         [VICEApplication runErrorMessage:@"Error loading Resources!"];
     };
 }
@@ -518,11 +619,11 @@
     };
     const char *info = tag2text[[sender tag]];
 
-    if(!infoController) {
+    if (!infoController) {
         infoController = [[VICEInformationWindowController alloc] init];
     }
     [infoController showWindow:self];
-    [infoController setInformationText:[NSString stringWithCString:info]];
+    [infoController setInformationText:[NSString stringWithCString:info encoding:NSUTF8StringEncoding]];
 }
 
 // ----- Resource Updates -----
@@ -532,6 +633,12 @@
     [self updateMachineResources];
     [self updateOptionsResources];
     [self updateSettingsResources];
+    if(video0Menu != nil) {
+        [self updateVideo0Resources];
+    }
+    if(video1Menu != nil) {
+        [self updateVideo1Resources];
+    }
 }
 
 - (void)updateMachineResources
@@ -543,11 +650,11 @@
     int numItems = [menu numberOfItems];
     int i;
     BOOL foundTag = NO;
-    for(i=0;i<numItems;i++) {
+    for (i=0;i<numItems;i++) {
         NSMenuItem *item = [menu itemAtIndex:i];
         BOOL check = ([item tag] == tagValue);
         [item setState:check ? NSOnState : NSOffState];
-        if(check)
+        if (check)
             foundTag = YES;
     }
     return foundTag;
@@ -569,8 +676,10 @@
     [warpModeMenuItem setState:[self getIntResource:@"WarpMode"]];
     
     // Machine Video Standard
-    [self updateSubMenuCheckState:machineVideoStandardMenu 
-        withTag:[self getIntResource:@"MachineVideoStandard"]];
+    if(machineVideoStandardMenu != nil) {
+        [self updateSubMenuCheckState:machineVideoStandardMenu 
+            withTag:[self getIntResource:@"MachineVideoStandard"]];
+    }
     
     // Sound
     [soundPlaybackMenuItem setState:[self getIntResource:@"Sound"]];
@@ -579,9 +688,58 @@
     // VirtaulDevices
     [virtualDevicesMenuItem setState:[self getIntResource:@"VirtualDevices"]];
     // EmuID
-    [emuIDMenuItem setState:[self getIntResource:@"EmuID"]];
+    if(emuIDMenuItem != nil) {
+        [emuIDMenuItem setState:[self getIntResource:@"EmuID"]];
+    }
     // KeySetEnable
     [keySetEnableMenuItem setState:[self getIntResource:@"KeySetEnable"]];
+
+    // Mouse
+    if(mouseEmulationMenuItem != nil) {
+        [mouseEmulationMenuItem setState:[self getIntResource:@"Mouse"]];
+    }
+    // Lightpen
+    if(lightPenEmulationMenuItem != nil) {
+        [lightPenEmulationMenuItem setState:[self getIntResource:@"LightPen"]];
+    }
+}
+
+- (void)updateVideo0Resources
+{
+    NSString *name = [video0Menu title];
+    
+    NSString *res1 = [NSString stringWithFormat:@"%@VideoCache", name];    
+    [video0VideoCacheMenuItem setState:[self getIntResource:res1]];
+
+    NSString *res2 = [NSString stringWithFormat:@"%@DoubleSize", name];    
+    [video0DoubleSizeMenuItem setState:[self getIntResource:res2]];
+    
+    NSString *res3 = [NSString stringWithFormat:@"%@DoubleScan", name];        
+    [video0DoubleScanMenuItem setState:[self getIntResource:res3]];
+    
+    NSString *res4 = [NSString stringWithFormat:@"%@Scale2x", name];    
+    [video0Scale2xMenuItem setState:[self getIntResource:res4]];
+    
+    if(palEmulationMenuItem != nil) {
+        [palEmulationMenuItem setState:[self getIntResource:@"PALEmulation"]];
+    }
+}
+
+- (void)updateVideo1Resources
+{
+    NSString *name = [video1Menu title];
+    
+    NSString *res1 = [NSString stringWithFormat:@"%@VideoCache", name];    
+    [video1VideoCacheMenuItem setState:[self getIntResource:res1]];
+
+    NSString *res2 = [NSString stringWithFormat:@"%@DoubleSize", name];    
+    [video1DoubleSizeMenuItem setState:[self getIntResource:res2]];
+    
+    NSString *res3 = [NSString stringWithFormat:@"%@DoubleScan", name];        
+    [video1DoubleScanMenuItem setState:[self getIntResource:res3]];
+    
+    NSString *res4 = [NSString stringWithFormat:@"%@Scale2x", name];    
+    [video1Scale2xMenuItem setState:[self getIntResource:res4]];
 }
 
 - (void)updateSettingsResources
@@ -597,47 +755,12 @@
 
 // ----- Tools -----
 
-- (NSString *)pickOpenFileWithTitle:(NSString *)title types:(NSArray *)types
+- (VICEFilePanel *)getFilePanel
 {
-    NSOpenPanel *panel = [NSOpenPanel openPanel];
-    [panel setAllowsMultipleSelection:NO];
-    [panel setCanChooseFiles:YES];
-    [panel setCanChooseDirectories:NO];
-    [panel setTitle:title];    
-    
-    int result = [panel runModalForDirectory:nil file:nil types:types];
-    if(result==NSOKButton) {
-        return [panel filename];
-    }    
-    return nil;
-}
-
-- (NSString *)pickSaveFileWithTitle:(NSString *)title types:(NSArray *)types
-{
-    NSSavePanel *panel = [NSSavePanel savePanel];
-    [panel setTitle:title];    
-    [panel setAllowedFileTypes:types];
-    
-    int result = [panel runModalForDirectory:nil file:nil];
-    if(result==NSOKButton) {
-        return [panel filename];
-    }    
-    return nil;
-}
-
-- (NSString *)pickDirectoryWithTitle:(NSString *)title
-{
-    NSOpenPanel *panel = [NSOpenPanel openPanel];
-    [panel setAllowsMultipleSelection:NO];
-    [panel setCanChooseFiles:NO];
-    [panel setCanChooseDirectories:YES];
-    [panel setTitle:title];    
-    
-    int result = [panel runModalForDirectory:nil file:nil types:nil];
-    if(result==NSOKButton) {
-        return [panel filename];
-    }    
-    return nil;
+    if(filePanel == nil) {
+        filePanel = [[VICEFilePanel alloc] init];
+    }
+    return filePanel;
 }
 
 - (BOOL)setIntResource:(NSString *)name toValue:(int)value
@@ -651,7 +774,7 @@
 {
     NSNumber *number = [[VICEApplication theMachineController]
         getIntResource:name];
-    if(number==nil)
+    if (number==nil)
         return 0;
     return [number intValue];
 }
