@@ -95,7 +95,7 @@
 // enumerate media
 -(NSArray *)enumMediaDrivers;
 // has driver container
--(BOOL)mediaDriverHasOptions:(NSString *)driver;
+-(BOOL)mediaDriverHasFormats:(NSString *)driver;
 // enumerate media formats
 -(NSArray *)enumMediaFormats:(NSString *)driver;
 // extension for media 
@@ -109,17 +109,17 @@
 // dump keymap
 -(BOOL)dumpKeymap:(NSString *)path;
 
-// ----- Mouse -----
+// ----- Mouse & Lightpen -----
 // mouse moved
--(void)mouseMoveToX:(int)deltaX andY:(int)deltaY;
+-(void)mouseMoveToX:(int)x andY:(int)y;
 // mouse pressed
--(void)mousePressed;
-// mouse release
--(void)mouseReleased;
+-(void)mouseButton:(BOOL)left withState:(BOOL)pressed;
+// lightpen update
+-(void)lightpenUpdateOnScreen:(int)screen toX:(int)x andY:(int)y withButton1:(BOOL)b1 andButton2:(BOOL)b2;
 
 // ----- Drive Commands -----
 // disk image
--(BOOL)smartAttachImage:(NSString *)path;
+-(BOOL)smartAttachImage:(NSString *)path withProgNum:(int)num andRun:(BOOL)run;
 // attach disk image
 -(BOOL)attachDiskImage:(int)unit path:(NSString *)path;
 // detach disk image
@@ -170,5 +170,11 @@
 //! netplay mode (see network.h: network_mode_t)
 -(int)getNetplayMode;
 
+// ----- ImageContents -----
+//! get disk image contents
+-(NSDictionary *)diskimageContents:(NSString *)path;
+//! get tape image contents
+-(NSDictionary *)tapeimageContents:(NSString *)path;
+
 @end
 
