@@ -34,6 +34,7 @@
 #include "keyboard.h"
 #include "diskimage.h"
 #include "mousedrv.h"
+#include "lightpen.h"
 #include "printer.h"
 #include "archdep.h"
 #include "log.h"
@@ -46,10 +47,12 @@
 #include "clipboard.h"
 #include "datasette.h"
 #include "vdrive-internal.h"
-#include "gfxoutputdrv/ffmpegdrv.h"
 #include "fliplist.h"
 #include "network.h"
 #include "event.h"
+#include "imagecontents/diskcontents.h"
+#include "imagecontents/tapecontents.h"
+#include "imagecontents.h"
 
 #import "vicemachinecontroller.h"
 #import "vicemachine.h"
@@ -65,14 +68,14 @@
 {
     NSFileManager *fileManager = [NSFileManager defaultManager];
     NSString *prefPath = [NSString stringWithCString:archdep_pref_path encoding:NSUTF8StringEncoding];
-    if(![fileManager fileExistsAtPath:prefPath]) {
-        if(![fileManager createDirectoryAtPath:prefPath attributes:nil]) {
+    if (![fileManager fileExistsAtPath:prefPath]) {
+        if (![fileManager createDirectoryAtPath:prefPath attributes:nil]) {
             [[theVICEMachine app] runErrorMessage:@"Error creating Preferences Dir"];
             return nil;
         }
     }
     BOOL isDir;
-    if([fileManager fileExistsAtPath:prefPath isDirectory:&isDir] && isDir) {
+    if ([fileManager fileExistsAtPath:prefPath isDirectory:&isDir] && isDir) {
         return prefPath;
     }
     [[theVICEMachine app] runErrorMessage:@"Invalid Preferences Dir"];
@@ -84,7 +87,7 @@
 -(NSNumber *)getIntResource:(NSString *)name
 {
     int value;
-    if(resources_get_int([name cStringUsingEncoding:NSUTF8StringEncoding],&value)==0) {
+    if (resources_get_int([name cStringUsingEncoding:NSUTF8StringEncoding],&value)==0) {
         return [NSNumber numberWithInt:value];
     }
     return nil;
@@ -92,9 +95,13 @@
 
 -(NSString *)getStringResource:(NSString *)name
 {
-    const char *value;
-    if(resources_get_string([name cStringUsingEncoding:NSUTF8StringEncoding],&value)==0) {
-        return [NSString stringWithCString:value encoding:NSUTF8StringEncoding];
+    const char *value = NULL;
+    if (resources_get_string([name cStringUsingEncoding:NSUTF8StringEncoding],&value)==0) {
+        if(value != NULL) {
+            return [NSString stringWithCString:value encoding:NSUTF8StringEncoding];
+        } else {
+            return nil;
+        }
     }
     return nil;
 }
@@ -114,7 +121,7 @@
 -(BOOL)loadResources:(NSString *)path
 {
     const char *cPath;
-    if(path==nil)
+    if (path==nil)
         cPath = NULL;
     else
         cPath = [path fileSystemRepresentation];
@@ -130,7 +137,7 @@
 -(BOOL)saveResources:(NSString *)path
 {
     const char *cPath;
-    if(path==nil)
+    if (path==nil)
         cPath = NULL;
     else
         cPath = [path fileSystemRepresentation];
@@ -150,7 +157,7 @@
 
 -(void)resetMachine:(BOOL)hardReset
 {
-    if(hardReset)
+    if (hardReset)
         machine_trigger_reset(MACHINE_RESET_MODE_HARD);
     else
         machine_trigger_reset(MACHINE_RESET_MODE_SOFT);
@@ -165,7 +172,7 @@
 
 -(void)activateMonitor
 {
-    if([theVICEMachine isPaused])
+    if ([theVICEMachine isPaused])
         monitor_startup();
     else
         monitor_startup_trap();
@@ -189,7 +196,7 @@ static void loadSnapshotTrap(WORD unusedWord, void *unusedData)
 
 static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
 {
-    if(machine_write_snapshot(snapshotName, snapshotSaveRoms, snapshotSaveDisks, 0) < 0) {
+    if (machine_write_snapshot(snapshotName, snapshotSaveRoms, snapshotSaveDisks, 0) < 0) {
         [[theVICEMachine app] runErrorMessage:@"Error saving Snapshot!"];        
     } else {
         log_message(LOG_DEFAULT,"saved snapshot '%s'",snapshotName);
@@ -200,7 +207,7 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
 -(void)loadSnapshot:(NSString *)path
 {
     snapshotName = strdup([path fileSystemRepresentation]);
-    if([theVICEMachine isPaused])
+    if ([theVICEMachine isPaused])
         loadSnapshotTrap(0,NULL);
     else
         interrupt_maincpu_trigger_trap(loadSnapshotTrap, NULL);
@@ -211,7 +218,7 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
     snapshotName = strdup([path fileSystemRepresentation]);
     snapshotSaveRoms = saveRoms;
     snapshotSaveDisks = saveDisks;
-    if([theVICEMachine isPaused])
+    if ([theVICEMachine isPaused])
         saveSnapshotTrap(0,NULL);
     else
         interrupt_maincpu_trigger_trap(saveSnapshotTrap, NULL);
@@ -221,7 +228,7 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
 {
     NSFileManager *fileManager = [NSFileManager defaultManager];
     NSString *prefPath = [self checkAndGetPrefDir];
-    if(prefPath==nil)
+    if (prefPath==nil)
         return nil;
 
     // find file with highest index
@@ -229,30 +236,30 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
     int highestIndex = -1;
     NSString *path = nil;
     NSString *lastPath = nil;
-    for(i=0;i<10;i++) {
+    for (i=0;i<10;i++) {
         lastPath = path;
         path = [NSString stringWithFormat:@"%@/quicksnap%d.vsf",prefPath,i];
-        if(![fileManager fileExistsAtPath:path]) {
+        if (![fileManager fileExistsAtPath:path]) {
             break;
         }
         highestIndex = i;
     }
     
-    if(load) {
-        if(lastPath==nil)
+    if (load) {
+        if (lastPath==nil)
             [[theVICEMachine app] runErrorMessage:@"No Quick Snapshot File found!"];
         
-        if(highestIndex==9)
+        if (highestIndex==9)
             return path;
         else
             return lastPath;
     }
     else {
         // move all files one up to make space for new save
-        if(highestIndex==9) {
+        if (highestIndex==9) {
             NSString *newPath = [NSString stringWithFormat:@"%@/quicksnap0.vsf",prefPath];
             [fileManager removeFileAtPath:newPath handler:nil];
-            for(i=1;i<10;i++) {
+            for (i=1;i<10;i++) {
                 NSString *oldPath = [NSString stringWithFormat:@"%@/quicksnap%d.vsf",prefPath,i];
                 [fileManager movePath:oldPath toPath:newPath handler:nil];
                 newPath = oldPath;
@@ -266,7 +273,7 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
 -(void)saveQuickSnapshot
 {
     NSString *path = [self getQuickSnapshotFileName:FALSE];
-    if(path!=nil) {
+    if (path!=nil) {
         [self saveSnapshot:path withROMS:FALSE andDisks:FALSE];
     }
 }
@@ -274,7 +281,7 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
 -(void)loadQuickSnapshot
 {
     NSString *path = [self getQuickSnapshotFileName:TRUE];
-    if(path!=nil) {
+    if (path!=nil) {
         [self loadSnapshot:path];
     }
 }
@@ -328,7 +335,7 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
 {
     // fetch real canvas for id
     video_canvas_t *canvas = [theVICEMachine getCanvasForId:canvasId];
-    if(canvas==NULL)
+    if (canvas==NULL)
         return false;
     
     int result = screenshot_save([driver cStringUsingEncoding:NSUTF8StringEncoding],
@@ -362,29 +369,53 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
     return [a autorelease];
 }
 
--(BOOL)mediaDriverHasOptions:(NSString *)driver
+-(gfxoutputdrv_t *)findDriverByName:(NSString *)driverName
 {
-    if([driver compare:@"FFMPEG"]==NSOrderedSame)
-        return TRUE;
-    else
-        return FALSE;
+    int i;
+    gfxoutputdrv_t *driver = gfxoutput_drivers_iter_init();
+    for (i = 0; i < gfxoutput_num_drivers(); i++) {
+        NSString *name = [NSString stringWithCString:driver->name encoding:NSUTF8StringEncoding];
+        if ([name compare:driverName]==NSOrderedSame) {
+            return driver;
+        }
+        driver = gfxoutput_drivers_iter_next();        
+    }
+    return NULL;
 }
 
--(NSArray *)enumMediaFormats:(NSString *)driver
+-(BOOL)mediaDriverHasFormats:(NSString *)driverName
 {
-    // currently only FFMPEG here
+    gfxoutputdrv_t *driver = [self findDriverByName:driverName];
+    if (driver == NULL)
+        return FALSE;
+    
+    return (driver->formatlist != NULL);
+}
+
+-(NSArray *)enumMediaFormats:(NSString *)driverName
+{
+    // find driver
+    gfxoutputdrv_t *driver = [self findDriverByName:driverName];
+    if (driver == NULL)
+        return nil;
+        
+    // get formatlist
+    gfxoutputdrv_format_t *formatlist = driver->formatlist;
+    if (formatlist == NULL)
+        return nil;
+
+    // enumerate all formats and codecs
     int i;
     NSMutableArray *a = [[NSMutableArray alloc] init];
-#ifdef HAVE_FFMPEG 
-    for (i=0;ffmpegdrv_formatlist[i].name!=NULL;i++) {
-        NSString *fname = [NSString stringWithCString:ffmpegdrv_formatlist[i].name encoding:NSUTF8StringEncoding];
+    for (i=0;formatlist[i].name!=NULL;i++) {
+        NSString *fname = [NSString stringWithCString:formatlist[i].name encoding:NSUTF8StringEncoding];
         
         // fetch video codecs
         int j;
-        ffmpegdrv_codec_t *video_codecs = ffmpegdrv_formatlist[i].video_codecs;
+        gfxoutputdrv_codec_t *video_codecs = formatlist[i].video_codecs;
         NSMutableDictionary *video = [[NSMutableDictionary alloc] init];
-        if(video_codecs!=NULL) {
-            for(j=0;video_codecs->name!=NULL;j++) {
+        if (video_codecs!=NULL) {
+            for (j=0;video_codecs->name!=NULL;j++) {
                 NSString *vname = [NSString stringWithCString:video_codecs->name encoding:NSUTF8StringEncoding];
                 [video setObject:vname forKey:[NSNumber numberWithInt:video_codecs->id]];
                 video_codecs++;
@@ -392,10 +423,10 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
         }
         
         // fetch audio codecs
-        ffmpegdrv_codec_t *audio_codecs = ffmpegdrv_formatlist[i].audio_codecs;
+        gfxoutputdrv_codec_t *audio_codecs = formatlist[i].audio_codecs;
         NSMutableDictionary *audio = [[NSMutableDictionary alloc] init];
-        if(audio_codecs!=NULL) {
-            for(j=0;audio_codecs->name!=NULL;j++) {
+        if (audio_codecs!=NULL) {
+            for (j=0;audio_codecs->name!=NULL;j++) {
                 NSString *aname = [NSString stringWithCString:audio_codecs->name encoding:NSUTF8StringEncoding];
                 [audio setObject:aname forKey:[NSNumber numberWithInt:audio_codecs->id]];
                 audio_codecs++;                
@@ -404,17 +435,34 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
 
         [a addObject:[NSArray arrayWithObjects:fname,video,audio,nil]];
     }
-#endif
+
     return [a autorelease];
 }
 
--(NSString *)defaultExtensionForMediaDriver:(NSString *)driver andFormat:(NSString *)format
+-(NSString *)defaultExtensionForMediaDriver:(NSString *)driverName andFormat:(NSString *)formatName
 {
-    if(format==nil) {
-        return [driver lowercaseString];
-    } else {
-        return format;
+    // find driver
+    gfxoutputdrv_t *driver = [self findDriverByName:driverName];
+    if (driver == NULL)
+        return nil;
+
+    // use global extension if available
+    if (driver->default_extension != NULL)
+        return [NSString stringWithCString:driver->default_extension encoding:NSUTF8StringEncoding];
+    
+    // search format
+    gfxoutputdrv_format_t *formatlist = driver->formatlist;
+    if (formatlist == NULL)
+        return nil;
+
+    int i;
+    for (i=0;formatlist[i].name!=NULL;i++) {
+        NSString *fname = [NSString stringWithCString:formatlist[i].name encoding:NSUTF8StringEncoding];
+        if ([fname compare:formatName]==NSOrderedSame) {
+            return fname;
+        }
     }
+    return nil;
 }
 
 // ----- Keyboard -----
@@ -436,29 +484,39 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
     return (keyboard_keymap_dump([path fileSystemRepresentation]) == 0);
 }
 
-// ----- Mouse -----
+// ----- Mouse & Lightpen -----
 
 -(void)mouseMoveToX:(int)x andY:(int)y
 {
     mouse_move(x,y);
 }
 
--(void)mousePressed
+-(void)mouseButton:(BOOL)left withState:(BOOL)pressed
 {
-    mouse_button_left(1);
+    if(left)
+        mouse_button_left(pressed);
+    else
+        mouse_button_right(pressed);
 }
 
--(void)mouseReleased
+-(void)lightpenUpdateOnScreen:(int)screen toX:(int)x andY:(int)y 
+                  withButton1:(BOOL)b1 andButton2:(BOOL)b2
 {
-    mouse_button_left(0);
+    int buttons = 0;
+    if(b1)
+        buttons |= LP_HOST_BUTTON_1;
+    if(b2)
+        buttons |= LP_HOST_BUTTON_2;
+    
+    lightpen_update(screen, x, y, buttons);
 }
 
 // ----- Drive -----
 
--(BOOL)smartAttachImage:(NSString *)path
+-(BOOL)smartAttachImage:(NSString *)path withProgNum:(int)num andRun:(BOOL)run
 {
     return autostart_autodetect([path fileSystemRepresentation],
-        NULL,0,AUTOSTART_MODE_RUN) == 0;
+        NULL, num, run ? AUTOSTART_MODE_RUN : AUTOSTART_MODE_LOAD) == 0;
 }
 
 -(BOOL)attachDiskImage:(int)unit path:(NSString *)path
@@ -486,7 +544,7 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
 -(NSString *)getDiskName:(int)unit
 {
     const char *diskName = file_system_get_disk_name(unit);
-    if(diskName==NULL)
+    if (diskName==NULL)
         return nil;
     else
         return [NSString stringWithCString:diskName encoding:NSUTF8StringEncoding];
@@ -532,10 +590,10 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
 -(void)typeStringOnKeyboard:(NSString *)string toPetscii:(BOOL)convert
 {
     const char *cstr = [string cStringUsingEncoding:NSUTF8StringEncoding];
-    if(convert) {
+    if (convert) {
         int len = [string length];
-        char *pstr = (char *)lib_malloc(len+1);
-        memcpy(pstr,cstr,len);
+        char *pstr = (char *)malloc(len + 1);
+        memcpy(pstr,cstr,len+1);
         charset_petconvstring(pstr,0);
         
         kbdbuf_feed(pstr);
@@ -568,7 +626,7 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
 -(void)removeFromFliplist:(int)unit path:(NSString *)path
 {
     const char *cstr = NULL;
-    if(path!=nil) {
+    if (path!=nil) {
         cstr = [path cStringUsingEncoding:NSUTF8StringEncoding];
     }
     fliplist_remove(unit,cstr);
@@ -601,4 +659,89 @@ static void saveSnapshotTrap(WORD unusedWord, void *unusedData)
     return network_get_mode();
 }
 
+// ----- Image Contents -----
+
+// convert latin1 chars with special meaning to similar chars in CBM font
+-(void)fixChars:(unsigned char *)str
+{
+    while(*str != 0) {
+        unsigned char code = *str;
+        // non breaking space
+        if(code==0xa0)
+          *str=0x20;
+        // soft hyphen
+        if(code==0xad)
+          *str=0xed;
+        str++;
+    }
+}
+
+-(NSDictionary *)convertImageContentsToDictionary:(image_contents_t *)ic
+{
+    image_contents_file_list_t *list = ic->file_list;
+    int num_files = 0;
+    while(list!=NULL) {
+        num_files++;
+        list = list->next;
+    }
+    
+    NSMutableArray *files = [NSMutableArray arrayWithCapacity:num_files];
+    list = ic->file_list;
+    while(list!=NULL) {
+        char *file = image_contents_file_to_string(list, 0);
+        [self fixChars:(unsigned char *)file];
+        NSString *sfile = [NSString stringWithCString:file encoding:NSISOLatin1StringEncoding];
+        lib_free(file);
+        
+        NSDictionary *entry = [NSDictionary dictionaryWithObjectsAndKeys:
+            sfile, @"fileName",
+            nil, nil];
+        
+        [files addObject:entry];
+        list = list->next;
+    }
+    
+    [self fixChars:(unsigned char *)ic->name];
+    [self fixChars:(unsigned char *)ic->id];
+    NSDictionary *result = [NSDictionary dictionaryWithObjectsAndKeys:
+            [NSNumber numberWithInt:ic->blocks_free], @"blocks_free",
+            [NSString stringWithCString:(char *)ic->name encoding:NSISOLatin1StringEncoding], @"name",
+            [NSString stringWithCString:(char *)ic->id encoding:NSISOLatin1StringEncoding], @"id",
+            files, @"files",
+            nil, nil];
+    
+    image_contents_destroy(ic);        
+    return result;
+}
+
+-(NSDictionary *)diskimageContents:(NSString *)path
+{
+    const char *cstr = [path cStringUsingEncoding:NSUTF8StringEncoding];
+
+    // HACK: temporarly disable logging. otherwise log window outputs block UI!
+    log_enable(0);
+    image_contents_t *ic = diskcontents_filesystem_read(cstr);
+    log_enable(1);
+
+    if(ic == NULL) {
+        return nil;
+    }
+    return [self convertImageContentsToDictionary:ic];
+}
+
+-(NSDictionary *)tapeimageContents:(NSString *)path
+{
+    const char *cstr = [path cStringUsingEncoding:NSUTF8StringEncoding];
+
+    // HACK: temporarly disable logging. otherwise log window outputs block UI!
+    log_enable(0);
+    image_contents_t *ic = tapecontents_read(cstr);
+    log_enable(1);
+    
+    if(ic == NULL) {
+        return nil;
+    }
+    return [self convertImageContentsToDictionary:ic];
+}
+
 @end
