@@ -86,7 +86,7 @@ void ui_display_drive_led(int drive_number, unsigned int pwm1, unsigned int pwm2
 void ui_display_drive_current_image(unsigned int drive_number,
                                     const char *image)
 {
-    NSString *string = [NSString stringWithCString:image];
+    NSString *string = [NSString stringWithCString:image encoding:NSUTF8StringEncoding];
     [[theVICEMachine machineNotifier] postDisplayDriveImageNotification:drive_number
                                                    image:string];
 }
@@ -100,7 +100,7 @@ void ui_set_tape_status(int enable)
 
 void ui_display_tape_current_image(const char *image)
 {
-    NSString *string = [NSString stringWithCString:image];
+    NSString *string = [NSString stringWithCString:image encoding:NSUTF8StringEncoding];
     [[theVICEMachine machineNotifier] postDisplayTapeImageNotification:string];
 }
 
@@ -137,7 +137,7 @@ void ui_display_recording(int recording_status)
 
 void ui_display_playback(int playback_status, char *version)
 {
-    NSString *string = [NSString stringWithCString:version ? version : ""];
+    NSString *string = [NSString stringWithCString:version ? version : ""  encoding:NSUTF8StringEncoding];
     [[theVICEMachine machineNotifier] postDisplayPlaybackNotification:(BOOL)playback_status
                                                version:string];
 }
@@ -161,12 +161,13 @@ void ui_display_joyport(BYTE *joyport)
 
 void ui_display_volume(int vol)
 {
-    // TODO
+    [[theVICEMachine machineNotifier] postVolumeChangeNotification:vol];
 }
 
 void ui_update_menus()
 {
-    // nothing to do...
+    // post a resource update
+    [[theVICEMachine machineNotifier] postChangedResourcesNotification];
 }
 
 // ----- Alerts & Dialogs -----
@@ -175,8 +176,9 @@ void ui_error(const char *format, ...)
 {
     va_list args;
     va_start(args, format);
-    NSString *string = [[NSString alloc] initWithFormat:[NSString stringWithCString:format]
-                                              arguments:args];
+    NSString *string = [[NSString alloc] 
+        initWithFormat:[NSString stringWithCString:format encoding:NSUTF8StringEncoding]
+             arguments:args];
     va_end(args);
 
     [[theVICEMachine app] runErrorMessage:string];
@@ -187,8 +189,9 @@ void ui_message(const char *format, ...)
 {
     va_list args;
     va_start(args, format);
-    NSString *string = [[NSString alloc] initWithFormat:[NSString stringWithCString:format]
-                                              arguments:args];
+    NSString *string = [[NSString alloc] 
+        initWithFormat:[NSString stringWithCString:format encoding:NSUTF8StringEncoding]
+             arguments:args];
     va_end(args);
 
     [[theVICEMachine app] runWarningMessage:string];
@@ -199,21 +202,14 @@ ui_jam_action_t ui_jam_dialog(const char *format,...)
 {
     va_list args;
     va_start(args, format);
-    NSString * string = [[NSString alloc] initWithFormat:[NSString stringWithCString:format]
-                                               arguments:args];
+    NSString * string = [[NSString alloc] 
+        initWithFormat:[NSString stringWithCString:format encoding:NSUTF8StringEncoding]
+             arguments:args];
     va_end(args);
 
     int result = [[theVICEMachine app] runCPUJamDialog:string];
     [string release];
-
-    switch (result) {
-    case 0:
-        return UI_JAM_MONITOR;
-    case 1:
-        return UI_JAM_RESET;
-    default:
-        return UI_JAM_HARD_RESET;
-    }
+    return result;
 }
 
 int ui_extend_image_dialog(void)
@@ -226,12 +222,13 @@ char* ui_get_file(const char *format,...)
 {
     va_list args;
     va_start(args, format);
-    NSString * string = [[NSString alloc] initWithFormat:[NSString stringWithCString:format]
-                                               arguments:args];
+    NSString * string = [[NSString alloc] 
+        initWithFormat:[NSString stringWithCString:format encoding:NSUTF8StringEncoding]
+             arguments:args];
     va_end(args);
 
     NSString * path = [[theVICEMachine app] getOpenFileName:string types:nil];
-    if(path != nil) {
+    if (path != nil) {
         return strdup([path cStringUsingEncoding:NSUTF8StringEncoding]);
     } else {
         return NULL;
