@@ -48,9 +48,20 @@
 // Pause State
 #define VICETogglePauseNotification               @"VICETogglePauseNotification"
 
-// Mouse
+// Mouse & Lightpen
 #define VICEToggleMouseNotification               @"VICEToggleMouseNotification"
+#define VICEToggleLightpenNotification            @"VICEToggleLightpenNotification"
 
 // Resource Updates
 #define VICEChangedResourcesNotification          @"VICEResourcesChanged"
 
+// Volume Change
+#define VICEChangeVolumeNotification              @"VICEChangeVolumeNotification"
+
+// Monitor notification from Application
+#define VICEMonitorStateNotification              @"VICEMonitorStateNotification"
+#define VICEMonitorStateOff             0
+#define VICEMonitorStateOn              1
+#define VICEMonitorStateSuspend         2
+#define VICEMonitorStateResume          3
+
