@@ -27,41 +27,149 @@
 
 #include "videoarch.h"
 #include "palette.h"
+#include "resources.h"
+#include "cmdline.h"
+#include "translate.h"
+#include "log.h"
 
 #import "vicemachinenotifier.h"
 #import "vicemachine.h"
 #import "vicewindow.h"
 
-// VICE Video Resources
+// Mac Video Log
+log_t video_log = LOG_ERR;
+
+// video parameter struct
+static video_param_t video_param;
+
+// ---------- VICE Video Resources ----------
+
+/* tell all canvases to reconfigure after setting new video_param resources */
+static void video_reconfigure()
+{
+    int numCanvases = [theVICEMachine getNumCanvases];
+    int i;
+    
+    for(i=0;i<numCanvases;i++) {
+        video_canvas_t *canvas = [theVICEMachine getCanvasForId:i];
+
+        NSData *data = [NSData dataWithBytes:&canvas length:sizeof(video_canvas_t *)];
+
+        // call UI thread to reconfigure canvas
+        [[theVICEMachine app] reconfigureCanvas:data];
+    }
+}
+
+static int set_sync_draw_mode(int val, void *param)
+{
+    if((val < 0) || (val > SYNC_DRAW_LAST))
+        return;
+    
+    if(val != video_param.sync_draw_mode) {
+        video_param.sync_draw_mode = val;
+        video_reconfigure();
+    }
+}
+
+static int set_sync_draw_buffers(int val, void *param)
+{
+    if(val < 1)
+        val = 0;
+    else if(val > 16)
+        val = 16;
+
+    if(val != video_param.sync_draw_buffers) {            
+        video_param.sync_draw_buffers = val;
+        video_reconfigure();
+    }
+}
+
+static int set_sync_draw_flicker_fix(int val, void *param)
+{
+    if(val)
+        val = 1;
+    else
+        val = 0;
+
+    if(val != video_param.sync_draw_flicker_fix) {            
+        video_param.sync_draw_flicker_fix = val;
+        video_reconfigure();
+    }
+}
+
+static resource_int_t resources_int[] =
+{
+    { "SyncDrawMode", 0, RES_EVENT_NO, NULL,
+       &video_param.sync_draw_mode, set_sync_draw_mode, NULL },
+    { "SyncDrawBuffers", 0, RES_EVENT_NO, NULL,
+       &video_param.sync_draw_buffers, set_sync_draw_buffers, NULL },
+    { "SyncDrawFlickerFix", 0, RES_EVENT_NO, NULL,
+       &video_param.sync_draw_flicker_fix, set_sync_draw_flicker_fix, NULL },
+    { NULL }
+ };
 
 int video_arch_resources_init(void)
 {
-    return 0;
+    return resources_register_int(resources_int);
 }
 
 void video_arch_resources_shutdown(void)
 {
 }
 
-// VICE interface:
+// ---------- VICE Video Command Line ----------
+
+static const cmdline_option_t cmdline_options[] = {
+    { "-syncdrawmode", SET_RESOURCE, 1,
+      NULL, NULL, "SyncDrawMode", NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
+      "<0-3>", T_("Enable draw synchronization to vertical blank") },
+    { "-syncdrawbuffers", SET_RESOURCE, 1,
+      NULL, NULL, "SyncDrawBuffers", NULL,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
+      "<0-8>", T_("Set number of buffers used for sync draw (0=use default)") },
+    { "-syncdrawflickerfix", SET_RESOURCE, 0,
+      NULL, NULL, "SyncDrawFlickerFix", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
+      NULL, T_("Enable flicker fixing in sync draw") },
+    { "+syncdrawflickerfix", SET_RESOURCE, 0,
+      NULL, NULL, "SyncDrawFlickerFix", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_STRING,
+      IDCLS_UNUSED, IDCLS_UNUSED,
+      NULL, T_("Enable flicker fixing in sync draw") },
+    { NULL }
+};
 
 int video_init_cmdline_options(void)
 {
-    return 0;
+    return cmdline_register_options(cmdline_options);
 }
 
+// --------- init/exit MacVICE video ----------
+
 int video_init(void)
 {
-   return 0;
+    if (video_log == LOG_ERR)
+  	    video_log = log_open("MacVideo");
 }
 
 void video_shutdown(void)
 {
+    if (video_log != LOG_ERR)
+        log_close(video_log);
 }
 
 void video_arch_canvas_init(struct video_canvas_s *canvas)
 {
+    canvas->pitch = 0;
     canvas->window = nil;
+    canvas->view = nil;
+    canvas->canvasId = 0;
+    
+    canvas->video_param = &video_param;
     canvas->video_draw_buffer_callback = NULL;
 }
 
@@ -79,15 +187,15 @@ video_canvas_t *video_canvas_create(struct video_canvas_s *canvas,
     video_canvas_t *canvasPtr = canvas;
     NSData *data = [NSData dataWithBytes:&canvasPtr length:sizeof(video_canvas_t *)];
 
+    // register canvas in machine controller and return Id for it
+    canvas->canvasId = [theVICEMachine registerCanvas:canvas];
+
     // call UI thread to create canvas
     [[theVICEMachine app] createCanvas:data withSize:NSMakeSize(w,h)];
 
     // init rendering
     video_canvas_set_palette(canvas,canvas->palette);
 
-    // register canvas in machine controller (to allow access via id)
-    canvas->canvasId = [theVICEMachine registerCanvas:canvas];
-
     // re-post all required notifications for new window
     [[theVICEMachine machineNotifier] notifyNewWindow];
 
@@ -129,6 +237,8 @@ void video_canvas_resize(video_canvas_t * canvas,
     [[theVICEMachine app] resizeCanvas:data withSize:NSMakeSize(width,height)];
 }
 
+extern int vsync_frame_counter;
+
 void video_canvas_refresh(video_canvas_t *canvas,
                           unsigned int xs, unsigned int ys,
                           unsigned int xi, unsigned int yi,
@@ -145,25 +255,20 @@ void video_canvas_refresh(video_canvas_t *canvas,
     w = MIN(w, canvas->width - xi);
     h = MIN(h, canvas->height - yi);
 
-    // render into texture buffer
-    video_canvas_render(canvas, canvas->buffer,
+    // get drawing buffer
+    VICEGLView *view = canvas->view;
+    BYTE *buffer = [view beginMachineDraw:vsync_frame_counter];
+    if(buffer == NULL) {
+        return;
+    }
+        
+    // draw into buffer
+    video_canvas_render(canvas, buffer,
                         w, h, xs, ys, xi, yi, 
                         canvas->pitch, canvas->depth);
 
-#if 1
-    // call updateCanvas selector in main thread - non-blocking
-    VICEWindow *window = canvas->window;
-    [window performSelectorOnMainThread:@selector(updateCanvas:) 
-                             withObject:nil 
-                          waitUntilDone:NO];
-#else
-    // call updateCanvas via proxy object - blocks if main app blocks
-    // encapsulate canvas ptr
-    video_canvas_t *canvasPtr = canvas;    
-    NSData *data = [NSData dataWithBytes:&canvasPtr length:sizeof(video_canvas_t *)];
-    // call UI thread to resize canvas
-    [[theVICEMachine app] updateCanvas:data];
-#endif
+    // notify end drawing
+    [view endMachineDraw];
 }
 
 // ----- Palette Stuff -----
@@ -182,41 +287,34 @@ int video_canvas_set_palette(video_canvas_t *c, palette_t *p)
     DWORD bmask = 0;
 
     c->palette = p;
+    
+    // set 32bit palette
     for (i = 0; i < p->num_entries; i++)
     {
         DWORD col;
 
-        switch (c->depth)
-        {
-            case 16:    /* RGB 5:5:5 */
-                /* TODO */
-                rbits = 3; rshift = 10; rmask = 0x1f;
-                gbits = 3; gshift = 5; gmask = 0x1f;
-                bbits = 3; bshift = 0; bmask = 0x1f;
-                break;
-            case 32:    /* RGB 8:8:8 */
-            default:
-                rbits = 0; rshift = 16; rmask = 0xff;
-                gbits = 0; gshift = 8; gmask = 0xff;
-                bbits = 0; bshift = 0; bmask = 0xff;
-        }
+        rbits = 0; rshift = 16; rmask = 0xff;
+        gbits = 0; gshift = 8; gmask = 0xff;
+        bbits = 0; bshift = 0; bmask = 0xff;
+
         col = (p->entries[i].red   >> rbits) << rshift
             | (p->entries[i].green >> gbits) << gshift
-            | (p->entries[i].blue  >> bbits) << bshift;
+            | (p->entries[i].blue  >> bbits) << bshift
+            | 0xff000000; // alpha
 
         video_render_setphysicalcolor(c->videoconfig, i, col, c->depth);
     }
-    if (c->depth > 8)
+
+    // set colors for palemu
+    for (i = 0; i < 256; i++)
     {
-        for (i = 0; i < 256; i++)
-        {
-            video_render_setrawrgb(i,
-                                   ((i & (rmask << rbits)) >> rbits) << rshift,
-                                   ((i & (gmask << gbits)) >> gbits) << gshift,
-                                   ((i & (bmask << bbits)) >> bbits) << bshift);
-        }
-        video_render_initraw();
+        video_render_setrawrgb(i,
+                               ((i & (rmask << rbits)) >> rbits) << rshift,
+                               ((i & (gmask << gbits)) >> gbits) << gshift,
+                               ((i & (bmask << bbits)) >> bbits) << bshift);
     }
+    video_render_setrawalpha(0xff000000);
+    video_render_initraw();
 
     return 0;
 }
