@@ -26,6 +26,7 @@
  */
 
 #import "fullscreenwindow.h"
+#import "vicewindow.h"
 
 // for SetSystemUIMode:
 #include <QuickTime/QuickTime.h>
@@ -39,7 +40,7 @@
                               backing:NSBackingStoreBuffered
                                 defer:NO
                                screen:[NSScreen mainScreen]];
-    if(self==nil)
+    if (self==nil)
         return nil;
                                        
     [self setBackgroundColor:[NSColor blackColor]];
@@ -109,7 +110,12 @@
 -(void)toggleFullscreen:(id)sender
 {
     // report to VICEWindow to close fullscreen
-    [[self delegate] toggleFullscreen:self];
+    [toggler toggleFullscreen:self];
+}
+
+-(void)setToggler:(id<FullscreenToggling>)t
+{
+    toggler = t;
 }
 
 @end
