@@ -27,22 +27,13 @@
 
 #import <Cocoa/Cocoa.h>
 #import "viceglview.h"
-#import "joystickview.h"
 #import "fullscreenwindow.h"
 
-@interface VICEWindow : NSWindow
+@interface VICEWindow : NSWindow <FullscreenToggling>
 {
     NSBox *canvasContainer;
     VICEGLView *canvasView;
     
-    NSBox * statusBox;
-    NSTextField * recplayView;
-    NSTextField * speedView;
-    JoystickView *joystickView1;
-    JoystickView *joystickView2;
-
-    NSDrawer * peripheralDrawer;
-
     NSSize original_canvas_size;
     BOOL isFullscreen;
     FullscreenWindow *fullscreenWindow;
@@ -64,8 +55,6 @@
 // resize to multiple size taken from [sender tag]
 - (void)resizeCanvasToMultipleSize:(id)sender;
 
--(void)updateCanvas:(id)sender;
-
 // ----- copy & paste support -----
 // copy
 -(IBAction)copy:(id)sender;
