@@ -2,7 +2,7 @@
  * ui.c - Gnome based graphical user interface.  
  *
  * Written by
- *  Martin Pottendorfer <Martin.Pottendorfer@alcatel.at>
+ *  pottendo <pottendo@gmx.net>
  *  Heavily derived from Oliver Schaertel <orschaer@forwiss.uni-erlangen.de>
  *  GTK+ port.
  *
@@ -42,6 +42,7 @@
 #include "ui.h"
 #include "uiarch.h"
 #include "uicolor.h"
+
 #ifdef HAVE_OPENGL_SYNC
 #include "openGL_sync.h"
 #endif
@@ -62,8 +63,9 @@ void video_arch_resources_shutdown(void)
 
 int video_init(void)
 {
-    if (gnomevideo_log == LOG_ERR)
+    if (gnomevideo_log == LOG_ERR) {
         gnomevideo_log = log_open("GnomeVideo");
+    }
 
     return 0;
 }
@@ -82,15 +84,13 @@ void video_arch_canvas_init(struct video_canvas_s *canvas)
     canvas->video_draw_buffer_callback = NULL;
 
 #ifdef HAVE_FULLSCREEN
-    canvas->fullscreenconfig
-        = (fullscreenconfig_t *)lib_calloc(1, sizeof(fullscreenconfig_t));
+    canvas->fullscreenconfig = lib_calloc(1, sizeof(fullscreenconfig_t));
     fullscreen_init_alloc_hooks(canvas);
 #endif
 }
 
 
-video_canvas_t *video_canvas_create(video_canvas_t *canvas, unsigned int *width,
-                                    unsigned int *height, int mapped)
+video_canvas_t *video_canvas_create(video_canvas_t *canvas, unsigned int *width, unsigned int *height, int mapped)
 {
     int res;
 
@@ -99,8 +99,7 @@ video_canvas_t *video_canvas_create(video_canvas_t *canvas, unsigned int *width,
     canvas->hwscale_image = NULL;
 #endif
 
-    res = ui_open_canvas_window(canvas, canvas->viewport->title,
-				*width, *height, 1);
+    res = ui_open_canvas_window(canvas, canvas->viewport->title, *width, *height, 1);
     if (res < 0) {
         return NULL;
     }
@@ -120,8 +119,10 @@ void video_canvas_destroy(video_canvas_t *canvas)
         lib_free(canvas->fullscreenconfig);
     }
 #endif
-    if (canvas->gdk_image != NULL)
+    if (canvas->gdk_image != NULL) {
         g_object_unref(canvas->gdk_image);
+    }
+
 #ifdef HAVE_HWSCALE
     lib_free(canvas->hwscale_image);
 #endif
@@ -137,25 +138,30 @@ int video_canvas_set_palette(video_canvas_t *canvas, struct palette_s *palette)
 }
 
 /* Change the size of the canvas. */
-void video_canvas_resize(video_canvas_t *canvas, unsigned int width,
-                         unsigned int height)
+void video_canvas_resize(video_canvas_t *canvas, unsigned int width, unsigned int height)
 {
-    if (console_mode || vsid_mode)
+    if (console_mode || vsid_mode) {
         return;
+    }
 
-    if (canvas->videoconfig->doublesizex)
+    if (canvas->videoconfig->doublesizex) {
         width *= 2;
+    }
 
-    if (canvas->videoconfig->doublesizey)
+    if (canvas->videoconfig->doublesizey) {
         height *= 2;
+    }
 
-    if (canvas->gdk_image != NULL)
+    if (canvas->gdk_image != NULL) {
         g_object_unref(canvas->gdk_image);
+    }
     canvas->gdk_image = gdk_image_new(GDK_IMAGE_FASTEST, gtk_widget_get_visual(canvas->emuwindow), width, height);
+
 #ifdef HAVE_HWSCALE
     lib_free(canvas->hwscale_image);
-    canvas->hwscale_image = lib_malloc(canvas->gdk_image->width * canvas->gdk_image->height * 3);
+    canvas->hwscale_image = lib_malloc(canvas->gdk_image->width * canvas->gdk_image->height * 4);
 #endif
+
     if (video_canvas_set_palette(canvas, canvas->palette) < 0) {
         log_debug("Setting palette for this mode failed. (Try 16/24/32 bpp.)");
         exit(-1);
@@ -178,18 +184,15 @@ void video_canvas_unmap(video_canvas_t *s)
 }
 
 /* Refresh a canvas.  */
-void video_canvas_refresh(video_canvas_t *canvas,
-                          unsigned int xs, unsigned int ys,
-                          unsigned int xi, unsigned int yi,
-                          unsigned int w, unsigned int h)
+void video_canvas_refresh(video_canvas_t *canvas, unsigned int xs, unsigned int ys, unsigned int xi, unsigned int yi, unsigned int w, unsigned int h)
 {
 #if 0
-    log_debug("XS%i YS%i XI%i YI%i W%i H%i PS%i", xs, ys, xi, yi, w, h,
-              canvas->draw_buffer->draw_buffer_width);
+    log_debug("XS%i YS%i XI%i YI%i W%i H%i PS%i", xs, ys, xi, yi, w, h, canvas->draw_buffer->draw_buffer_width);
 #endif
 
-    if (console_mode || vsid_mode)
+    if (console_mode || vsid_mode) {
         return;
+    }
 
     if (canvas->videoconfig->doublesizex) {
         xi *= 2;
@@ -209,24 +212,18 @@ void video_canvas_refresh(video_canvas_t *canvas,
 #endif
 
     if (xi + w > canvas->gdk_image->width || yi + h > canvas->gdk_image->height) {
-        log_debug("Attempt to draw outside canvas!\n"
-                  "XI%i YI%i W%i H%i CW%i CH%i\n",
-                  xi, yi, w, h, canvas->gdk_image->width, canvas->gdk_image->height);
+        log_debug("Attempt to draw outside canvas!\nXI%i YI%i W%i H%i CW%i CH%i\n", xi, yi, w, h, canvas->gdk_image->width, canvas->gdk_image->height);
         exit(-1);
     }
 
 #ifdef HAVE_HWSCALE
     if (canvas->videoconfig->hwscale) {
-        video_canvas_render(canvas, canvas->hwscale_image,
-                            w, h, xs, ys, xi, yi, canvas->gdk_image->width * 3,
-                            24);
+        video_canvas_render(canvas, canvas->hwscale_image, w, h, xs, ys, xi, yi, canvas->gdk_image->width * 4, 32);
         gtk_widget_queue_draw(canvas->emuwindow);
     } else
 #endif
     {
-        video_canvas_render(canvas, canvas->gdk_image->mem,
-                            w, h, xs, ys, xi, yi, canvas->gdk_image->bpl,
-                            canvas->gdk_image->bits_per_pixel);
+        video_canvas_render(canvas, canvas->gdk_image->mem, w, h, xs, ys, xi, yi, canvas->gdk_image->bpl, canvas->gdk_image->bits_per_pixel);
         gtk_widget_queue_draw_area(canvas->emuwindow, xi, yi, w, h);
     }
 }
