@@ -2,7 +2,7 @@
  * uicartridge.c - Cartridge save image dialog for the Xaw widget set.
  *
  * Written by
- *  Martin Pottendorfer <Martin.Pottendorfer@alcatel.at>
+ *  pottendo <pottendo@gmx.net>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -30,37 +30,13 @@
 
 #include "ui.h"
 #include "uiarch.h"
+#include "uiapi.h"
 #include "cartridge.h"
 #include "uifileentry.h"
+#include "uilib.h"
 #include "lib.h"
 
-static GtkWidget *cartridge_dialog, *fileentry;
-
-static GtkWidget *build_cartridge_dialog(void)
-{
-    GtkWidget *d, *box;
-    
-    d = gtk_dialog_new_with_buttons(_("Save Cartridge"), 
-				    NULL,
-				    GTK_DIALOG_DESTROY_WITH_PARENT,
-				    GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				    GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-				    NULL);
-    box = gtk_hbox_new(0, FALSE);
-
-    fileentry = vice_file_entry(_("Save Cartridge"), NULL, NULL, 
-				GTK_FILE_CHOOSER_ACTION_SAVE);
-    gtk_dialog_set_default_response(GTK_DIALOG(d), GTK_RESPONSE_ACCEPT);
-
-    gtk_box_pack_start(GTK_BOX(box), fileentry,
-		       TRUE, TRUE, 0);
-    gtk_widget_show(fileentry);
-    
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(d)->vbox), box, TRUE, TRUE, 0);
-    gtk_widget_show(box);
-    
-    return d;
-}
+static GtkWidget *cartridge_dialog;
 
 void ui_cartridge_dialog(void)
 {
@@ -69,37 +45,33 @@ void ui_cartridge_dialog(void)
     
     if (cartridge_dialog)
     {
-	gdk_window_show(cartridge_dialog->window);
-	gdk_window_raise(cartridge_dialog->window);
-	gtk_widget_show(cartridge_dialog);
-    }
-    else
-    {
-	cartridge_dialog = build_cartridge_dialog();
-	g_signal_connect(G_OBJECT(cartridge_dialog),
-			 "destroy",
-			 G_CALLBACK(gtk_widget_destroyed),
-			 &cartridge_dialog);
+        gdk_window_show(cartridge_dialog->window);
+        gdk_window_raise(cartridge_dialog->window);
+        gtk_widget_show(cartridge_dialog);
+    } else {
+        uilib_file_filter_enum_t filter = UILIB_FILTER_ALL;
+        cartridge_dialog = vice_file_entry(_("Save Cartridge"), NULL, NULL, &filter, 1, UI_FC_SAVE);
+        g_signal_connect(G_OBJECT(cartridge_dialog), "destroy", G_CALLBACK(gtk_widget_destroyed), &cartridge_dialog);
     }
 
     ui_popup(cartridge_dialog, _("Save Cartridge"), FALSE);
     res = gtk_dialog_run(GTK_DIALOG(cartridge_dialog));
     ui_popdown(cartridge_dialog);
     
-    if (res != GTK_RESPONSE_ACCEPT)
-	return;
+    if (res != GTK_RESPONSE_ACCEPT) {
+        return;
+    }
     
-    name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fileentry));
-    if (!name)
-    {
-	ui_error(_("Invalid filename"));
-	return;
+    name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(cartridge_dialog));
+    if (!name) {
+        ui_error(_("Invalid filename"));
+        return;
     }
 	    
-    if (cartridge_save_image (name) < 0)
+    if (cartridge_save_image (name) < 0) {
         ui_error(_("Cannot write cartridge image file\n`%s'\n"), name);
-    else
+    } else {
 	ui_message(_("Successfully wrote `%s'\n"), name);
+    }
     lib_free(name);
 }
-
