@@ -45,8 +45,7 @@
 
 
 extern int screen;
-extern GdkColor drive_led_on_red_pixel, drive_led_on_green_pixel,
-drive_led_off_pixel, motor_running_pixel, tape_control_pixel;
+extern GdkColor drive_led_on_red_pixel, drive_led_on_green_pixel, drive_led_off_pixel, motor_running_pixel, tape_control_pixel;
 extern GdkColor drive_led_on_red_pixels[16];
 extern GdkColor drive_led_on_green_pixels[16];
 
@@ -79,39 +78,39 @@ int uicolor_alloc_colors(video_canvas_t *c)
     tape_control_pixel.blue = 0xaf00;
 
     /* different colors intensities for drive leds */
-    for (i = 0; i < 16; i++)
-    {
-	drive_led_on_red_pixels[i].red = 0x1000*i + 0xf00;
-	drive_led_on_red_pixels[i].green = 0;
-	drive_led_on_red_pixels[i].blue = 0;
+    for (i = 0; i < 16; i++) {
+        drive_led_on_red_pixels[i].red = 0x1000 * i + 0xf00;
+        drive_led_on_red_pixels[i].green = 0;
+        drive_led_on_red_pixels[i].blue = 0;
 
-	drive_led_on_green_pixels[i].red = 0;
-	drive_led_on_green_pixels[i].green =  0x1000*i + 0xf00;
-	drive_led_on_green_pixels[i].blue = 0;
+        drive_led_on_green_pixels[i].red = 0;
+        drive_led_on_green_pixels[i].green =  0x1000 * i + 0xf00;
+        drive_led_on_green_pixels[i].blue = 0;
     }
     
     return 0;
 }
 
 unsigned int endian_swap(unsigned int color, unsigned int bpp, unsigned int swap) {
-    if (! swap)
+    if (!swap) {
         return color;
+    }
 
-    if (bpp == 8)
+    if (bpp == 8) {
         return color;
+    }
 
-    if (bpp == 16)
-        return ((color >> 8) & 0x00ff)
-             | ((color << 8) & 0xff00);
+    if (bpp == 16) {
+        return ((color >> 8) & 0x00ff) | ((color << 8) & 0xff00);
+    }
 
-    if (bpp == 24)
+    if (bpp == 24) {
         return color; /* 24 bpp output special case at renderer level, always writes out with LSB order regardless of host CPU, handled elsewhere */
+    }
 
-    if (bpp == 32)
-        return ((color >> 24) & 0x000000ff)
-             | ((color >>  8) & 0x0000ff00)
-             | ((color <<  8) & 0x00ff0000)
-             | ((color << 24) & 0xff000000);
+    if (bpp == 32) {
+        return ((color >> 24) & 0x000000ff) | ((color >>  8) & 0x0000ff00) | ((color <<  8) & 0x00ff0000) | ((color << 24) & 0xff000000);
+    }
     
     /* err? */
     return color;
@@ -135,6 +134,7 @@ int uicolor_set_palette(struct video_canvas_s *c, const palette_t *palette)
         swap = 0;
     } else {
         GdkVisual *vis = c->gdk_image->visual;
+
         bpp = vis->depth;
         rb = vis->red_prec;
         gb = vis->green_prec;
@@ -142,11 +142,13 @@ int uicolor_set_palette(struct video_canvas_s *c, const palette_t *palette)
         rs = vis->red_shift;
         gs = vis->green_shift;
         bs = vis->blue_shift;
+
 #ifdef WORDS_BIGENDIAN
         swap = vis->byte_order == GDK_LSB_FIRST;
 #else
         swap = vis->byte_order == GDK_MSB_FIRST;
 #endif
+
         /* 24 bpp modes do not really work with the existing
          * arrangement as they have been written to assume the A component is
          * in the 32-bit longword bits 24-31. If any arch needs 24 bpp, that
@@ -157,26 +159,13 @@ int uicolor_set_palette(struct video_canvas_s *c, const palette_t *palette)
         palette_entry_t color = palette->entries[i];
         /* scale 256 color palette for Gdk terms, then shift to precision,
          * then move component where it needs to be. */
-        DWORD color_pixel = endian_swap(
-            color.red   << 8 >> (16 - rb) << rs |
-            color.green << 8 >> (16 - gb) << gs |
-            color.blue  << 8 >> (16 - bb) << bs,
-            bpp,
-            swap
-        );
-        video_render_setphysicalcolor(c->videoconfig, i, color_pixel,
-                                      bpp);
+        DWORD color_pixel = endian_swap(color.red << 8 >> (16 - rb) << rs | color.green << 8 >> (16 - gb) << gs | color.blue  << 8 >> (16 - bb) << bs, bpp, swap);
+
+        video_render_setphysicalcolor(c->videoconfig, i, color_pixel, bpp);
     }
     
     for (i = 0; i < 256; i ++) {
-        video_render_setrawrgb(i, 
-            endian_swap(i << 8 >> (16 - rb) << rs,
-                        bpp, swap),
-            endian_swap(i << 8 >> (16 - gb) << gs,
-                        bpp, swap),
-            endian_swap(i << 8 >> (16 - bb) << bs,
-                        bpp, swap)
-        );
+        video_render_setrawrgb(i, endian_swap(i << 8 >> (16 - rb) << rs, bpp, swap), endian_swap(i << 8 >> (16 - gb) << gs, bpp, swap), endian_swap(i << 8 >> (16 - bb) << bs, bpp, swap));
     }
     
     video_render_initraw();
