@@ -4,7 +4,7 @@
  * Written by
  *  Ettore Perazzoli <ettore@comm2000.it>
  *  Oliver Schaertel GTK+ port
- *  Martin Pottendorfer Gnome port
+ *  pottendo <pottendo@gmx.net>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -39,12 +39,13 @@
 #include "machine.h"
 #include "resources.h"
 #include "x11menu.h"
+#include "uiapi.h"
 #include "uimenu.h"
 
 /* Separator item.  */
 ui_menu_entry_t ui_menu_separator[] = {
     { "--" },
-    { NULL },
+    { NULL }
 };
 
 static int menu_popup = 0;
@@ -88,7 +89,7 @@ static void delete_checkmark_cb(GtkWidget *w, gpointer data)
 {
     checkmark_t *cm;
     
-    cm = (checkmark_t *) data;
+    cm = (checkmark_t *)data;
     checkmark_list = g_list_remove(checkmark_list, data);
     lib_free(cm->name);
     lib_free(cm);
@@ -98,16 +99,17 @@ static void add_accelerator(GtkWidget *w, GtkAccelGroup *accel, guint accel_key,
 {
     GtkAccelFlags flags = 0;
 
-    if (mod & UI_HOTMOD_CONTROL)
+    if (mod & UI_HOTMOD_CONTROL) {
         flags |= GDK_CONTROL_MASK;
-    if (mod & UI_HOTMOD_META)
+    }
+    if (mod & UI_HOTMOD_META) {
         flags |= GDK_MOD1_MASK;
-    if (mod & UI_HOTMOD_SHIFT)
+    }
+    if (mod & UI_HOTMOD_SHIFT) {
         flags |= GDK_SHIFT_MASK;
+    }
 
-    gtk_widget_add_accelerator(w, "activate",
-                               accel, accel_key,
-                               flags, GTK_ACCEL_VISIBLE);
+    gtk_widget_add_accelerator(w, "activate", accel, accel_key, flags, GTK_ACCEL_VISIBLE);
 }
 
 static char *make_menu_label(ui_menu_entry_t *e)
@@ -115,10 +117,11 @@ static char *make_menu_label(ui_menu_entry_t *e)
     char *trans;
 
     /* Check wether NO_TRANS prefix is there, if yes don't translate it */
-    if (strncmp(e->string, NO_TRANS, strlen(NO_TRANS)) == 0)
+    if (strncmp(e->string, NO_TRANS, strlen(NO_TRANS)) == 0) {
         trans = lib_stralloc(e->string + strlen(NO_TRANS));
-    else
+    } else {
         trans = lib_stralloc(_(e->string));
+    }
 
     return trans;
 }
@@ -132,119 +135,98 @@ void ui_menu_create(GtkWidget *w, GtkAccelGroup *accel, const char *menu_name, u
     level++;
 
 #ifdef DEBUG_MENUS
-    printf("allocate new: %s\t(%p)\t%s\n",
-	   gtk_type_name(GTK_WIDGET_TYPE(w)), w,
-	   menu_name);
+    printf("allocate new: %s\t(%p)\t%s\n", gtk_type_name(GTK_WIDGET_TYPE(w)), w, menu_name);
 #endif
 
-        for (i = j = 0; list[i].string; i++) {
-            GtkWidget *new_item = NULL;
-            int do_right_justify = 0;
+    for (i = j = 0; list[i].string; i++) {
+        GtkWidget *new_item = NULL;
+        int do_right_justify = 0;
+        char name[256];
 
-            char name[256];
-
-            sprintf(name, "MenuItem%d", j);	/* ugly... */
-            switch (*list[i].string) 
-	    {
-	    case '-':		/* line */
-		new_item  = gtk_menu_item_new();
+        sprintf(name, "MenuItem%d", j);	/* ugly... */
+        switch (*list[i].string) {
+            case '-':		/* line */
+                new_item  = gtk_menu_item_new();
                 break;
-	    case '*':		/* toggle */
-	    {
-		/* Add this item to the list of calls to perform to update the
-		   menu status. */
-                char *label = make_menu_label(&list[i]);
-		if (list[i].callback) 
-		{
-		    checkmark_t *cmt;
-		    new_item = gtk_check_menu_item_new_with_label(label + 1);
-		    
-		    cmt = (checkmark_t *)lib_malloc(sizeof(checkmark_t));
-		    cmt->name = lib_stralloc(list[i].string+1);
-		    cmt->w = new_item;
-		    cmt->cb = list[i].callback;
-		    cmt->obj.value = (void*) list[i].callback_data;
-		    cmt->obj.status = CB_NORMAL;
-		    cmt->handlerid = 
-			g_signal_connect(G_OBJECT(new_item),"activate",
-					 G_CALLBACK(list[i].callback),
-					 (gpointer) &(cmt->obj)); 
-		    g_signal_connect(G_OBJECT(new_item), "destroy",
-				     G_CALLBACK(delete_checkmark_cb),
-				     (gpointer) cmt);
-		    checkmark_list = g_list_prepend(checkmark_list, cmt);
-		    obj = &cmt->obj;
-		} 
-		else 
-		    new_item = gtk_menu_item_new_with_label(label + 1);
+            case '*':		/* toggle */
+                {
+                    /* Add this item to the list of calls to perform to update the
+                       menu status. */
+                    char *label = make_menu_label(&list[i]);
 
-		j++;
-		lib_free(label);
-		break;
-	    }
+                    if (list[i].callback) {
+                        checkmark_t *cmt;
+
+                        new_item = gtk_check_menu_item_new_with_label(label + 1);
+
+                        cmt = lib_malloc(sizeof(checkmark_t));
+                        cmt->name = lib_stralloc(list[i].string + 1);
+                        cmt->w = new_item;
+                        cmt->cb = list[i].callback;
+                        cmt->obj.value = (void*)list[i].callback_data;
+                        cmt->obj.status = CB_NORMAL;
+                        cmt->handlerid = g_signal_connect(G_OBJECT(new_item), "activate", G_CALLBACK(list[i].callback), (gpointer)&(cmt->obj)); 
+                        g_signal_connect(G_OBJECT(new_item), "destroy", G_CALLBACK(delete_checkmark_cb), (gpointer)cmt);
+                        checkmark_list = g_list_prepend(checkmark_list, cmt);
+                        obj = &cmt->obj;
+                    } else {
+                        new_item = gtk_menu_item_new_with_label(label + 1);
+                    }
+
+                    j++;
+                    lib_free(label);
+                    break;
+                }
             case 0:
                 break;
-	    default:
-	    {
-		char *item, *itemp;
-		item = itemp = make_menu_label(&list[i]);
-                if (strncmp(item, "RJ", 2) == 0)
+            default:
                 {
-                    do_right_justify = 1;
-                    item += 2;
+                    char *item, *itemp;
+
+                    item = itemp = make_menu_label(&list[i]);
+                    if (strncmp(item, "RJ", 2) == 0) {
+                        do_right_justify = 1;
+                        item += 2;
+                    }
+
+                    new_item = gtk_menu_item_new_with_label(item);
+                    if (list[i].callback) {
+                        obj = lib_malloc(sizeof(ui_menu_cb_obj));
+                        obj->value = (void*)list[i].callback_data;
+
+                        g_signal_connect(G_OBJECT(new_item), "activate", G_CALLBACK(list[i].callback), (gpointer)obj); 
+                    }
+                    lib_free(itemp);
+                    j++;
                 }
+        }
 
-		new_item = gtk_menu_item_new_with_label(item);
-		if (list[i].callback) {
-		    obj = (ui_menu_cb_obj*)lib_malloc(sizeof(ui_menu_cb_obj));
-		    obj->value = (void*) list[i].callback_data;
-		    
-		    g_signal_connect(G_OBJECT(new_item),"activate",
-				     G_CALLBACK(list[i].callback),
-				     (gpointer) obj); 
-		}
-		lib_free(itemp);
-		j++;
-	    }
+        if (new_item) {
+            gtk_menu_shell_append(GTK_MENU_SHELL(w), new_item);
+            gtk_widget_show(new_item);
+            if (do_right_justify) {
+                gtk_menu_item_set_right_justified(GTK_MENU_ITEM(new_item), TRUE);
             }
-
-            if (new_item)
-            {
-	        gtk_menu_shell_append(GTK_MENU_SHELL(w), new_item);
-	        gtk_widget_show(new_item);
-                if (do_right_justify)
-                    gtk_menu_item_set_right_justified(GTK_MENU_ITEM(new_item), TRUE);
 #ifdef DEBUG_MENUS
-	    printf("allocate new: %s\t(%p)\t%s\n",
-		   gtk_type_name(GTK_WIDGET_TYPE(new_item)), new_item,
-		   list[i].string);
+            printf("allocate new: %s\t(%p)\t%s\n", gtk_type_name(GTK_WIDGET_TYPE(new_item)), new_item, list[i].string);
 #endif
-            }
+        }
 
-            if (list[i].sub_menu) 
-	    {
-                GtkWidget *sub;
-                if (new_item && *list[i].string != '-')
-                {
-                    sub = gtk_menu_new();
-		    gtk_menu_item_set_submenu(GTK_MENU_ITEM(new_item),sub);
-                }
-                else
-                {
-                    sub = w;
-                }
-		ui_menu_create(sub, accel, list[i].string, 
-				     list[i].sub_menu);
-            } 
-	    else 
-	    {            /* no submenu */
-	        if (accel && list[i].hotkey_keysym != KEYSYM_NONE
-		    && list[i].callback != NULL && new_item != NULL)
-                    add_accelerator(new_item,
-                               accel, list[i].hotkey_keysym,
-                               list[i].hotkey_modifier);
+        if (list[i].sub_menu) {
+            GtkWidget *sub;
+            if (new_item && *list[i].string != '-') {
+                sub = gtk_menu_new();
+                gtk_menu_item_set_submenu(GTK_MENU_ITEM(new_item), sub);
+            } else {
+                sub = w;
+            }
+            ui_menu_create(sub, accel, list[i].string, list[i].sub_menu);
+        } else {            /* no submenu */
+            if (accel && list[i].hotkey_keysym != KEYSYM_NONE && list[i].callback != NULL && new_item != NULL) {
+                add_accelerator(new_item, accel, list[i].hotkey_keysym, list[i].hotkey_modifier);
             }
         }
+    }
     
     level--;
 }
@@ -258,19 +240,19 @@ static void menu_handle_block(gpointer data, gpointer user_data)
 {
     checkmark_t *cm = (checkmark_t *)data;
 
-    if (user_data)
-	g_signal_handler_block(GTK_OBJECT(cm->w), cm->handlerid);
-    else
-	g_signal_handler_unblock(GTK_OBJECT(cm->w), cm->handlerid);
+    if (user_data) {
+        g_signal_handler_block(GTK_OBJECT(cm->w), cm->handlerid);
+    } else {
+        g_signal_handler_unblock(GTK_OBJECT(cm->w), cm->handlerid);
+    }
 }
 
 static void menu_update_checkmarks(gpointer data, gpointer user_data)
 {
-    checkmark_t *cm = (checkmark_t *) data;
+    checkmark_t *cm = (checkmark_t *)data;
     
     cm->obj.status = CB_REFRESH;
-    ((void*(*)(GtkWidget*, ui_callback_data_t))
-     cm->cb)(cm->w, (ui_callback_data_t) &cm->obj);
+    ((void*(*)(GtkWidget*, ui_callback_data_t))cm->cb)(cm->w, (ui_callback_data_t) &cm->obj);
     cm->obj.status = CB_NORMAL;
 }
 
@@ -287,8 +269,9 @@ void ui_menu_update_all(void)
 }
 
 void ui_menu_set_tick(GtkWidget *w, int flag) {
-    if(GTK_IS_CHECK_MENU_ITEM(w))
-      gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(w), flag != 0);
+    if (GTK_IS_CHECK_MENU_ITEM(w)) {
+        gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(w), flag != 0);
+    }
 }
 
 void ui_menu_set_sensitive(GtkWidget *w, int flag)
@@ -302,60 +285,54 @@ void ui_menu_set_sensitive(GtkWidget *w, int flag)
    functions are defined through `UI_MENU_DEFINE_TOGGLE()',
    `UI_MENU_DEFINE_RADIO()' or `UI_MENU_DEFINE_STRING_RADIO()'.  */
 
-void _ui_menu_toggle_helper(GtkWidget *w,
-                            ui_callback_data_t event_data,
-                            const char *resource_name)
+void _ui_menu_toggle_helper(GtkWidget *w, ui_callback_data_t event_data, const char *resource_name)
 {
     int current_value;
 
-    if (resources_get_int(resource_name, &current_value) < 0)
+    if (resources_get_int(resource_name, &current_value) < 0) {
         return;
+    }
 
-    if(!CHECK_MENUS) {
+    if (!CHECK_MENUS) {
         resources_set_int(resource_name, !current_value);
-	ui_update_menus();
+        ui_update_menus();
     } else {
         ui_menu_set_tick(w, current_value);
     }
 }
 
-void _ui_menu_radio_helper(GtkWidget *w,
-                           ui_callback_data_t event_data,
-                           const char *resource_name)
+void _ui_menu_radio_helper(GtkWidget *w, ui_callback_data_t event_data, const char *resource_name)
 {
     int current_value;
 
     resources_get_int(resource_name, &current_value);
 
     if (!CHECK_MENUS) {
-        if (current_value != (int)UI_MENU_CB_PARAM) {
-            resources_set_int(resource_name, (int)UI_MENU_CB_PARAM);
+        if (current_value != vice_ptr_to_int(UI_MENU_CB_PARAM)) {
+            resources_set_int(resource_name, vice_ptr_to_int(UI_MENU_CB_PARAM));
             ui_update_menus();
         }
     } else {
-	ui_menu_set_tick(w, current_value == (int)UI_MENU_CB_PARAM);
-    }  
+        ui_menu_set_tick(w, current_value == vice_ptr_to_int(UI_MENU_CB_PARAM));
+    }
 }
 
-void _ui_menu_string_radio_helper(GtkWidget *w, 
-                                  ui_callback_data_t event_data,
-                                  const char *resource_name)
+void _ui_menu_string_radio_helper(GtkWidget *w, ui_callback_data_t event_data, const char *resource_name)
 {
     const char *current_value;
 
     resources_get_string(resource_name, &current_value);
 
-    if (current_value == NULL)
+    if (current_value == NULL) {
         return;
+    }
 
     if (!CHECK_MENUS) {
         if (strcmp(current_value, (const char *)UI_MENU_CB_PARAM) != 0) {
-	    resources_set_string(resource_name,(const char *)UI_MENU_CB_PARAM);
-	    ui_update_menus();
-	}
+            resources_set_string(resource_name,(const char *)UI_MENU_CB_PARAM);
+            ui_update_menus();
+        }
     } else {
-        ui_menu_set_tick(w, strcmp(current_value,
-                         (const char *) UI_MENU_CB_PARAM) == 0);
+        ui_menu_set_tick(w, strcmp(current_value, (const char *)UI_MENU_CB_PARAM) == 0);
     }
 }
-
