@@ -2,7 +2,7 @@
  * uisnapshot.c - Snapshot dialog for the Gnome widget set.
  *
  * Written by
- *  Martin Pottendorfer (Martin.Pottendorfer@alcatel.at)
+ *  pottendo <pottendo@gmx.net>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -30,54 +30,45 @@
 #include "uisnapshot.h"
 #include "ui.h"
 #include "uiarch.h"
+#include "uiapi.h"
 #include "machine.h"
 #include "uifileentry.h"
+#include "uilib.h"
 #include "lib.h"
 
-static GtkWidget *snapshot_dialog, *attach_disk, *attach_rom, *fileentry;
+static GtkWidget *snapshot_dialog, *attach_disk, *attach_rom;
 
 static GtkWidget *build_snapshot_dialog(void)
 {
     GtkWidget *d, *box, *tmp;
-    
-    d = gtk_dialog_new_with_buttons(_("Save Snapshot"), 
-			 NULL,
-			 GTK_DIALOG_DESTROY_WITH_PARENT,
-			 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-			 GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
-			 NULL);
+    uilib_file_filter_enum_t filter[] = { UILIB_FILTER_SNAPSHOT, UILIB_FILTER_ALL };
+
+    d = vice_file_entry(_("Save Snapshot"), NULL, NULL, filter, sizeof(filter) / sizeof(*filter), UI_FC_SAVE);
     box = gtk_hbox_new(0, FALSE);
 
-    fileentry = vice_file_entry(_("Save Snapshot"), NULL, "*.vsf", 
-				GTK_FILE_CHOOSER_ACTION_SAVE);
     gtk_dialog_set_default_response(GTK_DIALOG(d), GTK_RESPONSE_ACCEPT);
-    
-    gtk_box_pack_start(GTK_BOX(box), fileentry, TRUE, TRUE, 0);
-    gtk_widget_show(fileentry);
-    
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(d)->vbox), box, TRUE, TRUE, 0);
-    gtk_widget_show(box);
-    
+
     tmp = gtk_frame_new(_("Snapshot options"));
     box = gtk_vbox_new(0, FALSE);
-    
-    attach_disk = 
-	gtk_check_button_new_with_label(_("Save currently attached disks"));
+
+    attach_disk = gtk_check_button_new_with_label(_("Save currently attached disks"));
     gtk_box_pack_start(GTK_BOX(box), attach_disk, FALSE, FALSE, 0);
     gtk_widget_show(attach_disk);
 
-    attach_rom = 
-	gtk_check_button_new_with_label(_("Save currently attached ROMs"));
+    attach_rom = gtk_check_button_new_with_label(_("Save currently attached ROMs"));
     gtk_box_pack_start(GTK_BOX(box), attach_rom, FALSE, FALSE, 0);
     gtk_widget_show(attach_rom);
-    
+
     gtk_container_add(GTK_CONTAINER(tmp), box);
     gtk_widget_show(box);
-    
-    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(d)->vbox), tmp, TRUE, TRUE, 
-		       0);
+
+#if GTK_CHECK_VERSION(2, 14, 0)
+    gtk_box_pack_start(GTK_BOX(gtk_dialog_get_content_area(GTK_DIALOG(d))), tmp, TRUE, TRUE, 0);
+#else
+    gtk_box_pack_start(GTK_BOX(GTK_DIALOG(d)->vbox), tmp, TRUE, TRUE, 0);
+#endif
     gtk_widget_show(tmp);
-    
+
     return d;
 }
 
@@ -85,42 +76,35 @@ void ui_snapshot_dialog(void)
 {
     gint res;
     char *name;
-    
-    if (snapshot_dialog)
-    {
-	gdk_window_show(snapshot_dialog->window);
-	gdk_window_raise(snapshot_dialog->window);
-	gtk_widget_show(snapshot_dialog);
-    }
-    else
-    {
-	snapshot_dialog = build_snapshot_dialog();
-	g_signal_connect(G_OBJECT(snapshot_dialog),
-			 "destroy",
-			 G_CALLBACK(gtk_widget_destroyed),
-			 &snapshot_dialog);
+
+    if (snapshot_dialog) {
+        gdk_window_show(snapshot_dialog->window);
+        gdk_window_raise(snapshot_dialog->window);
+        gtk_widget_show(snapshot_dialog);
+    } else {
+        snapshot_dialog = build_snapshot_dialog();
+        g_signal_connect(G_OBJECT(snapshot_dialog), "destroy", G_CALLBACK(gtk_widget_destroyed), &snapshot_dialog);
     }
 
     ui_popup(snapshot_dialog, "Save Snapshot", FALSE);
     res = gtk_dialog_run(GTK_DIALOG(snapshot_dialog));
     ui_popdown(snapshot_dialog);
-    
-    if (res != GTK_RESPONSE_ACCEPT)
-	return;
-    
-    name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fileentry));
-    if (!name)
-    {
-	ui_error(_("Invalid filename"));
-	return;
+
+    if (res != GTK_RESPONSE_ACCEPT) {
+        return;
     }
     
+    name = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(snapshot_dialog));
+    if (!name) {
+        ui_error(_("Invalid filename"));
+        return;
+    }
+
     /* ok button pressed */
-    if (machine_write_snapshot(name, GTK_TOGGLE_BUTTON(attach_rom)->active, 
-			       GTK_TOGGLE_BUTTON(attach_disk)->active, 0) < 0)
+    if (machine_write_snapshot(name, GTK_TOGGLE_BUTTON(attach_rom)->active, GTK_TOGGLE_BUTTON(attach_disk)->active, 0) < 0) {
         ui_error(_("Cannot write snapshot file\n`%s'\n"), name);
-    else
-	ui_message(_("Successfully wrote `%s'\n"), name);
+    } else {
+        ui_message(_("Successfully wrote `%s'\n"), name);
+    }
     lib_free(name);
 }
-
