@@ -25,8 +25,8 @@
  *
  */
 
-#ifndef _X11MENU_H
-#define _X11MENU_H
+#ifndef VICE_X11MENU_H
+#define VICE_X11MENU_H
 
 #include "vice.h"
 
@@ -51,12 +51,11 @@ typedef struct ui_menu_entry_s {
     ui_hotkey_modifier_t hotkey_modifier;
 } ui_menu_entry_t;
 
-void ui_set_drive_menu(int drvnr, ui_menu_entry_t *menu);
-void ui_set_tape_menu(ui_menu_entry_t *menu);
-void ui_set_topmenu(ui_menu_entry_t *menu);
-void ui_set_speedmenu(ui_menu_entry_t *menu);
-void ui_set_left_menu(ui_menu_entry_t *menu);
-void ui_set_right_menu(ui_menu_entry_t *menu);
+extern void ui_set_drive_menu(int drvnr, ui_menu_entry_t *menu);
+extern void ui_set_tape_menu(ui_menu_entry_t *menu);
+extern void ui_set_topmenu(ui_menu_entry_t *menu);
+extern void ui_set_speedmenu(ui_menu_entry_t *menu);
+extern void ui_set_left_menu(ui_menu_entry_t *menu);
+extern void ui_set_right_menu(ui_menu_entry_t *menu);
 
 #endif
-
