@@ -24,21 +24,21 @@
  *
  */
 
-#ifndef _ARCHDEP_H
-#define _ARCHDEP_H
+#ifndef VICE_ARCHDEP_H
+#define VICE_ARCHDEP_H
 
 #include "archapi.h"
 
 /* Filesystem dependant operators.  */
-#define FSDEVICE_DEFAULT_DIR   "."
-#define FSDEV_DIR_SEP_STR      "\\"
-#define FSDEV_DIR_SEP_CHR      '\\'
-#define FSDEV_EXT_SEP_STR      "."
-#define FSDEV_EXT_SEP_CHR      '.'
+#define FSDEVICE_DEFAULT_DIR "."
+#define FSDEV_DIR_SEP_STR    "\\"
+#define FSDEV_DIR_SEP_CHR    '\\'
+#define FSDEV_EXT_SEP_STR    "."
+#define FSDEV_EXT_SEP_CHR    '.'
 
 /* Path separator.  */
-#define ARCHDEP_FINDPATH_SEPARATOR_CHAR         ';'
-#define ARCHDEP_FINDPATH_SEPARATOR_STRING       ";"
+#define ARCHDEP_FINDPATH_SEPARATOR_CHAR   ';'
+#define ARCHDEP_FINDPATH_SEPARATOR_STRING ";"
 
 /* Modes for fopen().  */
 #define MODE_READ              "r"
@@ -102,7 +102,9 @@
 /* No key symcode.  */
 #define ARCHDEP_KEYBOARD_SYM_NONE 0
 
+/* Default sound fragment size */
+#define ARCHDEP_SOUND_FRAGMENT_SIZE 2
+
 extern void archdep_workaround_nop(const char *otto);
  
 #endif
-
