@@ -43,10 +43,14 @@
 #include "uidigimax.h"
 #include "uidqbb.h"
 #include "uidrivec64.h"
+#include "uieasyflash.h"
 #include "uigeoram.h"
 #include "uiide64.h"
 #include "uiisepic.h"
+#include "uijoystick.h"
 #include "uikeyboard.h"
+#include "uilib.h"
+#include "uilightpen.h"
 #include "uimidi.h"
 #include "uimmc64.h"
 #include "uimouse.h"
@@ -57,16 +61,16 @@
 #include "uirom.h"
 #include "uirs232user.h"
 #include "uisid.h"
+#include "uisoundexpander.h"
 #include "uitfe.h"
 #include "uivicii.h"
 #include "uivideo.h"
 
-
 static const unsigned int romset_dialog_resources[UIROM_TYPE_MAX] = {
     IDD_C64ROM_RESOURCE_DIALOG,
     IDD_C64ROMDRIVE_RESOURCE_DIALOG,
-    0 };
-
+    0
+};
 
 static const ui_menu_toggle_t c64_ui_menu_toggles[] = {
     { "EmuID", IDM_TOGGLE_EMUID },
@@ -78,6 +82,7 @@ static const ui_menu_toggle_t c64_ui_menu_toggles[] = {
     { "Mouse", IDM_MOUSE },
     { "CartridgeReset", IDM_TOGGLE_CART_RESET },
     { "IsepicSwitch", IDM_ISEPIC_SWITCH },
+    { "SFXSoundSampler", IDM_TOGGLE_SFX_SS },
     { NULL, 0 }
 };
 
@@ -135,9 +140,63 @@ static const uikeyboard_mapping_entry_t mapping_entry[C64UI_KBD_NUM_MAP] = {
       IDC_C64KBD_MAPPING_SYMDE_BROWSE, "KeymapSymDeFile" }
 };
 
-static uikeyboard_config_t uikeyboard_config =
-    { IDD_C64KBD_MAPPING_SETTINGS_DIALOG, C64UI_KBD_NUM_MAP, mapping_entry,
-      IDC_C64KBD_MAPPING_DUMP };
+static uilib_localize_dialog_param c64_kbd_trans[] = {
+    { IDC_C64KBD_MAPPING_SELECT_SYM, IDS_SYMBOLIC_US, 0 },
+    { IDC_C64KBD_MAPPING_SELECT_SYMDE, IDS_SYMBOLIC_DE, 0 },
+    { IDC_C64KBD_MAPPING_SELECT_POS, IDS_POSITIONAL, 0 },
+    { IDC_C64KBD_MAPPING_SYM_BROWSE, IDS_BROWSE, 0 },
+    { IDC_C64KBD_MAPPING_SYMDE_BROWSE, IDS_BROWSE, 0 },
+    { IDC_C64KBD_MAPPING_POS_BROWSE, IDS_BROWSE, 0 },
+    { IDC_C64KBD_MAPPING_DUMP, IDS_DUMP_KEYSET, 0 },
+    { IDC_KBD_SHORTCUT_DUMP, IDS_DUMP_SHORTCUTS, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_dialog_group c64_kbd_left_group[] = {
+    { IDC_C64KBD_MAPPING_SELECT_SYM, 1 },
+    { IDC_C64KBD_MAPPING_SELECT_SYMDE, 1 },
+    { IDC_C64KBD_MAPPING_SELECT_POS, 1 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group c64_kbd_middle_group[] = {
+    { IDC_C64KBD_MAPPING_SYM, 0 },
+    { IDC_C64KBD_MAPPING_SYMDE, 0 },
+    { IDC_C64KBD_MAPPING_POS, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group c64_kbd_right_group[] = {
+    { IDC_C64KBD_MAPPING_SYM_BROWSE, 0 },
+    { IDC_C64KBD_MAPPING_SYMDE_BROWSE, 0 },
+    { IDC_C64KBD_MAPPING_POS_BROWSE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group c64_kbd_buttons_group[] = {
+    { IDC_C64KBD_MAPPING_DUMP, 1 },
+    { IDC_KBD_SHORTCUT_DUMP, 1 },
+    { 0, 0 }
+};
+
+static int c64_kbd_move_buttons_group[] = {
+    IDC_C64KBD_MAPPING_DUMP,
+    IDC_KBD_SHORTCUT_DUMP,
+    0
+};
+
+static uikeyboard_config_t uikeyboard_config = {
+    IDD_C64KBD_MAPPING_SETTINGS_DIALOG,
+    C64UI_KBD_NUM_MAP,
+    mapping_entry,
+    IDC_C64KBD_MAPPING_DUMP,
+    c64_kbd_trans,
+    c64_kbd_left_group,
+    c64_kbd_middle_group,
+    c64_kbd_right_group,
+    c64_kbd_buttons_group,
+    c64_kbd_move_buttons_group
+};
 
 ui_menu_translation_table_t c64ui_menu_translation_table[] = {
     { IDM_EXIT, IDS_MI_EXIT },
@@ -168,6 +227,7 @@ ui_menu_translation_table_t c64ui_menu_translation_table[] = {
     { IDM_TOGGLE_DOUBLESIZE, IDS_MI_TOGGLE_DOUBLESIZE },
     { IDM_TOGGLE_DOUBLESCAN, IDS_MI_TOGGLE_DOUBLESCAN },
     { IDM_TOGGLE_DRIVE_TRUE_EMULATION, IDS_MI_DRIVE_TRUE_EMULATION },
+    { IDM_TOGGLE_AUTOSTART_HANDLE_TDE, IDS_MI_AUTOSTART_HANDLE_TDE },
     { IDM_TOGGLE_VIDEOCACHE, IDS_MI_TOGGLE_VIDEOCACHE },
     { IDM_DRIVE_SETTINGS, IDS_MI_DRIVE_SETTINGS },
     { IDM_CART_ATTACH_CRT, IDS_MI_CART_ATTACH_CRT },
@@ -239,13 +299,17 @@ ui_menu_translation_table_t c64ui_menu_translation_table[] = {
     { IDM_TOGGLE_FASTPAL, IDS_MI_TOGGLE_FASTPAL },
     { IDM_TOGGLE_SCALE2X, IDS_MI_TOGGLE_SCALE2X },
     { IDM_SWAP_JOYSTICK, IDS_MI_SWAP_JOYSTICK },
+    { IDM_SWAP_EXTRA_JOYSTICK, IDS_MI_SWAP_EXTRA_JOYSTICK },
+    { IDM_ALLOW_JOY_OPPOSITE_TOGGLE, IDS_MI_ALLOW_JOY_OPPOSITE },
     { IDM_JOYKEYS_TOGGLE, IDS_MI_JOYKEYS_TOGGLE },
     { IDM_TOGGLE_VIRTUAL_DEVICES, IDS_MI_TOGGLE_VIRTUAL_DEVICES },
     { IDM_TOGGLE_EMUID, IDS_MI_TOGGLE_EMUID },
     { IDM_MOUSE, IDS_MI_MOUSE },
+    { IDM_AUTOSTART_SETTINGS, IDS_MI_AUTOSTART_SETTINGS },
     { IDM_VIDEO_SETTINGS, IDS_MI_VIDEO_SETTINGS },
     { IDM_DEVICEMANAGER, IDS_MI_DEVICEMANAGER },
     { IDM_JOY_SETTINGS, IDS_MI_JOY_SETTINGS },
+    { IDM_EXTRA_JOY_SETTINGS, IDS_MI_USERPORT_JOY_SETTINGS },
     { IDM_KEYBOARD_SETTINGS, IDS_MI_KEYBOARD_SETTINGS },
     { IDM_SOUND_SETTINGS, IDS_MI_SOUND_SETTINGS },
     { IDM_ROM_SETTINGS, IDS_MI_ROM_SETTINGS },
@@ -253,6 +317,7 @@ ui_menu_translation_table_t c64ui_menu_translation_table[] = {
     { IDM_DATASETTE_SETTINGS, IDS_MI_DATASETTE_SETTINGS },
     { IDM_VICII_SETTINGS, IDS_MI_VICII_SETTINGS },
     { IDM_MOUSE_SETTINGS, IDS_MI_MOUSE_SETTINGS },
+    { IDM_LIGHTPEN_SETTINGS, IDS_MI_LIGHTPEN_SETTINGS },
     { IDM_SID_SETTINGS, IDS_MI_SID_SETTINGS },
     { IDM_RS232_SETTINGS, IDS_MI_RS232_SETTINGS },
     { IDM_REU_SETTINGS, IDS_MI_REU_SETTINGS },
@@ -269,6 +334,9 @@ ui_menu_translation_table_t c64ui_menu_translation_table[] = {
 #endif
     { IDM_ACIA_SETTINGS, IDS_MI_ACIA_SETTINGS },
     { IDM_RS232USER_SETTINGS, IDS_MI_RS232USER_SETTINGS },
+    { IDM_EASYFLASH_SETTINGS, IDS_MI_EASYFLASH_SETTINGS },
+    { IDM_SFX_SE_SETTINGS, IDS_MI_SFX_SE_SETTINGS },
+    { IDM_TOGGLE_SFX_SS, IDS_MI_TOGGLE_SFX_SS },
     { IDM_SETTINGS_SAVE_FILE, IDS_MI_SETTINGS_SAVE_FILE },
     { IDM_SETTINGS_LOAD_FILE, IDS_MI_SETTINGS_LOAD_FILE },
     { IDM_SETTINGS_SAVE, IDS_MI_SETTINGS_SAVE },
@@ -277,6 +345,7 @@ ui_menu_translation_table_t c64ui_menu_translation_table[] = {
     { IDM_TOGGLE_SAVE_SETTINGS_ON_EXIT, IDS_MI_SAVE_SETTINGS_ON_EXIT },
     { IDM_TOGGLE_CONFIRM_ON_EXIT, IDS_MI_CONFIRM_ON_EXIT },
     { IDM_LANG_EN, IDS_MI_LANG_EN },
+    { IDM_LANG_DA, IDS_MI_LANG_DA },
     { IDM_LANG_DE, IDS_MI_LANG_DE },
     { IDM_LANG_FR, IDS_MI_LANG_FR },
     { IDM_LANG_HU, IDS_MI_LANG_HU },
@@ -284,6 +353,7 @@ ui_menu_translation_table_t c64ui_menu_translation_table[] = {
     { IDM_LANG_NL, IDS_MI_LANG_NL },
     { IDM_LANG_PL, IDS_MI_LANG_PL },
     { IDM_LANG_SV, IDS_MI_LANG_SV },
+    { IDM_LANG_TR, IDS_MI_LANG_TR },
     { IDM_CMDLINE, IDS_MI_CMDLINE },
     { IDM_CONTRIBUTORS, IDS_MI_CONTRIBUTORS },
     { IDM_LICENSE, IDS_MI_LICENSE },
@@ -323,81 +393,197 @@ ui_popup_translation_table_t c64ui_popup_translation_table[] = {
     { 0, 0 }
 };
 
+static uilib_localize_dialog_param c64_main_trans[] = {
+    { IDC_KERNAL, IDS_KERNAL, 0 },
+    { IDC_C64ROM_KERNAL_BROWSE, IDS_BROWSE, 0 },
+    { IDC_BASIC, IDS_BASIC, 0 },
+    { IDC_C64ROM_BASIC_BROWSE, IDS_BROWSE, 0 },
+    { IDC_CHARACTER, IDS_CHARACTER, 0 },
+    { IDC_C64ROM_CHARGEN_BROWSE, IDS_BROWSE, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_localize_dialog_param c64_drive_trans[] = {
+    { IDC_DRIVEROM_1541_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1541II_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1570_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1571_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1581_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_2031_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_2040_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_3040_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_4040_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1001_BROWSE, IDS_BROWSE, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_localize_dialog_param c64_main_res_trans[] = {
+    { 0, IDS_COMPUTER_RESOURCES_CAPTION, -1 },
+    { IDC_COMPUTER_RESOURCES, IDS_COMPUTER_RESOURCES, 0 },
+    { IDC_C64ROM_KERNAL_RESOURCE, IDS_KERNAL, 0 },
+    { IDC_C64ROM_BASIC_RESOURCE, IDS_BASIC, 0 },
+    { IDC_C64ROM_CHARGEN_RESOURCE, IDS_CHARACTER, 0 },
+    { IDOK, IDS_OK, 0 },
+    { IDCANCEL, IDS_CANCEL, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_dialog_group c64_main_left_group[] = {
+    { IDC_KERNAL, 0 },
+    { IDC_BASIC, 0 },
+    { IDC_CHARACTER, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group c64_main_middle_group[] = {
+    { IDC_C64ROM_KERNAL_FILE, 0 },
+    { IDC_C64ROM_BASIC_FILE, 0} ,
+    { IDC_C64ROM_CHARGEN_FILE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group c64_main_right_group[] = {
+    { IDC_C64ROM_KERNAL_BROWSE, 0 },
+    { IDC_C64ROM_BASIC_BROWSE, 0 },
+    { IDC_C64ROM_CHARGEN_BROWSE, 0 },
+    { 0, 0}
+};
+
+static uilib_dialog_group c64_drive_left_group[] = {
+    { IDC_1541, 0 },
+    { IDC_1541_II, 0 },
+    { IDC_1570, 0 },
+    { IDC_1571, 0 },
+    { IDC_1581, 0 },
+    { IDC_2031, 0 },
+    { IDC_2040, 0 },
+    { IDC_3040, 0 },
+    { IDC_4040, 0 },
+    { IDC_1001, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group c64_drive_middle_group[] = {
+    { IDC_DRIVEROM_1541_FILE, 0 },
+    { IDC_DRIVEROM_1541II_FILE, 0 },
+    { IDC_DRIVEROM_1570_FILE, 0 },
+    { IDC_DRIVEROM_1571_FILE, 0 },
+    { IDC_DRIVEROM_1581_FILE, 0 },
+    { IDC_DRIVEROM_2031_FILE, 0 },
+    { IDC_DRIVEROM_2040_FILE, 0 },
+    { IDC_DRIVEROM_3040_FILE, 0 },
+    { IDC_DRIVEROM_4040_FILE, 0 },
+    { IDC_DRIVEROM_1001_FILE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group c64_drive_right_group[] = {
+    { IDC_DRIVEROM_1541_BROWSE, 0 },
+    { IDC_DRIVEROM_1541II_BROWSE, 0 },
+    { IDC_DRIVEROM_1570_BROWSE, 0 },
+    { IDC_DRIVEROM_1571_BROWSE, 0 },
+    { IDC_DRIVEROM_1581_BROWSE, 0 },
+    { IDC_DRIVEROM_2031_BROWSE, 0 },
+    { IDC_DRIVEROM_2040_BROWSE, 0 },
+    { IDC_DRIVEROM_3040_BROWSE, 0 },
+    { IDC_DRIVEROM_4040_BROWSE, 0 },
+    { IDC_DRIVEROM_1001_BROWSE, 0 },
+    { 0, 0 }
+};
+
 static void c64_ui_specific(WPARAM wparam, HWND hwnd)
 {
     uic64cart_proc(wparam, hwnd);
 
     switch (wparam) {
-      case IDM_VICII_SETTINGS:
-        ui_vicii_settings_dialog(hwnd);
-        break;
-      case IDM_SID_SETTINGS:
-        ui_sid_settings_dialog(hwnd);
-        break;
-      case IDM_REU_SETTINGS:
-        ui_reu_settings_dialog(hwnd);
-        break;
-      case IDM_GEORAM_SETTINGS:
-        ui_georam_settings_dialog(hwnd);
-        break;
-      case IDM_RAMCART_SETTINGS:
-        ui_ramcart_settings_dialog(hwnd);
-        break;
-      case IDM_DQBB_SETTINGS:
-        ui_dqbb_settings_dialog(hwnd);
-        break;
-      case IDM_ISEPIC_SETTINGS:
-        ui_isepic_settings_dialog(hwnd);
-        break;
-      case IDM_PLUS60K_SETTINGS:
-        ui_plus60k_settings_dialog(hwnd);
-        break;
-      case IDM_PLUS256K_SETTINGS:
-        ui_plus256k_settings_dialog(hwnd);
-        break;
-      case IDM_C64_256K_SETTINGS:
-        ui_c64_256k_settings_dialog(hwnd);
-        break;
-      case IDM_MIDI_SETTINGS:
-        ui_midi_settings_dialog(hwnd);
-        break;
-      case IDM_MMC64_SETTINGS:
-        ui_mmc64_settings_dialog(hwnd);
-        break;
-      case IDM_DIGIMAX_SETTINGS:
-        ui_digimax_settings_dialog(hwnd);
-        break;
-      case IDM_IDE64_SETTINGS:
-        uiide64_settings_dialog(hwnd);
-        break;
-      case IDM_ROM_SETTINGS:
-        uirom_settings_dialog(hwnd, translate_res(IDD_C64ROM_SETTINGS_DIALOG),
-                              translate_res(IDD_C64DRIVEROM_SETTINGS_DIALOG),
-                              romset_dialog_resources, uirom_settings);
-        break;
+        case IDM_VICII_SETTINGS:
+            ui_vicii_settings_dialog(hwnd);
+            break;
+        case IDM_SID_SETTINGS:
+            ui_sid_settings_dialog(hwnd);
+            break;
+        case IDM_REU_SETTINGS:
+            ui_reu_settings_dialog(hwnd);
+            break;
+        case IDM_GEORAM_SETTINGS:
+            ui_georam_settings_dialog(hwnd);
+            break;
+        case IDM_RAMCART_SETTINGS:
+            ui_ramcart_settings_dialog(hwnd);
+            break;
+        case IDM_DQBB_SETTINGS:
+            ui_dqbb_settings_dialog(hwnd);
+            break;
+        case IDM_ISEPIC_SETTINGS:
+            ui_isepic_settings_dialog(hwnd);
+            break;
+        case IDM_PLUS60K_SETTINGS:
+            ui_plus60k_settings_dialog(hwnd);
+            break;
+        case IDM_PLUS256K_SETTINGS:
+            ui_plus256k_settings_dialog(hwnd);
+            break;
+        case IDM_C64_256K_SETTINGS:
+            ui_c64_256k_settings_dialog(hwnd);
+            break;
+        case IDM_MIDI_SETTINGS:
+            ui_midi_settings_dialog(hwnd);
+            break;
+        case IDM_MMC64_SETTINGS:
+            ui_mmc64_settings_dialog(hwnd);
+            break;
+        case IDM_DIGIMAX_SETTINGS:
+            ui_digimax_settings_dialog(hwnd);
+            break;
+        case IDM_LIGHTPEN_SETTINGS:
+            ui_lightpen_settings_dialog(hwnd);
+            break;
+        case IDM_EASYFLASH_SETTINGS:
+            ui_easyflash_settings_dialog(hwnd);
+            break;
+        case IDM_SFX_SE_SETTINGS:
+            ui_soundexpander_settings_dialog(hwnd);
+            break;
+        case IDM_IDE64_SETTINGS:
+            uiide64_settings_dialog(hwnd);
+            break;
+        case IDM_JOY_SETTINGS:
+            ui_joystick_settings_dialog(hwnd);
+            break;
+        case IDM_EXTRA_JOY_SETTINGS:
+            ui_extra_joystick_settings_dialog(hwnd);
+            break;
+        case IDM_ROM_SETTINGS:
+            uirom_settings_dialog(hwnd, IDD_C64ROM_SETTINGS_DIALOG, IDD_C64DRIVEROM_SETTINGS_DIALOG,
+                                  romset_dialog_resources, uirom_settings,
+                                  c64_main_trans, c64_drive_trans,
+                                  c64_main_left_group, c64_main_middle_group, c64_main_right_group,
+                                  c64_drive_left_group, c64_drive_middle_group, c64_drive_right_group,
+                                  c64_main_res_trans);
+            break;
 #ifdef HAVE_TFE
-      case IDM_TFE_SETTINGS:
-        ui_tfe_settings_dialog(hwnd);
-        break;
+        case IDM_TFE_SETTINGS:
+           ui_tfe_settings_dialog(hwnd);
+           break;
 #endif
-      case IDM_VIDEO_SETTINGS:
-        ui_video_settings_dialog(hwnd, UI_VIDEO_CHIP_VICII, UI_VIDEO_CHIP_NONE);
-        break;
-      case IDM_DRIVE_SETTINGS:
-        uidrivec64_settings_dialog(hwnd);
-        break;
-      case IDM_ACIA_SETTINGS:
-        ui_acia_settings_dialog(hwnd, 1, NULL, 1, 1);
-        break;
-      case IDM_RS232USER_SETTINGS:
-        ui_rs232user_settings_dialog(hwnd);
-        break;
-      case IDM_KEYBOARD_SETTINGS:
-        uikeyboard_settings_dialog(hwnd, &uikeyboard_config);
-        break;
-      case IDM_MOUSE_SETTINGS:
-        ui_mouse_settings_dialog(hwnd);
-        break;
+        case IDM_VIDEO_SETTINGS:
+            ui_video_settings_dialog(hwnd, UI_VIDEO_CHIP_VICII, UI_VIDEO_CHIP_NONE);
+            break;
+        case IDM_DRIVE_SETTINGS:
+            uidrivec64_settings_dialog(hwnd);
+            break;
+        case IDM_ACIA_SETTINGS:
+            ui_acia_settings_dialog(hwnd, 1, NULL, 1, 1);
+            break;
+        case IDM_RS232USER_SETTINGS:
+            ui_rs232user_settings_dialog(hwnd);
+            break;
+        case IDM_KEYBOARD_SETTINGS:
+            uikeyboard_settings_dialog(hwnd, &uikeyboard_config);
+            break;
+        case IDM_MOUSE_SETTINGS:
+            ui_mouse_settings_dialog(hwnd);
+            break;
     }
 }
 
@@ -415,4 +601,3 @@ int c64ui_init(void)
 void c64ui_shutdown(void)
 {
 }
-
