@@ -31,6 +31,7 @@
 #include <windows.h>
 
 #include "debug.h"
+#include "machine.h"
 #include "petui.h"
 #include "res.h"
 #include "resources.h"
@@ -39,18 +40,19 @@
 #include "uiacia.h"
 #include "uicbm2set.h"
 #include "uidrivepetcbm2.h"
+#include "uijoystick.h"
 #include "uikeyboard.h"
+#include "uilib.h"
 #include "uirom.h"
 #include "uisid.h"
 #include "uivideo.h"
 #include "winmain.h"
 
-
 static const unsigned int romset_dialog_resources[UIROM_TYPE_MAX] = {
     IDD_CBM2ROM_RESOURCE_DIALOG,
     IDD_CBM2ROMDRIVE_RESOURCE_DIALOG,
-    0 };
-
+    0
+};
 
 static const ui_menu_toggle_t cbm2_ui_menu_toggles[] = {
     { "EmuID", IDM_TOGGLE_EMUID },
@@ -121,9 +123,78 @@ static const uikeyboard_mapping_entry_t mapping_entry[CBM2UI_KBD_NUM_MAP] = {
       IDC_CBM2KBD_MAPPING_DEPOS_BROWSE, "KeymapBusinessDEPosFile" }
 };
 
-static uikeyboard_config_t uikeyboard_config =
-    { IDD_CBM2KBD_MAPPING_SETTINGS_DIALOG, CBM2UI_KBD_NUM_MAP, mapping_entry,
-      IDC_CBM2KBD_MAPPING_DUMP };
+static uilib_localize_dialog_param cbm2_kbd_trans[] = {
+    { IDC_CBM2KBD_MAPPING_SELECT_GRSYM, IDS_GR_SYM, 0 },
+    { IDC_CBM2KBD_MAPPING_SELECT_GRPOS, IDS_GR_POS, 0 },
+    { IDC_CBM2KBD_MAPPING_SELECT_UKSYM, IDS_UK_SYM, 0 },
+    { IDC_CBM2KBD_MAPPING_SELECT_UKPOS, IDS_UK_POS, 0 },
+    { IDC_CBM2KBD_MAPPING_SELECT_DESYM, IDS_DE_SYM, 0 },
+    { IDC_CBM2KBD_MAPPING_SELECT_DEPOS, IDS_DE_POS, 0 },
+    { IDC_CBM2KBD_MAPPING_GRSYM_BROWSE, IDS_BROWSE, 0 },
+    { IDC_CBM2KBD_MAPPING_GRPOS_BROWSE, IDS_BROWSE, 0 },
+    { IDC_CBM2KBD_MAPPING_UKSYM_BROWSE, IDS_BROWSE, 0 },
+    { IDC_CBM2KBD_MAPPING_UKPOS_BROWSE, IDS_BROWSE, 0 },
+    { IDC_CBM2KBD_MAPPING_DESYM_BROWSE, IDS_BROWSE, 0 },
+    { IDC_CBM2KBD_MAPPING_DEPOS_BROWSE, IDS_BROWSE, 0 },
+    { IDC_CBM2KBD_MAPPING_DUMP, IDS_DUMP_KEYSET, 0 },
+    { IDC_KBD_SHORTCUT_DUMP, IDS_DUMP_SHORTCUTS, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_dialog_group cbm2_kbd_left_group[] = {
+    { IDC_CBM2KBD_MAPPING_SELECT_GRSYM, 1 },
+    { IDC_CBM2KBD_MAPPING_SELECT_GRPOS, 1 },
+    { IDC_CBM2KBD_MAPPING_SELECT_UKSYM, 1 },
+    { IDC_CBM2KBD_MAPPING_SELECT_UKPOS, 1 },
+    { IDC_CBM2KBD_MAPPING_SELECT_DESYM, 1 },
+    { IDC_CBM2KBD_MAPPING_SELECT_DEPOS, 1 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group cbm2_kbd_middle_group[] = {
+    { IDC_CBM2KBD_MAPPING_GRSYM, 0 },
+    { IDC_CBM2KBD_MAPPING_GRPOS, 0 },
+    { IDC_CBM2KBD_MAPPING_UKSYM, 0 },
+    { IDC_CBM2KBD_MAPPING_UKPOS, 0 },
+    { IDC_CBM2KBD_MAPPING_DESYM, 0 },
+    { IDC_CBM2KBD_MAPPING_DEPOS, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group cbm2_kbd_right_group[] = {
+    { IDC_CBM2KBD_MAPPING_GRSYM_BROWSE, 0 },
+    { IDC_CBM2KBD_MAPPING_GRPOS_BROWSE, 0 },
+    { IDC_CBM2KBD_MAPPING_UKSYM_BROWSE, 0 },
+    { IDC_CBM2KBD_MAPPING_UKPOS_BROWSE, 0 },
+    { IDC_CBM2KBD_MAPPING_DESYM_BROWSE, 0 },
+    { IDC_CBM2KBD_MAPPING_DEPOS_BROWSE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group cbm2_kbd_buttons_group[] = {
+    { IDC_CBM2KBD_MAPPING_DUMP, 1 },
+    { IDC_KBD_SHORTCUT_DUMP, 1 },
+    { 0, 0 }
+};
+
+static int cbm2_kbd_move_buttons_group[] = {
+    IDC_CBM2KBD_MAPPING_DUMP,
+    IDC_KBD_SHORTCUT_DUMP,
+    0
+};
+
+static uikeyboard_config_t uikeyboard_config = {
+    IDD_CBM2KBD_MAPPING_SETTINGS_DIALOG,
+    CBM2UI_KBD_NUM_MAP,
+    mapping_entry,
+    IDC_CBM2KBD_MAPPING_DUMP,
+    cbm2_kbd_trans,
+    cbm2_kbd_left_group,
+    cbm2_kbd_middle_group,
+    cbm2_kbd_right_group,
+    cbm2_kbd_buttons_group,
+    cbm2_kbd_move_buttons_group
+};
 
 ui_menu_translation_table_t cbm2ui_menu_translation_table[] = {
     { IDM_EXIT, IDS_MI_EXIT },
@@ -154,6 +225,7 @@ ui_menu_translation_table_t cbm2ui_menu_translation_table[] = {
     { IDM_TOGGLE_CRTCDOUBLESIZE, IDS_MI_TOGGLE_DOUBLESIZE },
     { IDM_TOGGLE_CRTCDOUBLESCAN, IDS_MI_TOGGLE_DOUBLESCAN },
     { IDM_TOGGLE_DRIVE_TRUE_EMULATION, IDS_MI_DRIVE_TRUE_EMULATION },
+    { IDM_TOGGLE_AUTOSTART_HANDLE_TDE, IDS_MI_AUTOSTART_HANDLE_TDE },
     { IDM_TOGGLE_CRTCVIDEOCACHE, IDS_MI_TOGGLE_VIDEOCACHE },
     { IDM_DRIVE_SETTINGS, IDS_MI_DRIVE_SETTINGS },
     { IDM_FLIP_ADD, IDS_MI_FLIP_ADD },
@@ -201,9 +273,11 @@ ui_menu_translation_table_t cbm2ui_menu_translation_table[] = {
     { IDM_TOGGLE_WARP_MODE, IDS_MI_TOGGLE_WARP_MODE },
     { IDM_TOGGLE_ALWAYSONTOP, IDS_MI_TOGGLE_ALWAYSONTOP },
     { IDM_SWAP_JOYSTICK, IDS_MI_SWAP_JOYSTICK },
+    { IDM_ALLOW_JOY_OPPOSITE_TOGGLE, IDS_MI_ALLOW_JOY_OPPOSITE },
     { IDM_JOYKEYS_TOGGLE, IDS_MI_JOYKEYS_TOGGLE },
     { IDM_TOGGLE_VIRTUAL_DEVICES, IDS_MI_TOGGLE_VIRTUAL_DEVICES },
     { IDM_TOGGLE_EMUID, IDS_MI_TOGGLE_EMUID },
+    { IDM_AUTOSTART_SETTINGS, IDS_MI_AUTOSTART_SETTINGS },
     { IDM_VIDEO_SETTINGS, IDS_MI_VIDEO_SETTINGS },
     { IDM_DEVICEMANAGER, IDS_MI_DEVICEMANAGER },
     { IDM_JOY_SETTINGS, IDS_MI_JOY_SETTINGS },
@@ -223,6 +297,7 @@ ui_menu_translation_table_t cbm2ui_menu_translation_table[] = {
     { IDM_TOGGLE_SAVE_SETTINGS_ON_EXIT, IDS_MI_SAVE_SETTINGS_ON_EXIT },
     { IDM_TOGGLE_CONFIRM_ON_EXIT, IDS_MI_CONFIRM_ON_EXIT },
     { IDM_LANG_EN, IDS_MI_LANG_EN },
+    { IDM_LANG_DA, IDS_MI_LANG_DA },
     { IDM_LANG_DE, IDS_MI_LANG_DE },
     { IDM_LANG_FR, IDS_MI_LANG_FR },
     { IDM_LANG_HU, IDS_MI_LANG_HU },
@@ -230,6 +305,7 @@ ui_menu_translation_table_t cbm2ui_menu_translation_table[] = {
     { IDM_LANG_NL, IDS_MI_LANG_NL },
     { IDM_LANG_PL, IDS_MI_LANG_PL },
     { IDM_LANG_SV, IDS_MI_LANG_SV },
+    { IDM_LANG_TR, IDS_MI_LANG_TR },
     { IDM_CMDLINE, IDS_MI_CMDLINE },
     { IDM_CONTRIBUTORS, IDS_MI_CONTRIBUTORS },
     { IDM_LICENSE, IDS_MI_LICENSE },
@@ -264,40 +340,162 @@ ui_popup_translation_table_t cbm2ui_popup_translation_table[] = {
     { 0, 0 }
 };
 
+static uilib_localize_dialog_param cbm2_main_trans[] = {
+    { IDC_KERNAL, IDS_KERNAL, 0 },
+    { IDC_CBM2ROM_KERNAL_BROWSE, IDS_BROWSE, 0 },
+    { IDC_BASIC, IDS_BASIC, 0 },
+    { IDC_CBM2ROM_BASIC_BROWSE, IDS_BROWSE, 0 },
+    { IDC_CHARACTER, IDS_CHARACTER, 0 },
+    { IDC_CBM2ROM_CHARGEN_BROWSE, IDS_BROWSE, 0 },
+    { IDC_CART_1, IDS_CART_1, 0 },
+    { IDC_CBM2ROM_CART1_BROWSE, IDS_BROWSE, 0 },
+    { IDC_CART_2, IDS_CART_2, 0 },
+    { IDC_CBM2ROM_CART2_BROWSE, IDS_BROWSE, 0 },
+    { IDC_CART_4, IDS_CART_4, 0 },
+    { IDC_CBM2ROM_CART4_BROWSE, IDS_BROWSE, 0 },
+    { IDC_CART_6, IDS_CART_6, 0 },
+    { IDC_CBM2ROM_CART6_BROWSE, IDS_BROWSE, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_localize_dialog_param cbm2_drive_trans[] = {
+    { IDC_DRIVEROM_2031_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_2040_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_3040_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_4040_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1001_BROWSE, IDS_BROWSE, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_localize_dialog_param cbm2_main_res_trans[] = {
+    { 0, IDS_COMPUTER_RESOURCES_CAPTION, -1 },
+    { IDC_COMPUTER_RESOURCES, IDS_COMPUTER_RESOURCES, 0 },
+    { IDC_CBM2ROM_KERNAL_RESOURCE, IDS_KERNAL, 0 },
+    { IDC_CBM2ROM_BASIC_RESOURCE, IDS_BASIC, 0 },
+    { IDC_CBM2ROM_CHARGEN_RESOURCE, IDS_CHARACTER, 0 },
+    { IDC_CBM2ROM_CART1_RESOURCE, IDS_CART_1, 0 },
+    { IDC_CBM2ROM_CART2_RESOURCE, IDS_CART_2, 0 },
+    { IDC_CBM2ROM_CART4_RESOURCE, IDS_CART_4, 0 },
+    { IDC_CBM2ROM_CART6_RESOURCE, IDS_CART_6, 0 },
+    { IDOK, IDS_OK, 0 },
+    { IDCANCEL, IDS_CANCEL, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_dialog_group cbm2_main_left_group[] = {
+    { IDC_KERNAL, 0 },
+    { IDC_BASIC, 0 },
+    { IDC_CHARACTER, 0 },
+    { IDC_CART_1, 0 },
+    { IDC_CART_2, 0 },
+    { IDC_CART_4, 0 },
+    { IDC_CART_6, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group cbm2_main_middle_group[] = {
+    { IDC_CBM2ROM_KERNAL_FILE, 0 },
+    { IDC_CBM2ROM_BASIC_FILE, 0 },
+    { IDC_CBM2ROM_CHARGEN_FILE, 0 },
+    { IDC_CBM2ROM_CART1_FILE, 0 },
+    { IDC_CBM2ROM_CART2_FILE, 0 },
+    { IDC_CBM2ROM_CART4_FILE, 0 },
+    { IDC_CBM2ROM_CART6_FILE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group cbm2_main_right_group[] = {
+    { IDC_CBM2ROM_KERNAL_BROWSE, 0 },
+    { IDC_CBM2ROM_BASIC_BROWSE, 0 },
+    { IDC_CBM2ROM_CHARGEN_BROWSE, 0 },
+    { IDC_CBM2ROM_CART1_BROWSE, 0 },
+    { IDC_CBM2ROM_CART2_BROWSE, 0 },
+    { IDC_CBM2ROM_CART4_BROWSE, 0 },
+    { IDC_CBM2ROM_CART6_BROWSE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group cbm2_drive_left_group[] = {
+    { IDC_2031, 0 },
+    { IDC_2040, 0 },
+    { IDC_3040, 0 },
+    { IDC_4040, 0 },
+    { IDC_1001, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group cbm2_drive_middle_group[] = {
+    { IDC_DRIVEROM_2031_FILE, 0 },
+    { IDC_DRIVEROM_2040_FILE, 0 },
+    { IDC_DRIVEROM_3040_FILE, 0 },
+    { IDC_DRIVEROM_4040_FILE, 0 },
+    { IDC_DRIVEROM_1001_FILE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group cbm2_drive_right_group[] = {
+    { IDC_DRIVEROM_2031_BROWSE, 0 },
+    { IDC_DRIVEROM_2040_BROWSE, 0 },
+    { IDC_DRIVEROM_3040_BROWSE, 0 },
+    { IDC_DRIVEROM_4040_BROWSE, 0 },
+    { IDC_DRIVEROM_1001_BROWSE, 0 },
+    { 0, 0 }
+};
+
 static void cbm2_ui_specific(WPARAM wparam, HWND hwnd)
 {
     switch (wparam) {
-      case IDM_CBM2_SETTINGS:
-        ui_cbm2_settings_dialog(hwnd);
-        break;
-      case IDM_SID_SETTINGS:
-        ui_sid_settings_dialog(hwnd);
-        break;
-      case IDM_ROM_SETTINGS:
-        uirom_settings_dialog(hwnd, translate_res(IDD_CBM2ROM_SETTINGS_DIALOG),
-                              translate_res(IDD_CBM2DRIVEROM_SETTINGS_DIALOG),
-                              romset_dialog_resources, uirom_settings);
-        break;
-      case IDM_VIDEO_SETTINGS:
-        ui_video_settings_dialog(hwnd, UI_VIDEO_CHIP_CRTC, UI_VIDEO_CHIP_NONE);
-        break;
-      case IDM_DRIVE_SETTINGS:
-        uidrivepetcbm2_settings_dialog(hwnd);
-        break;
-      case IDM_ACIA_SETTINGS:
-        ui_acia_settings_dialog(hwnd, 0, NULL, 0, 0);
-        break;
-      case IDM_KEYBOARD_SETTINGS:
-        uikeyboard_settings_dialog(hwnd, &uikeyboard_config);
-        break;
+        case IDM_CBM2_SETTINGS:
+            ui_cbm2_settings_dialog(hwnd);
+            break;
+        case IDM_JOY_SETTINGS:
+            if (machine_class == VICE_MACHINE_CBM5x0) {
+                ui_joystick_settings_dialog(hwnd);
+            } else {
+                ui_extra_joystick_settings_dialog(hwnd);
+            }
+            break;
+        case IDM_SID_SETTINGS:
+            ui_sid_settings_dialog(hwnd);
+            break;
+        case IDM_ROM_SETTINGS:
+            uirom_settings_dialog(hwnd, IDD_CBM2ROM_SETTINGS_DIALOG, IDD_CBM2DRIVEROM_SETTINGS_DIALOG,
+                                  romset_dialog_resources, uirom_settings,
+                                  cbm2_main_trans, cbm2_drive_trans,
+                                  cbm2_main_left_group, cbm2_main_middle_group, cbm2_main_right_group,
+                                  cbm2_drive_left_group, cbm2_drive_middle_group, cbm2_drive_right_group,
+                                  cbm2_main_res_trans);
+            break;
+        case IDM_VIDEO_SETTINGS:
+            ui_video_settings_dialog(hwnd, UI_VIDEO_CHIP_CRTC, UI_VIDEO_CHIP_NONE);
+            break;
+        case IDM_DRIVE_SETTINGS:
+            uidrivepetcbm2_settings_dialog(hwnd);
+            break;
+        case IDM_ACIA_SETTINGS:
+            ui_acia_settings_dialog(hwnd, 0, NULL, 0, 0);
+            break;
+        case IDM_KEYBOARD_SETTINGS:
+            uikeyboard_settings_dialog(hwnd, &uikeyboard_config);
+            break;
     }
 }
 
 int cbm2ui_init(void)
 {
+    int i;
     ui_register_machine_specific(cbm2_ui_specific);
     ui_register_menu_toggles(cbm2_ui_menu_toggles);
     ui_register_res_values(cbm2_ui_res_values);
+
+    for (i = 0; cbm2ui_menu_translation_table[i].idm != 0; i++) {
+        if (cbm2ui_menu_translation_table[i].idm == IDM_JOY_SETTINGS) {
+            cbm2ui_menu_translation_table[i].ids = (machine_class == VICE_MACHINE_CBM5x0) ? IDS_MI_JOY_SETTINGS : IDS_MI_USERPORT_JOY_SETTINGS;
+        }
+        if (cbm2ui_menu_translation_table[i].idm == IDM_SWAP_JOYSTICK) {
+            cbm2ui_menu_translation_table[i].ids = (machine_class == VICE_MACHINE_CBM5x0) ? IDS_MI_SWAP_JOYSTICK : IDS_MI_SWAP_EXTRA_JOYSTICK;
+        }
+    }
     ui_register_translation_tables(cbm2ui_menu_translation_table, cbm2ui_popup_translation_table);
     return 0;
 }
@@ -305,4 +503,3 @@ int cbm2ui_init(void)
 void cbm2ui_shutdown(void)
 {
 }
-
