@@ -32,45 +32,45 @@
 
 #include "hardsid.h"
 #include "log.h"
+#include "maincpu.h"
 #include "sid-resources.h"
 #include "types.h"
 
 #define HARDSID_FLUSH_CYCLES 1000
 #define HARDSID_FLUSH_MS 50
 
-extern CLOCK maincpu_clk;
 static CLOCK lastaccess_clk;
 static UINT_PTR ftimer;
 static DWORD lastaccess_ms;
 static int lastaccess_chipno;
 
-typedef BYTE (CALLBACK* GetHardSIDCount_t)    (void);
-typedef void (CALLBACK* InitHardSID_Mapper_t) (void);
-typedef void (CALLBACK* MuteHardSID_Line_t)   (BOOL);
-typedef BYTE (CALLBACK* ReadFromHardSID_t)    (BYTE, BYTE);
-typedef void (CALLBACK* SetDebug_t)           (BOOL);
-typedef void (CALLBACK* WriteToHardSID_t)     (BYTE, BYTE, BYTE);
+typedef BYTE (CALLBACK* GetHardSIDCount_t)(void);
+typedef void (CALLBACK* InitHardSID_Mapper_t)(void);
+typedef void (CALLBACK* MuteHardSID_Line_t)(BOOL);
+typedef BYTE (CALLBACK* ReadFromHardSID_t)(BYTE, BYTE);
+typedef void (CALLBACK* SetDebug_t)(BOOL);
+typedef void (CALLBACK* WriteToHardSID_t)(BYTE, BYTE, BYTE);
 
 /* HardSID USB (HardSID 4U) */
-typedef void (CALLBACK* HardSID_Reset_t) (BYTE);
-typedef void (CALLBACK* HardSID_AbortPlay_t) (BYTE); //hard flush
-typedef void (CALLBACK* HardSID_Flush_t) (BYTE); //soft flush
-typedef void (CALLBACK* HardSID_Write_t) (BYTE, WORD, BYTE, BYTE);
-typedef void (CALLBACK* HardSID_Delay_t) (BYTE, WORD);
+typedef void (CALLBACK* HardSID_Reset_t)(BYTE);
+typedef void (CALLBACK* HardSID_AbortPlay_t)(BYTE); //hard flush
+typedef void (CALLBACK* HardSID_Flush_t)(BYTE); //soft flush
+typedef void (CALLBACK* HardSID_Write_t)(BYTE, WORD, BYTE, BYTE);
+typedef void (CALLBACK* HardSID_Delay_t)(BYTE, WORD);
 
-static GetHardSIDCount_t       GetHardSIDCount;
-static InitHardSID_Mapper_t    InitHardSID_Mapper;
-static MuteHardSID_Line_t      MuteHardSID_Line;
-static ReadFromHardSID_t       ReadFromHardSID;
-static SetDebug_t              SetDebug;
-static WriteToHardSID_t        WriteToHardSID;
+static GetHardSIDCount_t GetHardSIDCount;
+static InitHardSID_Mapper_t InitHardSID_Mapper;
+static MuteHardSID_Line_t MuteHardSID_Line;
+static ReadFromHardSID_t ReadFromHardSID;
+static SetDebug_t SetDebug;
+static WriteToHardSID_t WriteToHardSID;
 
 /* HardSID USB (HardSID 4U) */
-static HardSID_Reset_t					HardSID_Reset;
-static HardSID_AbortPlay_t				HardSID_AbortPlay;
-static HardSID_Flush_t					HardSID_Flush;
-static HardSID_Write_t					HardSID_Write;
-static HardSID_Delay_t					HardSID_Delay;
+static HardSID_Reset_t HardSID_Reset;
+static HardSID_AbortPlay_t HardSID_AbortPlay;
+static HardSID_Flush_t HardSID_Flush;
+static HardSID_Write_t HardSID_Write;
+static HardSID_Delay_t HardSID_Delay;
 
 static HINSTANCE dll = NULL;
 static unsigned int device_map[2] = { 0, 0 };
@@ -82,33 +82,23 @@ static int init_interface(void)
     if (dll == NULL) {
         dll = LoadLibrary("HARDSID.DLL");
         if (dll != NULL) {
-            GetHardSIDCount = (GetHardSIDCount_t)
-                              GetProcAddress(dll, "GetHardSIDCount");
-            InitHardSID_Mapper = (InitHardSID_Mapper_t)
-                                 GetProcAddress(dll, "InitHardSID_Mapper");
-            MuteHardSID_Line = (MuteHardSID_Line_t)
-                               GetProcAddress(dll, "MuteHardSID_Line");
-            ReadFromHardSID = (ReadFromHardSID_t)
-                              GetProcAddress(dll, "ReadFromHardSID");
-            SetDebug = (SetDebug_t)
-                       GetProcAddress(dll, "SetDebug");
-            WriteToHardSID = (WriteToHardSID_t)
-                             GetProcAddress(dll, "WriteToHardSID");
+            GetHardSIDCount = (GetHardSIDCount_t)GetProcAddress(dll, "GetHardSIDCount");
+            InitHardSID_Mapper = (InitHardSID_Mapper_t)GetProcAddress(dll, "InitHardSID_Mapper");
+            MuteHardSID_Line = (MuteHardSID_Line_t)GetProcAddress(dll, "MuteHardSID_Line");
+            ReadFromHardSID = (ReadFromHardSID_t)GetProcAddress(dll, "ReadFromHardSID");
+            SetDebug = (SetDebug_t)GetProcAddress(dll, "SetDebug");
+            WriteToHardSID = (WriteToHardSID_t)GetProcAddress(dll, "WriteToHardSID");
 
 /* HardSID USB (HardSID 4U) */
-            HardSID_Reset = (HardSID_Reset_t)
-                             GetProcAddress(dll, "HardSID_Reset");
-            HardSID_AbortPlay = (HardSID_AbortPlay_t)
-                             GetProcAddress(dll, "HardSID_Flush");
-            HardSID_Flush = (HardSID_Flush_t)
-                             GetProcAddress(dll, "HardSID_SoftFlush");
-            HardSID_Write = (HardSID_Write_t)
-                             GetProcAddress(dll, "HardSID_Write");
-            HardSID_Delay = (HardSID_Delay_t)
-                             GetProcAddress(dll, "HardSID_Delay");
+            HardSID_Reset = (HardSID_Reset_t)GetProcAddress(dll, "HardSID_Reset");
+            HardSID_AbortPlay = (HardSID_AbortPlay_t)GetProcAddress(dll, "HardSID_Flush");
+            HardSID_Flush = (HardSID_Flush_t)GetProcAddress(dll, "HardSID_SoftFlush");
+            HardSID_Write = (HardSID_Write_t)GetProcAddress(dll, "HardSID_Write");
+            HardSID_Delay = (HardSID_Delay_t)GetProcAddress(dll, "HardSID_Delay");
 
-            if (HardSID_Reset == NULL)
+            if (HardSID_Reset == NULL) {
                 has_usb_hardsid = 0;
+            }
         } else {
             return -1;
         }
@@ -121,12 +111,9 @@ void hardsid_reset(void)
 {
     int chipno;
 
-    if (dll != NULL)
-    {
-        if (has_usb_hardsid)
-        {
-            for (chipno = 0; chipno < 4; chipno++)
-            {
+    if (dll != NULL) {
+        if (has_usb_hardsid) {
+            for (chipno = 0; chipno < 4; chipno++) {
                 HardSID_AbortPlay((BYTE)chipno);
             }
         }
@@ -135,8 +122,7 @@ void hardsid_reset(void)
 
 static VOID CALLBACK ftimerproc(HWND hwnd, UINT message, UINT idTimer, DWORD dwTime)
 { 
-    if (lastaccess_chipno>=0 && lastaccess_ms>0 && (dwTime-lastaccess_ms)>=HARDSID_FLUSH_MS)
-    {
+    if (lastaccess_chipno >= 0 && lastaccess_ms > 0 && (dwTime - lastaccess_ms) >= HARDSID_FLUSH_MS) {
         lastaccess_chipno = -1;
         lastaccess_ms = 0;
         lastaccess_clk = 0;
@@ -149,12 +135,9 @@ int hardsid_open(void)
     int res;
     int chipno;
 
-
     res = init_interface();
-    if (dll != NULL && has_usb_hardsid)
-    {
-        for (chipno = 0; chipno < 4; chipno++)
-        {
+    if (dll != NULL && has_usb_hardsid) {
+        for (chipno = 0; chipno < 4; chipno++) {
             HardSID_Reset((BYTE)chipno);
         }
         lastaccess_clk = 0;
@@ -170,10 +153,10 @@ static void pcisa_hardsid_close(void)
     int chipno;
     WORD addr;
 
-    for (chipno = 0; chipno < 2; chipno++)
-    {
-        for (addr = 0; addr < 24; addr++)
+    for (chipno = 0; chipno < 2; chipno++) {
+        for (addr = 0; addr < 24; addr++) {
            hardsid_store(addr, 0, chipno);
+        }
     }
 }
 
@@ -182,23 +165,17 @@ static void usb_hardsid_close(void)
     int chipno;
 
     KillTimer(NULL, ftimer);
-    for (chipno = 0; chipno < 4; chipno++)
-    {
+    for (chipno = 0; chipno < 4; chipno++) {
         HardSID_AbortPlay((BYTE)chipno);
     }
 }
 
-
 int hardsid_close(void)
 {
-    if (dll != NULL)
-    {
-        if (has_usb_hardsid)
-        {
+    if (dll != NULL) {
+        if (has_usb_hardsid) {
             usb_hardsid_close();
-        }
-        else
-        {
+        } else {
             pcisa_hardsid_close();
         }
     }
@@ -207,8 +184,9 @@ int hardsid_close(void)
 
 int hardsid_read(WORD addr, int chipno)
 {
-    if (dll != NULL && !has_usb_hardsid)
+    if (dll != NULL && !has_usb_hardsid) {
         return ReadFromHardSID((BYTE)device_map[chipno], (UCHAR)(addr & 0x1f));
+    }
 
     return 0;
 }
@@ -218,42 +196,31 @@ void hardsid_store(WORD addr, BYTE val, int chipno)
     CLOCK elapsed_cycles;
     BOOL flushneeded = FALSE;
 
-    if (dll != NULL)
-    {
-        if (!has_usb_hardsid)
-        {
+    if (dll != NULL) {
+        if (!has_usb_hardsid) {
             WriteToHardSID((BYTE)device_map[chipno], (UCHAR)(addr & 0x1f), val);
-        }
-        else
-        {
+        } else {
             lastaccess_chipno = chipno;
             lastaccess_ms = GetTickCount();
 
-            if (lastaccess_clk==0)
-            {
+            if (lastaccess_clk == 0) {
                 elapsed_cycles = 0;
-            }
-            else
-            {
-                elapsed_cycles = (maincpu_clk - lastaccess_clk)&0xffff;
-                if (elapsed_cycles>HARDSID_FLUSH_CYCLES)
-                {
+            } else {
+                elapsed_cycles = (maincpu_clk - lastaccess_clk) & 0xffff;
+                if (elapsed_cycles > HARDSID_FLUSH_CYCLES) {
                     flushneeded = TRUE;
                     elapsed_cycles = 0;
                 }
             }
             lastaccess_clk = maincpu_clk;
 
-            if (dll != NULL)
-            {
-                while (elapsed_cycles>0xffff)
-                {
-                    HardSID_Delay((BYTE)device_map[chipno], (WORD) 0xffff);
-                    elapsed_cycles-= 0xffff;
+            if (dll != NULL) {
+                while (elapsed_cycles > 0xffff) {
+                    HardSID_Delay((BYTE)device_map[chipno], (WORD)0xffff);
+                    elapsed_cycles -= 0xffff;
                 }
-                HardSID_Write((BYTE)device_map[chipno], (WORD) elapsed_cycles, (UCHAR)(addr & 0x1f), val);
-                if (flushneeded)
-                {
+                HardSID_Write((BYTE)device_map[chipno], (WORD)elapsed_cycles, (UCHAR)(addr & 0x1f), val);
+                if (flushneeded) {
                     HardSID_Flush((BYTE)device_map[chipno]);
                 }
             }
@@ -267,8 +234,9 @@ void hardsid_set_machine_parameter(long cycles_per_sec)
 
 unsigned int hardsid_available(void)
 {
-    if (init_interface() < 0)
+    if (init_interface() < 0) {
         return 0;
+    }
 
     return (unsigned int)GetHardSIDCount();
 }
@@ -277,4 +245,3 @@ void hardsid_set_device(unsigned int chipno, unsigned int device)
 {
     device_map[chipno] = device;
 }
-
