@@ -37,7 +37,9 @@
 #include "ui.h"
 #include "uiacia.h"
 #include "uidrivepetcbm2.h"
+#include "uijoystick.h"
 #include "uikeyboard.h"
+#include "uilib.h"
 #include "uipetreu.h"
 #include "uipetset.h"
 #include "uirom.h"
@@ -48,8 +50,8 @@
 static const unsigned int romset_dialog_resources[UIROM_TYPE_MAX] = {
     IDD_PETROM_RESOURCE_DIALOG,
     IDD_PETROMDRIVE_RESOURCE_DIALOG,
-    0 };
-
+    0
+};
 
 static const ui_menu_toggle_t pet_ui_menu_toggles[] = {
     { "EmuID", IDM_TOGGLE_EMUID },
@@ -116,9 +118,78 @@ static const uikeyboard_mapping_entry_t mapping_entry[PETUI_KBD_NUM_MAP] = {
       IDC_PETKBD_MAPPING_DEPOS_BROWSE, "KeymapBusinessDEPosFile" }
 };
 
-static uikeyboard_config_t uikeyboard_config =
-    { IDD_PETKBD_MAPPING_SETTINGS_DIALOG, PETUI_KBD_NUM_MAP, mapping_entry,
-      IDC_PETKBD_MAPPING_DUMP };
+static uilib_localize_dialog_param pet_kbd_trans[] = {
+    { IDC_PETKBD_MAPPING_SELECT_GRSYM, IDS_GR_SYM, 0 },
+    { IDC_PETKBD_MAPPING_SELECT_GRPOS, IDS_GR_POS, 0 },
+    { IDC_PETKBD_MAPPING_SELECT_UKSYM, IDS_UK_SYM, 0 },
+    { IDC_PETKBD_MAPPING_SELECT_UKPOS, IDS_UK_POS, 0 },
+    { IDC_PETKBD_MAPPING_SELECT_DESYM, IDS_DE_SYM, 0 },
+    { IDC_PETKBD_MAPPING_SELECT_DEPOS, IDS_DE_POS, 0 },
+    { IDC_PETKBD_MAPPING_GRSYM_BROWSE, IDS_BROWSE, 0 },
+    { IDC_PETKBD_MAPPING_GRPOS_BROWSE, IDS_BROWSE, 0 },
+    { IDC_PETKBD_MAPPING_UKSYM_BROWSE, IDS_BROWSE, 0 },
+    { IDC_PETKBD_MAPPING_UKPOS_BROWSE, IDS_BROWSE, 0 },
+    { IDC_PETKBD_MAPPING_DESYM_BROWSE, IDS_BROWSE, 0 },
+    { IDC_PETKBD_MAPPING_DEPOS_BROWSE, IDS_BROWSE, 0 },
+    { IDC_PETKBD_MAPPING_DUMP, IDS_DUMP_KEYSET, 0 },
+    { IDC_KBD_SHORTCUT_DUMP, IDS_DUMP_SHORTCUTS, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_dialog_group pet_kbd_left_group[] = {
+    { IDC_PETKBD_MAPPING_SELECT_GRSYM, 1 },
+    { IDC_PETKBD_MAPPING_SELECT_GRPOS, 1 },
+    { IDC_PETKBD_MAPPING_SELECT_UKSYM, 1 },
+    { IDC_PETKBD_MAPPING_SELECT_UKPOS, 1 },
+    { IDC_PETKBD_MAPPING_SELECT_DESYM, 1 },
+    { IDC_PETKBD_MAPPING_SELECT_DEPOS, 1 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group pet_kbd_middle_group[] = {
+    { IDC_PETKBD_MAPPING_GRSYM, 0 },
+    { IDC_PETKBD_MAPPING_GRPOS, 0 },
+    { IDC_PETKBD_MAPPING_UKSYM, 0 },
+    { IDC_PETKBD_MAPPING_UKPOS, 0 },
+    { IDC_PETKBD_MAPPING_DESYM, 0 },
+    { IDC_PETKBD_MAPPING_DEPOS, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group pet_kbd_right_group[] = {
+    { IDC_PETKBD_MAPPING_GRSYM_BROWSE, 0 },
+    { IDC_PETKBD_MAPPING_GRPOS_BROWSE, 0 },
+    { IDC_PETKBD_MAPPING_UKSYM_BROWSE, 0 },
+    { IDC_PETKBD_MAPPING_UKPOS_BROWSE, 0 },
+    { IDC_PETKBD_MAPPING_DESYM_BROWSE, 0 },
+    { IDC_PETKBD_MAPPING_DEPOS_BROWSE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group pet_kbd_buttons_group[] = {
+    { IDC_PETKBD_MAPPING_DUMP, 1 },
+    { IDC_KBD_SHORTCUT_DUMP, 1 },
+    { 0, 0 }
+};
+
+static int pet_kbd_move_buttons_group[] = {
+    IDC_PETKBD_MAPPING_DUMP,
+    IDC_KBD_SHORTCUT_DUMP,
+    0
+};
+
+static uikeyboard_config_t uikeyboard_config = {
+    IDD_PETKBD_MAPPING_SETTINGS_DIALOG,
+    PETUI_KBD_NUM_MAP,
+    mapping_entry,
+    IDC_PETKBD_MAPPING_DUMP,
+    pet_kbd_trans,
+    pet_kbd_left_group,
+    pet_kbd_middle_group,
+    pet_kbd_right_group,
+    pet_kbd_buttons_group,
+    pet_kbd_move_buttons_group
+};
 
 ui_menu_translation_table_t petui_menu_translation_table[] = {
     { IDM_EXIT, IDS_MI_EXIT },
@@ -149,6 +220,7 @@ ui_menu_translation_table_t petui_menu_translation_table[] = {
     { IDM_TOGGLE_CRTCDOUBLESIZE, IDS_MI_TOGGLE_DOUBLESIZE },
     { IDM_TOGGLE_CRTCDOUBLESCAN, IDS_MI_TOGGLE_DOUBLESCAN },
     { IDM_TOGGLE_DRIVE_TRUE_EMULATION, IDS_MI_DRIVE_TRUE_EMULATION },
+    { IDM_TOGGLE_AUTOSTART_HANDLE_TDE, IDS_MI_AUTOSTART_HANDLE_TDE },
     { IDM_TOGGLE_CRTCVIDEOCACHE, IDS_MI_TOGGLE_VIDEOCACHE },
     { IDM_DRIVE_SETTINGS, IDS_MI_DRIVE_SETTINGS },
     { IDM_FLIP_ADD, IDS_MI_FLIP_ADD },
@@ -195,13 +267,15 @@ ui_menu_translation_table_t petui_menu_translation_table[] = {
     { IDM_MAXIMUM_SPEED_CUSTOM, IDS_MI_MAXIMUM_SPEED_CUSTOM },
     { IDM_TOGGLE_WARP_MODE, IDS_MI_TOGGLE_WARP_MODE },
     { IDM_TOGGLE_ALWAYSONTOP, IDS_MI_TOGGLE_ALWAYSONTOP },
-    { IDM_SWAP_JOYSTICK, IDS_MI_SWAP_JOYSTICK },
+    { IDM_SWAP_EXTRA_JOYSTICK, IDS_MI_SWAP_EXTRA_JOYSTICK },
+    { IDM_ALLOW_JOY_OPPOSITE_TOGGLE, IDS_MI_ALLOW_JOY_OPPOSITE },
     { IDM_JOYKEYS_TOGGLE, IDS_MI_JOYKEYS_TOGGLE },
     { IDM_TOGGLE_VIRTUAL_DEVICES, IDS_MI_TOGGLE_VIRTUAL_DEVICES },
     { IDM_TOGGLE_EMUID, IDS_MI_TOGGLE_EMUID },
+    { IDM_AUTOSTART_SETTINGS, IDS_MI_AUTOSTART_SETTINGS },
     { IDM_VIDEO_SETTINGS, IDS_MI_VIDEO_SETTINGS },
     { IDM_DEVICEMANAGER, IDS_MI_DEVICEMANAGER },
-    { IDM_JOY_SETTINGS, IDS_MI_JOY_SETTINGS },
+    { IDM_EXTRA_JOY_SETTINGS, IDS_MI_USERPORT_JOY_SETTINGS },
     { IDM_KEYBOARD_SETTINGS, IDS_MI_KEYBOARD_SETTINGS },
     { IDM_SOUND_SETTINGS, IDS_MI_SOUND_SETTINGS },
     { IDM_ROM_SETTINGS, IDS_MI_ROM_SETTINGS },
@@ -217,6 +291,7 @@ ui_menu_translation_table_t petui_menu_translation_table[] = {
     { IDM_TOGGLE_SAVE_SETTINGS_ON_EXIT, IDS_MI_SAVE_SETTINGS_ON_EXIT },
     { IDM_TOGGLE_CONFIRM_ON_EXIT, IDS_MI_CONFIRM_ON_EXIT },
     { IDM_LANG_EN, IDS_MI_LANG_EN },
+    { IDM_LANG_DA, IDS_MI_LANG_DA },
     { IDM_LANG_DE, IDS_MI_LANG_DE },
     { IDM_LANG_FR, IDS_MI_LANG_FR },
     { IDM_LANG_HU, IDS_MI_LANG_HU },
@@ -224,6 +299,7 @@ ui_menu_translation_table_t petui_menu_translation_table[] = {
     { IDM_LANG_NL, IDS_MI_LANG_NL },
     { IDM_LANG_PL, IDS_MI_LANG_PL },
     { IDM_LANG_SV, IDS_MI_LANG_SV },
+    { IDM_LANG_TR, IDS_MI_LANG_TR },
     { IDM_CMDLINE, IDS_MI_CMDLINE },
     { IDM_CONTRIBUTORS, IDS_MI_CONTRIBUTORS },
     { IDM_LICENSE, IDS_MI_LICENSE },
@@ -260,35 +336,143 @@ ui_popup_translation_table_t petui_popup_translation_table[] = {
     { 0, 0 }
 };
 
+static uilib_localize_dialog_param pet_main_trans[] = {
+    { IDC_KERNAL, IDS_KERNAL, 0 },
+    { IDC_PETROM_KERNAL_BROWSE, IDS_BROWSE, 0 },
+    { IDC_BASIC, IDS_BASIC, 0 },
+    { IDC_PETROM_BASIC_BROWSE, IDS_BROWSE, 0 },
+    { IDC_CHARACTER, IDS_CHARACTER, 0 },
+    { IDC_PETROM_CHARGEN_BROWSE, IDS_BROWSE, 0 },
+    { IDC_EDITOR, IDS_EDITOR, 0 },
+    { IDC_PETROM_EDITOR_BROWSE, IDS_BROWSE, 0 },
+    { IDC_ROM_9, IDS_ROM_9, 0 },
+    { IDC_PETROM_ROM9_BROWSE, IDS_BROWSE, 0 },
+    { IDC_ROM_A, IDS_ROM_A, 0 },
+    { IDC_PETROM_ROMA_BROWSE, IDS_BROWSE, 0 },
+    { IDC_ROM_B, IDS_ROM_B, 0 },
+    { IDC_PETROM_ROMB_BROWSE, IDS_BROWSE, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_localize_dialog_param pet_drive_trans[] = {
+    { IDC_DRIVEROM_2031_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_2040_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_3040_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_4040_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1001_BROWSE, IDS_BROWSE, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_localize_dialog_param pet_main_res_trans[] = {
+    { 0, IDS_COMPUTER_RESOURCES_CAPTION, -1 },
+    { IDC_COMPUTER_RESOURCES, IDS_COMPUTER_RESOURCES, 0 },
+    { IDC_PETROM_KERNAL_RESOURCE, IDS_KERNAL, 0 },
+    { IDC_PETROM_BASIC_RESOURCE, IDS_BASIC, 0 },
+    { IDC_PETROM_CHARGEN_RESOURCE, IDS_CHARACTER, 0 },
+    { IDC_PETROM_EDITOR_RESOURCE, IDS_EDITOR, 0 },
+    { IDC_PETROM_ROM9_RESOURCE, IDS_ROM_9, 0 },
+    { IDC_PETROM_ROMA_RESOURCE, IDS_ROM_A, 0 },
+    { IDC_PETROM_ROMB_RESOURCE, IDS_ROM_B, 0 },
+    { IDOK, IDS_OK, 0 },
+    { IDCANCEL, IDS_CANCEL, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_dialog_group pet_main_left_group[] = {
+    { IDC_KERNAL, 0 },
+    { IDC_BASIC, 0 },
+    { IDC_CHARACTER, 0 },
+    { IDC_EDITOR, 0 },
+    { IDC_ROM_9, 0 },
+    { IDC_ROM_A, 0 },
+    { IDC_ROM_B, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group pet_main_middle_group[] = {
+    { IDC_PETROM_KERNAL_FILE, 0 },
+    { IDC_PETROM_BASIC_FILE, 0 },
+    { IDC_PETROM_CHARGEN_FILE, 0 },
+    { IDC_PETROM_EDITOR_FILE, 0 },
+    { IDC_PETROM_ROM9_FILE, 0 },
+    { IDC_PETROM_ROMA_FILE, 0 },
+    { IDC_PETROM_ROMB_FILE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group pet_main_right_group[] = {
+    { IDC_PETROM_KERNAL_BROWSE, 0 },
+    { IDC_PETROM_BASIC_BROWSE, 0 },
+    { IDC_PETROM_CHARGEN_BROWSE, 0 },
+    { IDC_PETROM_EDITOR_BROWSE, 0 },
+    { IDC_PETROM_ROM9_BROWSE, 0 },
+    { IDC_PETROM_ROMA_BROWSE, 0 },
+    { IDC_PETROM_ROMB_BROWSE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group pet_drive_left_group[] = {
+    { IDC_2031, 0 },
+    { IDC_2040, 0 },
+    { IDC_3040, 0 },
+    { IDC_4040, 0 },
+    { IDC_1001, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group pet_drive_middle_group[] = {
+    { IDC_DRIVEROM_2031_FILE, 0 },
+    { IDC_DRIVEROM_2040_FILE, 0 },
+    { IDC_DRIVEROM_3040_FILE, 0 },
+    { IDC_DRIVEROM_4040_FILE, 0 },
+    { IDC_DRIVEROM_1001_FILE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group pet_drive_right_group[] = {
+    { IDC_DRIVEROM_2031_BROWSE, 0 },
+    { IDC_DRIVEROM_2040_BROWSE, 0 },
+    { IDC_DRIVEROM_3040_BROWSE, 0 },
+    { IDC_DRIVEROM_4040_BROWSE, 0 },
+    { IDC_DRIVEROM_1001_BROWSE, 0 },
+    { 0, 0 }
+};
+
 static void pet_ui_specific(WPARAM wparam, HWND hwnd)
 {
     switch (wparam) {
-      case IDM_PET_SETTINGS:
-        ui_pet_settings_dialog(hwnd);
-        break;
-      case IDM_PETREU_SETTINGS:
-        ui_petreu_settings_dialog(hwnd);
-        break;
-      case IDM_SIDCART_SETTINGS:
-        ui_sidcart_settings_dialog(hwnd);
-        break;
-      case IDM_ROM_SETTINGS:
-        uirom_settings_dialog(hwnd, translate_res(IDD_PETROM_SETTINGS_DIALOG),
-                              translate_res(IDD_PETDRIVEROM_SETTINGS_DIALOG),
-                              romset_dialog_resources, uirom_settings);
-        break;
-      case IDM_VIDEO_SETTINGS:
-        ui_video_settings_dialog(hwnd, UI_VIDEO_CHIP_CRTC, UI_VIDEO_CHIP_NONE);
-        break;
-      case IDM_DRIVE_SETTINGS:
-        uidrivepetcbm2_settings_dialog(hwnd);
-        break;
-      case IDM_ACIA_SETTINGS:
-        ui_acia_settings_dialog(hwnd, 0, NULL, 0, 0);
-        break;
-      case IDM_KEYBOARD_SETTINGS:
-        uikeyboard_settings_dialog(hwnd, &uikeyboard_config);
-        break;
+        case IDM_PET_SETTINGS:
+            ui_pet_settings_dialog(hwnd);
+            break;
+        case IDM_PETREU_SETTINGS:
+            ui_petreu_settings_dialog(hwnd);
+            break;
+        case IDM_SIDCART_SETTINGS:
+            ui_sidcart_settings_dialog(hwnd);
+            break;
+        case IDM_ROM_SETTINGS:
+            uirom_settings_dialog(hwnd, IDD_PETROM_SETTINGS_DIALOG, IDD_PETDRIVEROM_SETTINGS_DIALOG,
+                                  romset_dialog_resources, uirom_settings,
+                                  pet_main_trans, pet_drive_trans,
+                                  pet_main_left_group, pet_main_middle_group, pet_main_right_group,
+                                  pet_drive_left_group, pet_drive_middle_group, pet_drive_right_group,
+                                  pet_main_res_trans);
+            break;
+        case IDM_VIDEO_SETTINGS:
+            ui_video_settings_dialog(hwnd, UI_VIDEO_CHIP_CRTC, UI_VIDEO_CHIP_NONE);
+            break;
+        case IDM_DRIVE_SETTINGS:
+            uidrivepetcbm2_settings_dialog(hwnd);
+            break;
+        case IDM_ACIA_SETTINGS:
+            ui_acia_settings_dialog(hwnd, 0, NULL, 0, 0);
+            break;
+        case IDM_EXTRA_JOY_SETTINGS:
+            ui_extra_joystick_settings_dialog(hwnd);
+            break;
+        case IDM_KEYBOARD_SETTINGS:
+            uikeyboard_settings_dialog(hwnd, &uikeyboard_config);
+            break;
     }
 }
 
@@ -303,4 +487,3 @@ int petui_init(void)
 void petui_shutdown(void)
 {
 }
-
