@@ -39,7 +39,9 @@
 #include "ui.h"
 #include "uiacia.h"
 #include "uidriveplus4.h"
+#include "uijoystick.h"
 #include "uikeyboard.h"
+#include "uilib.h"
 #include "uiplus4cart.h"
 #include "uiplus4mem.h"
 #include "uirom.h"
@@ -50,8 +52,8 @@
 static const unsigned int romset_dialog_resources[UIROM_TYPE_MAX] = {
     IDD_PLUS4ROM_RESOURCE_DIALOG,
     IDD_PLUS4ROMDRIVE_RESOURCE_DIALOG,
-    0 };
-
+    0
+};
 
 static const ui_menu_toggle_t plus4_ui_menu_toggles[] = {
     { "TEDDoubleSize", IDM_TOGGLE_DOUBLESIZE },
@@ -109,9 +111,58 @@ static const uikeyboard_mapping_entry_t mapping_entry[PLUS4UI_KBD_NUM_MAP] = {
       IDC_PLUS4KBD_MAPPING_POS_BROWSE, "KeymapPosFile" }
 };
 
-static uikeyboard_config_t uikeyboard_config =
-   { IDD_PLUS4KBD_MAPPING_SETTINGS_DIALOG, PLUS4UI_KBD_NUM_MAP, mapping_entry,
-     IDC_PLUS4KBD_MAPPING_DUMP };
+static uilib_localize_dialog_param plus4_kbd_trans[] = {
+    { IDC_PLUS4KBD_MAPPING_SELECT_SYM, IDS_SYMBOLIC, 0 },
+    { IDC_PLUS4KBD_MAPPING_SELECT_POS, IDS_POSITIONAL, 0 },
+    { IDC_PLUS4KBD_MAPPING_SYM_BROWSE, IDS_BROWSE, 0 },
+    { IDC_PLUS4KBD_MAPPING_POS_BROWSE, IDS_BROWSE, 0 },
+    { IDC_PLUS4KBD_MAPPING_DUMP, IDS_DUMP_KEYSET, 0 },
+    { IDC_KBD_SHORTCUT_DUMP, IDS_DUMP_SHORTCUTS, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_dialog_group plus4_kbd_left_group[] = {
+    { IDC_PLUS4KBD_MAPPING_SELECT_SYM, 1 },
+    { IDC_PLUS4KBD_MAPPING_SELECT_POS, 1 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group plus4_kbd_middle_group[] = {
+    { IDC_PLUS4KBD_MAPPING_SYM, 0 },
+    { IDC_PLUS4KBD_MAPPING_POS, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group plus4_kbd_right_group[] = {
+    { IDC_PLUS4KBD_MAPPING_SYM_BROWSE, 0 },
+    { IDC_PLUS4KBD_MAPPING_POS_BROWSE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group plus4_kbd_buttons_group[] = {
+    { IDC_PLUS4KBD_MAPPING_DUMP, 1 },
+    { IDC_KBD_SHORTCUT_DUMP, 1 },
+    { 0, 0 }
+};
+
+static int plus4_kbd_move_buttons_group[] = {
+    IDC_PLUS4KBD_MAPPING_DUMP,
+    IDC_KBD_SHORTCUT_DUMP,
+    0
+};
+
+static uikeyboard_config_t uikeyboard_config = {
+    IDD_PLUS4KBD_MAPPING_SETTINGS_DIALOG,
+    PLUS4UI_KBD_NUM_MAP,
+    mapping_entry,
+    IDC_PLUS4KBD_MAPPING_DUMP,
+    plus4_kbd_trans,
+    plus4_kbd_left_group,
+    plus4_kbd_middle_group,
+    plus4_kbd_right_group,
+    plus4_kbd_buttons_group,
+    plus4_kbd_move_buttons_group
+};
 
 ui_menu_translation_table_t plus4ui_menu_translation_table[] = {
     { IDM_EXIT, IDS_MI_EXIT },
@@ -142,6 +193,7 @@ ui_menu_translation_table_t plus4ui_menu_translation_table[] = {
     { IDM_TOGGLE_DOUBLESIZE, IDS_MI_TOGGLE_DOUBLESIZE },
     { IDM_TOGGLE_DOUBLESCAN, IDS_MI_TOGGLE_DOUBLESCAN },
     { IDM_TOGGLE_DRIVE_TRUE_EMULATION, IDS_MI_DRIVE_TRUE_EMULATION },
+    { IDM_TOGGLE_AUTOSTART_HANDLE_TDE, IDS_MI_AUTOSTART_HANDLE_TDE },
     { IDM_TOGGLE_VIDEOCACHE, IDS_MI_TOGGLE_VIDEOCACHE },
     { IDM_DRIVE_SETTINGS, IDS_MI_DRIVE_SETTINGS },
     { IDM_CART_ATTACH_C1LO, IDS_MI_CART_ATTACH_C1LO },
@@ -198,11 +250,14 @@ ui_menu_translation_table_t plus4ui_menu_translation_table[] = {
     { IDM_TOGGLE_FASTPAL, IDS_MI_TOGGLE_FASTPAL },
     { IDM_TOGGLE_SCALE2X, IDS_MI_TOGGLE_SCALE2X },
     { IDM_SWAP_JOYSTICK, IDS_MI_SWAP_JOYSTICK },
+    { IDM_ALLOW_JOY_OPPOSITE_TOGGLE, IDS_MI_ALLOW_JOY_OPPOSITE },
     { IDM_JOYKEYS_TOGGLE, IDS_MI_JOYKEYS_TOGGLE },
     { IDM_TOGGLE_VIRTUAL_DEVICES, IDS_MI_TOGGLE_VIRTUAL_DEVICES },
+    { IDM_AUTOSTART_SETTINGS, IDS_MI_AUTOSTART_SETTINGS },
     { IDM_VIDEO_SETTINGS, IDS_MI_VIDEO_SETTINGS },
     { IDM_DEVICEMANAGER, IDS_MI_DEVICEMANAGER },
     { IDM_JOY_SETTINGS, IDS_MI_JOY_SETTINGS },
+    { IDM_EXTRA_JOY_SETTINGS, IDS_MI_SIDCART_JOY_SETTINGS },
     { IDM_KEYBOARD_SETTINGS, IDS_MI_KEYBOARD_SETTINGS },
     { IDM_SOUND_SETTINGS, IDS_MI_SOUND_SETTINGS },
     { IDM_ROM_SETTINGS, IDS_MI_ROM_SETTINGS },
@@ -218,6 +273,7 @@ ui_menu_translation_table_t plus4ui_menu_translation_table[] = {
     { IDM_TOGGLE_SAVE_SETTINGS_ON_EXIT, IDS_MI_SAVE_SETTINGS_ON_EXIT },
     { IDM_TOGGLE_CONFIRM_ON_EXIT, IDS_MI_CONFIRM_ON_EXIT },
     { IDM_LANG_EN, IDS_MI_LANG_EN },
+    { IDM_LANG_DA, IDS_MI_LANG_DA },
     { IDM_LANG_DE, IDS_MI_LANG_DE },
     { IDM_LANG_FR, IDS_MI_LANG_FR },
     { IDM_LANG_HU, IDS_MI_LANG_HU },
@@ -225,6 +281,7 @@ ui_menu_translation_table_t plus4ui_menu_translation_table[] = {
     { IDM_LANG_NL, IDS_MI_LANG_NL },
     { IDM_LANG_PL, IDS_MI_LANG_PL },
     { IDM_LANG_SV, IDS_MI_LANG_SV },
+    { IDM_LANG_TR, IDS_MI_LANG_TR },
     { IDM_CMDLINE, IDS_MI_CMDLINE },
     { IDM_CONTRIBUTORS, IDS_MI_CONTRIBUTORS },
     { IDM_LICENSE, IDS_MI_LICENSE },
@@ -261,34 +318,131 @@ ui_popup_translation_table_t plus4ui_popup_translation_table[] = {
     { 0, 0 }
 };
 
+static uilib_localize_dialog_param plus4_main_trans[] = {
+    { IDC_KERNAL, IDS_KERNAL, 0 },
+    { IDC_PLUS4ROM_KERNAL_BROWSE, IDS_BROWSE, 0 },
+    { IDC_BASIC, IDS_BASIC, 0 },
+    { IDC_PLUS4ROM_BASIC_BROWSE, IDS_BROWSE, 0 },
+    { IDC_3_PLUS_1_LO, IDS_3_PLUS_1_LO, 0 },
+    { IDC_PLUS4ROM_3P1LO_BROWSE, IDS_BROWSE, 0 },
+    { IDC_3_PLUS_1_HI, IDS_3_PLUS_1_HI, 0 },
+    { IDC_PLUS4ROM_3P1HI_BROWSE, IDS_BROWSE, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_localize_dialog_param plus4_drive_trans[] = {
+    { IDC_DRIVEROM_1541_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1541II_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1551_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1570_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1571_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1581_BROWSE, IDS_BROWSE, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_localize_dialog_param plus4_main_res_trans[] = {
+    { 0, IDS_COMPUTER_RESOURCES_CAPTION, -1 },
+    { IDC_COMPUTER_RESOURCES, IDS_COMPUTER_RESOURCES, 0 },
+    { IDC_PLUS4ROM_KERNAL_RESOURCE, IDS_KERNAL, 0 },
+    { IDC_PLUS4ROM_BASIC_RESOURCE, IDS_BASIC, 0 },
+    { IDC_PLUS4ROM_3P1LO_RESOURCE, IDS_3_PLUS_1_LO, 0 },
+    { IDC_PLUS4ROM_3P1HI_RESOURCE, IDS_3_PLUS_1_HI, 0 },
+    { IDOK, IDS_OK, 0 },
+    { IDCANCEL, IDS_CANCEL, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_dialog_group plus4_main_left_group[] = {
+    { IDC_KERNAL, 0 },
+    { IDC_BASIC, 0 },
+    { IDC_3_PLUS_1_LO, 0 },
+    { IDC_3_PLUS_1_HI, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group plus4_main_middle_group[] = {
+    { IDC_PLUS4ROM_KERNAL_FILE, 0 },
+    { IDC_PLUS4ROM_BASIC_FILE, 0 },
+    { IDC_PLUS4ROM_3P1LO_FILE, 0 },
+    { IDC_PLUS4ROM_3P1HI_FILE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group plus4_main_right_group[] = {
+    { IDC_PLUS4ROM_KERNAL_BROWSE, 0 },
+    { IDC_PLUS4ROM_BASIC_BROWSE, 0 },
+    { IDC_PLUS4ROM_3P1LO_BROWSE, 0 },
+    { IDC_PLUS4ROM_3P1HI_BROWSE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group plus4_drive_left_group[] = {
+    { IDC_1541, 0 },
+    { IDC_1541_II, 0 },
+    { IDC_1551, 0 },
+    { IDC_1570, 0 },
+    { IDC_1571, 0 },
+    { IDC_1581, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group plus4_drive_middle_group[] = {
+    { IDC_DRIVEROM_1541_FILE, 0 },
+    { IDC_DRIVEROM_1541II_FILE, 0 },
+    { IDC_DRIVEROM_1551_FILE, 0 },
+    { IDC_DRIVEROM_1570_FILE, 0 },
+    { IDC_DRIVEROM_1571_FILE, 0 },
+    { IDC_DRIVEROM_1581_FILE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group plus4_drive_right_group[] = {
+    { IDC_DRIVEROM_1541_BROWSE, 0 },
+    { IDC_DRIVEROM_1541II_BROWSE, 0 },
+    { IDC_DRIVEROM_1551_BROWSE, 0 },
+    { IDC_DRIVEROM_1570_BROWSE, 0 },
+    { IDC_DRIVEROM_1571_BROWSE, 0 },
+    { IDC_DRIVEROM_1581_BROWSE, 0 },
+    { 0, 0 }
+};
+
 static void plus4_ui_specific(WPARAM wparam, HWND hwnd)
 {
     uiplus4cart_proc(wparam, hwnd);
 
     switch (wparam) {
-      case IDM_PLUS4_SETTINGS:
-        ui_plus4_memory_dialog(hwnd);
-        break;
-      case IDM_ROM_SETTINGS:
-        uirom_settings_dialog(hwnd, translate_res(IDD_PLUS4ROM_SETTINGS_DIALOG),
-                              translate_res(IDD_PLUS4DRIVEROM_SETTINGS_DIALOG),
-                              romset_dialog_resources, uirom_settings);
-        break;
-      case IDM_VIDEO_SETTINGS:
-        ui_video_settings_dialog(hwnd, UI_VIDEO_CHIP_TED, UI_VIDEO_CHIP_NONE);
-        break;
-      case IDM_DRIVE_SETTINGS:
-        uidriveplus4_settings_dialog(hwnd);
-        break;
-      case IDM_ACIA_SETTINGS:
-        ui_acia_settings_dialog(hwnd, 0, NULL, 0, 0);
-        break;
-      case IDM_SIDCART_SETTINGS:
-        ui_sidcart_settings_dialog(hwnd);
-        break;
-      case IDM_KEYBOARD_SETTINGS:
-        uikeyboard_settings_dialog(hwnd, &uikeyboard_config);
-        break;
+        case IDM_PLUS4_SETTINGS:
+            ui_plus4_memory_dialog(hwnd);
+            break;
+        case IDM_JOY_SETTINGS:
+            ui_joystick_settings_dialog(hwnd);
+            break;
+        case IDM_EXTRA_JOY_SETTINGS:
+            ui_extra_joystick_settings_dialog(hwnd);
+            break;
+        case IDM_ROM_SETTINGS:
+            uirom_settings_dialog(hwnd, IDD_PLUS4ROM_SETTINGS_DIALOG, IDD_PLUS4DRIVEROM_SETTINGS_DIALOG,
+                                  romset_dialog_resources, uirom_settings,
+                                  plus4_main_trans, plus4_drive_trans,
+                                  plus4_main_left_group, plus4_main_middle_group, plus4_main_right_group,
+                                  plus4_drive_left_group, plus4_drive_middle_group, plus4_drive_right_group,
+                                  plus4_main_res_trans);
+            break;
+        case IDM_VIDEO_SETTINGS:
+            ui_video_settings_dialog(hwnd, UI_VIDEO_CHIP_TED, UI_VIDEO_CHIP_NONE);
+            break;
+        case IDM_DRIVE_SETTINGS:
+            uidriveplus4_settings_dialog(hwnd);
+            break;
+        case IDM_ACIA_SETTINGS:
+            ui_acia_settings_dialog(hwnd, 0, NULL, 0, 0);
+            break;
+        case IDM_SIDCART_SETTINGS:
+            ui_sidcart_settings_dialog(hwnd);
+            break;
+        case IDM_KEYBOARD_SETTINGS:
+            uikeyboard_settings_dialog(hwnd, &uikeyboard_config);
+            break;
     }
 }
 
@@ -306,4 +460,3 @@ int plus4ui_init(void)
 void plus4ui_shutdown(void)
 {
 }
-
