@@ -38,6 +38,7 @@
 #include "ui.h"
 #include "uilib.h"
 #include "util.h"
+#include "videoarch.h"
 
 /* UI-related resources.  */
 
@@ -57,6 +58,8 @@ struct {
     char *monitor_dimensions;
     char *initialdir[UILIB_SELECTOR_STYLES_NUM];
     int alwaysontop;
+    int keep_aspect_ratio;
+    int aspect_ratio;
 } ui_resources;
 
 static int set_fullscreen_device(int val, void *param)
@@ -109,18 +112,17 @@ static int set_confirm_on_exit(int val, void *param)
 
 static int set_single_cpu(int val, void *param)
 {
-    DWORD process_affinity;
-    DWORD system_affinity;
+    UINT_PTR process_affinity;
+    UINT_PTR system_affinity;
 
     ui_resources.single_cpu = (int)val;
 
-    if (GetProcessAffinityMask(GetCurrentProcess(), &process_affinity,
-        &system_affinity)) {
+    if (GetProcessAffinityMask(GetCurrentProcess(), &process_affinity, &system_affinity)) {
         /* Check if multi CPU system or not */
         if ((system_affinity & (system_affinity - 1))) {
             if (ui_resources.single_cpu == 1) {
                 //  Set it to first CPU
-                SetThreadAffinityMask(GetCurrentThread(),system_affinity ^ (system_affinity & (system_affinity - 1)));
+                SetThreadAffinityMask(GetCurrentThread(), system_affinity ^ (system_affinity & (system_affinity - 1)));
             } else {
                 //  Set it to all CPU
                 SetThreadAffinityMask(GetCurrentThread(),system_affinity);
@@ -132,9 +134,11 @@ static int set_single_cpu(int val, void *param)
 
 static int set_monitor_dimensions(const char *name, void *param)
 {
-    if (ui_resources.monitor_dimensions != NULL && name != NULL)
-        if (strcmp(name, ui_resources.monitor_dimensions) == 0)
+    if (ui_resources.monitor_dimensions != NULL && name != NULL) {
+        if (strcmp(name, ui_resources.monitor_dimensions) == 0) {
             return 0;
+        }
+    }
 
     util_string_set(&ui_resources.monitor_dimensions, name ? name : "");
 
@@ -143,11 +147,13 @@ static int set_monitor_dimensions(const char *name, void *param)
 
 static int set_initial_dir(const char *name, void *param)
 {
-    int index = (int)param;
+    int index = vice_ptr_to_int(param);
 
-    if (ui_resources.initialdir[index] != NULL && name != NULL)
-        if (strcmp(name, ui_resources.initialdir[index]) == 0)
+    if (ui_resources.initialdir[index] != NULL && name != NULL) {
+        if (strcmp(name, ui_resources.initialdir[index]) == 0) {
             return 0;
+        }
+    }
 
     util_string_set(&ui_resources.initialdir[index], name ? name : "");
 
@@ -156,13 +162,13 @@ static int set_initial_dir(const char *name, void *param)
 
 static int set_window_xpos(int val, void *param)
 {
-    ui_resources.window_xpos[(int) param] = val;
+    ui_resources.window_xpos[vice_ptr_to_int(param)] = val;
     return 0;
 }
 
 static int set_window_ypos(int val, void *param)
 {
-    ui_resources.window_ypos[(int) param] = val;
+    ui_resources.window_ypos[vice_ptr_to_int(param)] = val;
     return 0;
 }
 
@@ -179,6 +185,48 @@ static int set_alwaysontop(int val, void *param)
     return 0;
 }
 
+void resize_every_canvas(void)
+{
+    video_canvas_t *canvas;
+    int window_index;
+
+    for (window_index = 0; window_index < number_of_windows; window_index++) {
+        canvas = video_canvas_for_hwnd(window_handles[window_index]);
+        if (canvas != NULL) {
+            ui_resize_canvas_window(canvas);
+        }
+    }
+}
+
+static int set_keep_aspect_ratio(int val, void *param)
+{
+    int old_val = ui_resources.keep_aspect_ratio;
+
+    ui_resources.keep_aspect_ratio = val;
+    if (!old_val && val) {
+        resize_every_canvas();
+    }
+    return 0;
+}
+
+static int set_aspect_ratio(int val, void *param)
+{
+    int old_val = ui_resources.aspect_ratio;
+
+    if (val < 500) {
+        val = 500;
+    }
+    if (val > 2000) {
+        val = 2000;
+    }
+    ui_resources.aspect_ratio = val;
+
+    if (val != old_val) {
+        resize_every_canvas();
+    }
+    return 0;
+}
+
 static const resource_string_t resources_string[] = {
     { "MonitorDimensions", "", RES_EVENT_NO, NULL,
       &ui_resources.monitor_dimensions, set_monitor_dimensions, NULL },
@@ -200,11 +248,11 @@ static const resource_string_t resources_string[] = {
 static const resource_int_t resources_int[] = {
     { "FullscreenDevice", 0, RES_EVENT_NO, NULL,
       &ui_resources.fullscreendevice, set_fullscreen_device, NULL },
-    { "FullscreenBitdepth", 8, RES_EVENT_NO, NULL,
+    { "FullscreenBitdepth", -1, RES_EVENT_NO, NULL,
       &ui_resources.fullscreenbitdepth, set_fullscreen_bitdepth, NULL },
-    { "FullscreenWidth", 640, RES_EVENT_NO, NULL,
+    { "FullscreenWidth", -1, RES_EVENT_NO, NULL,
       &ui_resources.fullscreenwidth, set_fullscreen_width, NULL },
-    { "FullscreenHeight", 480, RES_EVENT_NO, NULL,
+    { "FullscreenHeight", -1, RES_EVENT_NO, NULL,
       &ui_resources.fullscreenheight, set_fullscreen_height, NULL },
     { "FullscreenRefreshRate", 0, RES_EVENT_NO, NULL,
       &ui_resources.fullscreenrefreshrate, set_fullscreen_refreshrate, NULL },
@@ -228,6 +276,10 @@ static const resource_int_t resources_int[] = {
       &ui_resources.vblank_sync, set_vblank_sync, NULL },
     { "AlwaysOnTop", 0, RES_EVENT_NO, NULL,
       &ui_resources.alwaysontop, set_alwaysontop, NULL },
+    { "KeepAspectRatio", 0, RES_EVENT_NO, NULL,
+      &ui_resources.keep_aspect_ratio, set_keep_aspect_ratio, NULL },
+    { "AspectRatio", 1000, RES_EVENT_NO, NULL,
+      &ui_resources.aspect_ratio, set_aspect_ratio, NULL },
     { NULL }
 };
 
@@ -235,8 +287,9 @@ int ui_resources_init(void)
 {
     translate_resources_init();
 
-    if (resources_register_string(resources_string) < 0)
+    if (resources_register_string(resources_string) < 0) {
         return -1;
+    }
 
     return resources_register_int(resources_int);
 }
@@ -246,12 +299,13 @@ void ui_resources_shutdown(void)
     int i;
 
     translate_resources_shutdown();
-    if (ui_resources.monitor_dimensions != NULL)
-        lib_free(ui_resources.monitor_dimensions);
+    lib_free(ui_resources.monitor_dimensions);
+    ui_resources.monitor_dimensions = NULL;
 
-    for (i = 0; i < UILIB_SELECTOR_STYLES_NUM; i++)
-        if (ui_resources.initialdir[i] != NULL)
-            lib_free(ui_resources.initialdir[i]);
+    for (i = 0; i < UILIB_SELECTOR_STYLES_NUM; i++) {
+        lib_free(ui_resources.initialdir[i]);
+        ui_resources.initialdir[i] = NULL;
+    }
 }
 
 int ui_vblank_sync_enabled()
