@@ -24,10 +24,9 @@
  *
  */
 
-#ifndef _UIGEORAM_H
-#define _UIGEORAM_H
+#ifndef VICE_UIGEORAM_H
+#define VICE_UIGEORAM_H
 
 extern void ui_georam_settings_dialog(HWND hwnd);
 
 #endif
-
