@@ -26,8 +26,8 @@
  *
  */
 
-#ifndef _UILIB_H
-#define _UILIB_H
+#ifndef VICE_UILIB_H
+#define VICE_UILIB_H
 
 #include <windows.h>
 #include <tchar.h>
@@ -63,28 +63,26 @@
 #define UILIB_FILTER_KEYMAP         (1 << 13)
 
 
-extern TCHAR *uilib_select_file(HWND hwnd, const TCHAR *title, DWORD filterlist,
-                                unsigned int type, int style);
-extern TCHAR *uilib_select_file_autostart(HWND hwnd, const TCHAR *title,
-                                          DWORD filterlist, unsigned int type,
-                                          int style, int *autostart,
-                                          char *resource_readonly);
-extern void uilib_select_browse(HWND hwnd, const TCHAR *title,
-                                DWORD filterlist, unsigned int type, int idc);
+extern TCHAR *uilib_select_file(HWND hwnd, const TCHAR *title, DWORD filterlist, unsigned int type, int style);
+extern TCHAR *uilib_select_file_autostart(HWND hwnd, const TCHAR *title, DWORD filterlist, unsigned int type, int style, int *autostart, char *resource_readonly);
+extern void uilib_select_browse(HWND hwnd, const TCHAR *title, DWORD filterlist, unsigned int type, int idc);
 
 extern void uilib_show_options(HWND param);
-extern void ui_show_text(HWND hParent, const char *szCaption,
-                         const char *szHeader, const char *szText);
+extern void ui_show_text(HWND hParent, const char *szCaption, const char *szHeader, const char *szText);
 
 extern int ui_messagebox(LPCTSTR lpText, LPCTSTR lpCaption, UINT uType);
 extern void uilib_shutdown(void);
 
 
 #define UILIB_DIALOGBOX_MAX 256
+
 struct uilib_dialogbox_param_s {
     HWND hwnd;
     unsigned int idd_dialog;
     unsigned int idc_dialog;
+    unsigned int idc_dialog_trans;
+    char *idc_dialog_trans_text;
+    char *idd_dialog_caption;
     TCHAR string[UILIB_DIALOGBOX_MAX];
     unsigned int updated;
 };
@@ -100,20 +98,30 @@ typedef struct {
 } uilib_dialog_group;
 
 extern void uilib_get_group_extent(HWND hwnd, uilib_dialog_group *group, int *xsize, int *ysize);
+extern void uilib_get_group_max_x(HWND hwnd, uilib_dialog_group *group, int *xpos);
+extern void uilib_get_group_min_x(HWND hwnd, uilib_dialog_group *group, int *xpos);
+extern void uilib_get_group_width(HWND hwnd, uilib_dialog_group *group, int *width);
+extern void uilib_set_group_width(HWND hwnd, uilib_dialog_group *group, int size);
 extern void uilib_move_and_adjust_group_width(HWND hwnd, uilib_dialog_group *group, int xpos);
 extern void uilib_move_group(HWND hwnd, uilib_dialog_group *group, int xpos);
 extern void uilib_adjust_group_width(HWND hwnd, uilib_dialog_group *group);
 extern void uilib_move_and_adjust_element_width(HWND hwnd, int idc, int xpos);
+extern void uilib_move_and_set_element_width(HWND hwnd, int idc, int xpos, int new_xsize);
 extern void uilib_adjust_element_width(HWND hwnd, int idc);
+extern void uilib_move_element(HWND hwnd, int idc, int xpos);
+extern void uilib_get_element_width(HWND hwnd, int idc, int *width);
+extern void uilib_get_element_size(HWND hwnd, int idc, int *width);
+extern void uilib_get_element_max_x(HWND hwnd, int idc, int *width);
+extern void uilib_get_element_min_x(HWND hwnd, int idc, int *width);
 extern void uilib_set_element_width(HWND hwnd, int idc, int xsize);
+extern void uilib_center_buttons(HWND hwnd, int *bottons, int resize);
 
 typedef struct {
     unsigned int idc;
     unsigned int ids;
     int element_type;
 } uilib_localize_dialog_param;
+
 extern void uilib_localize_dialog(HWND hwnd, uilib_localize_dialog_param *param);
 
-
 #endif
-
