@@ -25,20 +25,20 @@
  *
  */
 
-#ifndef _UIVIDEO_H
-#define _UIVIDEO_H
+#ifndef VICE_UIVIDEO_H
+#define VICE_UIVIDEO_H
 
 #include <windows.h>
 
-#define UI_VIDEO_PAL	0
-#define UI_VIDEO_RGB	1
+#define UI_VIDEO_PAL 0
+#define UI_VIDEO_RGB 1
 
-#define UI_VIDEO_CHIP_NONE      -1
-#define UI_VIDEO_CHIP_VICII     0
-#define UI_VIDEO_CHIP_VIC       1
-#define UI_VIDEO_CHIP_CRTC      2
-#define UI_VIDEO_CHIP_VDC       3
-#define UI_VIDEO_CHIP_TED       4
+#define UI_VIDEO_CHIP_NONE  -1
+#define UI_VIDEO_CHIP_VICII 0
+#define UI_VIDEO_CHIP_VIC   1
+#define UI_VIDEO_CHIP_CRTC  2
+#define UI_VIDEO_CHIP_VDC   3
+#define UI_VIDEO_CHIP_TED   4
 
 void ui_video_settings_dialog(HWND hwnd, int chip_type1, int chip_type2);
 
