@@ -35,12 +35,16 @@
 #include "debug.h"
 #include "lib.h"
 #include "res.h"
+#include "resources.h"
+#include "system.h"
 #include "translate.h"
 #include "ui.h"
 #include "uicart.h"
 #include "uidrivevic20.h"
+#include "uijoystick.h"
 #include "uikeyboard.h"
 #include "uilib.h"
+#include "uilightpen.h"
 #include "uimidi.h"
 #include "uirom.h"
 #include "uirs232user.h"
@@ -53,7 +57,8 @@
 static const unsigned int romset_dialog_resources[UIROM_TYPE_MAX] = {
     IDD_VIC20ROM_RESOURCE_DIALOG,
     IDD_VIC20ROMDRIVE_RESOURCE_DIALOG,
-    0 };
+    0
+};
 
 static const ui_menu_toggle_t vic20_ui_menu_toggles[] = {
     { "EmuID", IDM_TOGGLE_EMUID },
@@ -63,6 +68,10 @@ static const ui_menu_toggle_t vic20_ui_menu_toggles[] = {
     { "PALEmulation", IDM_TOGGLE_FASTPAL },
     { "VICVideoCache", IDM_TOGGLE_VIDEOCACHE },
     { "IEEE488", IDM_IEEE488 },
+    { "Mouse", IDM_PADDLES },
+    { "CartridgeReset", IDM_TOGGLE_CART_RESET },
+    { "FinalExpansionWriteBack", IDM_FINAL_EXPANSION_WRITEBACK },
+    { "MegaCartNvRAMWriteBack", IDM_MEGACART_WRITEBACK },
     { NULL, 0 }
 };
 
@@ -118,44 +127,66 @@ static const uikeyboard_mapping_entry_t mapping_entry[VIC20UI_KBD_NUM_MAP] = {
       IDC_VIC20KBD_MAPPING_POS_BROWSE, "KeymapPosFile" }
 };
 
-static uikeyboard_config_t uikeyboard_config =
-    { IDD_VIC20KBD_MAPPING_SETTINGS_DIALOG, VIC20UI_KBD_NUM_MAP,
-      mapping_entry, IDC_VIC20KBD_MAPPING_DUMP };
+static uilib_localize_dialog_param vic20_kbd_trans[] = {
+    { IDC_VIC20KBD_MAPPING_SELECT_SYM, IDS_SYMBOLIC, 0 },
+    { IDC_VIC20KBD_MAPPING_SELECT_POS, IDS_POSITIONAL, 0 },
+    { IDC_VIC20KBD_MAPPING_SYM_BROWSE, IDS_BROWSE, 0 },
+    { IDC_VIC20KBD_MAPPING_POS_BROWSE, IDS_BROWSE, 0 },
+    { IDC_VIC20KBD_MAPPING_DUMP, IDS_DUMP_KEYSET, 0 },
+    { IDC_KBD_SHORTCUT_DUMP, IDS_DUMP_SHORTCUTS, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_dialog_group vic20_kbd_left_group[] = {
+    { IDC_VIC20KBD_MAPPING_SELECT_SYM, 1 },
+    { IDC_VIC20KBD_MAPPING_SELECT_POS, 1 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group vic20_kbd_middle_group[] = {
+    { IDC_VIC20KBD_MAPPING_SYM, 0 },
+    { IDC_VIC20KBD_MAPPING_POS, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group vic20_kbd_right_group[] = {
+    { IDC_VIC20KBD_MAPPING_SYM_BROWSE, 0 },
+    { IDC_VIC20KBD_MAPPING_POS_BROWSE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group vic20_kbd_buttons_group[] = {
+    { IDC_VIC20KBD_MAPPING_DUMP, 1 },
+    { IDC_KBD_SHORTCUT_DUMP, 1 },
+    { 0, 0 }
+};
+
+static int vic20_kbd_move_buttons_group[] = {
+    IDC_VIC20KBD_MAPPING_DUMP,
+    IDC_KBD_SHORTCUT_DUMP,
+    0
+};
+
+static uikeyboard_config_t uikeyboard_config = {
+    IDD_VIC20KBD_MAPPING_SETTINGS_DIALOG,
+    VIC20UI_KBD_NUM_MAP,
+    mapping_entry,
+    IDC_VIC20KBD_MAPPING_DUMP,
+    vic20_kbd_trans,
+    vic20_kbd_left_group,
+    vic20_kbd_middle_group,
+    vic20_kbd_right_group,
+    vic20_kbd_buttons_group,
+    vic20_kbd_move_buttons_group
+};
 
 static const uicart_params_t vic20_ui_cartridges[] = {
-    {
-        IDM_CART_VIC20_8KB_2000,
-        CARTRIDGE_VIC20_16KB_2000,
-        IDS_ATTACH_4_8_16_CART_2000,
-        UILIB_FILTER_ALL
-    },
-    {
-        IDM_CART_VIC20_16KB_4000,
-        CARTRIDGE_VIC20_16KB_4000,
-        IDS_ATTACH_4_8_16_CART_4000,
-        UILIB_FILTER_ALL
-    },
-    {
-        IDM_CART_VIC20_8KB_6000,
-        CARTRIDGE_VIC20_16KB_6000,
-        IDS_ATTACH_4_8_16_CART_6000,
-        UILIB_FILTER_ALL
-    },
-    {
-        IDM_CART_VIC20_8KB_A000,
-        CARTRIDGE_VIC20_8KB_A000,
-        IDS_ATTACH_4_8_CART_A000,
-        UILIB_FILTER_ALL
-    },
-    {
-        IDM_CART_VIC20_4KB_B000,
-        CARTRIDGE_VIC20_4KB_B000,
-        IDS_ATTACH_4_CART_B000,
-        UILIB_FILTER_ALL
-    },
-    {
-        0, 0, 0, 0
-    }
+    { IDM_CART_VIC20_8KB_2000, CARTRIDGE_VIC20_16KB_2000, IDS_ATTACH_4_8_16_CART_2000, UILIB_FILTER_ALL },
+    { IDM_CART_VIC20_16KB_4000, CARTRIDGE_VIC20_16KB_4000, IDS_ATTACH_4_8_16_CART_4000, UILIB_FILTER_ALL },
+    { IDM_CART_VIC20_8KB_6000, CARTRIDGE_VIC20_16KB_6000, IDS_ATTACH_4_8_16_CART_6000, UILIB_FILTER_ALL },
+    { IDM_CART_VIC20_8KB_A000, CARTRIDGE_VIC20_8KB_A000, IDS_ATTACH_4_8_CART_A000, UILIB_FILTER_ALL },
+    { IDM_CART_VIC20_4KB_B000, CARTRIDGE_VIC20_4KB_B000, IDS_ATTACH_4_CART_B000, UILIB_FILTER_ALL },
+    { 0, 0, 0, 0 }
 };
 
 ui_menu_translation_table_t vic20ui_menu_translation_table[] = {
@@ -187,6 +218,7 @@ ui_menu_translation_table_t vic20ui_menu_translation_table[] = {
     { IDM_TOGGLE_DOUBLESIZE, IDS_MI_TOGGLE_DOUBLESIZE },
     { IDM_TOGGLE_DOUBLESCAN, IDS_MI_TOGGLE_DOUBLESCAN },
     { IDM_TOGGLE_DRIVE_TRUE_EMULATION, IDS_MI_DRIVE_TRUE_EMULATION },
+    { IDM_TOGGLE_AUTOSTART_HANDLE_TDE, IDS_MI_AUTOSTART_HANDLE_TDE },
     { IDM_TOGGLE_VIDEOCACHE, IDS_MI_TOGGLE_VIDEOCACHE },
     { IDM_DRIVE_SETTINGS, IDS_MI_DRIVE_SETTINGS },
     { IDM_FLIP_ADD, IDS_MI_FLIP_ADD },
@@ -237,15 +269,20 @@ ui_menu_translation_table_t vic20ui_menu_translation_table[] = {
     { IDM_TOGGLE_ALWAYSONTOP, IDS_MI_TOGGLE_ALWAYSONTOP },
     { IDM_TOGGLE_FASTPAL, IDS_MI_TOGGLE_FASTPAL },
     { IDM_TOGGLE_SCALE2X, IDS_MI_TOGGLE_SCALE2X },
-    { IDM_SWAP_JOYSTICK, IDS_MI_SWAP_JOYSTICK },
+    { IDM_SWAP_EXTRA_JOYSTICK, IDS_MI_SWAP_EXTRA_JOYSTICK },
+    { IDM_ALLOW_JOY_OPPOSITE_TOGGLE, IDS_MI_ALLOW_JOY_OPPOSITE },
     { IDM_JOYKEYS_TOGGLE, IDS_MI_JOYKEYS_TOGGLE },
     { IDM_TOGGLE_VIRTUAL_DEVICES, IDS_MI_TOGGLE_VIRTUAL_DEVICES },
     { IDM_TOGGLE_EMUID, IDS_MI_TOGGLE_EMUID },
     { IDM_IEEE488, IDS_MI_IEEE488 },
+    { IDM_PADDLES, IDS_MI_PADDLES },
+    { IDM_AUTOSTART_SETTINGS, IDS_MI_AUTOSTART_SETTINGS },
     { IDM_VIDEO_SETTINGS, IDS_MI_VIDEO_SETTINGS },
     { IDM_DEVICEMANAGER, IDS_MI_DEVICEMANAGER },
     { IDM_JOY_SETTINGS, IDS_MI_JOY_SETTINGS },
+    { IDM_EXTRA_JOY_SETTINGS, IDS_MI_USERPORT_JOY_SETTINGS },
     { IDM_KEYBOARD_SETTINGS, IDS_MI_KEYBOARD_SETTINGS },
+    { IDM_LIGHTPEN_SETTINGS, IDS_MI_LIGHTPEN_SETTINGS },
     { IDM_SOUND_SETTINGS, IDS_MI_SOUND_SETTINGS },
     { IDM_ROM_SETTINGS, IDS_MI_ROM_SETTINGS },
     { IDM_RAM_SETTINGS, IDS_MI_RAM_SETTINGS },
@@ -260,6 +297,7 @@ ui_menu_translation_table_t vic20ui_menu_translation_table[] = {
     { IDM_TOGGLE_SAVE_SETTINGS_ON_EXIT, IDS_MI_SAVE_SETTINGS_ON_EXIT },
     { IDM_TOGGLE_CONFIRM_ON_EXIT, IDS_MI_CONFIRM_ON_EXIT },
     { IDM_LANG_EN, IDS_MI_LANG_EN },
+    { IDM_LANG_DA, IDS_MI_LANG_DA },
     { IDM_LANG_DE, IDS_MI_LANG_DE },
     { IDM_LANG_FR, IDS_MI_LANG_FR },
     { IDM_LANG_HU, IDS_MI_LANG_HU },
@@ -267,6 +305,7 @@ ui_menu_translation_table_t vic20ui_menu_translation_table[] = {
     { IDM_LANG_NL, IDS_MI_LANG_NL },
     { IDM_LANG_PL, IDS_MI_LANG_PL },
     { IDM_LANG_SV, IDS_MI_LANG_SV },
+    { IDM_LANG_TR, IDS_MI_LANG_TR },
     { IDM_CMDLINE, IDS_MI_CMDLINE },
     { IDM_CONTRIBUTORS, IDS_MI_CONTRIBUTORS },
     { IDM_LICENSE, IDS_MI_LICENSE },
@@ -274,11 +313,19 @@ ui_menu_translation_table_t vic20ui_menu_translation_table[] = {
     { IDM_TOGGLE_FULLSCREEN, IDS_MI_TOGGLE_FULLSCREEN },
     { IDM_SIDCART_SETTINGS, IDS_MI_SIDCART_SETTINGS },
     { IDM_MIDI_SETTINGS, IDS_MI_MIDI_SETTINGS },
+    { IDM_FINAL_EXPANSION_WRITEBACK, IDS_MI_FINAL_EXPANSION_WRITEBACK },
+    { IDM_MEGACART_WRITEBACK, IDS_MI_MEGACART_WRITEBACK },
+    { IDM_MEGACART_WRITEBACK_FILE, IDS_MI_MEGACART_WRITEBACK_FILE },
+    { IDM_CART_VIC20_GENERIC, IDS_MI_CART_VIC20_GENERIC },
+    { IDM_CART_VIC20_MEGACART, IDS_MI_CART_VIC20_MEGACART },
+    { IDM_CART_VIC20_FINAL_EXPANSION, IDS_MI_CART_VIC20_FINAL_EXPANSION },
+    { IDM_CART_VIC20_SMART_ATTACH, IDS_MI_CART_VIC20_SMART_ATTACH },
     { IDM_CART_VIC20_8KB_2000, IDS_MI_CART_VIC20_8KB_2000 },
     { IDM_CART_VIC20_16KB_4000, IDS_MI_CART_VIC20_16KB_4000 },
     { IDM_CART_VIC20_8KB_6000, IDS_MI_CART_VIC20_8KB_6000 },
     { IDM_CART_VIC20_8KB_A000, IDS_MI_CART_VIC20_8KB_A000 },
     { IDM_CART_VIC20_4KB_B000, IDS_MI_CART_VIC20_4KB_B000 },
+    { IDM_TOGGLE_CART_RESET, IDS_MI_TOGGLE_CART_RESET },
     { IDM_VIC_SETTINGS, IDS_MI_VIC_SETTINGS },
     { 0, 0 }
 };
@@ -290,6 +337,7 @@ ui_popup_translation_table_t vic20ui_popup_translation_table[] = {
     { 2, IDS_MP_FLIP_LIST },
     { 2, IDS_MP_DATASETTE_CONTROL },
     { 2, IDS_MP_ATTACH_CARTRIDGE_IMAGE },
+    { 3, IDS_MP_ADD_TO_GENERIC },
     { 2, IDS_MP_RESET },
 #ifdef DEBUG
     { 2, IDS_MP_DEBUG },
@@ -309,49 +357,184 @@ ui_popup_translation_table_t vic20ui_popup_translation_table[] = {
     { 0, 0 }
 };
 
+static uilib_localize_dialog_param vic20_main_trans[] = {
+    { IDC_VIC20ROM_KERNAL, IDS_KERNAL, 0 },
+    { IDC_VIC20ROM_KERNAL_BROWSE, IDS_BROWSE, 0 },
+    { IDC_VIC20ROM_BASIC, IDS_BASIC, 0 },
+    { IDC_VIC20ROM_BASIC_BROWSE, IDS_BROWSE, 0 },
+    { IDC_VIC20ROM_CHARGEN, IDS_CHARACTER, 0 },
+    { IDC_VIC20ROM_CHARGEN_BROWSE, IDS_BROWSE, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_localize_dialog_param vic20_drive_trans[] = {
+    { IDC_DRIVEROM_1541_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1541II_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1570_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1571_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1581_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_2031_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_2040_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_3040_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_4040_BROWSE, IDS_BROWSE, 0 },
+    { IDC_DRIVEROM_1001_BROWSE, IDS_BROWSE, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_localize_dialog_param vic20_main_res_trans[] = {
+    { 0, IDS_COMPUTER_RESOURCES_CAPTION, -1 },
+    { IDC_COMPUTER_RESOURCES, IDS_COMPUTER_RESOURCES, 0 },
+    { IDC_VIC20ROM_KERNAL_RESOURCE, IDS_KERNAL, 0 },
+    { IDC_VIC20ROM_BASIC_RESOURCE, IDS_BASIC, 0 },
+    { IDC_VIC20ROM_CHARGEN_RESOURCE, IDS_CHARACTER, 0 },
+    { IDOK, IDS_OK, 0 },
+    { IDCANCEL, IDS_CANCEL, 0 },
+    { 0, 0, 0 }
+};
+
+static uilib_dialog_group vic20_main_left_group[] = {
+    { IDC_KERNAL, 0 },
+    { IDC_BASIC, 0 },
+    { IDC_CHARACTER, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group vic20_main_middle_group[] = {
+    { IDC_VIC20ROM_KERNAL_FILE, 0 },
+    { IDC_VIC20ROM_BASIC_FILE, 0} ,
+    { IDC_VIC20ROM_CHARGEN_FILE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group vic20_main_right_group[] = {
+    { IDC_VIC20ROM_KERNAL_BROWSE, 0 },
+    { IDC_VIC20ROM_BASIC_BROWSE, 0} ,
+    { IDC_VIC20ROM_CHARGEN_BROWSE, 0 },
+    { 0, 0}
+};
+
+static uilib_dialog_group vic20_drive_left_group[] = {
+    { IDC_1541, 0 },
+    { IDC_1541_II, 0 },
+    { IDC_1570, 0 },
+    { IDC_1571, 0 },
+    { IDC_1581, 0 },
+    { IDC_2031, 0 },
+    { IDC_2040, 0 },
+    { IDC_3040, 0 },
+    { IDC_4040, 0 },
+    { IDC_1001, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group vic20_drive_middle_group[] = {
+    { IDC_DRIVEROM_1541_FILE, 0 },
+    { IDC_DRIVEROM_1541II_FILE, 0 },
+    { IDC_DRIVEROM_1570_FILE, 0 },
+    { IDC_DRIVEROM_1571_FILE, 0 },
+    { IDC_DRIVEROM_1581_FILE, 0 },
+    { IDC_DRIVEROM_2031_FILE, 0 },
+    { IDC_DRIVEROM_2040_FILE, 0 },
+    { IDC_DRIVEROM_3040_FILE, 0 },
+    { IDC_DRIVEROM_4040_FILE, 0 },
+    { IDC_DRIVEROM_1001_FILE, 0 },
+    { 0, 0 }
+};
+
+static uilib_dialog_group vic20_drive_right_group[] = {
+    { IDC_DRIVEROM_1541_BROWSE, 0 },
+    { IDC_DRIVEROM_1541II_BROWSE, 0 },
+    { IDC_DRIVEROM_1570_BROWSE, 0 },
+    { IDC_DRIVEROM_1571_BROWSE, 0 },
+    { IDC_DRIVEROM_1581_BROWSE, 0 },
+    { IDC_DRIVEROM_2031_BROWSE, 0 },
+    { IDC_DRIVEROM_2040_BROWSE, 0 },
+    { IDC_DRIVEROM_3040_BROWSE, 0 },
+    { IDC_DRIVEROM_4040_BROWSE, 0 },
+    { IDC_DRIVEROM_1001_BROWSE, 0 },
+    { 0, 0 }
+};
+
 /* Probably one should simply remove the size numbers from the IDM_* stuff */
 static void vic20_ui_specific(WPARAM wparam, HWND hwnd)
 {
+    TCHAR *st_name;
+
     switch (wparam) {
-      case IDM_CART_VIC20_8KB_2000:
-      case IDM_CART_VIC20_16KB_4000:
-      case IDM_CART_VIC20_8KB_6000:
-      case IDM_CART_VIC20_8KB_A000:
-      case IDM_CART_VIC20_4KB_B000:
-        uicart_attach(wparam, hwnd, vic20_ui_cartridges);
-        break;
-      case IDM_CART_SET_DEFAULT:
-        cartridge_set_default();
-        break;
-      case IDM_CART_DETACH:
-        cartridge_detach_image();
-        break;
-      case IDM_VIC_SETTINGS:
-        ui_vic_settings_dialog(hwnd);
-        break;
-      case IDM_SIDCART_SETTINGS:
-        ui_sidcart_settings_dialog(hwnd);
-        break;
-      case IDM_MIDI_SETTINGS:
-        ui_midi_settings_dialog(hwnd);
-        break;
-      case IDM_ROM_SETTINGS:
-        uirom_settings_dialog(hwnd, IDD_VIC20ROM_SETTINGS_DIALOG,
-                              translate_res(IDD_VIC20DRIVEROM_SETTINGS_DIALOG),
-                              romset_dialog_resources, uirom_settings); 
-        break;
-      case IDM_VIDEO_SETTINGS:
-        ui_video_settings_dialog(hwnd, UI_VIDEO_CHIP_VIC, UI_VIDEO_CHIP_NONE);
-        break;
-      case IDM_DRIVE_SETTINGS:
-        uidrivevic20_settings_dialog(hwnd);
-        break;
-      case IDM_RS232USER_SETTINGS:
-        ui_rs232user_settings_dialog(hwnd);
-        break;
-      case IDM_KEYBOARD_SETTINGS:
-        uikeyboard_settings_dialog(hwnd, &uikeyboard_config);
-        break;
+        case IDM_CART_VIC20_GENERIC:
+            uicart_attach_special(hwnd, translate_text(IDS_SELECT_GENERIC), UILIB_FILTER_ALL, CARTRIDGE_VIC20_GENERIC);
+            break;
+        case IDM_CART_VIC20_MEGACART:
+            uicart_attach_special(hwnd, translate_text(IDS_SELECT_MEGACART), UILIB_FILTER_ALL, CARTRIDGE_VIC20_MEGACART);
+            break;
+        case IDM_CART_VIC20_FINAL_EXPANSION:
+            uicart_attach_special(hwnd, translate_text(IDS_SELECT_FINAL_EXPANSION), UILIB_FILTER_ALL, CARTRIDGE_VIC20_FINAL_EXPANSION);
+            break;
+        case IDM_CART_VIC20_SMART_ATTACH:
+            uicart_attach_special(hwnd, translate_text(IDS_SELECT_CARTRIDGE_IMAGE), UILIB_FILTER_ALL, CARTRIDGE_VIC20_DETECT);
+            break;
+        case IDM_CART_VIC20_8KB_2000:
+        case IDM_CART_VIC20_16KB_4000:
+        case IDM_CART_VIC20_8KB_6000:
+        case IDM_CART_VIC20_8KB_A000:
+        case IDM_CART_VIC20_4KB_B000:
+            uicart_attach(wparam, hwnd, vic20_ui_cartridges);
+            break;
+        case IDM_CART_SET_DEFAULT:
+            cartridge_set_default();
+            break;
+        case IDM_CART_DETACH:
+            cartridge_detach_image();
+            break;
+        case IDM_VIC_SETTINGS:
+            ui_vic_settings_dialog(hwnd);
+            break;
+        case IDM_SIDCART_SETTINGS:
+            ui_sidcart_settings_dialog(hwnd);
+            break;
+        case IDM_MIDI_SETTINGS:
+            ui_midi_settings_dialog(hwnd);
+            break;
+        case IDM_JOY_SETTINGS:
+            ui_joystick_settings_dialog(hwnd);
+            break;
+        case IDM_LIGHTPEN_SETTINGS:
+            ui_lightpen_settings_dialog(hwnd);
+            break;
+        case IDM_EXTRA_JOY_SETTINGS:
+            ui_extra_joystick_settings_dialog(hwnd);
+            break;
+        case IDM_ROM_SETTINGS:
+            uirom_settings_dialog(hwnd, IDD_VIC20ROM_SETTINGS_DIALOG, IDD_VIC20DRIVEROM_SETTINGS_DIALOG,
+                                  romset_dialog_resources, uirom_settings, 
+                                  vic20_main_trans, vic20_drive_trans,
+                                  vic20_main_left_group, vic20_main_middle_group, vic20_main_right_group,
+                                  vic20_drive_left_group, vic20_drive_middle_group, vic20_drive_right_group,
+                                  vic20_main_res_trans);
+            break;
+        case IDM_VIDEO_SETTINGS:
+            ui_video_settings_dialog(hwnd, UI_VIDEO_CHIP_VIC, UI_VIDEO_CHIP_NONE);
+            break;
+        case IDM_DRIVE_SETTINGS:
+            uidrivevic20_settings_dialog(hwnd);
+            break;
+        case IDM_RS232USER_SETTINGS:
+            ui_rs232user_settings_dialog(hwnd);
+            break;
+        case IDM_KEYBOARD_SETTINGS:
+            uikeyboard_settings_dialog(hwnd, &uikeyboard_config);
+            break;
+        case IDM_MEGACART_WRITEBACK_FILE:
+            if ((st_name = uilib_select_file(hwnd, translate_text(IDS_MI_MEGACART_WRITEBACK_FILE), UILIB_FILTER_ALL, UILIB_SELECTOR_TYPE_FILE_SAVE, UILIB_SELECTOR_STYLE_DEFAULT)) != NULL) {
+                char *name;
+
+                name = system_wcstombs_alloc(st_name);
+
+                resources_set_string("MegaCartNvRAMfilename", name);
+                system_wcstombs_free(name);
+                lib_free(st_name);
+            }
+            break;
     }
 }
 
@@ -367,4 +550,3 @@ int vic20ui_init(void)
 void vic20ui_shutdown(void)
 {
 }
-
