@@ -31,8 +31,10 @@
 
 #include "vsync.h"
 #include "kbdbuf.h"
+#include "lightpendrv.h"
 #include "machine.h"
 #include "ui.h"
+#include "uiapi.h"
 #include "mousedrv.h"
 #include "videoarch.h"
 
@@ -62,7 +64,7 @@ signed long vsyncarch_frequency(void)
         }
 #ifdef HAS_LONGLONG_INTEGER
         li.QuadPart >>= perf_rotate;
-            frequency = (signed long)li.QuadPart;
+        frequency = (signed long)li.QuadPart;
 #else
         for (i = 0; i < perf_rotate; i++) {
             li.LowPart >>= 1;
@@ -92,7 +94,7 @@ unsigned long vsyncarch_gettime(void)
 
 #ifdef HAS_LONGLONG_INTEGER
     li.QuadPart >>= perf_rotate;
-        return (unsigned long)li.QuadPart;
+    return (unsigned long)li.QuadPart;
 #else
     for (i = 0; i < perf_rotate; i++) {
         li.LowPart >>= 1;
@@ -115,15 +117,15 @@ void vsyncarch_init(void)
             return;
         }
 #ifdef HAS_LONGLONG_INTEGER
-        while (li.QuadPart & 0xffffffffe0000000) {
+        while (li.QuadPart & uint64_t_C(0xffffffffe0000000)) {
             li.QuadPart >>= 1;
             perf_rotate++;
         }
 #else
-        while ((li.HighPart & 0xffffffff) || (li.LowPart & 0xe0000000)) {
+        while ((li.HighPart & 0xffffffffu) || (li.LowPart & 0xe0000000u)) {
             li.LowPart >>= 1;
             if (li.HighPart&1) {
-                li.LowPart = li.LowPart || 0x80000000;
+                li.LowPart = li.LowPart || 0x80000000u;
             }
             li.HighPart >>= 1;
             perf_rotate++;
@@ -143,16 +145,16 @@ void vsyncarch_display_speed(double speed, double frame_rate, int warp_enabled)
 
 void vsyncarch_sync_with_raster(video_canvas_t *c)
 {
-    IDirectDraw2_WaitForVerticalBlank(c->dd_object2, DDWAITVB_BLOCKBEGIN,
-				      0);
+    IDirectDraw2_WaitForVerticalBlank(c->dd_object2, DDWAITVB_BLOCKBEGIN, 0);
 }
 
 void vsyncarch_sleep(signed long delay)
 {
     unsigned long start, now;
 
-    if (delay <= vsyncarch_frequency() / 1000)
+    if (delay <= vsyncarch_frequency() / 1000) {
         return;
+    }
 
     start = vsyncarch_gettime();
     do {
@@ -166,6 +168,9 @@ void vsyncarch_presync(void)
     /* Update mouse */
     mouse_update_mouse();
 
+    /* Update lightpen */
+    win32_lightpen_update();
+
     /* Flush keypresses emulated through the keyboard buffer.  */
     kbdbuf_flush();
     joystick_update();
@@ -181,4 +186,3 @@ int vsyncarch_vbl_sync_enabled(void)
 {
     return ui_vblank_sync_enabled();
 }
-
