@@ -62,7 +62,9 @@
 #include "drive-resources.h"
 #include "drive.h"
 #include "drivecpu.h"
+#include "easyflash.h"
 #include "functionrom.h"
+#include "georam.h"
 #include "imagecontents.h"
 #include "kbdbuf.h"
 #include "keyboard.h"
@@ -79,13 +81,14 @@
 #include "parallel.h"
 #include "patchrom.h"
 #include "printer.h"
-#include "reu.h"
-#include "georam.h"
 #include "ramcart.h"
+#include "reu.h"
 #include "rs232drv.h"
 #include "rsuser.h"
 #include "screenshot.h"
 #include "serial.h"
+#include "sfx_soundexpander.h"
+#include "sfx_soundsampler.h"
 #include "sid-cmdline-options.h"
 #include "sid-resources.h"
 #include "sid.h"
@@ -102,6 +105,7 @@
 #include "z80mem.h"
 
 #ifdef HAVE_MOUSE
+#include "lightpen.h"
 #include "mouse.h"
 #endif
 
@@ -112,8 +116,8 @@
 /* dummy functions until the C128 version of the
    256K expansion can be made */
 
-int c64_256k_enabled=0;
-int c64_256k_start=0xdf80;
+int c64_256k_enabled = 0;
+int c64_256k_start = 0xdf80;
 
 void REGPARM2 c64_256k_store(WORD addr, BYTE byte)
 {
@@ -121,17 +125,17 @@ void REGPARM2 c64_256k_store(WORD addr, BYTE byte)
 
 BYTE REGPARM1 c64_256k_read(WORD addr)
 {
-  return 0xff;
+    return 0xff;
 }
 
 BYTE REGPARM1 c64_256k_ram_segment2_read(WORD addr)
 {
-  return mem_ram[addr];
+    return mem_ram[addr];
 }
 
 void REGPARM2 c64_256k_ram_segment2_store(WORD addr, BYTE byte)
 {
-  mem_ram[addr]=byte;
+    mem_ram[addr] = byte;
 }
 
 void c64_256k_cia_set_vbank(int ciabank)
@@ -141,31 +145,38 @@ void c64_256k_cia_set_vbank(int ciabank)
 /* dummy functions until the C128 version of the 
    +60K expansion can be made */
 
-int plus60k_enabled=0;
+int plus60k_enabled = 0;
 
 BYTE REGPARM1 plus60k_ram_read(WORD addr)
 {
-  return mem_ram[addr];
+    return mem_ram[addr];
 }
 
 void REGPARM2 plus60k_ram_store(WORD addr, BYTE value)
 {
-  mem_ram[addr] = value;
+    mem_ram[addr] = value;
 }
 
 /* dummy functions until the C128 version of the
    +256K expansion can be made */
 
-int plus256k_enabled=0;
+int plus256k_enabled = 0;
 
 BYTE REGPARM1 plus256k_ram_high_read(WORD addr)
 {
-  return mem_ram[addr];
+    return mem_ram[addr];
 }
 
 void REGPARM2 plus256k_ram_high_store(WORD addr, BYTE byte)
 {
-  mem_ram[addr]=byte;
+    mem_ram[addr] = byte;
+}
+
+/* Lightpen trigger function; needs to trigger both VICII and VDC */
+void c128_trigger_light_pen(CLOCK mclk)
+{
+    vicii_trigger_light_pen(mclk);
+    vdc_trigger_light_pen(mclk);
 }
 
 machine_context_t machine_context;
@@ -173,12 +184,11 @@ machine_context_t machine_context;
 #define NUM_KEYBOARD_MAPPINGS 2
 
 const char *machine_keymap_res_name_list[NUM_KEYBOARD_MAPPINGS] = {
-    "KeymapSymFile", "KeymapPosFile"
+    "KeymapSymFile",
+    "KeymapPosFile"
 };
 
-char *machine_keymap_file_list[NUM_KEYBOARD_MAPPINGS] = {
-    NULL, NULL
-};
+char *machine_keymap_file_list[NUM_KEYBOARD_MAPPINGS] = { NULL, NULL };
 
 const char machine_name[] = "C128";
 int machine_class = VICE_MACHINE_C128;
@@ -188,162 +198,27 @@ static void machine_vsync_hook(void);
 /* ------------------------------------------------------------------------- */
 
 static const trap_t c128_serial_traps[] = {
-    {
-        "SerialListen",
-        0xE355,
-        0xE5BA,
-        { 0x20, 0x73, 0xE5 },
-        serial_trap_attention,
-        c128memrom_trap_read,
-        c128memrom_trap_store
-    },
-    {
-        "SerialSaListen",
-        0xE37C,
-        0xE5BA,
-        { 0x20, 0x73, 0xE5 },
-        serial_trap_attention,
-        c128memrom_trap_read,
-        c128memrom_trap_store
-    },
-    {
-        "SerialSendByte",
-        0xE38C,
-        0xE5BA,
-        { 0x20, 0x73, 0xE5 },
-        serial_trap_send,
-        c128memrom_trap_read,
-        c128memrom_trap_store
-    },
-    {
-        "SerialReceiveByte",
-        0xE43E,
-        0xE5BA,
-        { 0x20, 0x73, 0xE5 },
-        serial_trap_receive,
-        c128memrom_trap_read,
-        c128memrom_trap_store
-    },
-    {
-        "Serial ready",
-        0xE569,
-        0xE572,
-        { 0xAD, 0x00, 0xDD },
-        serial_trap_ready,
-        c128memrom_trap_read,
-        c128memrom_trap_store
-    },
-    {
-        "Serial ready",
-        0xE4F5,
-        0xE572,
-        { 0xAD, 0x00, 0xDD },
-        serial_trap_ready,
-        c128memrom_trap_read,
-        c128memrom_trap_store
-    },
-    {
-        "SerialListen",
-        0xED24,
-        0xEDAB,
-        { 0x20, 0x97, 0xEE },
-        serial_trap_attention,
-        c64memrom_trap_read,
-        c64memrom_trap_store
-    },
-    {
-        "SerialSaListen",
-        0xED37,
-        0xEDAB,
-        { 0x20, 0x8E, 0xEE },
-        serial_trap_attention,
-        c64memrom_trap_read,
-        c64memrom_trap_store
-    },
-    {
-        "SerialSendByte",
-        0xED41,
-        0xEDAB,
-        { 0x20, 0x97, 0xEE },
-        serial_trap_send,
-        c64memrom_trap_read,
-        c64memrom_trap_store
-    },
-    {
-        "SerialReceiveByte",
-        0xEE14,
-        0xEDAB,
-        { 0xA9, 0x00, 0x85 },
-        serial_trap_receive,
-        c64memrom_trap_read,
-        c64memrom_trap_store
-    },
-    {
-        "SerialReady",
-        0xEEA9,
-        0xEDAB,
-        { 0xAD, 0x00, 0xDD },
-        serial_trap_ready,
-        c64memrom_trap_read,
-        c64memrom_trap_store
-    },
-    {
-        NULL,
-        0,
-        0,
-        { 0, 0, 0 },
-        NULL,
-        NULL,
-        NULL
-    }
+    { "SerialListen", 0xE355, 0xE5BA, { 0x20, 0x73, 0xE5 }, serial_trap_attention, c128memrom_trap_read, c128memrom_trap_store },
+    { "SerialSaListen", 0xE37C, 0xE5BA, { 0x20, 0x73, 0xE5 }, serial_trap_attention, c128memrom_trap_read, c128memrom_trap_store },
+    { "SerialSendByte", 0xE38C, 0xE5BA, { 0x20, 0x73, 0xE5 }, serial_trap_send, c128memrom_trap_read, c128memrom_trap_store },
+    { "SerialReceiveByte", 0xE43E, 0xE5BA, { 0x20, 0x73, 0xE5 }, serial_trap_receive, c128memrom_trap_read, c128memrom_trap_store },
+    { "Serial ready", 0xE569, 0xE572, { 0xAD, 0x00, 0xDD }, serial_trap_ready, c128memrom_trap_read, c128memrom_trap_store },
+    { "Serial ready", 0xE4F5, 0xE572, { 0xAD, 0x00, 0xDD }, serial_trap_ready, c128memrom_trap_read, c128memrom_trap_store },
+    { "SerialListen", 0xED24, 0xEDAB, { 0x20, 0x97, 0xEE }, serial_trap_attention, c64memrom_trap_read, c64memrom_trap_store },
+    { "SerialSaListen", 0xED37, 0xEDAB, { 0x20, 0x8E, 0xEE }, serial_trap_attention, c64memrom_trap_read, c64memrom_trap_store },
+    { "SerialSendByte", 0xED41, 0xEDAB, { 0x20, 0x97, 0xEE }, serial_trap_send, c64memrom_trap_read, c64memrom_trap_store },
+    { "SerialReceiveByte", 0xEE14, 0xEDAB, { 0xA9, 0x00, 0x85 }, serial_trap_receive, c64memrom_trap_read, c64memrom_trap_store },
+    { "SerialReady", 0xEEA9, 0xEDAB, { 0xAD, 0x00, 0xDD }, serial_trap_ready, c64memrom_trap_read, c64memrom_trap_store },
+    { NULL, 0, 0, { 0, 0, 0 }, NULL, NULL, NULL }
 };
 
 /* Tape traps.  */
 static const trap_t c128_tape_traps[] = {
-    {
-        "TapeFindHeader",
-        0xE8D3,
-        0xE8D6,
-        { 0x20, 0xF2, 0xE9 },
-        tape_find_header_trap,
-        c128memrom_trap_read,
-        c128memrom_trap_store
-    },
-    {
-        "TapeReceive",
-        0xEA60,
-        0xEE57,
-        { 0x20, 0x9B, 0xEE },
-        tape_receive_trap,
-        c128memrom_trap_read,
-        c128memrom_trap_store
-    },
-    {
-        "TapeFindHeader",
-        0xF72F,
-        0xF732,
-        { 0x20, 0x41, 0xF8 },
-        tape_find_header_trap,
-        c64memrom_trap_read,
-        c64memrom_trap_store
-    },
-    {
-        "TapeReceive",
-        0xF8A1,
-        0xFC93,
-        { 0x20, 0xBD, 0xFC },
-        tape_receive_trap,
-        c64memrom_trap_read,
-        c64memrom_trap_store
-    },
-    {
-        NULL,
-        0,
-        0,
-        { 0, 0, 0 },
-        NULL,
-        NULL,
-        NULL
+    { "TapeFindHeader", 0xE8D3, 0xE8D6, { 0x20, 0xF2, 0xE9 }, tape_find_header_trap, c128memrom_trap_read, c128memrom_trap_store },
+    { "TapeReceive", 0xEA60, 0xEE57, { 0x20, 0x9B, 0xEE }, tape_receive_trap, c128memrom_trap_read, c128memrom_trap_store },
+    { "TapeFindHeader", 0xF72F, 0xF732, { 0x20, 0x41, 0xF8 }, tape_find_header_trap, c64memrom_trap_read, c64memrom_trap_store },
+    { "TapeReceive", 0xF8A1, 0xFC93, { 0x20, 0xBD, 0xFC }, tape_receive_trap, c64memrom_trap_read, c64memrom_trap_store },
+    { NULL, 0, 0, { 0, 0, 0 }, NULL, NULL, NULL
     }
 };
 
@@ -377,7 +252,7 @@ int machine_resources_init(void)
 {
     if (traps_resources_init() < 0
         || vsync_resources_init() < 0
-	|| machine_video_resources_init() < 0
+        || machine_video_resources_init() < 0
         || c128_resources_init() < 0
         || c64export_resources_init() < 0
         || reu_resources_init() < 0
@@ -385,6 +260,9 @@ int machine_resources_init(void)
         || ramcart_resources_init() < 0
         || mmc64_resources_init() < 0
         || digimax_resources_init() < 0
+        || sfx_soundexpander_resources_init() < 0
+        || sfx_soundsampler_resources_init() < 0
+        || easyflash_resources_init() < 0
 #ifdef HAVE_TFE
         || tfe_resources_init() < 0
 #endif
@@ -398,6 +276,7 @@ int machine_resources_init(void)
         || serial_resources_init() < 0
         || printer_resources_init() < 0
 #ifdef HAVE_MOUSE
+        || lightpen_resources_init() < 0
         || mouse_resources_init() < 0
 #endif
 #ifndef COMMON_KBD
@@ -411,8 +290,9 @@ int machine_resources_init(void)
 #endif
         || mmu_resources_init() < 0
         || z80mem_resources_init() < 0
-        || functionrom_resources_init() < 0)
+        || functionrom_resources_init() < 0) {
         return -1;
+    }
 
     return 0;
 }
@@ -449,6 +329,9 @@ int machine_cmdline_options_init(void)
         || ramcart_cmdline_options_init() < 0
         || mmc64_cmdline_options_init() < 0
         || digimax_cmdline_options_init() < 0
+        || sfx_soundexpander_cmdline_options_init() < 0
+        || sfx_soundsampler_cmdline_options_init() < 0
+        || easyflash_cmdline_options_init() < 0
 #ifdef HAVE_TFE
         || tfe_cmdline_options_init() < 0
 #endif
@@ -462,6 +345,7 @@ int machine_cmdline_options_init(void)
         || serial_cmdline_options_init() < 0
         || printer_cmdline_options_init() < 0
 #ifdef HAVE_MOUSE
+        || lightpen_cmdline_options_init() < 0
         || mouse_cmdline_options_init() < 0
 #endif
 #ifndef COMMON_KBD
@@ -475,8 +359,9 @@ int machine_cmdline_options_init(void)
 #endif
         || mmu_cmdline_options_init() < 0
         || functionrom_cmdline_options_init() < 0
-        || z80mem_cmdline_options_init() < 0)
+        || z80mem_cmdline_options_init() < 0) {
         return -1;
+    }
 
     return 0;
 }
@@ -488,19 +373,19 @@ static void c128_monitor_init(void)
     monitor_interface_t *drive_interface_init[DRIVE_NUM];
     monitor_cpu_type_t *asmarray[3];
 
-    asmarray[0]=&asm6502;
-    asmarray[1]=&asmz80;
-    asmarray[2]=NULL;
+    asmarray[0] = &asm6502;
+    asmarray[1] = &asmz80;
+    asmarray[2] = NULL;
 
     asm6502_init(&asm6502);
     asmz80_init(&asmz80);
 
-    for (dnr = 0; dnr < DRIVE_NUM; dnr++)
+    for (dnr = 0; dnr < DRIVE_NUM; dnr++) {
         drive_interface_init[dnr] = drivecpu_monitor_interface_get(dnr);
+    }
 
     /* Initialize the monitor.  */
-    monitor_init(maincpu_monitor_interface_get(), drive_interface_init,
-                 asmarray);
+    monitor_init(maincpu_monitor_interface_get(), drive_interface_init, asmarray);
 }
 
 void machine_setup_context(void)
@@ -516,18 +401,21 @@ int machine_specific_init(void)
 {
     c128_log = log_open("C128");
 
-    if (mem_load() < 0)
+    if (mem_load() < 0) {
         return -1;
+    }
 
-    if (z80mem_load() < 0)
+    if (z80mem_load() < 0) {
         return -1;
+    }
 
     /* Setup trap handling.  */
     traps_init();
 
     /* Initialize serial traps.  */
-    if (serial_init(c128_serial_traps) < 0)
+    if (serial_init(c128_serial_traps) < 0) {
         return -1;
+    }
 
     serial_trap_init(0xa4);
     serial_iec_bus_init();
@@ -549,15 +437,15 @@ int machine_specific_init(void)
     drive_init();
 
     /* Initialize autostart. FIXME: at least 0xa26 is only for 40 cols */
-    autostart_init((CLOCK)
-                   (3 * C128_PAL_RFSH_PER_SEC * C128_PAL_CYCLES_PER_RFSH),
-                   1, 0xa27, 0xe0, 0xec, 0xee);
+    autostart_init((CLOCK)(3 * C128_PAL_RFSH_PER_SEC * C128_PAL_CYCLES_PER_RFSH), 1, 0xa27, 0xe0, 0xec, 0xee);
 
-    if (vdc_init() == NULL)
+    if (vdc_init() == NULL) {
         return -1;
+    }
 
-    if (vicii_init(VICII_EXTENDED) == NULL)
+    if (vicii_init(VICII_EXTENDED) == NULL) {
         return -1;
+    }
 
     cia1_init(machine_context.cia1);
     cia2_init(machine_context.cia2);
@@ -568,8 +456,9 @@ int machine_specific_init(void)
 
 #ifndef COMMON_KBD
     /* Initialize the keyboard.  */
-    if (c128_kbd_init() < 0)
+    if (c128_kbd_init() < 0) {
         return -1;
+    }
 #endif
 
     c64keyboard_init();
@@ -578,16 +467,14 @@ int machine_specific_init(void)
 
     /* Initialize vsync and register our hook function.  */
     vsync_init(machine_vsync_hook);
-    vsync_set_machine_parameter(machine_timing.rfsh_per_sec,
-                                machine_timing.cycles_per_sec);
+    vsync_set_machine_parameter(machine_timing.rfsh_per_sec, machine_timing.cycles_per_sec);
 
     /* Initialize sound.  Notice that this does not really open the audio
        device yet.  */
     sound_init(machine_timing.cycles_per_sec, machine_timing.cycles_per_rfsh);
 
     /* Initialize keyboard buffer.  */
-    kbdbuf_init(842, 208, 10, (CLOCK)(machine_timing.rfsh_per_sec
-                * machine_timing.cycles_per_rfsh));
+    kbdbuf_init(842, 208, 10, (CLOCK)(machine_timing.rfsh_per_sec * machine_timing.cycles_per_rfsh));
 
     /* Initialize the C128-specific part of the UI.  */
     c128ui_init();
@@ -612,6 +499,12 @@ int machine_specific_init(void)
 #ifdef HAVE_MOUSE
     /* Initialize mouse support (if present).  */
     mouse_init();
+
+    /* Initialize lightpen support and register VICII/VDC callbacks */
+    lightpen_init();
+    lightpen_register_timing_callback(vicii_lightpen_timing, 1);
+    lightpen_register_timing_callback(vdc_lightpen_timing, 0);
+    lightpen_register_trigger_callback(c128_trigger_light_pen);
 #endif
 
     c64iec_init();
@@ -626,21 +519,22 @@ int machine_specific_init(void)
     mmu_init();
 
     machine_drive_stub();
-#if defined (USE_XF86_EXTENSIONS) && \
-    (defined(USE_XF86_VIDMODE_EXT) || defined (HAVE_XRANDR))
+
+#if defined (USE_XF86_EXTENSIONS) && (defined(USE_XF86_VIDMODE_EXT) || defined (HAVE_XRANDR))
     {
-	/* set fullscreen if user used `-fullscreen' on cmdline 
-	   use VICII as default */
-	int fs;
-	resources_get_int("UseFullscreen", &fs);
-	if (fs)
-	{
-	    resources_get_int("40/80ColumnKey", &fs);
-	    if (fs == 1)
-		resources_set_int("VICIIFullscreen", 1);
-	    else
-		resources_set_int("VDCFullscreen", 1);
-	}
+        /* set fullscreen if user used `-fullscreen' on cmdline 
+           use VICII as default */
+        int fs;
+
+        resources_get_int("UseFullscreen", &fs);
+        if (fs) {
+            resources_get_int("40/80ColumnKey", &fs);
+            if (fs == 1) {
+                resources_set_int("VICIIFullscreen", 1);
+            } else {
+                resources_set_int("VDCFullscreen", 1);
+            }
+        }
     }
 #endif
 
@@ -686,7 +580,6 @@ void machine_specific_reset(void)
 
 void machine_specific_powerup(void)
 {
-    /*vicii_reset_registers();*/
 }
 
 void machine_specific_shutdown(void)
@@ -724,30 +617,23 @@ void machine_handle_pending_alarms(int num_write_cycles)
 
 void machine_kbdbuf_reset_c128(void)
 {
-    kbdbuf_reset(842, 208, 10, (CLOCK)(machine_timing.rfsh_per_sec
-                 * machine_timing.cycles_per_rfsh));
+    kbdbuf_reset(842, 208, 10, (CLOCK)(machine_timing.rfsh_per_sec * machine_timing.cycles_per_rfsh));
 }
 
 void machine_kbdbuf_reset_c64(void)
 {
-    kbdbuf_reset(631, 198, 10, (CLOCK)(machine_timing.rfsh_per_sec
-                 * machine_timing.cycles_per_rfsh));
+    kbdbuf_reset(631, 198, 10, (CLOCK)(machine_timing.rfsh_per_sec * machine_timing.cycles_per_rfsh));
 }
 
 void machine_autostart_reset_c128(void)
 {
-
     /* FIXME: at least 0xa26 is only for 40 cols */
-    autostart_reinit((CLOCK)(3 * machine_timing.rfsh_per_sec
-                     * machine_timing.cycles_per_rfsh),
-                     1, 0xa27, 0xe0, 0xec, 0xee);
+    autostart_reinit((CLOCK)(3 * machine_timing.rfsh_per_sec * machine_timing.cycles_per_rfsh), 1, 0xa27, 0xe0, 0xec, 0xee);
 }
 
 void machine_autostart_reset_c64(void)
 {
-    autostart_reinit((CLOCK)(3 * machine_timing.rfsh_per_sec
-                       * machine_timing.cycles_per_rfsh),
-                       1, 0xcc, 0xd1, 0xd3, 0xd5);
+    autostart_reinit((CLOCK)(3 * machine_timing.rfsh_per_sec * machine_timing.cycles_per_rfsh), 1, 0xcc, 0xd1, 0xd3, 0xd5);
 }
 
 /* ------------------------------------------------------------------------- */
@@ -789,62 +675,56 @@ long machine_get_cycles_per_second(void)
 
 void machine_get_line_cycle(unsigned int *line, unsigned int *cycle, int *half_cycle)
 {
-    *line = (unsigned int)((maincpu_clk) / machine_timing.cycles_per_line
-            % machine_timing.screen_lines);
-
+    *line = (unsigned int)((maincpu_clk) / machine_timing.cycles_per_line % machine_timing.screen_lines);
     *cycle = (unsigned int)((maincpu_clk) % machine_timing.cycles_per_line);
-
     *half_cycle = (int)vicii_get_half_cycle();
 }
 
 void machine_change_timing(int timeval)
 {
-   int border_mode;
+    int border_mode;
 
     switch (timeval) {
-      default:
-      case MACHINE_SYNC_PAL ^ VICII_BORDER_MODE(VICII_NORMAL_BORDERS):
-      case MACHINE_SYNC_NTSC ^ VICII_BORDER_MODE(VICII_NORMAL_BORDERS):
-        timeval ^= VICII_BORDER_MODE(VICII_NORMAL_BORDERS);
-        border_mode = VICII_NORMAL_BORDERS;
-        break;
-      case MACHINE_SYNC_PAL ^ VICII_BORDER_MODE(VICII_FULL_BORDERS):
-      case MACHINE_SYNC_NTSC ^ VICII_BORDER_MODE(VICII_FULL_BORDERS):
-        timeval ^= VICII_BORDER_MODE(VICII_FULL_BORDERS);
-        border_mode = VICII_FULL_BORDERS;
-        break;
-      case MACHINE_SYNC_PAL ^ VICII_BORDER_MODE(VICII_DEBUG_BORDERS):
-      case MACHINE_SYNC_NTSC ^ VICII_BORDER_MODE(VICII_DEBUG_BORDERS):
-        timeval ^= VICII_BORDER_MODE(VICII_DEBUG_BORDERS);
-        border_mode = VICII_DEBUG_BORDERS;
-        break;
-   }
-
-    switch (timeval) {
-      case MACHINE_SYNC_PAL:
-        machine_timing.cycles_per_sec = C128_PAL_CYCLES_PER_SEC;
-        machine_timing.cycles_per_rfsh = C128_PAL_CYCLES_PER_RFSH;
-        machine_timing.rfsh_per_sec = C128_PAL_RFSH_PER_SEC;
-        machine_timing.cycles_per_line = C128_PAL_CYCLES_PER_LINE;
-        machine_timing.screen_lines = C128_PAL_SCREEN_LINES;
-        break;
-      case MACHINE_SYNC_NTSC:
-        machine_timing.cycles_per_sec = C128_NTSC_CYCLES_PER_SEC;
-        machine_timing.cycles_per_rfsh = C128_NTSC_CYCLES_PER_RFSH;
-        machine_timing.rfsh_per_sec = C128_NTSC_RFSH_PER_SEC;
-        machine_timing.cycles_per_line = C128_NTSC_CYCLES_PER_LINE;
-        machine_timing.screen_lines = C128_NTSC_SCREEN_LINES;
-        break;
-      default:
-        log_error(c128_log, "Unknown machine timing.");
+        default:
+        case MACHINE_SYNC_PAL ^ VICII_BORDER_MODE(VICII_NORMAL_BORDERS):
+        case MACHINE_SYNC_NTSC ^ VICII_BORDER_MODE(VICII_NORMAL_BORDERS):
+            timeval ^= VICII_BORDER_MODE(VICII_NORMAL_BORDERS);
+            border_mode = VICII_NORMAL_BORDERS;
+            break;
+        case MACHINE_SYNC_PAL ^ VICII_BORDER_MODE(VICII_FULL_BORDERS):
+        case MACHINE_SYNC_NTSC ^ VICII_BORDER_MODE(VICII_FULL_BORDERS):
+            timeval ^= VICII_BORDER_MODE(VICII_FULL_BORDERS);
+            border_mode = VICII_FULL_BORDERS;
+            break;
+        case MACHINE_SYNC_PAL ^ VICII_BORDER_MODE(VICII_DEBUG_BORDERS):
+        case MACHINE_SYNC_NTSC ^ VICII_BORDER_MODE(VICII_DEBUG_BORDERS):
+            timeval ^= VICII_BORDER_MODE(VICII_DEBUG_BORDERS);
+            border_mode = VICII_DEBUG_BORDERS;
+            break;
     }
 
-    vsync_set_machine_parameter(machine_timing.rfsh_per_sec,
-                                machine_timing.cycles_per_sec);
-    sound_set_machine_parameter(machine_timing.cycles_per_sec,
-                                machine_timing.cycles_per_rfsh);
-    debug_set_machine_parameter(machine_timing.cycles_per_line,
-                                machine_timing.screen_lines);
+    switch (timeval) {
+        case MACHINE_SYNC_PAL:
+            machine_timing.cycles_per_sec = C128_PAL_CYCLES_PER_SEC;
+            machine_timing.cycles_per_rfsh = C128_PAL_CYCLES_PER_RFSH;
+            machine_timing.rfsh_per_sec = C128_PAL_RFSH_PER_SEC;
+            machine_timing.cycles_per_line = C128_PAL_CYCLES_PER_LINE;
+            machine_timing.screen_lines = C128_PAL_SCREEN_LINES;
+            break;
+        case MACHINE_SYNC_NTSC:
+            machine_timing.cycles_per_sec = C128_NTSC_CYCLES_PER_SEC;
+            machine_timing.cycles_per_rfsh = C128_NTSC_CYCLES_PER_RFSH;
+            machine_timing.rfsh_per_sec = C128_NTSC_RFSH_PER_SEC;
+            machine_timing.cycles_per_line = C128_NTSC_CYCLES_PER_LINE;
+            machine_timing.screen_lines = C128_NTSC_SCREEN_LINES;
+            break;
+        default:
+            log_error(c128_log, "Unknown machine timing.");
+    }
+
+    vsync_set_machine_parameter(machine_timing.rfsh_per_sec, machine_timing.cycles_per_sec);
+    sound_set_machine_parameter(machine_timing.cycles_per_sec, machine_timing.cycles_per_rfsh);
+    debug_set_machine_parameter(machine_timing.cycles_per_line, machine_timing.screen_lines);
     drive_set_machine_parameter(machine_timing.cycles_per_sec);
     serial_iec_device_set_machine_parameter(machine_timing.cycles_per_sec);
     sid_set_machine_parameter(machine_timing.cycles_per_sec);
@@ -857,8 +737,7 @@ void machine_change_timing(int timeval)
 
 /* ------------------------------------------------------------------------- */
 
-int machine_write_snapshot(const char *name, int save_roms, int save_disks,
-                           int event_mode)
+int machine_write_snapshot(const char *name, int save_roms, int save_disks, int event_mode)
 {
     return c128_snapshot_write(name, save_roms, save_disks, event_mode);
 }
@@ -893,8 +772,7 @@ int machine_screenshot(screenshot_t *screenshot, struct video_canvas_s *canvas)
     return -1;
 }
 
-int machine_canvas_async_refresh(struct canvas_refresh_s *refresh,
-                                 struct video_canvas_s *canvas)
+int machine_canvas_async_refresh(struct canvas_refresh_s *refresh, struct video_canvas_s *canvas)
 {
     if (canvas == vicii_get_canvas()) {
         vicii_async_refresh(refresh);
@@ -910,7 +788,7 @@ int machine_canvas_async_refresh(struct canvas_refresh_s *refresh,
 
 void machine_update_memory_ptrs(void)
 {
-     vicii_update_memory_ptrs_external();
+    vicii_update_memory_ptrs_external();
 }
 
 int machine_num_keyboard_mappings(void)
@@ -927,4 +805,3 @@ BYTE machine_tape_type_default(void)
 {
     return TAPE_CAS_TYPE_BAS;
 }
-
