@@ -43,7 +43,7 @@
 #include "snapshot.h"
 #include "tpi.h"
 #include "types.h"
-#include "ui.h"
+#include "uiapi.h"
 
 #ifdef HAVE_RS232
 #include "c64acia.h"
