@@ -24,15 +24,10 @@
  *
  */
 
-#ifndef _Z80MEM_H
-#define _Z80MEM_H
+#ifndef VICE_Z80MEM_H
+#define VICE_Z80MEM_H
 
-#ifdef WATCOM_COMPILE
-#include "../mem.h"
-#else
 #include "mem.h"
-#endif
-
 #include "types.h"
 
 extern int z80mem_resources_init(void);
@@ -61,4 +56,3 @@ extern read_func_ptr_t io_read_tab[];
 extern unsigned int z80_old_reg_pc;
 
 #endif
-
