@@ -25,33 +25,27 @@
  *
  */
 
-#ifndef _C64_H
-#define _C64_H
+#ifndef VICE_C64_H
+#define VICE_C64_H
 
 #define C64_PAL_CYCLES_PER_SEC  985248
 #define C64_PAL_CYCLES_PER_LINE 63
 #define C64_PAL_SCREEN_LINES    312
-#define C64_PAL_CYCLES_PER_RFSH (C64_PAL_SCREEN_LINES \
-                                 * C64_PAL_CYCLES_PER_LINE)
+#define C64_PAL_CYCLES_PER_RFSH (C64_PAL_SCREEN_LINES * C64_PAL_CYCLES_PER_LINE)
 /* PAL refresh rate: 50.123432124542124 */
-#define C64_PAL_RFSH_PER_SEC    (1.0 / ((double)C64_PAL_CYCLES_PER_RFSH \
-                                        / (double)C64_PAL_CYCLES_PER_SEC))
+#define C64_PAL_RFSH_PER_SEC    (1.0 / ((double)C64_PAL_CYCLES_PER_RFSH / (double)C64_PAL_CYCLES_PER_SEC))
 
 #define C64_NTSC_CYCLES_PER_SEC  1022730
 #define C64_NTSC_CYCLES_PER_LINE 65
 #define C64_NTSC_SCREEN_LINES    263
-#define C64_NTSC_CYCLES_PER_RFSH (C64_NTSC_SCREEN_LINES \
-                                  * C64_NTSC_CYCLES_PER_LINE)
-#define C64_NTSC_RFSH_PER_SEC    (1.0 / ((double)C64_NTSC_CYCLES_PER_RFSH \
-                                        / (double)C64_NTSC_CYCLES_PER_SEC))
+#define C64_NTSC_CYCLES_PER_RFSH (C64_NTSC_SCREEN_LINES * C64_NTSC_CYCLES_PER_LINE)
+#define C64_NTSC_RFSH_PER_SEC    (1.0 / ((double)C64_NTSC_CYCLES_PER_RFSH / (double)C64_NTSC_CYCLES_PER_SEC))
 
 #define C64_NTSCOLD_CYCLES_PER_SEC  1022730
 #define C64_NTSCOLD_CYCLES_PER_LINE 64
 #define C64_NTSCOLD_SCREEN_LINES    262
-#define C64_NTSCOLD_CYCLES_PER_RFSH (C64_NTSCOLD_SCREEN_LINES \
-                                    * C64_NTSCOLD_CYCLES_PER_LINE)
-#define C64_NTSCOLD_RFSH_PER_SEC  (1.0 / ((double)C64_NTSCOLD_CYCLES_PER_RFSH \
-                                        / (double)C64_NTSCOLD_CYCLES_PER_SEC))
+#define C64_NTSCOLD_CYCLES_PER_RFSH (C64_NTSCOLD_SCREEN_LINES * C64_NTSCOLD_CYCLES_PER_LINE)
+#define C64_NTSCOLD_RFSH_PER_SEC  (1.0 / ((double)C64_NTSCOLD_CYCLES_PER_RFSH / (double)C64_NTSCOLD_CYCLES_PER_SEC))
 
 /* $01 bits 6 and 7 fall-off cycles (1->0), average is about 350 msec */
 #define C64_CPU_DATA_PORT_FALL_OFF_CYCLES 350000
@@ -70,4 +64,3 @@ typedef struct machine_context_s {
 extern machine_context_t machine_context;
 
 #endif
-
