@@ -41,18 +41,18 @@ void machine_video_init(void)
 
 int machine_video_resources_init(void)
 {
-    if (video_resources_pal_init() < 0
-        || video_resources_init() < 0)
+    if (video_resources_pal_init() < 0 || video_resources_init() < 0) {
         return -1;
+    }
 
     return 0;
 }
 
 struct video_canvas_s *machine_video_canvas_get(unsigned int window)
 {
-    if (window == 0)
+    if (window == 0) {
         return vicii_get_canvas();
+    }
 
     return NULL;
 }
-
