@@ -24,8 +24,8 @@
  *
  */
 
-#ifndef _EPYXFASTLOAD_H
-#define _EPYXFASTLOAD_H
+#ifndef VICE_EPYXFASTLOAD_H
+#define VICE_EPYXFASTLOAD_H
 
 #include <stdio.h>
 
@@ -41,4 +41,3 @@ extern void epyxfastload_detach(void);
 extern void rex_detach(void);
 
 #endif
-
