@@ -44,7 +44,7 @@
 /* De-assert ~GAME */
 /* Assert ~EXROM */
 /* Disable export_ram */
-#define EXPERT_PRG      ((0 << 0) | (0 << 1))
+#define EXPERT_PRG ((0 << 0) | (0 << 1))
 
 /* De-assert ~GAME */
 /* De-assert ~EXROM */
@@ -54,30 +54,27 @@
 /* Enable ~GAME */
 /* Disable ~EXROM */
 /* Disable export_ram */
-#define EXPERT_ON       ((1 << 0) | (1 << 1))
-
+#define EXPERT_ON ((1 << 0) | (1 << 1))
 
 static const c64export_resource_t export_res = {
     "Expert", 1, 1
 };
 
-/* Cartridge mode.  */
-extern int cartmode;
-
 static int ack_reset = 0;
 
-
 BYTE REGPARM1 expert_io1_read(WORD addr)
 {
-    if (cartmode == CARTRIDGE_MODE_ON)
+    if (cartmode == CARTRIDGE_MODE_ON) {
         cartridge_config_changed(EXPERT_OFF, EXPERT_OFF, CMODE_READ);
+    }
     return 0;
 }
 
 void REGPARM2 expert_io1_store(WORD addr, BYTE value)
 {
-    if (cartmode == CARTRIDGE_MODE_ON)
+    if (cartmode == CARTRIDGE_MODE_ON) {
         cartridge_config_changed(EXPERT_OFF, EXPERT_OFF, CMODE_READ);
+    }
 }
 
 BYTE REGPARM1 expert_roml_read(WORD addr)
@@ -97,8 +94,9 @@ BYTE REGPARM1 expert_romh_read(WORD addr)
 
 void expert_ack_nmi(void)
 {
-    if (cartmode == CARTRIDGE_MODE_ON)
+    if (cartmode == CARTRIDGE_MODE_ON) {
         cartridge_config_changed(EXPERT_ON, EXPERT_ON, CMODE_READ);
+    }
 }
 
 void expert_ack_reset(void)
@@ -141,8 +139,9 @@ void expert_config_setup(BYTE *rawcart)
 
 int expert_bin_attach(const char *filename, BYTE *rawcart)
 {
-    if (c64export_add(&export_res) < 0)
+    if (c64export_add(&export_res) < 0) {
         return -1;
+    }
 
     /* Set default mode */
     resources_set_int("CartridgeMode", CARTRIDGE_MODE_PRG);
@@ -153,14 +152,17 @@ int expert_crt_attach(FILE *fd, BYTE *rawcart)
 {
     BYTE chipheader[0x10];
 
-    if (fread(chipheader, 0x10, 1, fd) < 1)
+    if (fread(chipheader, 0x10, 1, fd) < 1) {
         return -1;
+    }
 
-    if (fread(rawcart, 0x2000, 1, fd) < 1)
+    if (fread(rawcart, 0x2000, 1, fd) < 1) {
         return -1;
+    }
 
-    if (c64export_add(&export_res) < 0)
+    if (c64export_add(&export_res) < 0) {
         return -1;
+    }
 
     resources_set_int("CartridgeMode", CARTRIDGE_MODE_ON);
 
@@ -175,13 +177,12 @@ void expert_detach(void)
 void expert_mode_changed(int mode)
 {
     switch(mode) {
-      case(CARTRIDGE_MODE_PRG):
-        cartridge_config_changed(EXPERT_PRG, EXPERT_PRG, CMODE_READ);
-        break;
-      case(CARTRIDGE_MODE_OFF):
-      case(CARTRIDGE_MODE_ON):
-        cartridge_config_changed(EXPERT_OFF, EXPERT_OFF, CMODE_READ);
-        break;
+        case(CARTRIDGE_MODE_PRG):
+            cartridge_config_changed(EXPERT_PRG, EXPERT_PRG, CMODE_READ);
+            break;
+        case(CARTRIDGE_MODE_OFF):
+        case(CARTRIDGE_MODE_ON):
+            cartridge_config_changed(EXPERT_OFF, EXPERT_OFF, CMODE_READ);
+            break;
     }
 }
-
