@@ -42,7 +42,6 @@
 #include "util.h"
 #include "vicii-phi1.h"
 
-
 static const c64export_resource_t export_res = {
     "Retro Replay", 1, 1
 };
@@ -61,45 +60,43 @@ static unsigned int allow_bank;
 static int no_freeze;
 
 /* REU compatibility mapping.  */
-static unsigned int reu_mapping;
+unsigned int reu_mapping;
 
 BYTE REGPARM1 retroreplay_io1_read(WORD addr)
 {
     if (rr_active) {
         switch (addr & 0xff) {
-          case 0:
-          case 1:
-            io_source=IO_SOURCE_RR;
-            return ((roml_bank & 3) << 3) | ((roml_bank & 4) << 5) | allow_bank
-                   | reu_mapping;
-          default:
+            case 0:
+            case 1:
+                io_source = IO_SOURCE_RR;
+                return ((roml_bank & 3) << 3) | ((roml_bank & 4) << 5) | allow_bank | reu_mapping;
+            default:
 #ifdef HAVE_TFE
-            if (rr_clockport_enabled && tfe_enabled && tfe_as_rr_net && (addr&0xff)<0x10)
-              return 0;
-#endif
-            if (reu_mapping) {
-                if (export_ram) {
-                    if (allow_bank) {
-                        io_source=IO_SOURCE_RR;
-                        switch (roml_bank & 3) {
-                          case 0:
-                            return export_ram0[0x1e00 + (addr & 0xff)];
-                          case 1:
-                            return export_ram0[0x3e00 + (addr & 0xff)];
-                          case 2:
-                            return export_ram0[0x5e00 + (addr & 0xff)];
-                          case 3:
-                            return export_ram0[0x7e00 + (addr & 0xff)];
-                        }
-                    } else {
-                        io_source=IO_SOURCE_RR;
-                        return export_ram0[0x1e00 + (addr & 0xff)];
-                    }
+                if (rr_clockport_enabled && tfe_enabled && tfe_as_rr_net && (addr & 0xff) < 0x10) {
+                    return 0;
                 }
-                io_source=IO_SOURCE_RR;
-                return roml_banks[(addr & 0x1fff) + (roml_bank << 13)];
-            }
-            return 0;
+#endif
+                if (reu_mapping) {
+                    io_source = IO_SOURCE_RR;
+                    if (export_ram) {
+                        if (allow_bank) {
+                            switch (roml_bank & 3) {
+                                case 0:
+                                    return export_ram0[0x1e00 + (addr & 0xff)];
+                                case 1:
+                                    return export_ram0[0x3e00 + (addr & 0xff)];
+                                case 2:
+                                    return export_ram0[0x5e00 + (addr & 0xff)];
+                                case 3:
+                                    return export_ram0[0x7e00 + (addr & 0xff)];
+                            }
+                        } else {
+                            return export_ram0[0x1e00 + (addr & 0xff)];
+                        }
+                    }
+                    return roml_banks[(addr & 0x1fff) + (roml_bank << 13)];
+                }
+                return 0;
         }
     } else {
         return vicii_read_phi1();
@@ -110,51 +107,53 @@ void REGPARM2 retroreplay_io1_store(WORD addr, BYTE value)
 {
     if (rr_active) {
         switch (addr & 0xff) {
-          case 0:
-            cartridge_config_changed(0, value, CMODE_WRITE);
-            cartridge_romhbank_set(((value >> 3) & 3) | ((value >> 5) & 4));
-            cartridge_romlbank_set(((value >> 3) & 3) | ((value >> 5) & 4));
-            if (value & 4)
-                rr_active = 0;
-            break;
-          case 1:
-            if (write_once == 0) {
+            case 0:
+                cartridge_config_changed(0, value, CMODE_WRITE);
                 cartridge_romhbank_set(((value >> 3) & 3) | ((value >> 5) & 4));
                 cartridge_romlbank_set(((value >> 3) & 3) | ((value >> 5) & 4));
-                allow_bank = value & 2;
-                no_freeze = value & 4;
-                reu_mapping = value & 0x40;
-                rr_clockport_enabled = value & 1;
-                write_once = 1;
-            }
-            break;
-          default:
+                if (value & 4) {
+                    rr_active = 0;
+                }
+                break;
+            case 1:
+                if (write_once == 0) {
+                    cartridge_romhbank_set(((value >> 3) & 3) | ((value >> 5) & 4));
+                    cartridge_romlbank_set(((value >> 3) & 3) | ((value >> 5) & 4));
+                    allow_bank = value & 2;
+                    no_freeze = value & 4;
+                    reu_mapping = value & 0x40;
+                    rr_clockport_enabled = value & 1;
+                    write_once = 1;
+                }
+                break;
+            default:
 #ifdef HAVE_TFE
-            if (rr_clockport_enabled && tfe_enabled && tfe_as_rr_net && (addr&0xff)<0x10)
-              return;
+                if (rr_clockport_enabled && tfe_enabled && tfe_as_rr_net && (addr & 0xff) < 0x10) {
+                    return;
+                }
 #endif
-            if (reu_mapping) {
-                if (export_ram) {
-                    if (allow_bank) {
-                        switch (roml_bank & 3) {
-                          case 0:
+                if (reu_mapping) {
+                    if (export_ram) {
+                        if (allow_bank) {
+                            switch (roml_bank & 3) {
+                                case 0:
+                                    export_ram0[0x1e00 + (addr & 0xff)] = value;
+                                    break;
+                                case 1:
+                                    export_ram0[0x3e00 + (addr & 0xff)] = value;
+                                    break;
+                                case 2:
+                                    export_ram0[0x5e00 + (addr & 0xff)] = value;
+                                    break;
+                                case 3:
+                                    export_ram0[0x7e00 + (addr & 0xff)] = value;
+                                    break;
+                            }
+                        } else {
                             export_ram0[0x1e00 + (addr & 0xff)] = value;
-                            break;
-                          case 1:
-                            export_ram0[0x3e00 + (addr & 0xff)] = value;
-                            break;
-                          case 2:
-                            export_ram0[0x5e00 + (addr & 0xff)] = value;
-                            break;
-                          case 3:
-                            export_ram0[0x7e00 + (addr & 0xff)] = value;
-                            break;
                         }
-                    } else {
-                        export_ram0[0x1e00 + (addr & 0xff)] = value;
                     }
                 }
-            }
         }
     }
 }
@@ -163,25 +162,23 @@ BYTE REGPARM1 retroreplay_io2_read(WORD addr)
 {
     if (rr_active) {
         if (!reu_mapping) {
+            io_source = IO_SOURCE_RR;
             if (export_ram) {
                 if (allow_bank) {
-                    io_source=IO_SOURCE_RR;
                     switch (roml_bank & 3) {
-                      case 0:
-                        return export_ram0[0x1f00 + (addr & 0xff)];
-                      case 1:
-                        return export_ram0[0x3f00 + (addr & 0xff)];
-                      case 2:
-                        return export_ram0[0x5f00 + (addr & 0xff)];
-                      case 3:
-                        return export_ram0[0x7f00 + (addr & 0xff)];
+                        case 0:
+                            return export_ram0[0x1f00 + (addr & 0xff)];
+                        case 1:
+                            return export_ram0[0x3f00 + (addr & 0xff)];
+                        case 2:
+                            return export_ram0[0x5f00 + (addr & 0xff)];
+                        case 3:
+                            return export_ram0[0x7f00 + (addr & 0xff)];
                     }
                 } else {
-                    io_source=IO_SOURCE_RR;
                     return export_ram0[0x1f00 + (addr & 0xff)];
                 }
             }
-            io_source=IO_SOURCE_RR;
             return roml_banks[(addr & 0x1fff) + (roml_bank << 13)];
         }
         return 0;
@@ -197,18 +194,18 @@ void REGPARM2 retroreplay_io2_store(WORD addr, BYTE value)
             if (export_ram) {
                 if (allow_bank) {
                     switch (roml_bank & 3) {
-                      case 0:
-                        export_ram0[0x1f00 + (addr & 0xff)] = value;
-                        break;
-                      case 1:
-                        export_ram0[0x3f00 + (addr & 0xff)] = value;
-                        break;
-                      case 2:
-                        export_ram0[0x5f00 + (addr & 0xff)] = value;
-                        break;
-                      case 3:
-                        export_ram0[0x7f00 + (addr & 0xff)] = value;
-                        break;
+                        case 0:
+                            export_ram0[0x1f00 + (addr & 0xff)] = value;
+                            break;
+                        case 1:
+                            export_ram0[0x3f00 + (addr & 0xff)] = value;
+                            break;
+                        case 2:
+                            export_ram0[0x5f00 + (addr & 0xff)] = value;
+                            break;
+                        case 3:
+                            export_ram0[0x7f00 + (addr & 0xff)] = value;
+                            break;
                     }
                 } else {
                     export_ram0[0x1f00 + (addr & 0xff)] = value;
@@ -222,14 +219,14 @@ BYTE REGPARM1 retroreplay_roml_read(WORD addr)
 {
     if (export_ram) {
         switch (roml_bank & 3) {
-          case 0:
-            return export_ram0[addr & 0x1fff];
-          case 1:
-            return export_ram0[(addr & 0x1fff) + 0x2000];
-          case 2:
-            return export_ram0[(addr & 0x1fff) + 0x4000];
-          case 3:
-            return export_ram0[(addr & 0x1fff) + 0x6000];
+            case 0:
+                return export_ram0[addr & 0x1fff];
+            case 1:
+                return export_ram0[(addr & 0x1fff) + 0x2000];
+            case 2:
+                return export_ram0[(addr & 0x1fff) + 0x4000];
+            case 3:
+                return export_ram0[(addr & 0x1fff) + 0x6000];
         }
     }
 
@@ -240,18 +237,18 @@ void REGPARM2 retroreplay_roml_store(WORD addr, BYTE value)
 {
     if (export_ram) {
         switch (roml_bank & 3) {
-          case 0:
-            export_ram0[addr & 0x1fff] = value;
-            break;
-          case 1:
-            export_ram0[(addr & 0x1fff) + 0x2000] = value;
-            break;
-          case 2:
-            export_ram0[(addr & 0x1fff) + 0x4000] = value;
-            break;
-          case 3:
-            export_ram0[(addr & 0x1fff) + 0x6000] = value;
-            break;
+            case 0:
+                export_ram0[addr & 0x1fff] = value;
+                break;
+            case 1:
+                export_ram0[(addr & 0x1fff) + 0x2000] = value;
+                break;
+            case 2:
+                export_ram0[(addr & 0x1fff) + 0x4000] = value;
+                break;
+            case 3:
+                export_ram0[(addr & 0x1fff) + 0x6000] = value;
+                break;
         }
     }
 }
@@ -264,8 +261,9 @@ void retroreplay_freeze(void)
 
 int retroreplay_freeze_allowed(void)
 {
-    if (no_freeze)
+    if (no_freeze) {
         return 0;
+    }
     return 1;
 }
 
@@ -293,12 +291,13 @@ void retroreplay_config_setup(BYTE *rawcart)
 
 int retroreplay_bin_attach(const char *filename, BYTE *rawcart)
 {
-    if (util_file_load(filename, rawcart, 0x10000,
-        UTIL_FILE_LOAD_SKIP_ADDRESS | UTIL_FILE_LOAD_FILL) < 0)
+    if (util_file_load(filename, rawcart, 0x10000, UTIL_FILE_LOAD_SKIP_ADDRESS | UTIL_FILE_LOAD_FILL) < 0) {
         return -1;
+    }
 
-    if (c64export_add(&export_res) < 0)
+    if (c64export_add(&export_res) < 0) {
         return -1;
+    }
 
     return 0;
 }
