@@ -24,8 +24,8 @@
  *
  */
 
-#ifndef _RETROREPLAY_H
-#define _RETROREPLAY_H
+#ifndef VICE_RETROREPLAY_H
+#define VICE_RETROREPLAY_H
 
 #include <stdio.h>
 
@@ -48,8 +48,8 @@ extern void retroreplay_config_setup(BYTE *rawcart);
 extern int retroreplay_bin_attach(const char *filename, BYTE *rawcart);
 extern void retroreplay_detach(void);
 
-extern unsigned int  rr_active;
-extern unsigned int  rr_clockport_enabled;
+extern unsigned int rr_active;
+extern unsigned int rr_clockport_enabled;
+extern unsigned int reu_mapping;
 
 #endif
-
