@@ -24,8 +24,8 @@
  *
  */
 
-#ifndef _CBM2_RESOURCES_H
-#define _CBM2_RESOURCES_H
+#ifndef VICE_CBM2_RESOURCES_H
+#define VICE_CBM2_RESOURCES_H
 
 extern int cbm2_resources_init(void);
 extern void cbm2_resources_shutdown(void);
