@@ -42,13 +42,7 @@
 #include "emuid.h"
 #include "kbdbuf.h"
 #include "machine.h"
-
-#ifdef WATCOM_COMPILE
-#include "../mem.h"
-#else
 #include "mem.h"
-#endif
-
 #include "monitor.h"
 #include "ram.h"
 #include "resources.h"
