@@ -30,8 +30,8 @@
  */
 
 
-#ifndef _CRTC_MEM_H
-#define _CRTC_MEM_H
+#ifndef VICE_CRTC_MEM_H
+#define VICE_CRTC_MEM_H
 
 #include "types.h"
 
