@@ -45,7 +45,7 @@
 #include "tap.h"
 #include "translate.h"
 #include "types.h"
-#include "ui.h"
+#include "uiapi.h"
 
 
 #define MOTOR_DELAY         32000
@@ -228,7 +228,7 @@ inline static int datasette_move_buffer_forward(int offset)
             log_error(datasette_log,"Cannot read in tap-file.");
             return 0;
         }
-        last_tap = fread(tap_buffer, 1, TAP_BUFFER_LENGTH, current_image->fd);
+        last_tap = (long)fread(tap_buffer, 1, TAP_BUFFER_LENGTH, current_image->fd);
         next_tap = 0;
         if (next_tap >= last_tap)
             return 0;
@@ -251,7 +251,7 @@ inline static int datasette_move_buffer_back(int offset)
             log_error(datasette_log,"Cannot read in tap-file.");
             return 0;
         }
-        last_tap = fread(tap_buffer, 1, TAP_BUFFER_LENGTH, current_image->fd);
+        last_tap = (long)fread(tap_buffer, 1, TAP_BUFFER_LENGTH, current_image->fd);
         if (next_tap > last_tap)
             return 0;
     }
@@ -763,6 +763,11 @@ inline static void bit_write(void)
     write_time = maincpu_clk - last_write_clk;
     last_write_clk = maincpu_clk;
 
+    /* C16 TAPs use half the machine clock as base cycle */
+    if (machine_class == VICE_MACHINE_PLUS4) {
+        write_time = write_time / 2;
+    }
+
     if (write_time < (CLOCK)7)
         return;
 
@@ -784,7 +789,7 @@ inline static void bit_write(void)
             long_gap[1] = (BYTE)((write_time >> 8) & 0xff);
             long_gap[2] = (BYTE)((write_time >> 16) & 0xff);
             write_time &= 0xffffff;
-            bytes_written = fwrite(long_gap, 1, 3, current_image->fd);
+            bytes_written = (int)fwrite(long_gap, 1, 3, current_image->fd);
             current_image->current_file_seek_position += bytes_written;
             if (bytes_written < 3) {
                 datasette_control(DATASETTE_CONTROL_STOP);
@@ -797,6 +802,11 @@ inline static void bit_write(void)
 
     current_image->cycle_counter += write_time / 8;
 
+    /* Correct for C16 TAPs so the counter is the same during record/play */
+    if (machine_class == VICE_MACHINE_PLUS4) {
+        current_image->cycle_counter += write_time / 8;
+    }
+
     if (current_image->cycle_counter_total
         < current_image->cycle_counter)
         current_image->cycle_counter_total = current_image->cycle_counter;
