@@ -25,8 +25,8 @@
  *
  */
 
-#ifndef _DRIVE_CMDLINE_OPTIONS_H
-#define _DRIVE_CMDLINE_OPTIONS_H
+#ifndef VICE_DRIVE_CMDLINE_OPTIONS_H
+#define VICE_DRIVE_CMDLINE_OPTIONS_H
 
 extern int drive_cmdline_options_init(void);
 
