@@ -676,7 +676,7 @@ static int drive_snapshot_write_gcrimage_module(snapshot_t *s, unsigned int dnr)
     if (m == NULL)
         return -1;
 
-    tmpbuf = (BYTE *)lib_malloc(MAX_TRACKS_1571 * 4);
+    tmpbuf = lib_malloc(MAX_TRACKS_1571 * 4);
 
     for (i = 0; i < MAX_TRACKS_1571; i++) {
         tmpbuf[i * 4] = drive->gcr->track_size[i] & 0xff;
@@ -730,7 +730,7 @@ static int drive_snapshot_read_gcrimage_module(snapshot_t *s, unsigned int dnr)
                   GCRIMAGE_SNAP_MAJOR, GCRIMAGE_SNAP_MINOR);
     }
 
-    tmpbuf = (BYTE *)lib_malloc(MAX_TRACKS_1571 * 4);
+    tmpbuf = lib_malloc(MAX_TRACKS_1571 * 4);
 
     if (0
         || SMR_BA(m, drive->gcr->data,
