@@ -31,6 +31,7 @@
 
 #include <stdio.h>
 
+#include "debug.h"
 #include "drive.h"
 #include "drivecpu.h"
 #include "drivesync.h"
@@ -176,6 +177,7 @@ static void undump_prb(via_context_t *via_context, BYTE byte)
         iecbus->drv_port = (((iecbus->cpu_port >> 4) & 0x4)
                            | (iecbus->cpu_port >> 7)
                            | ((iecbus->cpu_bus << 3) & 0x80));
+
     } else {
         iec_drive_write((BYTE)(~byte), via1p->number);
     }
@@ -189,6 +191,8 @@ static void store_prb(via_context_t *via_context, BYTE byte, BYTE p_oldpb,
     via1p = (drivevia1_context_t *)(via_context->prv);
 
     if (byte != p_oldpb) {
+        DEBUG_IEC_DRV_WRITE(byte);
+
         if (iecbus != NULL) {
             BYTE *drive_data, *drive_bus;
             unsigned int unit;
@@ -208,8 +212,12 @@ static void store_prb(via_context_t *via_context, BYTE byte, BYTE p_oldpb,
             iecbus->drv_port = (((iecbus->cpu_port >> 4) & 0x4)
                                | (iecbus->cpu_port >> 7)
                                | ((iecbus->cpu_bus << 3) & 0x80));
+
+            DEBUG_IEC_BUS_WRITE(iecbus->drv_port);
+
         } else {
             iec_drive_write((BYTE)(~byte), via1p->number);
+            DEBUG_IEC_BUS_WRITE(~byte);
         }
     }
 }
@@ -302,6 +310,10 @@ static BYTE read_prb(via_context_t *via_context)
                | iec_drive_read(via1p->number)) ^ 0x85) | orval;
     }
 
+    DEBUG_IEC_DRV_READ(byte);
+
+    DEBUG_IEC_BUS_READ(byte);
+
     return byte;
 }
 
