@@ -58,14 +58,13 @@ static void set_cb2(int state)
 
 /* see interrupt.h; ugly, but more efficient... */
 static void set_int(via_context_t *via_context, unsigned int int_num,
-                    int value)
+                    int value, CLOCK rclk)
 {
     drive_context_t *drive_context;
 
     drive_context = (drive_context_t *)(via_context->context);
 
-    interrupt_set_irq(drive_context->cpu->int_status, int_num, value,
-                      *(via_context->clk_ptr));
+    interrupt_set_irq(drive_context->cpu->int_status, int_num, value, rclk);
 }
 
 static void restore_int(via_context_t *via_context, unsigned int int_num,
