@@ -24,8 +24,8 @@
  *
  */
 
-#ifndef _TCBM_RESOURCES_H
-#define _TCBM_RESOURCES_H
+#ifndef VICE_TCBM_RESOURCES_H
+#define VICE_TCBM_RESOURCES_H
 
 extern int tcbm_resources_init(void);
 extern void tcbm_resources_shutdown(void);
