@@ -25,8 +25,8 @@
  *
  */
 
-#ifndef _IMAGE_CONTENTS_H
-#define _IMAGE_CONTENTS_H
+#ifndef VICE_IMAGE_CONTENTS_H
+#define VICE_IMAGE_CONTENTS_H
 
 #include "types.h"
 
@@ -52,6 +52,7 @@ struct image_contents_s {
     image_contents_file_list_t *file_list;
 };
 typedef struct image_contents_s image_contents_t;
+typedef image_contents_t *(*read_contents_func_type)(const char *);
 
 struct image_contents_screencode_s {
     BYTE *line;
@@ -65,29 +66,15 @@ typedef struct image_contents_screencode_s image_contents_screencode_t;
 extern void image_contents_destroy(image_contents_t *contents);
 extern image_contents_t *image_contents_new(void);
 
-#define IMAGE_CONTENTS_STRING_PETSCII 0
-#define IMAGE_CONTENTS_STRING_ASCII   1
-
-extern char *image_contents_to_string(image_contents_t *contents,
-                                      unsigned int conversion_rule);
 extern image_contents_screencode_t *image_contents_to_screencode
                                    (image_contents_t *contents);
 extern void image_contents_screencode_destroy(image_contents_screencode_t *c);
 
-#define IMAGE_CONTENTS_AUTO 0
-#define IMAGE_CONTENTS_DISK 1
-#define IMAGE_CONTENTS_TAPE 2
-
-extern image_contents_t *image_contents_read(unsigned int type,
-                                             const char *filename,
-                                             unsigned int unit);
-extern char *image_contents_read_string(unsigned int type,
-                                        const char *filename,
-                                        unsigned int unit,
-                                        unsigned int conversion);
-extern char *image_contents_filename_by_number(unsigned int type,
-                                               const char *filename,
-                                               unsigned int unit,
+extern char *image_contents_to_string(image_contents_t * contents,
+                                      char convert_to_ascii);
+extern char *image_contents_file_to_string(image_contents_file_list_t * p,
+                                           char convert_to_ascii);
+extern char *image_contents_filename_by_number(image_contents_t *contents,
                                                unsigned int file_index);
 
 extern image_contents_t *diskcontents_iec_read(unsigned int unit);
