@@ -25,6 +25,8 @@
  *
  */
 
+#include "vice.h"
+
 const char info_license_text[] =
 "                 GNU GENERAL PUBLIC LICENSE\n"
 "                    Version 2, June 1991\n"
@@ -307,6 +309,440 @@ const char info_license_text[] =
 "the sharing and reuse of software generally.\n";
 
 
+/* Since the GNU licence text won't change and the SDL UI can
+   sometimes only handle 40 chars it's easier to use a specially
+   prepared text where needed.
+ */
+#ifdef USE_SDLUI
+const char info_license_text40[] =
+"       GNU GENERAL PUBLIC LICENSE\n"
+"          Version 2, June 1991\n"
+"\n"
+" Copyright (C) 1989, 1991 Free Software\n"
+" Foundation, Inc.  59 Temple Place,\n"
+" Suite 330, Boston, MA  02111-1307  USA\n"
+"\n"
+" Everyone is permitted to copy and\n"
+" distribute verbatim copies of this\n"
+" license document, but changing it is\n"
+" not allowed.\n"
+"\n"
+"\n"
+"                Preamble\n"
+"\n"
+"The licenses for most software are\n"
+"designed to take away your freedom to\n"
+"share and change it. By contrast, the\n"
+"GNU General Public License is intended\n"
+"to guarantee your freedom to share and\n"
+"change free software--to make sure the\n"
+"software is free for all its users.\n"
+"This General Public License applies to\n"
+"most of the Free Software Foundation's\n"
+"software and to any other program whose\n"
+"authors commit to using it.  (Some other\n"
+"Free Software Foundation software is\n"
+"covered by the GNU Library General\n"
+"Public License instead.)  You can apply\n"
+"it to your programs, too.\n"
+"\n"
+"When we speak of free software, we are\n"
+"referring to freedom, not price.  Our\n"
+"General Public Licenses are designed to\n"
+"make sure that you have the freedom to\n"
+"distribute copies of free software (and\n"
+"charge for this service if you wish),\n"
+"that you receive source code or can get\n"
+"it if you want it, that you can change\n"
+"the software or use pieces of it in new\n"
+"free programs; and that you know you can\n"
+"do these things.\n"
+"\n"
+"To protect your rights, we need to make\n"
+"restrictions that forbid anyone to deny\n"
+"you these rights or to ask you to\n"
+"surrender the rights.  These\n"
+"restrictions translate to certain\n"
+"responsibilities for you if you\n"
+"distribute copies of the software, or if\n"
+"you modify it.\n"
+"\n"
+"For example, if you distribute copies of\n"
+"such a program, whether gratis or for a\n"
+"fee, you must give the recipients all\n"
+"the rights that you have.  You must make\n"
+"sure that they, too, receive or can get\n"
+"the source code.  And you must show them\n"
+"these terms so they know their rights.\n"
+"\n"
+"We protect your rights with two steps:\n"
+"(1) copyright the software, and (2)\n"
+"offer you this license which gives you\n"
+"legal permission to copy, distribute\n"
+"and/or modify the software.\n"
+"\n"
+"Also, for each author's protection and\n"
+"ours, we want to make certain that\n"
+"everyone understands that there is no\n"
+"warranty for this free software.  If the\n"
+"software is modified by someone else and\n"
+"passed on, we want its recipients to\n"
+"know that what they have is not the\n"
+"original, so that any problems\n"
+"introduced by others will not reflect on\n"
+"the original authors' reputations.\n"
+"\n"
+"Finally, any free program is threatened\n"
+"constantly by software patents.  We wish\n"
+"to avoid the danger that redistributors\n"
+"of a free program will individually\n"
+"obtain patent licenses, in effect making\n"
+"the program proprietary.  To prevent\n"
+"this, we have made it clear that any\n"
+"patent must be licensed for everyone's\n"
+"free use or not licensed at all.\n"
+"\n"
+"The precise terms and conditions for\n"
+"copying, distribution and modification\n"
+"follow.\n"
+"\n"
+"\n"
+"GNU GENERAL PUBLIC LICENSE TERMS AND\n"
+"CONDITIONS FOR COPYING, DISTRIBUTION AND\n"
+"MODIFICATION\n"
+"\n"
+"0. This License applies to any program\n"
+"or other work which contains a notice\n"
+"placed by the copyright holder saying it\n"
+"may be distributed under the terms of\n"
+"this General Public License.  The\n"
+"\"Program\", below, refers to any such\n"
+"program or work, and a \"work based on\n"
+"the Program\" means either the Program or\n"
+"any derivative work under copyright law:\n"
+"that is to say, a work containing the\n"
+"Program or a portion of it, either\n"
+"verbatim or with modifications and/or\n"
+"translated into another language.\n"
+"(Hereinafter, translation is included\n"
+"without limitation in the term\n"
+"\"modification\".)  Each licensee is\n"
+"addressed as \"you\".\n"
+"\n"
+"Activities other than copying,\n"
+"distribution and modification are not\n"
+"covered by this License; they are\n"
+"outside its scope.  The act of running\n"
+"the Program is not restricted, and the\n"
+"output from the Program is covered only\n"
+"if its contents constitute a work based\n"
+"on the Program (independent of having\n"
+"been made by running the Program).\n"
+"Whether that is true depends on what the\n"
+"Program does.\n"
+"\n"
+"  1. You may copy and distribute\n"
+"verbatim copies of the Program's source\n"
+"code as you receive it, in any medium,\n"
+"provided that you conspicuously and\n"
+"appropriately publish on each copy an\n"
+"appropriate copyright notice and\n"
+"disclaimer of warranty; keep intact all\n"
+"the notices that refer to this License\n"
+"and to the absence of any warranty; and\n"
+"give any other recipients of the Program\n"
+"a copy of this License along with the\n"
+"Program.\n"
+"\n"
+"You may charge a fee for the physical\n"
+"act of transferring a copy, and you may\n"
+"at your option offer warranty protection\n"
+"in exchange for a fee.\n"
+"\n"
+"  2. You may modify your copy or copies\n"
+"of the Program or any portion of it,\n"
+"thus forming a work based on the\n"
+"Program, and copy and distribute such\n"
+"modifications or work under the terms of\n"
+"Section 1 above, provided that you also\n"
+"meet all of these conditions:\n"
+"\n"
+"    a) You must cause the modified files\n"
+"    to carry prominent notices stating\n"
+"    that you changed the files and the\n"
+"    date of any change.\n"
+"\n"
+"    b) You must cause any work that you\n"
+"    distribute or publish, that in whole\n"
+"    or in part contains or is derived\n"
+"    from the Program or any part\n"
+"    thereof, to be licensed as a whole\n"
+"    at no charge to all third parties\n"
+"    under the terms of this License.\n"
+"\n"
+"    c) If the modified program normally\n"
+"    reads commands interactively when\n"
+"    run, you must cause it, when started\n"
+"    running for such interactive use in\n"
+"    the most ordinary way, to print or\n"
+"    display an announcement including an\n"
+"    appropriate copyright notice and a\n"
+"    notice that there is no warranty (or\n"
+"    else, saying that you provide a\n"
+"    warranty) and that users may\n"
+"    redistribute the program under these\n"
+"    conditions, and telling the user how\n"
+"    to view a copy of this License.\n"
+"    (Exception: if the Program itself is\n"
+"    interactive but does not normally\n"
+"    print such an announcement, your\n"
+"    work based on the Program is not\n"
+"    required to print an announcement.)\n"
+"\n"
+"These requirements apply to the modified\n"
+"work as a whole.  If identifiable\n"
+"sections of that work are not derived\n"
+"from the Program, and can be reasonably\n"
+"considered independent and separate\n"
+"works in themselves, then this License,\n"
+"and its terms, do not apply to those\n"
+"sections when you distribute them as\n"
+"separate works.  But when you distribute\n"
+"the same sections as part of a whole\n"
+"which is a work based on the Program,\n"
+"the distribution of the whole must be on\n"
+"the terms of this License, whose\n"
+"permissions for other licensees extend\n"
+"to the entire whole, and thus to each\n"
+"and every part regardless of who wrote\n"
+"it.\n"
+"\n"
+"Thus, it is not the intent of this\n"
+"section to claim rights or contest your\n"
+"rights to work written entirely by you;\n"
+"rather, the intent is to exercise the\n"
+"right to control the distribution of\n"
+"derivative or collective works based on\n"
+"the Program.\n"
+"\n"
+"In addition, mere aggregation of another\n"
+"work not based on the Program with the\n"
+"Program (or with a work based on the\n"
+"Program) on a volume of a storage or\n"
+"distribution medium does not bring the\n"
+"other work under the scope of this\n"
+"License.\n"
+"\n"
+"  3. You may copy and distribute the\n"
+"Program (or a work based on it, under\n"
+"Section 2) in object code or executable\n"
+"form under the terms of Sections 1 and 2\n"
+"above provided that you also do one of\n"
+"the following:\n"
+"\n"
+"    a) Accompany it with the complete\n"
+"    corresponding machine-readable\n"
+"    source code, which must be\n"
+"    distributed under the terms of\n"
+"    Sections 1 and 2 above on a medium\n"
+"    customarily used for software\n"
+"    interchange; or,\n"
+"\n"
+"    b) Accompany it with a written\n"
+"    offer, valid for at least three\n"
+"    years, to give any third party, for\n"
+"    a charge no more than your cost of\n"
+"    physically performing source\n"
+"    distribution, a complete machine-\n"
+"    readable copy of the corresponding\n"
+"    source code, to be distributed under\n"
+"    the terms of Sections 1 and 2 above\n"
+"    on a medium customarily used for\n"
+"    software interchange; or,\n"
+"\n"
+"    c) Accompany it with the information\n"
+"    you received as to the offer to\n"
+"    distribute corresponding source\n"
+"    code.  (This alternative is allowed\n"
+"    only for noncommercial distribution\n"
+"    and only if you received the program\n"
+"    in object code or executable form\n"
+"    with such an offer, in accord with\n"
+"    Subsection b above.)\n"
+"\n"
+"The source code for a work means the\n"
+"preferred form of the work for making\n"
+"modifications to it.  For an executable\n"
+"work, complete source code means all the\n"
+"source code for all modules it contains,\n"
+"plus any associated interface definition\n"
+"files, plus the scripts used to control\n"
+"compilation and installation of the\n"
+"executable.  However, as a special\n"
+"exception, the source code distributed\n"
+"need not include anything that is\n"
+"normally distributed (in either source\n"
+"or binary form) with the major\n"
+"components (compiler, kernel, and so on)\n"
+"of the operating system on which the\n"
+"executable runs, unless that component\n"
+"itself accompanies the executable.\n"
+"\n"
+"If distribution of executable or object\n"
+"code is made by offering access to copy\n"
+"from a designated place, then offering\n"
+"equivalent access to copy the source\n"
+"code from the same place counts as\n"
+"distribution of the source code, even\n"
+"though third parties are not compelled\n"
+"to copy the source along with the object\n"
+"code.\n"
+"\n"
+"  4. You may not copy, modify,\n"
+"sublicense, or distribute the Program\n"
+"except as expressly provided under this\n"
+"License.  Any attempt otherwise to copy,\n"
+"modify, sublicense or distribute the\n"
+"Program is void, and will automatically\n"
+"terminate your rights under this\n"
+"License.  However, parties who have\n"
+"received copies, or rights, from you\n"
+"under this License will not have their\n"
+"licenses terminated so long as such\n"
+"parties remain in full compliance.\n"
+"\n"
+"  5. You are not required to accept this\n"
+"License, since you have not signed it.\n"
+"However, nothing else grants you\n"
+"permission to modify or distribute the\n"
+"Program or its derivative works.  These\n"
+"actions are prohibited by law if you do\n"
+"not accept this License.  Therefore, by\n"
+"modifying or distributing the Program\n"
+"(or any work based on the Program), you\n"
+"indicate your acceptance of this License\n"
+"to do so, and all its terms and\n"
+"conditions for copying, distributing or\n"
+"modifying the Program or works based on\n"
+"it.\n"
+"\n"
+"  6. Each time you redistribute the\n"
+"Program (or any work based on the\n"
+"Program), the recipient automatically\n"
+"receives a license from the original\n"
+"licensor to copy, distribute or modify\n"
+"the Program subject to these terms and\n"
+"conditions.  You may not impose any\n"
+"further restrictions on the recipients'\n"
+"exercise of the rights granted herein.\n"
+"You are not responsible for enforcing\n"
+"compliance by third parties to this\n"
+"License.\n"
+"\n"
+"  7. If, as a consequence of a court\n"
+"judgment or allegation of patent\n"
+"infringement or for any other reason\n"
+"(not limited to patent issues),\n"
+"conditions are imposed on you (whether\n"
+"by court order, agreement or otherwise)\n"
+"that contradict the conditions of this\n"
+"License, they do not excuse you from the\n"
+"conditions of this License.  If you\n"
+"cannot distribute so as to satisfy\n"
+"simultaneously your obligations under\n"
+"this License and any other pertinent\n"
+"obligations, then as a consequence you\n"
+"may not distribute the Program at all.\n"
+"For example, if a patent license would\n"
+"not permit royalty-free redistribution\n"
+"of the Program by all those who receive\n"
+"copies directly or indirectly through\n"
+"you, then the only way you could satisfy\n"
+"both it and this License would be to\n"
+"refrain entirely from distribution of\n"
+"the Program.\n"
+"\n"
+"If any portion of this section is held\n"
+"invalid or unenforceable under any\n"
+"particular circumstance, the balance of\n"
+"the section is intended to apply and the\n"
+"section as a whole is intended to apply\n"
+"in other circumstances.\n"
+"\n"
+"It is not the purpose of this section to\n"
+"induce you to infringe any patents or\n"
+"other property right claims or to\n"
+"contest validity of any such claims;\n"
+"this section has the sole purpose of\n"
+"protecting the integrity of the free\n"
+"software distribution system, which is\n"
+"implemented by public license practices.\n"
+"Many people have made generous\n"
+"contributions to the wide range of\n"
+"software distributed through that system\n"
+"in reliance on consistent application of\n"
+"that system; it is up to the\n"
+"author/donor to decide if he or she is\n"
+"willing to distribute software through\n"
+"any other system and a licensee cannot\n"
+"impose \n"
+"that choice.\n"
+"\n"
+"This section is intended to make\n"
+"thoroughly clear what is believed to be\n"
+"a consequence of the rest of this\n"
+"License.\n"
+"\n"
+"  8. If the distribution and/or use of\n"
+"the Program is restricted in certain\n"
+"countries either by patents or by\n"
+"copyrighted interfaces, the original\n"
+"copyright holder who places the Program\n"
+"under this License may add an explicit\n"
+"geographical distribution limitation\n"
+"excluding those countries, so that\n"
+"distribution is permitted only in or\n"
+"among countries not thus excluded.  In\n"
+"such case, this License incorporates the\n"
+"limitation as if written in the body of\n"
+"this License.\n"
+"\n"
+"  9. The Free Software Foundation may\n"
+"publish revised and/or new versions of\n"
+"the General Public License from time to\n"
+"time.  Such new versions will be similar\n"
+"in spirit to the present version, but\n"
+"may differ in detail to address new\n"
+"problems or concerns.\n"
+"\n"
+"Each version is given a distinguishing\n"
+"version number.  If the Program\n"
+"specifies a version number of this\n"
+"License which applies to it and \"any\n"
+"later version\", you have the option of\n"
+"following the terms and conditions\n"
+"either of that version or of any later\n"
+"version published by the Free Software\n"
+"Foundation.  If the Program does not\n"
+"specify a version number of this\n"
+"License, you may choose any version ever\n"
+"published by the Free Software\n"
+"Foundation.\n"
+"\n"
+"  10. If you wish to incorporate parts\n"
+"of the Program into other free programs\n"
+"whose distribution conditions are\n"
+"different, write to the author to ask\n"
+"for permission.  For software which is\n"
+"copyrighted by the Free Software\n"
+"Foundation, write to the Free Software\n"
+"Foundation; we sometimes make exceptions\n"
+"for this.  Our decision will be guided\n"
+"by the two goals of preserving the free\n"
+"status of all derivatives of our free\n"
+"software and of promoting\n";
+#endif
+
 const char info_warranty_text[] =
 "NO WARRANTY\n"
 "~~~~~~~~~~~\n"
@@ -337,6 +773,47 @@ const char info_warranty_text[] =
 "EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF\n"
 "THE POSSIBILITY OF SUCH DAMAGES.\n";
 
+#ifdef USE_SDLUI
+const char info_warranty_text40[] =
+"NO WARRANTY\n"
+"~~~~~~~~~~~\n"
+"\n"
+"  11. BECAUSE THE PROGRAM IS LICENSED\n"
+"FREE OF CHARGE, THERE IS NO WARRANTY FOR\n"
+"THE PROGRAM, TO THE EXTENT PERMITTED BY\n"
+"APPLICABLE LAW.  EXCEPT WHEN OTHERWISE\n"
+"STATED IN WRITING THE COPYRIGHT HOLDERS\n"
+"AND/OR OTHER PARTIES PROVIDE THE PROGRAM\n"
+"\"AS IS\" WITHOUT WARRANTY OF ANY KIND,\n"
+"EITHER EXPRESSED OR IMPLIED, INCLUDING,\n"
+"BUT NOT LIMITED TO, THE IMPLIED\n"
+"WARRANTIES OF MERCHANTABILITY AND\n"
+"FITNESS FOR A PARTICULAR PURPOSE.  THE\n"
+"ENTIRE RISK AS TO THE QUALITY AND\n"
+"PERFORMANCE OF THE PROGRAM IS WITH YOU.\n"
+"SHOULD THE PROGRAM PROVE DEFECTIVE, YOU\n"
+"ASSUME THE COST OF ALL NECESSARY\n"
+"SERVICING, REPAIR OR CORRECTION.\n"
+"\n"
+"  12. IN NO EVENT UNLESS REQUIRED BY\n"
+"APPLICABLE LAW OR AGREED TO IN WRITING\n"
+"WILL ANY COPYRIGHT HOLDER, OR ANY OTHER\n"
+"PARTY WHO MAY MODIFY AND/OR REDISTRIBUTE\n"
+"THE PROGRAM AS PERMITTED ABOVE, BE\n"
+"LIABLE TO YOU FOR DAMAGES, INCLUDING ANY\n"
+"GENERAL, SPECIAL, INCIDENTAL OR\n"
+"CONSEQUENTIAL DAMAGES ARISING OUT OF THE\n"
+"USE OR INABILITY TO USE THE PROGRAM\n"
+"(INCLUDING BUT NOT LIMITED TO LOSS OF\n"
+"DATA OR DATA BEING RENDERED INACCURATE\n"
+"OR LOSSES SUSTAINED BY YOU OR THIRD\n"
+"PARTIES OR A FAILURE OF THE PROGRAM TO\n"
+"OPERATE WITH ANY OTHER PROGRAMS), EVEN\n"
+"IF SUCH HOLDER OR OTHER PARTY HAS BEEN\n"
+"ADVISED OF THE POSSIBILITY OF SUCH\n"
+"DAMAGES.\n";
+#endif
+
 const char info_contrib_text[] =
 "VICE derives from X64, the first C64 emulator for the X Window\n"
 "System.  Here is an informal list of the people who were mostly\n"
@@ -373,11 +850,11 @@ const char info_contrib_text[] =
 "  video recording and netlink feature. Made the win32 user\n"
 "  changable keyboard shortcut system. Various bug(fixe)s. ;-)\n"
 "\n"
-"  Martin Pottendorfer <Martin.Pottendorfer@aut.alcatel.at>\n"
+"  pottendo <pottendo@gmx.net>\n"
 "  Implemented Gnome Port based on Oliver Schaertels GTK+ port\n"
 "  Added support code for internationalization based on gettext\n"
 "  Improved the *nix fullscreen support\n"
-"  Translated the UI to German\n"
+"  Translated the user interface to German\n"
 "  Implemented the fliplists + ui (unix).\n"
 "\n"
 "  Spiro Trikaliotis <Spiro.Trikaliotis@gmx.de> wrote the Win32\n"
@@ -387,26 +864,30 @@ const char info_contrib_text[] =
 "  the win32 port, added support for the TFE and RR-Net (cs8900a),\n"
 "  and wrote some further patches.\n"
 "\n"
-"  David Hansel <david@hansels.net> wrote the Star NL10 printer\n"
-"  driver, implemented IEC devices and improved the tape emulation.\n"
-"\n"
 "  Markus Brenner <markus@brenner.de> added VDC emulation to x128\n"
 "  and added support for some more cartridges.\n"
 "\n"
-"  Marco van den Heuvel <blackystardust68@yahoo.com> Translated\n"
-"  the UI to Dutch. Made the Internationalization support for the\n"
-"  Win32 and Amiga ports. Wrote the GEORAM and RamCart cartridge code.\n"
+"  David Hansel <david@hansels.net> wrote the Star NL10 printer\n"
+"  driver, implemented IEC devices and improved the tape emulation.\n"
+"\n"
+"  Marco van den Heuvel <blackystardust68@yahoo.com> Translated the\n"
+"  UI to Dutch. Made the Internationalization support for the Win32\n"
+"  and Amiga ports. Wrote the GEORAM and RamCart cartridge code.\n"
 "  Wrote the c64 +60K, +256K and 256K memory expansions code. Wrote\n"
-"  the pet REU code. Wrote the plus4 memory expansions code.\n"
-"  Made the ethernet support for the Msdos port. Maintains the\n"
-"  RiscOS, QNX 4.x, QNX 6.x, SkyOS, Solaris, Openserver, Unixware,\n"
-"  HPUX, GP2X, Minix 3.x, Amiga, ppc-BeOS and newly resurrected OS/2\n"
-"  binary ports. Added new .crt support. Added new screenshot formats.\n"
-"  Added new sound recording support. Added SIDcart support for pet,\n"
-"  plus4 and vic20. Improved the MMC64 emulation. Added 2 MHz mode for\n"
-"  x128. Added the Hummer userport joystick emulation. Added text copy\n"
-"  and paste support to the amiga and beos ports. Added DQBB and Isepic\n"
-"  cartridge support. And lots of other fixes and improvements.\n"
+"  the pet REU code. Wrote the plus4 memory expansions code. Made\n"
+"  the ethernet support for the Msdos port. Maintains the RiscOS,\n"
+"  QNX 4.x, QNX 6.x, SkyOS, Solaris, Openserver, Unixware, HPUX,\n"
+"  GP2X, Minix 3.x, Amiga, ppc-BeOS and newly resurrected OS/2\n"
+"  binary ports. Maintains the win64 and watcom project files.\n"
+"  Co-maintains the SDL port(s). Added new .crt support. Added new\n"
+"  screenshot formats. Added new sound recording support. Added\n"
+"  SIDcart support for pet, plus4 and vic20. Improved the MMC64\n"
+"  emulation. Added 2 MHz mode and banks 2/3 support for x128.\n"
+"  Added the various userport joystick emulations. Added text copy\n"
+"  and paste support to the amiga and beos ports. Added DQBB and\n"
+"  Isepic cartridge support. Added SFX soundsampler and\n"
+"  soundexpander support. Added digiblaster support. And lots of\n"
+"  other fixes and improvements.\n"
 "\n"
 "  Christian Vogelgsang <chris@vogelgsang.org> maintains the\n"
 "  Mac OS X port. Added Intel Mac support and universal binary\n"
@@ -417,14 +898,14 @@ const char info_contrib_text[] =
 "  Fabrizio Gennari <fabrizio.ge@tiscalinet.it> added some\n"
 "  improvements to the MSDOS- and GTK port.\n"
 "\n"
-"  Hannu Nuotio <<hannu.nuotio@tut.fi> implemented DTV flash\n"
+"  Hannu Nuotio <hannu.nuotio@tut.fi> implemented DTV flash\n"
 "  emulation, DTV support in the monitor, large parts of the\n"
 "  DTV VIC emulation, burst mode and skip cycle emulation\n"
-"  as well as many other things. Added experimental NEOS\n"
-"  and Amiga mouse support. Fixed mouse support for single size in\n"
-"  unix. Fixed mouse grab and menu popup for xaw. Added new monitor\n"
-"  commands and features. Added the memmap feature. Made MIDI\n"
-"  support and MIDI driver code for *nix.\n"
+"  as well as many other things. Added NEOS and Amiga mouse,\n"
+"  paddle and light pen support. Added new monitor commands and\n"
+"  features, including memmap. Made MIDI support and OSS MIDI\n"
+"  driver. Implemented most of the SDL UI. Rewrote xvic CPU/VIC-I\n"
+"  core for cycle based emulation.\n"
 "\n"
 "  M. Kiesel <mayne@users.sourceforge.net> started implementing\n"
 "  x64dtv. The C64DTV memory model and early versions of the\n"
@@ -435,7 +916,12 @@ const char info_contrib_text[] =
 "  palette, DTV SID support in resid, better DMA/Blitter support\n"
 "  and did lots of refactoring. Added new monitor commands and\n"
 "  features. Improved the VIC emulation for xvic. Made MIDI driver\n"
-"  code for win32.\n"
+"  code for win32.  Rewrote the xvic cartridge system. Added Mega-Cart\n"
+"  and Final Expansion V3.2 support to xvic.\n"
+"\n"
+"  Antti S. Lankila <alankila@bel.fi> Made the ReSID-fp engine,\n"
+"  rewrote the PAL emulation code and fixed the sound core for\n"
+"  lower latency.  Rewrote DTV SID support (ReSID-dtv).\n"
 "\n"
 "Former team members:\n"
 "\n"
@@ -482,6 +968,29 @@ const char info_contrib_text[] =
 "  6502 emulation and the XDebugger, and retired from the project\n"
 "  after x64 0.2.1.\n"
 "\n"
+"Internationalization Team:\n"
+"\n"
+"  Peter Krefting <peter@softwolves.pp.se> provided the Swedish\n"
+"  user interface translations.\n"
+"\n"
+"  Andrea Musuruane <musuruan@bmm.it> provided the Italian\n"
+"  user interface translations.\n" 
+"\n"
+"  Czirkos Zoltan <cirix@fw.hu> and Karai Csaba <cskarai@freemail.hu>\n"
+"  provided the Hungarian user interface translations.\n"
+"\n"
+"  Emir Akaydin (aka: Skate) <emir@akaydin.com> provided the\n"
+"  Turkish user interface translations (in world record time).\n"
+"\n"
+"  Mikkel Holm Olsen <vice-dk@symlink.dk> provided the Danish\n"
+"  user interface translations and fixed a few monitor bugs.\n"
+"\n"
+"  Paul Dub from Rivire-du-Loup, Qubec, provided the French\n"
+"  user interface translations.\n"
+"\n"
+"  Flooder <flooder@gower.pl> provided parts of a Polish\n"
+"  user interface translations.\n"
+"\n"
 "External contributors:\n"
 "\n"
 "  Michael Schwendt <sidplay@geocities.com> helped with the SID\n"
@@ -583,6 +1092,9 @@ const char info_contrib_text[] =
 "  X11 full screen, parts of custom ROM set support and\n"
 "  1351 mouse emulation for unix.\n"
 "\n"
+"  Nathan Huizinga <nathan.huizinga@chess.nl> added support for\n"
+"  Expert and Super Snapshot carts.\n"
+"\n"
 "  Luca Montecchiani <m.luca@usa.net> contributed a new Unix\n"
 "  joystick driver.\n"
 "\n"
@@ -591,24 +1103,6 @@ const char info_contrib_text[] =
 "  Manfred Spraul <manfreds@colorfullife.com> wrote the MS-Windows\n"
 "  text lister.\n"
 "\n"
-"  Peter Krefting <peter@softwolves.pp.se> provided the swedish\n"
-"  UI translations.\n"
-"\n"
-"  Czirkos Zoltan <cirix@fw.hu> and Karai Csaba <cskarai@freemail.hu>\n"
-"  provided the Hungarian UI translations.\n"
-"\n"
-"  Paul Dub from Rivire-du-Loup, Qubec, provided the french\n"
-"  translation for both Unix and Windows ports"
-"\n"
-"  Nathan Huizinga <nathan.huizinga@chess.nl> added support for\n"
-"  Expert and Super Snapshot carts.\n"
-"\n"
-"  Andrea Musuruane <musuruan@bmm.it> provided the italian\n"
-"  UI translations.\n" 
-"\n"
-"  Flooder <flooder@gower.pl> provided the polish\n"
-"  translation for the Unix ports\n" 
-"\n"
 "  Michael Klein <nip@c64.org> contributed the ESD sound driver,\n"
 "  basic support for the OPENCBM library and some other patches.\n"
 "\n"
@@ -696,7 +1190,10 @@ const char info_contrib_text[] =
 "  several fixes.\n"
 "\n"
 "  Ingo Korb <ingo@akana.de> Corrected block allocation and interleave\n"
-"  for c1541/vdrive."
+"  for c1541/vdrive, added rudimentary xplus4 tape recording support,\n"
+"  corrected a case of missing Pi symbols in petcat, changed the trap\n"
+"  opcode byte, stopped the high-level serial drive code from responding\n"
+"  to addresses 16-30 and was forced to update this entry himself.\n"
 "\n"
 "  Georg Feil <georg@sgl.sci.yorku.ca> Added support for toggling\n"
 "  CB2 sound output line in the PET emulator.\n"
@@ -710,19 +1207,21 @@ const char info_contrib_text[] =
 "  Marcus Sutton <loggedoubt@gmail.com> Made some console, dialog and\n"
 "  joystick fixes for the BeOS port.\n"
 "\n"
-"  Antti Lankila <alankila@bel.fi> Made the ReSID-fp engine and rewrote\n"
-"  the PAL emulation code.\n"
-"\n"
 "  Mustafa 'GnoStiC' Tufan <mtufan@gmail.com> Made improvements to the\n"
 "  gp2x port.\n"
 "\n"
 "  Ville-Matias Heikkila <viznut@iki.fi> Rewrote the vic20 sound code.\n"
 "\n"
+"  Errol Smith <strobey@users.sourceforge.net> improved VDC emulation.\n"
+"\n"
+"  Peter Edwards <sweetlilmre@users.sourceforge.net> implemented the\n"
+"  SDL UI slider control and fixed some GP2X/Dingoo SDL UI issues.\n"
+"\n"
 "(We hope we have not forgotten anybody; if you think we have,\n"
 "please tell us.)\n"
 "\n"
 "Thanks also to everyone else for sending suggestions, ideas, bug\n"
-"reports, questions and requests.  In particular, a warm thank\n"
+"reports, questions and requests.  In particular, a warm thanks\n"
 "goes to the following people:\n"
 "\n"
 "  Lutz Sammer\n"
@@ -740,8 +1239,7 @@ const char info_contrib_text[] =
 "  Ullrich von Bassewitz\n"
 "  Holger Busse\n"
 "\n"
-"Last but not least, a very special thank to Andreas Arens, Lutz\n"
+"Last but not least, a very special thanks to Andreas Arens, Lutz\n"
 "Sammer, Edgar Tornig, Christian Bauer, Wolfgang Lorenz, Miha\n"
-"Peternel and Per H^akan Sundell for writing cool emulators to\n"
-"compete with.  :-)\n";
-
+"Peternel and Per Hkan Sundell for writing cool emulators to\n"
+"compete with.  :-)\n\n";
