@@ -179,7 +179,7 @@ static mon_reg_list_t *mon_register_list_getz80(int mem)
 {
     mon_reg_list_t *mon_reg_list;
 
-    mon_reg_list = (mon_reg_list_t *)lib_malloc(sizeof(mon_reg_list_t) * 14);
+    mon_reg_list = lib_malloc(sizeof(mon_reg_list_t) * 14);
 
     mon_reg_list[0].name = "PC";
     mon_reg_list[0].val = (unsigned int)mon_register_get_val(mem, e_PC);
