@@ -2,7 +2,7 @@
  * pet-resources.h
  *
  * Written by
- *  Andreas Boose <boose@linux.rz.fh-hannover.de>
+ *  Andreas Boose <viceteam@t-online.de>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -24,10 +24,11 @@
  *
  */
 
-#ifndef _PET_RESOURCES_H
-#define _PET_RESOURCES_H
+#ifndef VICE_PET_RESOURCES_H
+#define VICE_PET_RESOURCES_H
 
 extern int pet_resources_init(void);
+extern void pet_resources_shutdown(void);
 
 extern int emu_id_enabled;
 
