@@ -70,6 +70,11 @@
 #include "network.h"
 #include "types.h"
 
+/* dummy functions */
+
+void ui_error(const char *format, ...)
+{
+}
 
 #define PETCATVERSION   2.17
 #define PETCATLEVEL     1
@@ -245,11 +250,28 @@ const char *a_ctrl1[] = {
     "", "down", "rvs on", "home", "delete", "", "", "",
     "",  "",  "",  "esc", "red", "right", "grn", "blu"
 };
+
+/* 0x00 - 0x1f */
+const char *b_ctrl1[] = {
+    "", "", "", "", "", "", "", "",
+    "", "", "", "", "", "", "", "",
+    "", "", "REVERSE ON", "", "", "", "", "",
+    "",  "",  "",  "", "", "", "", ""
+};
+
+/* 0x20 - 0x3f */
+const char *cbmchars[] = {
+    "space", "", "", "", "", "", "", "",
+    "", "", "", "", "", "", "", "",
+    "", "", "", "", "", "", "", "",
+    "",  "",  "",  "", "", "", "", ""
+};
+
 /* 0x80 - 0x9f */
 const char *a_ctrl2[] = {
     "", "orange", "", "", "", "f1", "f3", "f5",
     "f7", "f2", "f4", "f6", "f8", "shift return", "upper case", "",
-    "blk",  "up", "rvs off", "clr", "insert", "brown", "lt red", "grey1",
+    "blk",  "up", "rvs off", "clear", "insert", "brown", "lt red", "grey1",
     "grey2", "lt green", "lt blue", "grey3", "pur", "left", "yel", "cyn"
 };
 
@@ -684,11 +706,14 @@ static int p_expand(int version, int addr, int ctrls);
 static void p_tokenize(int version, unsigned int addr, int ctrls);
 static unsigned char sstrcmp(unsigned char *line, const char **wordlist,
                              int token, int maxitems);
+static unsigned char sstrcmp_codes(unsigned char *line, const char **wordlist,
+                            int token, int maxitems);
 
 /* ------------------------------------------------------------------------- */
 
 static FILE *source, *dest;
 static int kwlen;
+static int codesnocase=0; /* flag, =1 if controlcodes should be interpreted case insensitive */
 
 /* dummy functions */
 int cmdline_register_options(const cmdline_option_t *c)
@@ -717,6 +742,10 @@ void event_record_in_list(event_list_state_t *list, unsigned int type,
 
 /* ------------------------------------------------------------------------- */
 
+/*
+29/01/2009 gpz
+- added -ic option
+*/
 int main(int argc, char **argv)
 {
     char *progname, *outfilename = NULL;
@@ -747,6 +776,11 @@ int main(int argc, char **argv)
             /* Fall to error */
         }
 
+        if (!strcmp(argv[0], "-ic")) {
+            codesnocase = 1;
+            continue;
+        }
+
         if (!strcmp(argv[0], "-c")) {
             ctrls = 1;
             continue;
@@ -825,6 +859,7 @@ int main(int argc, char **argv)
             "   -c\t\tcontrols (interpret also control codes) <default if textmode>\n"
             "   -nc\t\tno controls (suppress control codes in printout)\n"
             "   \t\t<default if non-textmode>\n"
+            "   -ic\t\tinterpret control codes case-insensitive\n"
             "   -h\t\twrite header <default if output is stdout>\n"
             "   -nh\t\tno header <default if output is a file>\n"
             "   -skip <n>\tSkip <n> bytes in the beginning of input file. Ignored on P00.\n"
@@ -834,7 +869,7 @@ int main(int argc, char **argv)
             "   -k<version>\tlist all keywords for the specified Basic version\n"
             "   -k\t\tlist all Basic versions available.\n"
             "   -l\t\tSpecify load address for program (in hex, no loading chars!).\n"
-            "   -o<name>\tSpecify the output file name\n"
+            "   -o <name>\tSpecify the output file name\n"
             "   -f\t\tForce overwritten the output file\n"
             "   \t\tThe default depends on the BASIC version.\n");
 
@@ -870,7 +905,7 @@ int main(int argc, char **argv)
                 "\t10\tBasic v10.0 program (C64DX)\n\n");
 
         fprintf(stdout, "\tUsage examples:\n"
-            "\tpetcat -w2 -o outputfile.txt -- inputfile.prg\n"
+            "\tpetcat -2 -o outputfile.txt -- inputfile.prg\n"
             "\t\tConvert inputfile.prg to a text file in outputfile.txt,\n"
             "\t\tusing BASIC V2 only\n"
             "\tpetcat -wsimon -o outputfile.prg -- inputfile.txt\n"
@@ -1016,8 +1051,8 @@ int main(int argc, char **argv)
         if (wr_mode) {
             p_tokenize(version, load_addr, ctrls);
         } else {
-            if (hdr)
-                fprintf(dest, "\n\n%s ", (fil ? argv[0] : "<stdin>"));
+            if (hdr) /* iAN: name as comment when using petcat name.prg > name.txt */
+                fprintf(dest, "\n\n;%s ", (fil ? argv[0] : "<stdin>"));
 
             /*
              * Use TEXT mode if the offset doesn't equal BASIC load addresses
@@ -1039,12 +1074,14 @@ int main(int argc, char **argv)
             else {
 
                 /* get load address */
-                load_addr =(getc(source) & 0xff) + ((getc(source) & 0xff)<< 8);
+                /* iAN: load_addr split into 2 lines, when compiled with VC7.1 I got ==0108== instead of ==0801== !! */
+                load_addr = (getc(source) & 0xff) ;
+                load_addr |= (getc(source) & 0xff) << 8;
                 if (hdr)
                     fprintf(dest, "==%04x==\n", load_addr);
 
                 if (p_expand(version, load_addr, ctrls)) {
-                    fprintf(dest, "\n*** Machine language part skipped. ***\n");
+                    fprintf(dest, "\n;*** Machine language part skipped. ***\n");
                 }
                 else    /* End of BASIC on stdin. Is there more ? */
                     if (!fil && (c = getc(source)) != EOF &&
@@ -1419,7 +1456,15 @@ static void pet_2_asc(int ctrls)
     }      /* line */
 }
 
+/*
+      translate petscii code into an ascii representation
 
+29/01/2009 gpz
+- fixed $5b,$5d
+*/
+/*
+iAN: "left arrow" petscii 0x5f was converted as ascii 0x7f and not translated back correctly
+*/
 static void _p_toascii(int c, int ctrls)
 {
     switch (c) {
@@ -1428,7 +1473,28 @@ static void _p_toascii(int c, int ctrls)
       case 0x0d:
         fputc ('\n', dest);
         break;
-      case 0x60:
+      case 0x40:
+        fputc ('@', dest);
+        break;
+      case 0x5b:
+        fputc ('[', dest);
+        break;
+      case 0x5c:
+        fputc ('\\', dest);
+        break;
+      case 0x5d:
+        fputc (']', dest);
+        break;
+      case 0x5e:
+        fputc ('^', dest);
+        break;
+      case 0x5f:
+        fputc ('_', dest);
+        break;
+      case 0x60: /* produces the same screencode as $c0! */
+        fprintf(dest, CLARIF_LP_ST "$%02x" CLARIF_RP_ST, c & 0xff);
+        break;
+      case 0xc0:
         fprintf(dest, CLARIF_LP_ST "SHIFT-*" CLARIF_RP_ST);
         break;
       case 0x7c:
@@ -1545,7 +1611,8 @@ static int p_expand(int version, int addr, int ctrls)
             /* basic 2.0, 7.0 & 10.0 and extensions */
 
             if (!quote && c > 0x7f) {
-                if (c <= MAX_COMM) {
+                /* check for keywords common to all versions, include pi */
+                if (c <= MAX_COMM || c == 0xff) {
                     fprintf(dest, "%s", keyword[c & 0x7f]);
 
                     if (c == 0x9E) {
@@ -1715,10 +1782,26 @@ static int p_expand(int version, int addr, int ctrls)
   previous versions of petcat segfault (or with luck, output trash)
 - added error message when there is an unknown controlcode inside braces
 */
+
+/*
+29/01/2009 gpz:
+- raised length of input buffer from 256 to 256*8
+
+   the line may contain 256 _basic tokens_, some of which may either be
+   represented as literal basic commands or as petsciicodes in braces -
+   either of these representations is a few characters long so the input
+   buffer must consider this
+
+   note: this is still ugly =P
+- added recognition of control codes in the form {123} (decimal number)
+*/
+#define MAX_INLINE_LEN	(256*8)
+#define MAX_OUTLINE_LEN 256
+
 static void p_tokenize(int version, unsigned int addr, int ctrls)
 {
-    static char line[256];
-    static char tokenizedline[256];
+    static char line[MAX_INLINE_LEN+1];
+    static char tokenizedline[MAX_OUTLINE_LEN+1];
     unsigned char *p1, *p2, quote, c;
     unsigned char rem_data_mode, rem_data_endchar = '\0';
     int len = 0, match;
@@ -1728,9 +1811,14 @@ static void p_tokenize(int version, unsigned int addr, int ctrls)
 
     /* Copies from p2 to p1 */
 
-    while((p2 = (unsigned char *)fgets(line, 255, source)) != NULL) {
+    while ((p2 = (unsigned char *)fgets(line, MAX_INLINE_LEN, source)) != NULL) {
+        /*
+        iAN: skip comment line when starting with ";"
+        */
+        if (*line==';')
+            continue;
 
-	memset(tokenizedline, 0, 256);
+	memset(tokenizedline, 0, MAX_OUTLINE_LEN);
 	p1 = (unsigned char *)tokenizedline;
 
 #ifndef GEMDOS
@@ -1742,7 +1830,7 @@ static void p_tokenize(int version, unsigned int addr, int ctrls)
 #endif
 
 #ifdef DEBUG
-	fprintf(stderr,"line: %d\n",linum);
+	fprintf(stderr,"line: %d [%s]\n",linum,line);
 #endif
         quote = 0;
         rem_data_mode = 0;
@@ -1784,47 +1872,98 @@ static void p_tokenize(int version, unsigned int addr, int ctrls)
 #ifdef DEBUG
 	fprintf(stderr,"controlcode repeat count: len:%d kwlen:%d\n", len,kwlen);
 #endif
+			/* if we are already at the closing brace, then the previous
+			   value wasnt the repeat count but an actual decimal charactercode */
+                        if (*p == CLARIF_RP)
+			{
+
+				*p1++ = len;
+				p2 = p + (++kwlen);
+ 				continue;				
+			}
+	
 
                         if (*p == ' ')
                             ++p;
                     }
 
+#ifdef DEBUG
+	fprintf(stderr,"controlcode test: %s\n", p);
+#endif
+		    
 		if (
 		    ( 
-			((c = sstrcmp(p,hexcodes, 0, 0x100)) != KW_NONE) || /* 0x00-0xff */
+			((c = sstrcmp_codes(p,hexcodes, 0, 0x100)) != KW_NONE) || /* 0x00-0xff */
 
-			((c = sstrcmp(p,   ctrl1, 0, 0x20)) != KW_NONE) || /* 0x00-0x20 */
-                        ((c = sstrcmp(p, a_ctrl1, 0, 0x20)) != KW_NONE) || /* 0x00-0x20 */
+			((c = sstrcmp_codes(p,   ctrl1, 0, 0x20)) != KW_NONE) || /* 0x00-0x1f */
+                        ((c = sstrcmp_codes(p, a_ctrl1, 0, 0x20)) != KW_NONE) || /* 0x00-0x1f */
+                        ((c = sstrcmp_codes(p, b_ctrl1, 0, 0x20)) != KW_NONE) || /* 0x00-0x1f */
 
-                       (( ((c = sstrcmp(p,   ctrl2, 0, 0x20)) != KW_NONE) ||
-                          ((c = sstrcmp(p, a_ctrl2, 0, 0x20)) != KW_NONE)
+                       (( ((c = sstrcmp_codes(p,cbmchars, 0, 0x20)) != KW_NONE)  /* 0x20-0x3f */
+                         ) && (c += 0x20)) ||
+
+                       (( ((c = sstrcmp_codes(p,   ctrl2, 0, 0x20)) != KW_NONE) ||
+                          ((c = sstrcmp_codes(p, a_ctrl2, 0, 0x20)) != KW_NONE)
                          ) && (c += 0x80)) ||
 
-                       (( ((c = sstrcmp(p, cbmkeys, 0, 0x40)) != KW_NONE) ||
-			  ((c = sstrcmp(p,a_cbmkeys, 0, 0x40)) != KW_NONE)
+                       (( ((c = sstrcmp_codes(p, cbmkeys, 0, 0x40)) != KW_NONE) ||
+			  ((c = sstrcmp_codes(p,a_cbmkeys, 0, 0x40)) != KW_NONE)
 			) && (c += 0xA0)) 
 
 
-                    ) && (p[kwlen] == CLARIF_RP)
+                    )
 		   ) {
+#ifdef DEBUG
+	fprintf(stderr,"controlcode test 2: %c %s %d\n", p[kwlen],p,kwlen);
+#endif
+				if (p[kwlen] == '*')
+				{
+				    /* repetition count */
+					p+=(kwlen);
+					
+#ifdef DEBUG
+	fprintf(stderr,"controlcode test rpt: %s\n", p);
+#endif
+				    len = 1;
+#ifndef GEMDOS
+				    if (sscanf((char *)++p, "%d%n", &len, &kwlen) == 1) {
+					p += kwlen;
+#else
+				    if (sscanf(++p, "%d", &len) == 1) {
+					while (isspace(*p) || isdigit(*p)) p++;
+#endif
 
-                        for (; len-- > 0;)
-			{
-                            *p1++ = c;
-			}
-                        p2 = p + (++kwlen);
+#ifdef DEBUG
+	fprintf(stderr,"controlcode repeat count: len:%d kwlen:%d\n", len,kwlen);
+#endif
+					kwlen=0;
+				    }
+
+				}
+
+#ifdef DEBUG
+	fprintf(stderr,"controlcode test 3: %c %s %d\n", p[0],p,kwlen);
+#endif
+				
+				if (p[kwlen] == CLARIF_RP)
+				{
+					for (; len-- > 0;)
+					{
+					    *p1++ = c;
+					}
+					p2 = p + (++kwlen);
 
 #ifdef DEBUG
 	fprintf(stderr,"controlcode continue\n");
 #endif
 
-                        continue;
+					continue;
+				}
+			
                     	}
-			else
-			{
-				fprintf(stderr,"error: line %d - unknown control code: %s\n",linum,p);
-				exit(-1);
-			}
+
+			fprintf(stderr,"error: line %d - unknown control code: %s\n",linum,p);
+			exit(-1);
                 }
 #ifdef DEBUG
 /*	fprintf(stderr,"controlcode end\n"); */
@@ -2092,7 +2231,10 @@ static void p_tokenize(int version, unsigned int addr, int ctrls)
                 if (*p2 == 0x7e)                /*  '~' is ASCII for 'pi' */
                     *p1++ = 0xff;
 
-                else if ((*p2 >= 0x5b) && (*p2 <= 0x7e))
+                else if ((*p2 >= 0x5b) && (*p2 <= 0x5f)) /* iAN: '_' -> left arrow, no char value change */
+                    *p1++ = *p2;
+
+                else if ((*p2 >= 0x60) && (*p2 <= 0x7e))
                     *p1++ = *p2 ^ 0x20;
 
                 else if ((*p2 >= 'A') && (*p2 <= 'Z'))
@@ -2111,11 +2253,11 @@ static void p_tokenize(int version, unsigned int addr, int ctrls)
 
 #ifdef DEBUG
 	fprintf(stderr,"output line start: %s\n", line);
-/*	fprintf(stderr,"output line petscii: %s\n", tokenizedline); */
+        /*  fprintf(stderr,"output line petscii: %s\n", tokenizedline); */
 #endif
 
         *p1 = 0;
-        if ((len = strlen(tokenizedline) ) > 0) {
+        if ((len = (int)strlen(tokenizedline) ) > 0) {
             addr += len + 5;
             fprintf(dest, "%c%c%c%c%s%c", addr & 255, (addr>>8) & 255,
                    linum & 255, (linum>>8) & 255, tokenizedline, '\0');
@@ -2132,7 +2274,49 @@ static void p_tokenize(int version, unsigned int addr, int ctrls)
     fprintf(dest, "%c%c", 0, 0);        /* program end marker */
 }
 
+/*
+     look up a controlcode
+*/
+static unsigned char sstrcmp_codes(unsigned char *line, const char **wordlist,
+                            int token, int maxitems)
+{
+    int j;
+    const char *p, *q;
 
+    kwlen = 1;
+    /* search for keyword */
+    for (; token < maxitems; token++)
+    {
+        if (codesnocase)
+        {
+            for (p = wordlist[token], q = (char *)line, j = 0;
+                *p && *q && tolower(*p) == tolower(*q); p++, q++, j++);
+        }
+        else
+        {
+            for (p = wordlist[token], q = (char *)line, j = 0;
+                *p && *q && *p == *q; p++, q++, j++);
+        }
+
+        /*fprintf (stderr,
+                 "compare %s %s - %d %d\n", wordlist[token], line, j, kwlen);*/
+
+        /* found an exact or abbreviated keyword
+         */
+        if (j && (!*p) )
+        {
+            kwlen = j;
+            /*fprintf (stderr, "found %s %2x\n", wordlist[token], token);*/
+            return token;
+        }
+    } /* for */
+
+    return (KW_NONE);
+}
+
+/*
+     look up a keyword
+*/
 static unsigned char sstrcmp(unsigned char *line, const char **wordlist,
                             int token, int maxitems)
 {
@@ -2141,7 +2325,8 @@ static unsigned char sstrcmp(unsigned char *line, const char **wordlist,
 
     kwlen = 1;
     /* search for keyword */
-    for (; token < maxitems; token++) {
+    for (; token < maxitems; token++)
+    {
         for (p = wordlist[token], q = (char *)line, j = 0;
              *p && *q && *p == *q; p++, q++, j++);
 
@@ -2201,8 +2386,7 @@ char *system_mbstowcs_alloc(const char *mbs)
 
 void system_mbstowcs_free(char *wcs)
 {
-    if (wcs != NULL)
-        lib_free(wcs);
+    lib_free(wcs);
 }
 #endif
 
