@@ -56,7 +56,7 @@ static int set_video_cache_enabled(int val, void *param)
 
     raster_resource_chip = (raster_resource_chip_t *)param;
 
-    if(val == 99) {
+    if (val == 99) {
         if (machine_class == VICE_MACHINE_C64DTV) {
             val = 0;
         } else {
@@ -88,9 +88,7 @@ int raster_resources_chip_init(const char *chipname, raster_t *raster,
     unsigned int i;
     raster_resource_chip_t *raster_resource_chip;
 
-    raster_resource_chip
-        = (raster_resource_chip_t *)lib_calloc(
-        1, sizeof(raster_resource_chip_t));
+    raster_resource_chip = lib_calloc(1, sizeof(raster_resource_chip_t));
 
     raster->raster_resource_chip = raster_resource_chip;
     raster_resource_chip->raster = raster;
