@@ -82,7 +82,7 @@ rawfile_info_t *rawfile_open(const char *file_name, const char *path,
         return NULL;
     }
 
-    info = (rawfile_info_t *)lib_malloc(sizeof(rawfile_info_t));
+    info = lib_malloc(sizeof(rawfile_info_t));
 
     info->fd = fd;
     util_fname_split(complete, &(info->path), &(info->name));
@@ -118,6 +118,16 @@ int rawfile_seek_set(rawfile_info_t *info, int offset)
     return fseek(info->fd, offset, SEEK_SET);
 }
 
+unsigned int rawfile_get_bytes_left(struct rawfile_info_s *info)
+{
+    unsigned int old_pos = ftell(info->fd);
+    unsigned int size;
+    fseek(info->fd, 0, SEEK_END);
+    size = ftell(info->fd);
+    fseek(info->fd, old_pos, SEEK_SET);
+    return size - old_pos;
+}
+
 unsigned int rawfile_ferror(rawfile_info_t *info)
 {
     return (unsigned int)ferror(info->fd);
