@@ -24,8 +24,8 @@
  *
  */
 
-#ifndef _SID_CMDLINE_OPTIONS_H
-#define _SID_CMDLINE_OPTIONS_H
+#ifndef VICE_SID_CMDLINE_OPTIONS_H
+#define VICE_SID_CMDLINE_OPTIONS_H
 
 extern int sid_cmdline_options_init(void);
 extern int sidcart_cmdline_options_init(void);
