@@ -59,6 +59,31 @@ struct sid_snapshot_state_s;
 #define SID_MODEL_8580R5_1489D  19
 #define SID_MODEL_DEFAULT       99
 
+/* these definitions are the only valid combinations of
+   software SID engines and model, and are used in the
+   UI and command line code. */
+#define SID_FASTSID_6581          ((SID_ENGINE_FASTSID << 8) | SID_MODEL_6581)
+#define SID_FASTSID_8580          ((SID_ENGINE_FASTSID << 8) | SID_MODEL_8580)
+#define SID_RESID_6581            ((SID_ENGINE_RESID << 8) | SID_MODEL_6581)
+#define SID_RESID_8580            ((SID_ENGINE_RESID << 8) | SID_MODEL_8580)
+#define SID_RESID_8580D           ((SID_ENGINE_RESID << 8) | SID_MODEL_8580D)
+#define SID_RESID_DTVSID          ((SID_ENGINE_RESID << 8) | SID_MODEL_DTVSID)
+#define SID_CATWEASELMKIII        (SID_ENGINE_CATWEASELMKIII << 8)
+#define SID_HARDSID               (SID_ENGINE_HARDSID << 8)
+#define SID_PARSID_PORT1          (SID_ENGINE_PARSID_PORT1 << 8)
+#define SID_PARSID_PORT2          (SID_ENGINE_PARSID_PORT2 << 8)
+#define SID_PARSID_PORT3          (SID_ENGINE_PARSID_PORT3 << 8)
+#define SID_RESIDFP_6581R3_4885   ((SID_ENGINE_RESID_FP << 8) | SID_MODEL_6581R3_4885)
+#define SID_RESIDFP_6581R3_0486S  ((SID_ENGINE_RESID_FP << 8) | SID_MODEL_6581R3_0486S)
+#define SID_RESIDFP_6581R3_3984   ((SID_ENGINE_RESID_FP << 8) | SID_MODEL_6581R3_3984)
+#define SID_RESIDFP_6581R4AR_3789 ((SID_ENGINE_RESID_FP << 8) | SID_MODEL_6581R4AR_3789)
+#define SID_RESIDFP_6581R3_4485   ((SID_ENGINE_RESID_FP << 8) | SID_MODEL_6581R3_4485)
+#define SID_RESIDFP_6581R4_1986S  ((SID_ENGINE_RESID_FP << 8) | SID_MODEL_6581R4_1986S)
+#define SID_RESIDFP_8580R5_3691   ((SID_ENGINE_RESID_FP << 8) | SID_MODEL_8580R5_3691)
+#define SID_RESIDFP_8580R5_3691D  ((SID_ENGINE_RESID_FP << 8) | SID_MODEL_8580R5_3691D)
+#define SID_RESIDFP_8580R5_1489   ((SID_ENGINE_RESID_FP << 8) | SID_MODEL_8580R5_1489)
+#define SID_RESIDFP_8580R5_1489D  ((SID_ENGINE_RESID_FP << 8) | SID_MODEL_8580R5_1489D)
+
 extern BYTE REGPARM1 sid_read(WORD address);
 extern BYTE REGPARM1 sid2_read(WORD address);
 extern void REGPARM2 sid_store(WORD address, BYTE byte);
@@ -104,5 +129,6 @@ extern char *sid_sound_machine_dump_state(sound_t *psid);
 extern int sid_sound_machine_cycle_based(void);
 extern int sid_sound_machine_channels(void);
 extern void sid_sound_machine_enable(int enable);
+extern int sid_set_engine_model(int engine, int model);
 
 #endif
