@@ -38,10 +38,14 @@
 #define DIRECTSOUND_VERSION 0x0500
 #include <dsound.h>
 
+#ifdef USE_SDLUI
+#include <SDL/SDL_syswm.h>
+#endif
+
 #include "lib.h"
 #include "sound.h"
 #include "types.h"
-#include "ui.h"
+#include "uiapi.h"
 
 #ifndef HAVE_GUIDLIB
 /* FIXME: It would be better to convert the dxguid.lib from DX5 into the
@@ -50,12 +54,25 @@ const GUID IID_IDirectSoundNotify = {0xb0210783, 0x89cd, 0x11d0,
                                     {0xaf,0x08,0x00,0xa0,0xc9,0x25,0xcd,0x16}};
 #endif
 
+#ifdef USE_SDLUI
+HWND ui_get_main_hwnd(void)
+{
+    SDL_SysWMinfo info;
+
+    SDL_GetWMInfo(&info);
+
+    return info.window;
+}
+#endif
+
+
 /* ------------------------------------------------------------------------ */
 
-/* #define DEBUG_SOUND */
+#define DEBUG_SOUND 0
 
 /* Debugging stuff.  */
-#ifdef DEBUG_SOUND
+#if DEBUG_SOUND
+#include "log.h"
 static void sound_debug(const char *format, ...)
 {
     char tmp[1024];
@@ -210,6 +227,8 @@ PCMWAVEFORMAT pcmwf;
 DSCAPS  capabilities;
 WAVEFORMATEX    wfex;
 
+HWND ui_get_main_hwnd(void);
+
 static void dx_clear(void)
 {
 LPVOID  lpvPtr1;
@@ -297,11 +316,11 @@ HRESULT result;
     desc.dwSize = sizeof(DSBUFFERDESC);
     desc.dwFlags = DSBCAPS_PRIMARYBUFFER;
 
-    fragment_size = *fragsize;
-
-    buffer_size = *fragsize * *fragnr * (is16bit ? sizeof(SWORD) : 1)
-                  * *channels;
-
+    fragment_size = *fragsize; /* frames */
+    buffer_size = *fragsize * *fragnr * (is16bit ? 2 : 1) * *channels; /* bytes */
+    stream_buffer_size = fragment_size * *fragnr * *channels; /* nr of samples */
+    buffer_offset = 0; /* bytes */
+    
     result = IDirectSound_CreateSoundBuffer(ds, &desc, &pbuffer, NULL);
 
     if (result != DS_OK) {
@@ -319,8 +338,6 @@ HRESULT result;
     desc.dwBufferBytes = buffer_size;
     desc.lpwfxFormat = (LPWAVEFORMATEX)&pcmwf;
 
-    stream_buffer_size = fragment_size * *fragnr * *channels;
-
     result = IDirectSound_CreateSoundBuffer(ds, &desc, &buffer, NULL);
     if (result != DS_OK) {
         ui_error("Cannot create DirectSound buffer:\n%s", ds_error(result));
@@ -342,8 +359,6 @@ HRESULT result;
         return -1;
     }
 
-    buffer_offset= *fragsize * (is16bit ? sizeof(SWORD) : 1) * (*fragnr - 1)
-                   * *channels;
     dx_clear();
     /* Let's go...  */
     result = IDirectSoundBuffer_Play(buffer, 0, 0, DSBPLAY_LOOPING);
@@ -381,17 +396,21 @@ static void dx_close(void)
 
 static int dx_bufferspace(void)
 {
-    DWORD play_cursor, write_cursor;
+    DWORD play_cursor;
     int free_samples;
 
-    IDirectSoundBuffer_GetCurrentPosition(buffer, &play_cursor, &write_cursor);
-    if (play_cursor <= buffer_offset)
-        free_samples = stream_buffer_size - (buffer_offset - play_cursor)
-                       / (is16bit ? 2 : 1);
+    IDirectSoundBuffer_GetCurrentPosition(buffer, &play_cursor, NULL);
+    /* We should properly distinguish between buffer empty and buffer fill
+     * case. However, it's absolutely essential that the state where play and
+     * write cursors overlap is read as buffer being filled with data. */
+    if (play_cursor < buffer_offset)
+        free_samples = buffer_size - (buffer_offset - play_cursor);
     else
-        free_samples = (play_cursor - buffer_offset) / (is16bit ? 2 : 1);
+        free_samples = play_cursor - buffer_offset;
 
-    return free_samples / num_of_channels;
+    DEBUG(("play=%d, ourwrite=%d, free=%d", play_cursor, buffer_offset, free_samples));
+
+    return free_samples / (is16bit ? 2 : 1) / num_of_channels;
 }
 
 static int dx_write(SWORD *pbuf, size_t nr)
@@ -404,12 +423,12 @@ static int dx_write(SWORD *pbuf, size_t nr)
     DWORD buffer_lock_size; /* buffer_lock_end; */
     unsigned int i, count;
 
-    /* XXX: Assumes `nr' is multiple of `fragment_size'.  */
-    count = nr / fragment_size;
-    buffer_lock_size = fragment_size * (is16bit ? sizeof(SWORD) : 1);
+    count = (unsigned int)nr / fragment_size;
+    buffer_lock_size = fragment_size * (is16bit ? 2 : 1);
 
     /* Write one fragment at a time.  FIXME: This could be faster.  */
     for (i = 0; i < count; i++) {
+        /* lock buffer for writing */
         do {
             result = IDirectSoundBuffer_Lock(buffer, buffer_offset,
                                              buffer_lock_size,
@@ -418,36 +437,35 @@ static int dx_write(SWORD *pbuf, size_t nr)
 
             if (result == DSERR_BUFFERLOST) {
                 IDirectSoundBuffer_Restore(buffer);
-                result = IDirectSoundBuffer_Lock(buffer, buffer_offset,
-                                                 buffer_lock_size, &lpvPtr1,
-                                                 &dwBytes1,
-                                                 &lpvPtr2, &dwBytes2, 0);
+                dwBytes1 = dwBytes2 = 0;
             }
-        } while ((dwBytes1 + dwBytes2) < buffer_lock_size);
+        } while (dwBytes1 + dwBytes2 != buffer_lock_size);
+
+        /* put data as-is, or convert to 8 bits first */
         if (is16bit) {
             memcpy(lpvPtr1,pbuf,dwBytes1);
             if (lpvPtr2)
                 memcpy(lpvPtr2,(BYTE *)pbuf + dwBytes1, dwBytes2);
+            pbuf += fragment_size;
         } else {
-            SWORD *copyptr = pbuf;
             for (i = 0; i < dwBytes1; i++) {
-                ((BYTE *)lpvPtr1)[i]=(*(copyptr++) >> 8) + 0x80;
+                ((BYTE *)lpvPtr1)[i]=(*(pbuf++) >> 8) + 0x80;
             }
             if (lpvPtr2 != NULL) {
                 for (i = 0; i < dwBytes2; i++) {
-                    ((BYTE *)lpvPtr2)[i]=(*(copyptr++) >> 8) + 0x80;
+                    ((BYTE *)lpvPtr2)[i]=(*(pbuf++) >> 8) + 0x80;
                 }
             }
         }
 
+        /* done. */
         result = IDirectSoundBuffer_Unlock(buffer, lpvPtr1, dwBytes1,
                                            lpvPtr2, dwBytes2);
         buffer_offset += buffer_lock_size;
 
-        if (buffer_offset >= buffer_size)
+        /* loop */
+        if (buffer_offset == buffer_size)
             buffer_offset = 0;
-
-        pbuf += fragment_size;
     }
 
     pbuf -= num_of_channels;
@@ -461,16 +479,14 @@ static int dx_write(SWORD *pbuf, size_t nr)
 
 static int dx_suspend(void)
 {
-    int c, i;
-    SWORD *p = (SWORD *)lib_malloc(stream_buffer_size * sizeof(SWORD));
+    int i;
+    SWORD *p = lib_malloc(stream_buffer_size * sizeof(SWORD));
 
     if (!p)
         return 0;
 
-    for (c = 0; c < num_of_channels; c++) {
-        for (i = 0; i < stream_buffer_size/num_of_channels; i++) 
-            p[i * num_of_channels + c] = last_buffered_sample[c];
-    }
+    for (i = 0; i < stream_buffer_size; i ++)
+         p[i] = last_buffered_sample[i % num_of_channels];
 
     i = dx_write(p, stream_buffer_size);
     lib_free(p);
@@ -478,16 +494,14 @@ static int dx_suspend(void)
     return 0;
 }
 
+
 static int dx_resume(void)
 {
-    buffer_offset = buffer_size - fragment_size;
+    buffer_offset = 0;
     IDirectSoundBuffer_Play(buffer, 0, 0, DSBPLAY_LOOPING);
-
     return 0;
 }
 
-
-
 static sound_device_t dx_device =
 {
     "dx",
@@ -506,4 +520,3 @@ int sound_init_dx_device(void)
 {
     return sound_register_device(&dx_device);
 }
-
