@@ -27,12 +27,11 @@
 #include "vice.h"
 
 #ifdef USE_LAMEMP3
-#include <stdio.h>
-#include <lame/lame.h>
-
+#include "lamelib.h"
 #include "sound.h"
 #include "types.h"
 #include "archdep.h"
+#include "log.h"
 
 #define PCM_BUFFER_SIZE          SOUND_CHANNELS_MAX * SOUND_BUFSIZE
 #define MP3_BUFFER_SIZE          PCM_BUFFER_SIZE+(PCM_BUFFER_SIZE/4)+7200
@@ -50,15 +49,15 @@ static int mp3_init(const char *param, int *speed, int *fragsize, int *fragnr, i
   if (!mp3_fd)
     return 1;
 
-  gfp = lame_init();
-  lame_set_num_channels(gfp,*channels);
-  lame_set_in_samplerate(gfp,*speed);
-  lame_set_brate(gfp,128);
-  lame_set_quality(gfp,2);
+  gfp = vice_lame_init();
+  vice_lame_set_num_channels(gfp,*channels);
+  vice_lame_set_in_samplerate(gfp,*speed);
+  vice_lame_set_brate(gfp,128);
+  vice_lame_set_quality(gfp,2);
 
-  if (lame_init_params(gfp)<0)
+  if (vice_lame_init_params(gfp)<0)
   {
-    lame_close(gfp);
+    vice_lame_close(gfp);
     fclose(mp3_fd);
     return 1;
   }
@@ -87,7 +86,7 @@ static int mp3_write(SWORD *pbuf, size_t nr)
     }
   }
 
-  mp3_size=lame_encode_buffer_interleaved(gfp, pcm_buffer, (stereo==1) ? nr/2 : nr, mp3_buffer, MP3_BUFFER_SIZE);
+  mp3_size=vice_lame_encode_buffer_interleaved(gfp, pcm_buffer, (stereo==1) ? nr/2 : nr, mp3_buffer, MP3_BUFFER_SIZE);
   if (mp3_size!=0)
   {
     if (mp3_size!=fwrite(mp3_buffer, 1, mp3_size, mp3_fd))
@@ -100,11 +99,13 @@ static void mp3_close(void)
 {
   int mp3_size;
 
-  mp3_size=lame_encode_flush(gfp, mp3_buffer, MP3_BUFFER_SIZE);
+  mp3_size=vice_lame_encode_flush(gfp, mp3_buffer, MP3_BUFFER_SIZE);
 
   fwrite(mp3_buffer, 1, mp3_size, mp3_fd);
   fclose(mp3_fd);
   mp3_fd=NULL;
+  
+  vice_lame_close(gfp);
 }
 
 static sound_device_t mp3_device =
@@ -123,6 +124,14 @@ static sound_device_t mp3_device =
 
 int sound_init_mp3_device(void)
 {
+#ifndef HAVE_STATIC_LAME
+  int result = lamelib_open();
+  if (result != 0) {
+    log_debug("ERROR setting up dynamic lame lib!");
+    return result;
+  }
+#endif
+    
   return sound_register_device(&mp3_device);
 }
 #endif
