@@ -24,16 +24,18 @@
  *
  */
 
-#ifndef _SYSFILE_H
-#define _SYSFILE_H
+#ifndef VICE_SYSFILE_H
+#define VICE_SYSFILE_H
 
 #include <stdio.h>
 
 #include "types.h"
 
 extern int sysfile_init(const char *emu_id);
-extern int sysfile_init_resources(void);
-extern int sysfile_init_cmdline_options(void);
+extern void sysfile_shutdown(void);
+extern int sysfile_resources_init(void);
+extern void sysfile_resources_shutdown(void);
+extern int sysfile_cmdline_options_init(void);
 extern FILE *sysfile_open(const char *name, char **complete_path_return,
                           const char *open_mode);
 extern int sysfile_locate(const char *name, char **complete_path_return);
