@@ -24,8 +24,8 @@
  *
  */
 
-#ifndef _VIC_CMDLINE_OPTIONS_H
-#define _VIC_CMDLINE_OPTIONS_H
+#ifndef VICE_VIC_CMDLINE_OPTIONS_H
+#define VICE_VIC_CMDLINE_OPTIONS_H
 
 extern int vic_cmdline_options_init(void);
 
