@@ -204,6 +204,16 @@ static cmdline_option_t const cmdline_options[] =
       USE_PARAM_STRING, USE_DESCRIPTION_ID,
       IDCLS_UNUSED, IDCLS_DISABLE_EMULATOR_ID,
       NULL, NULL },
+    { "-OEMjoy", SET_RESOURCE, 0,
+      NULL, NULL, "OEMJoy", (resource_value_t)1,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_ENABLE_OEM_JOY,
+      NULL, NULL },
+    { "+OEMjoy", SET_RESOURCE, 0,
+      NULL, NULL, "OEMJoy", (resource_value_t)0,
+      USE_PARAM_STRING, USE_DESCRIPTION_ID,
+      IDCLS_UNUSED, IDCLS_DISABLE_OEM_JOY,
+      NULL, NULL },
     { "-ieee488", SET_RESOURCE, 0,
       NULL, NULL, "IEEE488", (resource_value_t)1,
       USE_PARAM_STRING, USE_DESCRIPTION_ID,
