@@ -24,15 +24,14 @@
  *
  */
 
-#ifndef _VIC20_RESOURCES_H
-#define _VIC20_RESOURCES_H
+#ifndef VICE_VIC20_RESOURCES_H
+#define VICE_VIC20_RESOURCES_H
 
 extern int vic20_resources_init(void);
 extern void vic20_resources_shutdown(void);
 
 extern int emu_id_enabled;
 extern int ieee488_enabled;
-extern int mem_rom_blocks;
 extern int ram_block_0_enabled;
 extern int ram_block_1_enabled;
 extern int ram_block_2_enabled;
