@@ -24,8 +24,8 @@
  *
  */
 
-#ifndef _VIC20MEMROM_H
-#define _VIC20MEMROM_H
+#ifndef VICE_VIC20MEMROM_H
+#define VICE_VIC20MEMROM_H
 
 #include "types.h"
 
