@@ -1,8 +1,9 @@
 /*
- * via.h - VIA emulation.
+ * via20via.h - VIC20 VIA emulation.
  *
  * Written by
- *   Andre' Fachat <fachat@physik.tu-chemnitz.de>
+ *  Andreas Boose <viceteam@t-online.de>
+ *  Andre' Fachat <fachat@physik.tu-chemnitz.de>
  *
  * This file is part of VICE, the Versatile Commodore Emulator.
  * See README for copyright notice.
@@ -24,30 +25,26 @@
  *
  */
 
-#ifndef _VIC20_VIA_H
-#define _VIC20_VIA_H
+#ifndef VICE_VIC20VIA_H
+#define VICE_VIC20VIA_H
 
 #include "types.h"
 
-struct snapshot_s;
+struct machine_context_s;
+struct via_context_s;
 
-extern void via1_init(void);
-extern void via1_reset(void);
-extern void via1_signal(int line, int edge);
-extern void REGPARM2 via1_store(ADDRESS addr, BYTE byte);
-extern BYTE REGPARM1 via1_read(ADDRESS addr);
-extern BYTE REGPARM1 via1_peek(ADDRESS addr);
-extern int via1_snapshot_write_module(struct snapshot_s *p);
-extern int via1_snapshot_read_module(struct snapshot_s *p);
+extern void vic20via1_setup_context(struct machine_context_s *machine_context);
+extern void via1_init(struct via_context_s *via_context);
+extern void REGPARM2 via1_store(WORD addr, BYTE byte);
+extern BYTE REGPARM1 via1_read(WORD addr);
+extern BYTE REGPARM1 via1_peek(WORD addr);
+
+extern void vic20via2_setup_context(struct machine_context_s *machine_context);
+extern void via2_init(struct via_context_s *via_context);
+extern void REGPARM2 via2_store(WORD addr, BYTE byte);
+extern BYTE REGPARM1 via2_read(WORD addr);
+extern BYTE REGPARM1 via2_peek(WORD addr);
 
-extern void via2_init(void);
-extern void via2_reset(void);
-extern void via2_signal(int line, int edge);
-extern void REGPARM2 via2_store(ADDRESS addr, BYTE byte);
-extern BYTE REGPARM1 via2_read(ADDRESS addr);
-extern BYTE REGPARM1 via2_peek(ADDRESS addr);
-extern int via2_snapshot_write_module(struct snapshot_s *p);
-extern int via2_snapshot_read_module(struct snapshot_s *p);
 extern void via2_set_tape_sense(int v);
 
 #endif
