@@ -49,9 +49,17 @@
 
 #define X_OFFSET vicii.screen_leftborderwidth
 
-#define SPRITE_EXPANDED_REPEAT_PIXELS_START(n) (0x11a + X_OFFSET + n * 0x10)
-#define SPRITE_NORMAL_REPEAT_PIXELS_START(n) (0x132 + X_OFFSET + n * 0x10)
-#define SPRITE_REPEAT_PIXELS_END(n) (0x157 + X_OFFSET + n * 0x10)
+#define SPRITE_EXPANDED_REPEAT_PIXELS_START(n) (vicii.sprite_wrap_x < 0x200 ? \
+                                               (0x11a + X_OFFSET + n * 0x10) :\
+                                               (0x122 + X_OFFSET + n * 0x10))
+
+#define SPRITE_NORMAL_REPEAT_PIXELS_START(n) (vicii.sprite_wrap_x < 0x200 ? \
+                                             (0x132 + X_OFFSET + n * 0x10) :\
+                                             (0x13a + X_OFFSET + n * 0x10))
+
+#define SPRITE_REPEAT_PIXELS_END(n) (vicii.sprite_wrap_x < 0x200 ? \
+                                    (0x157 + X_OFFSET + n * 0x10) :  \
+                                    (0x15f + X_OFFSET + n * 0x10))
 /* where the sprite pixels start repeating */
 #define SPRITE_REPEAT_BEGIN(n) (SPRITE_REPEAT_PIXELS_END(n) - 0xc)
 
@@ -524,14 +532,17 @@ inline static void draw_hires_sprite_expanded(BYTE *data_ptr, int n,
     int must_repeat_pixels = 0;
     DWORD repeat_pixel = 0;
     int i;
+    int spritex_unwrapped = (sprite_status->sprites[n].x + vicii.sprite_wrap_x)
+                            % vicii.sprite_wrap_x;
 
     sprmsk = sprite_doubling_table[(data_ptr[0] << 8) | data_ptr[1]];
 
-    if (sprite_status->sprites[n].x > SPRITE_EXPANDED_REPEAT_PIXELS_START(n)
-        && sprite_status->sprites[n].x < SPRITE_REPEAT_PIXELS_END(n)) {
+    
+    if (spritex_unwrapped > SPRITE_EXPANDED_REPEAT_PIXELS_START(n)
+        && spritex_unwrapped < SPRITE_REPEAT_PIXELS_END(n)) {
         /* sprite #n repeats pixel SPRITE_REPEAT_BEGIN(n)-1 up to SPRITE_REPEAT_BEGIN(n)+6 */ 
         /* no display from SPRITE_REPEAT_BEGIN(n)+7 to SPRITE_REPEAT_BEGIN(n)+11           */
-        size = SPRITE_REPEAT_BEGIN(n) - sprite_status->sprites[n].x;
+        size = SPRITE_REPEAT_BEGIN(n) - spritex_unwrapped;
         must_repeat_pixels = (size > 0);
         if (size1 > size)
             size1 = size;
@@ -629,14 +640,16 @@ inline static void draw_hires_sprite_normal(BYTE *data_ptr, int n,
     int must_repeat_pixels = 0;
     DWORD repeat_pixel;
     int i;
+    int spritex_unwrapped = (sprite_status->sprites[n].x + vicii.sprite_wrap_x)
+                            % vicii.sprite_wrap_x;
 
     sprmsk = (data_ptr[0] << 16) | (data_ptr[1] << 8) | data_ptr[2];
 
-    if (sprite_status->sprites[n].x > SPRITE_NORMAL_REPEAT_PIXELS_START(n)
-        && sprite_status->sprites[n].x < SPRITE_REPEAT_PIXELS_END(n)) {
+    if (spritex_unwrapped > SPRITE_NORMAL_REPEAT_PIXELS_START(n)
+        && spritex_unwrapped < SPRITE_REPEAT_PIXELS_END(n)) {
         /* sprite #n repeats pixel SPRITE_REPEAT_BEGIN(n)-1 up to SPRITE_REPEAT_BEGIN(n)+6 */ 
         /* no display from SPRITE_REPEAT_BEGIN(n)+7 to SPRITE_REPEAT_BEGIN(n)+11           */
-        size = SPRITE_REPEAT_BEGIN(n) - sprite_status->sprites[n].x;
+        size = SPRITE_REPEAT_BEGIN(n) - spritex_unwrapped;
         must_repeat_pixels = (size > 0);
 
         if (must_repeat_pixels) {
@@ -707,6 +720,8 @@ inline static void draw_mc_sprite_expanded(BYTE *data_ptr, int n, DWORD *c,
     BYTE cmsk = 0, sbit = 1 << n;
     BYTE data0, data1;
     int trim_size;
+    int spritex_unwrapped = (sprite_status->sprites[n].x + vicii.sprite_wrap_x)
+                            % vicii.sprite_wrap_x;
 
     mcsprmsk = (data_ptr[0] << 16) | (data_ptr[1] << 8) | data_ptr[2];
     collmsk = ((((msk_ptr[1] << 24) | (msk_ptr[2] << 16)
@@ -740,11 +755,11 @@ inline static void draw_mc_sprite_expanded(BYTE *data_ptr, int n, DWORD *c,
         mcsprmsk &= ~(1 << (22 - (sprite_xs >> 1) + delayed_shift));
 
     /* Fixes for the "Repeated pixels" bug */
-    if (sprite_status->sprites[n].x > SPRITE_EXPANDED_REPEAT_PIXELS_START(n)
-        && sprite_status->sprites[n].x < SPRITE_REPEAT_PIXELS_END(n)) {
+    if (spritex_unwrapped > SPRITE_EXPANDED_REPEAT_PIXELS_START(n)
+        && spritex_unwrapped < SPRITE_REPEAT_PIXELS_END(n)) {
         /* sprite #n repeats pixel SPRITE_REPEAT_BEGIN(n)-1 up to SPRITE_REPEAT_BEGIN(n)+6 */ 
         /* no display from SPRITE_REPEAT_BEGIN(n)+7 to SPRITE_REPEAT_BEGIN(n)+11           */
-        size = SPRITE_REPEAT_BEGIN(n) - sprite_status->sprites[n].x;
+        size = SPRITE_REPEAT_BEGIN(n) - spritex_unwrapped;
         if (size < 0)
             size = 0;
         must_repeat_pixels = (size > 0);
@@ -861,6 +876,8 @@ inline static void draw_mc_sprite_normal(BYTE *data_ptr, int n, DWORD *c,
     int delayed_shift;
     BYTE data0, data1, data2;
     int trim_size;
+    int spritex_unwrapped = (sprite_status->sprites[n].x + vicii.sprite_wrap_x)
+                            % vicii.sprite_wrap_x;
 
     mcsprmsk = (data_ptr[0] << 16) | (data_ptr[1] << 8) | data_ptr[2];
     collmsk = ((((msk_ptr[0] << 24) | (msk_ptr[1] << 16)
@@ -891,11 +908,11 @@ inline static void draw_mc_sprite_normal(BYTE *data_ptr, int n, DWORD *c,
              | mcsprtable[data2]);
     }
 
-    if (sprite_status->sprites[n].x > SPRITE_NORMAL_REPEAT_PIXELS_START(n)
-        && sprite_status->sprites[n].x < SPRITE_REPEAT_PIXELS_END(n)) {
+    if (spritex_unwrapped > SPRITE_NORMAL_REPEAT_PIXELS_START(n)
+        && spritex_unwrapped < SPRITE_REPEAT_PIXELS_END(n)) {
         /* sprite #n repeats pixel SPRITE_REPEAT_BEGIN(n)-1 up to SPRITE_REPEAT_BEGIN(n)+6 */ 
         /* no display from SPRITE_REPEAT_BEGIN(n)+7 to SPRITE_REPEAT_BEGIN(n)+11           */
-        size = SPRITE_REPEAT_BEGIN(n) - sprite_status->sprites[n].x;
+        size = SPRITE_REPEAT_BEGIN(n) - spritex_unwrapped;
         if (size < 0)
             size = 0;
         must_repeat_pixels = (size > 0);
@@ -1043,10 +1060,10 @@ static void draw_sprite_partial(BYTE *line_ptr, BYTE *gfx_msk_ptr,
 
         msk_ptr = gfx_msk_ptr
                   + (VICII_MAX_SPRITE_WIDTH + sprite_offset
-                    - VICII_RASTER_X(0) - vicii.raster.xsmooth) / 8;
+                    - VICII_RASTER_X(0) - vicii.raster.sprite_xsmooth) / 8;
         ptr = line_ptr + sprite_offset;
         lshift = (sprite_offset
-                 - vicii.raster.xsmooth) & 0x7;
+                 - vicii.raster.sprite_xsmooth) & 0x7;
         sptr = sprline - VICII_RASTER_X(0) + sprite_offset;
 
         if (sprite_status->sprites[n].multicolor)
@@ -1143,52 +1160,100 @@ void vicii_sprites_init(void)
 
 /* Set the X coordinate of the `num'th sprite to `new_x'; the current
    vicii.raster X position is `raster_x'.  */
-/* FIXME: This is a beast and most probably not cycle exact */
 void vicii_sprites_set_x_position(unsigned int num, int new_x, int raster_x)
 {
     raster_sprite_t *sprite;
     int x_offset;
+    int last_pos;
+    int next_pos;
+    int change_pos;
 
     sprite = vicii.raster.sprite_status->sprites + num;
 
-    x_offset = vicii.screen_leftborderwidth - 24;
+    x_offset = vicii_sprite_offset();
+
+    /* Handle spritegap in NTSC mode */
+    if (vicii.sprite_wrap_x > 0x200 && (unsigned int)new_x > 0x187)
+        new_x += (vicii.sprite_wrap_x - 0x200);
 
     new_x += x_offset;
 
+    /* transfer coordinates to a new timeline starting with memory fetch to
+       make calculation easier */
+    next_pos = (new_x - SPRITE_DISPLAY_IMMEDIATE_DATA_FETCHED(num)
+                    + vicii.sprite_wrap_x) % vicii.sprite_wrap_x;
+    last_pos = (sprite->x - SPRITE_DISPLAY_IMMEDIATE_DATA_FETCHED(num)
+                    + 2 * vicii.sprite_wrap_x) % vicii.sprite_wrap_x;
+    change_pos = (raster_x + 8 - SPRITE_DISPLAY_IMMEDIATE_DATA_FETCHED(num)
+                    + 2 * vicii.sprite_wrap_x) % vicii.sprite_wrap_x;
+
+    /* disabled display is at the very end even on the transfered timeline */
+    if (sprite->x == vicii.sprite_wrap_x)
+        last_pos = vicii.sprite_wrap_x;
+
     if (new_x >= vicii.sprite_wrap_x + VICII_RASTER_X(0)) {
         /* Sprites in the $1F8 - $1FF range are not visible at all and never
            cause collisions.  */
-        if (new_x >= 0x1f8 + x_offset)
+        if (new_x >= vicii.sprite_wrap_x + x_offset)
             new_x = vicii.sprite_wrap_x;
         else
             new_x -= vicii.sprite_wrap_x;
     }
 
-    if (new_x < sprite->x) {
-        if (raster_x + x_offset <= new_x
-            && sprite->x < (int)SPRITE_DISPLAY_IMMEDIATE_DATA_FETCHED(num))
+    if (next_pos < last_pos) {
+        if (change_pos <= next_pos)
         {
-            sprite->x = new_x;
+            if (raster_x + 8  > new_x) {
+                /* last line was already drawn */
+                raster_changes_sprites_add_int(&vicii.raster,
+                    SPRITE_DISPLAY_IMMEDIATE_DATA_FETCHED(num),
+                    &sprite->x, new_x);
+            } else {
+                sprite->x = new_x;
+            }
         } else {
-            if (raster_x + x_offset < sprite->x)
+            if (change_pos <= last_pos) {
+                /* too early to start at last_pos and too late to start
+                   at next_pos; disable display on this line */
                 sprite->x = vicii.sprite_wrap_x;
+            } else {
+                /* display already started on last_pos, change on next fetch */
+                if (raster_x + 8  < new_x && sprite->x > raster_x + 8) {
+                    /* last line was already drawn */
+                    sprite->x = new_x;
+                } else {
+                    raster_changes_sprites_add_int(&vicii.raster,
+                        SPRITE_DISPLAY_IMMEDIATE_DATA_FETCHED(num),
+                        &sprite->x, new_x);
+                }
+            }
         }
-        raster_changes_next_line_add_int(&vicii.raster, &sprite->x, new_x);
     } else {
-        /* new_x >= sprite->x */
-        if (new_x >= (int)SPRITE_DISPLAY_IMMEDIATE_DATA_FETCHED(num)
-            && sprite->x < (int)SPRITE_DISPLAY_IMMEDIATE_DATA_FETCHED(num))
-        {
-            raster_changes_sprites_add_int(&vicii.raster,
-                                            raster_x, &sprite->x, new_x);
+        /* next_pos >= last_pos */
+        if (change_pos <= last_pos) {
+            if (raster_x + 8  > new_x) {
+                /* last line was already drawn */
+                raster_changes_sprites_add_int(&vicii.raster,
+                    SPRITE_DISPLAY_IMMEDIATE_DATA_FETCHED(num),
+                    &sprite->x, new_x);
+            } else {
+                sprite->x = new_x;
+            }
+        } else {
+            if (change_pos >= next_pos) {
+                if (raster_x + 8  < sprite->x && new_x > raster_x + 8) {
+                    /* last line was already drawn */
+                    sprite->x = new_x;
+                } else {
+                    /* display already started on last_pos, change on next fetch */
+                    raster_changes_sprites_add_int(&vicii.raster,
+                        SPRITE_DISPLAY_IMMEDIATE_DATA_FETCHED(num), &sprite->x, new_x);
+                }
+            }
         }
-        if (raster_x + x_offset < sprite->x
-            && sprite->x < (int)SPRITE_DISPLAY_IMMEDIATE_DATA_FETCHED(num))
-        {
-            sprite->x = new_x;
-        }
-        raster_changes_next_line_add_int(&vicii.raster, &sprite->x, new_x);
     }
+    raster_changes_sprites_add_int(&vicii.raster,
+        SPRITE_DISPLAY_IMMEDIATE_DATA_FETCHED(num), &sprite->x, new_x);
 }
 
 void vicii_sprites_reset_xshift(void)
@@ -1221,3 +1286,7 @@ void vicii_sprites_shutdown(void)
     lib_free(sprline);
 }
 
+int vicii_sprite_offset(void)
+{
+    return vicii.screen_leftborderwidth - 24;
+}
