@@ -29,8 +29,8 @@
  *
  */
 
-#ifndef _VICIITYPES_H
-#define _VICIITYPES_H
+#ifndef VICE_VICIITYPES_H
+#define VICE_VICIITYPES_H
 
 #include "raster.h"
 #include "types.h"
@@ -155,7 +155,7 @@ typedef enum vicii_video_mode_s vicii_video_mode_t;
 
 struct vicii_light_pen_s {
     int triggered;
-    int x, y;
+    int x, y, x_extra_bits;
 };
 typedef struct vicii_light_pen_s vicii_light_pen_t;
 
