@@ -54,7 +54,7 @@ void render_08_1x2_04(const video_render_color_tables_t *color_tab, const BYTE *
         wend = 0;
     } else {
         /* alignment: 8 pixels*/
-        wstart = (unsigned int)(8 - ((unsigned long)trg & 7));
+        wstart = (unsigned int)(8 - (vice_ptr_to_uint(trg) & 7));
         wfast = (width - wstart) >> 3; /* fast loop for 8 pixel segments*/
         wend = (width - wstart) & 0x07; /* do not forget the rest*/
     }
@@ -129,7 +129,7 @@ void render_16_1x2_04(const video_render_color_tables_t *color_tab, const BYTE *
         wend = 0;
     } else {
         /* alignment: 8 pixels*/
-        wstart = (unsigned int)(8 - ((unsigned long)trg & 7));
+        wstart = (unsigned int)(8 - (vice_ptr_to_uint(trg) & 7));
         wfast = (width - wstart) >> 3; /* fast loop for 8 pixel segments*/
         wend  = (width - wstart) & 0x07; /* do not forget the rest*/
     }
@@ -205,7 +205,7 @@ void render_24_1x2_04(const video_render_color_tables_t *color_tab, const BYTE *
         wend = 0;
     } else {
         /* alignment: 4 pixels*/
-        wstart = (unsigned int)(4 - ((unsigned long)trg & 3));
+        wstart = (unsigned int)(4 - (vice_ptr_to_uint(trg) & 3));
         wfast = (width - wstart) >> 2; /* fast loop for 4 pixel segments*/
         wend = (width - wstart) & 0x03; /* do not forget the rest*/
     }
@@ -336,7 +336,7 @@ void render_32_1x2_04(const video_render_color_tables_t *color_tab, const BYTE *
         wend = 0;
     } else {
         /* alignment: 8 pixels*/
-        wstart = (unsigned int)8 - ((unsigned long)trg & 7);
+        wstart = (unsigned int)8 - (vice_ptr_to_uint(trg) & 7);
         wfast = (width - wstart) >> 3; /* fast loop for 8 pixel segments*/
         wend  = (width - wstart) & 0x07; /* do not forget the rest*/
     }
